@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -35,7 +35,7 @@ class AboutQET : public QDialog {
 	
 	// methods
 	private:
-	QWidget *title() const;
+	QWidget *titleTab() const;
 	QWidget *aboutTab() const;
 	QWidget *authorsTab() const;
 	QWidget *translatorsTab() const;
