@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -240,9 +240,14 @@ TitleBlockProperties BorderTitleBlock::exportTitleBlock() {
 	ip.date = date();
 	ip.title = title();
 	ip.filename = fileName();
+	ip.machine = machine();
+	ip.locmach = locmach();
+	ip.indexrev = indexrev();
+	ip.version = version();
 	ip.folio = folio();
 	ip.template_name = titleBlockTemplateName();
 	ip.display_at = m_edge;
+	ip.auto_page_num = autoPageNum();
 	ip.context = additional_fields_;
 	ip.collection = QET::QetCollection::Embedded;
 	
@@ -258,7 +263,12 @@ void BorderTitleBlock::importTitleBlock(const TitleBlockProperties &ip) {
 	setDate(ip.date);
 	setTitle(ip.title);
 	setFileName(ip.filename);
+	setMachine(ip.machine);
+	setLocMach(ip.locmach);
+	setIndicerev(ip.indexrev);
+	setVersion(QET::displayedVersion);
 	setFolio(ip.folio);
+	setAutoPageNum(ip.auto_page_num);
 	if (m_edge != ip.display_at)
 	{
 		m_edge = ip.display_at;
@@ -392,6 +402,15 @@ void BorderTitleBlock::displayBorder(bool db) {
 	if (change) emit(displayChanged());
 }
 
+/**
+ * @brief BorderTitleBlock::slot_setAutoPageNum
+ * @param pageAutoNum
+ * Set Page (Folio) Auto Num
+ */
+void BorderTitleBlock::slot_setAutoPageNum(QString pageAutoNum) {
+	btb_auto_page_num_=pageAutoNum;
+}
+
 /**
  * @brief BorderTitleBlock::updateRectangles
  * This method update the diagram rect according to the value of rows and columns (number and size)
@@ -682,9 +701,14 @@ void BorderTitleBlock::updateDiagramContextForTitleBlock(const DiagramContext &i
 	context.addValue("date",        btb_date_.toString(Qt::SystemLocaleShortDate));
 	context.addValue("title",       btb_title_);
 	context.addValue("filename",    btb_filename_);
+	context.addValue("machine",     btb_machine_);
+	context.addValue("locmach",     btb_locmach_);
+	context.addValue("indexrev",    btb_indexrev_);
+	context.addValue("version",     btb_version_);
 	context.addValue("folio",       btb_final_folio_);
 	context.addValue("folio-id",    folio_index_);
 	context.addValue("folio-total", folio_total_);
+	context.addValue("auto_page_num", btb_auto_page_num_);
 	
 	titleblock_template_renderer_ -> setContext(context);
 }
@@ -711,7 +735,7 @@ QString BorderTitleBlock::incrementLetters(const QString &string) {
 	@param total nombre total de schemas dans le projet
 	@param project_properties Project-wide properties, to be merged with diagram-wide ones.
 */
-void BorderTitleBlock::setFolioData(int index, int total, const DiagramContext &project_properties) {
+void BorderTitleBlock::setFolioData(int index, int total, QString autonum, const DiagramContext &project_properties) {
 	if (index < 1 || total < 1 || index > total) return;
 	
 	// memorise les informations
@@ -720,8 +744,14 @@ void BorderTitleBlock::setFolioData(int index, int total, const DiagramContext &
 	
 	// regenere le contenu du champ folio
 	btb_final_folio_ = btb_folio_;
+
+	if (btb_final_folio_.contains("%autonum")){
+	btb_final_folio_.replace("%autonum", autonum);
+	btb_folio_ = btb_final_folio_;
+	}
 	btb_final_folio_.replace("%id",    QString::number(folio_index_));
 	btb_final_folio_.replace("%total", QString::number(folio_total_));
-	
+
+
 	updateDiagramContextForTitleBlock(project_properties);
 }
