@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -23,6 +23,7 @@
 #include <QObject>
 #include <QRectF>
 #include <QDate>
+#include "numerotationcontext.h"
 class QPainter;
 class DiagramPosition;
 class TitleBlockTemplate;
@@ -94,9 +95,26 @@ class BorderTitleBlock : public QObject
 	QString title() const { return(btb_title_); }
 	/// @return the value of the title block "Folio" field
 	QString folio() const { return(btb_folio_); }
+	/// @return the value of the title block "Folio" field as displayed
+	QString finalfolio() const { return(btb_final_folio_); }
+	/// @return the value of the title block "Machine" field
+	QString machine() const { return(btb_machine_); }
+	/// @return the value of the title block "Locmach" field
+	QString locmach() const { return(btb_locmach_); }
+	/// @return the value of the revision index block "Folio" field
+	QString indexrev() const { return(btb_indexrev_); }
+	
 	/// @return the value of the title block "File" field
 	QString fileName() const { return(btb_filename_); }
-	
+	/// @return the value of the title block Additional Fields
+	QString version() const { return(btb_version_); }
+	/// @return the value of the title block Additional Fields
+	DiagramContext additionalFields() const { return (additional_fields_); }
+	/// @return the value of the title block
+	QString autoPageNum() const { return(btb_auto_page_num_); }
+	/// @return the value of the total number of folios
+	int folioTotal() const { return(folio_total_);}
+
 	// methods to get display options
 	/// @return true si le cartouche est affiche, false sinon
 	bool titleBlockIsDisplayed() const { return(display_titleblock_); }
@@ -131,10 +149,20 @@ class BorderTitleBlock : public QObject
 		}
 	}
 	/// @param author the new value of the "Folio" field
-	void setFolio(const QString &folio) { btb_folio_ = folio; }
-	void setFolioData(int, int, const DiagramContext & = DiagramContext());
+	void setFolio(const QString &folio) {
+		btb_folio_ = folio;
+		emit (titleBlockFolioChanged(folio));
+	}
+	void setFolioData(int, int, QString = NULL, const DiagramContext & = DiagramContext());
 	/// @param author the new value of the "File" field
+	void setMachine(const QString &machine) { btb_machine_ = machine; }
+	void setLocMach(const QString &locmach) { btb_locmach_ = locmach; }
+	void setIndicerev(const QString &indexrev){ btb_indexrev_ = indexrev; }
 	void setFileName(const QString &filename) { btb_filename_ = filename; }
+	/// @param author the new value of the "Version" field
+	void setVersion(const QString &version) { btb_version_ = version; }
+	/// @param author the new value of the "Auto Page Num" field	
+	void setAutoPageNum(const QString &auto_page_num) { btb_auto_page_num_ = auto_page_num;}
 	
 	void titleBlockToXml(QDomElement &);
 	void titleBlockFromXml(const QDomElement &);
@@ -159,6 +187,7 @@ class BorderTitleBlock : public QObject
 	void displayColumns(bool);
 	void displayRows(bool);
 	void displayBorder(bool);
+	void slot_setAutoPageNum (QString);
 	
 	private:
 	void updateRectangles();
@@ -181,6 +210,12 @@ class BorderTitleBlock : public QObject
 		Signal emitted after the title has changed
 	*/
 	void diagramTitleChanged(const QString &);
+
+	/**
+	 @brief titleBlockFolioChanged
+		Signal emitted after Folio has changed
+	*/
+	void titleBlockFolioChanged(const QString &);
 	
 	/**
 		Signal emitted when the title block requires its data to be updated in order
@@ -202,10 +237,15 @@ class BorderTitleBlock : public QObject
 		QDate   btb_date_;
 		QString btb_title_;
 		QString btb_folio_;
+		QString btb_machine_;
+		QString btb_locmach_;
+		QString btb_indexrev_;
 		QString btb_final_folio_;
+		QString btb_auto_page_num_;
 		int folio_index_;
 		int folio_total_;
 		QString btb_filename_;
+		QString btb_version_;
 		DiagramContext additional_fields_;
 		Qt::Edge m_edge;
 	
