@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -71,6 +71,7 @@ void SingleLineProperties::draw(QPainter *painter, QET::ConductorSegmentType dir
 	pen.setCapStyle(Qt::FlatCap);
 	pen.setJoinStyle(Qt::MiterJoin);
 	pen.setStyle(Qt::SolidLine);
+	pen.setWidthF(1);
 	painter -> setPen(pen);
 	painter -> setRenderHint(QPainter::Antialiasing, true);
 	
@@ -222,6 +223,7 @@ ConductorProperties::ConductorProperties() :
 	color(Qt::black),
 	text("_"),
 	text_size(9),
+	cond_size(1),
 	verti_rotate_text(270),
 	horiz_rotate_text(0),
 	m_show_text(true),
@@ -248,17 +250,20 @@ void ConductorProperties::toXml(QDomElement &e) const
 	if (color != QColor(Qt::black))
 		e.setAttribute("color", color.name());
 	
+	
 	if (type == Single)
 		singleLineProperties.toXml(e);
 
 	e.setAttribute("num", text);
+	e.setAttribute("formula", m_formula);
 	e.setAttribute("function", m_function);
 	e.setAttribute("tension-protocol", m_tension_protocol);
-	e.setAttribute("numsize", text_size);
+	e.setAttribute("numsize", QString::number(text_size));
+	e.setAttribute("condsize", QString::number(cond_size));
 	e.setAttribute("displaytext", m_show_text);
 	e.setAttribute("onetextperfolio", m_one_text_per_folio);
-	e.setAttribute("vertirotatetext", verti_rotate_text);
-	e.setAttribute("horizrotatetext", horiz_rotate_text);
+	e.setAttribute("vertirotatetext", QString::number(verti_rotate_text));
+	e.setAttribute("horizrotatetext", QString::number(horiz_rotate_text));
 	
 	QString conductor_style = writeStyle();
 	if (!conductor_style.isEmpty())
@@ -290,9 +295,11 @@ void ConductorProperties::fromXml(QDomElement &e)
 		type = Multi;
 
 	text                 = e.attribute("num");
+	m_formula            = e.attribute("formula");
 	m_function           = e.attribute("function");
 	m_tension_protocol   = e.attribute("tension-protocol");
 	text_size            = e.attribute("numsize", QString::number(9)).toInt();
+	cond_size            = e.attribute("condsize", QString::number(1)).toDouble();
 	m_show_text          = e.attribute("displaytext", QString::number(1)).toInt();
 	m_one_text_per_folio = e.attribute("onetextperfolio", QString::number(0)).toInt();
 	verti_rotate_text    = e.attribute("vertirotatetext").toDouble();
@@ -314,9 +321,11 @@ void ConductorProperties::toSettings(QSettings &settings, const QString &prefix)
 	settings.setValue(prefix + "style", writeStyle());
 	settings.setValue(prefix + "type", typeToString(type));
 	settings.setValue(prefix + "text", text);
+	settings.setValue(prefix + "formula", m_formula);
 	settings.setValue(prefix + "function", m_function);
 	settings.setValue(prefix + "tension-protocol", m_tension_protocol);
 	settings.setValue(prefix + "textsize", QString::number(text_size));
+	settings.setValue(prefix + "size", QString::number(cond_size));
 	settings.setValue(prefix + "displaytext", m_show_text);
 	settings.setValue(prefix + "onetextperfolio", m_one_text_per_folio);
 	settings.setValue(prefix + "vertirotatetext", QString::number(verti_rotate_text));
@@ -339,9 +348,11 @@ void ConductorProperties::fromSettings(QSettings &settings, const QString &prefi
 	singleLineProperties.fromSettings(settings, prefix);
 
 	text                 = settings.value(prefix + "text", "_").toString();
+	m_formula            = settings.value(prefix + "formula", "").toString();
 	m_function           = settings.value(prefix + "function", "").toString();
 	m_tension_protocol   = settings.value(prefix + "tension-protocol", "").toString();
 	text_size            = settings.value(prefix + "textsize", "7").toInt();
+	cond_size            = settings.value(prefix + "size", "1").toInt();
 	m_show_text          = settings.value(prefix + "displaytext", true).toBool();
 	m_one_text_per_folio = settings.value(prefix + "onetextperfolio", false).toBool();
 	verti_rotate_text    = settings.value((prefix + "vertirotatetext"), "270").toDouble();
@@ -361,6 +372,175 @@ QString ConductorProperties::typeToString(ConductorType t) {
 	}
 }
 
+/**
+ * @brief ConductorProperties::setText
+ * This method sets the current conductor text
+ * @param text to be setted
+ */
+void ConductorProperties::setText(QString text) {
+	text = text;
+}
+
+/**
+ * @brief ConductorProperties::applyForEqualAttributes
+ * Test each attribute of properties in the list separatly.
+ * For each attributes, if is equal, the attribute is apply to this.
+ * @param list
+ */
+void ConductorProperties::applyForEqualAttributes(QList<ConductorProperties> list)
+{
+	const QList<ConductorProperties> clist = list;
+	
+	if (clist.isEmpty())
+		return;
+
+	if (clist.size() == 1)
+	{
+		ConductorProperties cp = clist.first();
+		color                = cp.color;
+		text                 = cp.text;
+		m_formula            = cp.m_formula;
+		m_function           = cp.m_function;
+		m_tension_protocol   = cp.m_tension_protocol;
+		text_size            = cp.text_size;
+		cond_size            = cp.cond_size;
+		m_show_text          = cp.m_show_text;
+		m_one_text_per_folio = cp.m_one_text_per_folio;
+		verti_rotate_text    = cp.verti_rotate_text;
+		horiz_rotate_text    = cp.horiz_rotate_text;
+
+		return;
+	}
+
+	bool equal = true;
+	QColor c_value;
+	bool b_value;
+	QString s_value;
+	int i_value;
+	double d_value;
+	
+		//Color
+	c_value = clist.first().color;
+	for(ConductorProperties cp : clist)
+	{
+		if (cp.color != c_value)
+			equal = false;
+	}
+	if (equal)
+		color = c_value;
+	equal = true;
+
+		//text
+	s_value = clist.first().text;
+	for(ConductorProperties cp : clist)
+	{
+		if (cp.text != s_value)
+			equal = false;
+	}
+	if (equal)
+		text = s_value;
+	equal = true;
+
+		//formula
+	s_value = clist.first().m_formula;
+	for(ConductorProperties cp : clist)
+	{
+		if (cp.m_formula != s_value)
+			equal = false;
+	}
+	if (equal)
+		m_formula = s_value;
+	equal = true;
+
+		//function
+	s_value = clist.first().m_function;
+	for(ConductorProperties cp : clist)
+	{
+		if (cp.m_function != s_value)
+			equal = false;
+	}
+	if (equal)
+		m_function = s_value;
+	equal = true;
+
+		//Tension protocol
+	s_value = clist.first().m_tension_protocol;
+	for(ConductorProperties cp : clist)
+	{
+		if (cp.m_tension_protocol != s_value)
+			equal = false;
+	}
+	if (equal)
+		m_tension_protocol = s_value;
+	equal = true;
+
+		//text size
+	i_value = clist.first().text_size;
+	for(ConductorProperties cp : clist)
+	{
+		if (cp.text_size != i_value)
+			equal = false;
+	}
+	if (equal)
+		text_size = i_value;
+	equal = true;
+
+		//conductor size
+	d_value = clist.first().cond_size;
+	for(ConductorProperties cp : clist)
+	{
+		if (cp.cond_size != d_value)
+			equal = false;
+	}
+	if (equal)
+		cond_size = d_value;
+	equal = true;
+
+		//show text
+	b_value = clist.first().m_show_text;
+	for(ConductorProperties cp : clist)
+	{
+		if (cp.m_show_text != b_value)
+			equal = false;
+	}
+	if (equal)
+		m_show_text = b_value;
+	equal = true;
+
+		//One text per folio
+	b_value = clist.first().m_one_text_per_folio;
+	for(ConductorProperties cp : clist)
+	{
+		if (cp.m_one_text_per_folio != b_value)
+			equal = false;
+	}
+	if (equal)
+		m_one_text_per_folio = b_value;
+	equal = true;
+
+		//Text rotation for vertical conducor
+	d_value = clist.first().verti_rotate_text;
+	for(ConductorProperties cp : clist)
+	{
+		if (cp.verti_rotate_text != d_value)
+			equal = false;
+	}
+	if (equal)
+		verti_rotate_text = d_value;
+	equal = true;
+
+		//Text rotation for horizontal conducor
+	d_value = clist.first().horiz_rotate_text;
+	for(ConductorProperties cp : clist)
+	{
+		if (cp.horiz_rotate_text != d_value)
+			equal = false;
+	}
+	if (equal)
+		horiz_rotate_text = d_value;
+	equal = true;
+}
+
 /**
  * @brief ConductorProperties::defaultProperties
  * @return the default properties stored in the setting file
@@ -376,19 +556,23 @@ ConductorProperties ConductorProperties::defaultProperties()
 }
 
 /**
-	@param other l'autre ensemble de proprietes avec lequel il faut effectuer la comparaison
-	@return true si les deux ensembles de proprietes sont identiques, false sinon
-*/
-bool ConductorProperties::operator==(const ConductorProperties &other) const{
+ * @brief ConductorProperties::operator ==
+ * @param other
+ * @return true if other == this
+ */
+bool ConductorProperties::operator==(const ConductorProperties &other) const
+{
 	return(
 		other.type == type &&\
 		other.color == color &&\
 		other.style == style &&\
 		other.text == text &&\
+		other.m_formula == m_formula &&\
 		other.m_function == m_function &&\
 		other.m_tension_protocol == m_tension_protocol &&\
 		other.m_show_text == m_show_text &&\
 		other.text_size == text_size &&\
+		other.cond_size == cond_size &&\
 		other.verti_rotate_text == verti_rotate_text &&\
 		other.horiz_rotate_text == horiz_rotate_text &&\
 		other.singleLineProperties == singleLineProperties &&\
