@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -30,7 +30,7 @@ class SingleLineProperties {
 	public:
 	SingleLineProperties();
 	virtual ~SingleLineProperties();
-	
+
 	void setPhasesCount(int);
 	unsigned short int phasesCount();
 	bool isPen() const;
@@ -77,16 +77,25 @@ class ConductorProperties
 
 			//Attributes
 		ConductorType type;
-		QColor color;
+		
+		QColor  color;
+		
 		QString text,
 				m_function,
-				m_tension_protocol;
+				m_tension_protocol,
+				m_formula;
+		
 		int text_size;
-		double verti_rotate_text;
-		double horiz_rotate_text;
-		bool m_show_text;
-		bool m_one_text_per_folio;
+		
+		double  cond_size,
+				verti_rotate_text,
+				horiz_rotate_text;
+		
+		bool	m_show_text,
+				m_one_text_per_folio;
+		
 		Qt::PenStyle style;
+		
 		SingleLineProperties singleLineProperties;
 	
 			// methods
@@ -95,6 +104,8 @@ class ConductorProperties
 		void toSettings(QSettings &, const QString & = QString()) const;
 		void fromSettings(QSettings &, const QString & = QString());
 		static QString typeToString(ConductorType);
+		void setText(QString);
+		void applyForEqualAttributes(QList<ConductorProperties> list);
 
 		static ConductorProperties defaultProperties();
 	
