@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -35,8 +35,9 @@
  * else edit the properties by default of QElectroTech
  * @param parent, parent widget
  */
-NewDiagramPage::NewDiagramPage(QETProject *project, QWidget *parent) :
+NewDiagramPage::NewDiagramPage(QETProject *project, QWidget *parent, ProjectPropertiesDialog *ppd) :
 	ConfigPage (parent),
+	ppd_ (ppd),
 	m_project  (project)
 {
 	//By default we set the global default properties
@@ -47,9 +48,10 @@ NewDiagramPage::NewDiagramPage(QETProject *project, QWidget *parent) :
 	QList <TitleBlockTemplatesCollection *> c;
 	c << QETApp::commonTitleBlockTemplatesCollection() << QETApp::customTitleBlockTemplatesCollection();
 	if (m_project) c << m_project->embeddedTitleBlockTemplatesCollection();
-	ipw = new TitleBlockPropertiesWidget(c, TitleBlockProperties::defaultProperties(), true);
+	ipw = new TitleBlockPropertiesWidget(c, TitleBlockProperties::defaultProperties(), true, project, parent);
 	// default conductor properties
-	cpw = new ConductorPropertiesWidget(ConductorProperties::defaultProperties());
+	m_cpw = new ConductorPropertiesWidget(ConductorProperties::defaultProperties());
+	m_cpw->setHiddenAvailableAutonum(true);
 	// default propertie of report label
 	rpw = new ReportPropertieWidget(ReportProperties::defaultProperties());
 	// default properties of xref
@@ -58,12 +60,14 @@ NewDiagramPage::NewDiagramPage(QETProject *project, QWidget *parent) :
 	//If there is a project, we edit his properties
 	if (m_project) {
 		bpw	   -> setProperties		  (m_project -> defaultBorderProperties());
-		cpw	   -> setProperties       (m_project -> defaultConductorProperties());
+		m_cpw	   -> setProperties       (m_project -> defaultConductorProperties());
 		ipw    -> setProperties       (m_project -> defaultTitleBlockProperties());
 		rpw	   -> setReportProperties (m_project -> defaultReportProperties());
 		xrefpw -> setProperties		  (m_project -> defaultXRefProperties());
 	}
 
+	connect(ipw,SIGNAL(openAutoNumFolioEditor(QString)),this,SLOT(changeToAutoFolioTab()));
+
 	// main tab widget
 	QTabWidget *tab_widget      = new QTabWidget(this);
 	QWidget *diagram_widget     = new QWidget();
@@ -72,8 +76,8 @@ NewDiagramPage::NewDiagramPage(QETProject *project, QWidget *parent) :
 	diagram_layout -> addWidget(bpw);
 	diagram_layout -> addWidget(ipw);
 
-    tab_widget -> addTab (diagram_widget, tr("Folio"));
-	tab_widget -> addTab (cpw,            tr("Conducteur"));
+	tab_widget -> addTab (diagram_widget, tr("Folio"));
+	tab_widget -> addTab (m_cpw,            tr("Conducteur"));
 	tab_widget -> addTab (rpw,            tr("Reports de folio"));
 	tab_widget -> addTab (xrefpw,         tr("Références croisées"));
 
@@ -87,6 +91,7 @@ NewDiagramPage::NewDiagramPage(QETProject *project, QWidget *parent) :
  * @brief NewDiagramPage::~NewDiagramPage
  */
 NewDiagramPage::~NewDiagramPage() {
+	disconnect(ipw,SIGNAL(openAutoNumFolioEditor(QString)),this,SLOT(changeToAutoFolioTab()));
 }
 
 /**
@@ -112,9 +117,9 @@ void NewDiagramPage::applyConf() {
 			modified_project = true;
 		}
 
-		ConductorProperties new_conductor_prop = cpw -> properties();
+		ConductorProperties new_conductor_prop = m_cpw -> properties();
 		if (m_project -> defaultConductorProperties() != new_conductor_prop) {
-			m_project -> setDefaultConductorProperties(cpw -> properties());
+			m_project -> setDefaultConductorProperties(m_cpw -> properties());
 			modified_project = true;
 		}
 
@@ -144,7 +149,7 @@ void NewDiagramPage::applyConf() {
 		ipw-> properties().toSettings(settings, "diagrameditor/default");
 
 		// proprietes par defaut des conducteurs
-		cpw -> properties().toSettings(settings, "diagrameditor/defaultconductor");
+		m_cpw -> properties().toSettings(settings, "diagrameditor/defaultconductor");
 
 		// default report propertie
 		rpw->toSettings(settings, "diagrameditor/defaultreport");
@@ -157,6 +162,7 @@ void NewDiagramPage::applyConf() {
 			xrp.toSettings(settings, str += key);
 		}
 	}
+
 }
 
 /**
@@ -173,10 +179,48 @@ QIcon NewDiagramPage::icon() const {
  * @return title of this page
  */
 QString NewDiagramPage::title() const {
-    if (m_project) return(tr("Nouveau folio", "configuration page title"));
+	if (m_project) return(tr("Nouveau folio", "configuration page title"));
 	return(tr("Nouveau projet", "configuration page title"));
 }
 
+/**
+ * @brief NewDiagramPage::changeToAutoFolioTab
+ * Set the current tab to Autonum
+ */
+void NewDiagramPage::changeToAutoFolioTab(){
+	if (m_project){
+		ppd_->setCurrentPage(ProjectPropertiesDialog::Autonum);
+		ppd_->changeToFolio();
+		ppd_->exec();
+	}
+}
+
+/**
+ * @brief NewDiagramPage::setFolioAutonum
+ * Set temporary TBP to use in auto folio num
+ */
+void NewDiagramPage::setFolioAutonum(QString autoNum){
+	TitleBlockProperties tbptemp = ipw->propertiesAutoNum(autoNum);
+	ipw->setProperties(tbptemp);
+	applyConf();
+}
+
+/**
+ * @brief NewDiagramPage::saveCurrentTbp
+ * Save current TBP to retrieve after auto folio	num
+ */
+void NewDiagramPage::saveCurrentTbp(){
+	savedTbp = ipw->properties();
+}
+
+/**
+ * @brief NewDiagramPage::loadSavedTbp
+ * Retrieve saved auto folio num
+ */
+void NewDiagramPage::loadSavedTbp(){
+	ipw->setProperties(savedTbp);
+	applyConf();
+}
 
 /**
 	Constructeur
@@ -188,22 +232,26 @@ GeneralConfigurationPage::GeneralConfigurationPage(QWidget *parent) : ConfigPage
 	QSettings settings;
 	bool use_system_colors = settings.value("usesystemcolors", "true").toBool();
 	bool tabbed = settings.value("diagrameditor/viewmode", "tabbed") == "tabbed";
-	bool integrate_elements = settings.value("diagrameditor/integrate-elements", true).toBool();
 	bool zoom_out_folio = settings.value("diagrameditor/zoom-out-beyond-of-folio", false).toBool();
 	bool use_trackpad = settings.value("diagramview/gestures", false).toBool();
+	bool save_label_paste = settings.value("diagramcommands/save-label", true).toBool();
+	bool panel_folio = settings.value("genericpanel/folio", true).toBool();
 	bool highlight_integrated_elements = settings.value("diagrameditor/highlight-integrated-elements", true).toBool();
+	bool terminal_exportlist = settings.value("nomenclature-exportlist", true).toBool();
 	QString default_element_informations = settings.value("elementeditor/default-informations", "").toString();
 	
 	appearance_ = new QGroupBox(tr("Apparence"), this);
 	use_system_colors_ = new QCheckBox(tr("Utiliser les couleurs du système"), appearance_);
 	projects_view_mode_ = new QGroupBox(tr("Projets"), this);
-    windowed_mode_ = new QRadioButton(tr("Utiliser des fenêtres (appliqué au prochain lancement de QElectroTech)"), projects_view_mode_);
-    tabbed_mode_ = new QRadioButton(tr("Utiliser des onglets (appliqué au prochain lancement de QElectroTech)"), projects_view_mode_);
+	windowed_mode_ = new QRadioButton(tr("Utiliser des fenêtres (appliqué au prochain lancement de QElectroTech)"), projects_view_mode_);
+	tabbed_mode_ = new QRadioButton(tr("Utiliser des onglets (appliqué au prochain lancement de QElectroTech)"), projects_view_mode_);
 	use_trackpad_ = new QCheckBox(tr("Utiliser les gestes du pavé tactile"), projects_view_mode_);
+	save_label_paste_ = new QCheckBox(tr("Ne pas conserver les labels des éléments lors des copier coller"), projects_view_mode_);
+	folio_panel_ = new QCheckBox(tr("Utiliser les labels de folio à la place de leurs ID"), projects_view_mode_);
+	terminal_exportlist_ = new QCheckBox(tr("Exporter les bornes dans la nomenclature"), projects_view_mode_);
 	m_zoom_out_beyond_folio = new QCheckBox(tr("Autoriser le dézoom au delà du folio"), this);
 	
 	elements_management_ = new QGroupBox(tr("Gestion des éléments"), this);
-	integrate_elements_ = new QCheckBox(tr("Intégrer automatiquement les éléments dans les projets (recommandé)"));
 	highlight_integrated_elements_ = new QCheckBox(tr("Mettre en valeur dans le panel les éléments fraîchement intégrés", "configuration option"));
 	default_element_infos_label_ = new QLabel(
 		tr(
@@ -218,6 +266,9 @@ GeneralConfigurationPage::GeneralConfigurationPage(QWidget *parent) : ConfigPage
 	use_system_colors_ -> setChecked(use_system_colors);
 
 	use_trackpad_ -> setChecked(use_trackpad);
+	save_label_paste_ -> setChecked(save_label_paste);
+	folio_panel_     ->setChecked(panel_folio);
+	terminal_exportlist_ ->setChecked(terminal_exportlist);
 
 	if (tabbed) {
 		tabbed_mode_ -> setChecked(true);
@@ -227,7 +278,6 @@ GeneralConfigurationPage::GeneralConfigurationPage(QWidget *parent) : ConfigPage
 
 	m_zoom_out_beyond_folio -> setChecked(zoom_out_folio);
 	
-	integrate_elements_ -> setChecked(integrate_elements);
 	highlight_integrated_elements_ -> setChecked(highlight_integrated_elements);
 	default_element_infos_textfield_ -> setPlainText(default_element_informations);
 	
@@ -239,11 +289,14 @@ GeneralConfigurationPage::GeneralConfigurationPage(QWidget *parent) : ConfigPage
 	projects_view_mode_layout -> addWidget(windowed_mode_);
 	projects_view_mode_layout -> addWidget(tabbed_mode_);
 	projects_view_mode_layout -> addWidget(m_zoom_out_beyond_folio);
-    projects_view_mode_layout -> addWidget(use_trackpad_);
+	projects_view_mode_layout -> addWidget(use_trackpad_);
+	projects_view_mode_layout -> addWidget(save_label_paste_);
+	projects_view_mode_layout -> addWidget(folio_panel_);
+	projects_view_mode_layout -> addWidget(terminal_exportlist_);
+	
 	projects_view_mode_ -> setLayout(projects_view_mode_layout);
 	
 	QVBoxLayout *elements_management_layout = new QVBoxLayout();
-	elements_management_layout -> addWidget(integrate_elements_);
 	elements_management_layout -> addWidget(highlight_integrated_elements_);
 	elements_management_layout -> addWidget(default_element_infos_label_);
 	elements_management_layout -> addWidget(default_element_infos_textfield_);
@@ -253,7 +306,7 @@ GeneralConfigurationPage::GeneralConfigurationPage(QWidget *parent) : ConfigPage
 	lang_group_box = new QGroupBox(tr("Langue"), this);
 	QHBoxLayout *lang_layout = new QHBoxLayout(lang_group_box);
 	lang_combo_box = new QComboBox();
-    lang_label = new QLabel(tr("La nouvelle langue sera prise en compte au prochain lancement de QElectroTech."));
+	lang_label = new QLabel(tr("La nouvelle langue sera prise en compte au prochain lancement de QElectroTech."));
 	lang_layout->addWidget(lang_combo_box);
 	lang_layout->addWidget(lang_label);
 	fillLang(settings);
@@ -300,11 +353,13 @@ void GeneralConfigurationPage::applyConf()
 	QString view_mode = tabbed_mode_ -> isChecked() ? "tabbed" : "windowed";
 	settings.setValue("diagrameditor/viewmode", view_mode) ;
 	
-	settings.setValue("diagrameditor/integrate-elements", integrate_elements_ -> isChecked());
 	settings.setValue("diagrameditor/highlight-integrated-elements", highlight_integrated_elements_ -> isChecked());
 	settings.setValue("elementeditor/default-informations", default_element_infos_textfield_ -> toPlainText());
 	settings.setValue("diagramview/gestures", use_trackpad_ -> isChecked());
+	settings.setValue("diagramcommands/save-label", save_label_paste_ -> isChecked());
 	settings.setValue("diagrameditor/zoom-out-beyond-of-folio", m_zoom_out_beyond_folio->isChecked());
+	settings.setValue("genericpanel/folio",folio_panel_->isChecked());
+	settings.setValue("nomenclature/terminal-exportlist",terminal_exportlist_->isChecked());
 }
 
 /// @return l'icone de cette page
@@ -327,9 +382,11 @@ void GeneralConfigurationPage::fillLang(QSettings &settings) {
 
 	// all lang available on lang directory
 	lang_combo_box->addItem(QET::Icons::ar,           tr("Arabe"), "ar");
+	lang_combo_box->addItem(QET::Icons::br,           tr("Brézilien"), "pt_br");
 	lang_combo_box->addItem(QET::Icons::catalonia,    tr("Catalan"), "ca");
 	lang_combo_box->addItem(QET::Icons::cs,           tr("Tchèque"), "cs");
 	lang_combo_box->addItem(QET::Icons::de,           tr("Allemand"), "de");
+	lang_combo_box->addItem(QET::Icons::da,           tr("Danois"), "da");
 	lang_combo_box->addItem(QET::Icons::gr,           tr("Grec"), "el");
 	lang_combo_box->addItem(QET::Icons::en,           tr("Anglais"), "en");
 	lang_combo_box->addItem(QET::Icons::es,           tr("Espagnol"), "es");
