@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -19,6 +19,8 @@
 #define CONFIG_PAGES_H
 #include <QtWidgets>
 #include "configpage.h"
+#include "projectpropertiesdialog.h"
+#include "titleblockpropertieswidget.h"
 class BorderPropertiesWidget;
 class ConductorPropertiesWidget;
 class TitleBlockPropertiesWidget;
@@ -26,6 +28,7 @@ class ExportPropertiesWidget;
 class ReportPropertieWidget;
 class XRefPropertiesWidget;
 class QETProject;
+class TitleBlockProperties;
 
 /**
 	This configuration page enables users to define the properties of new
@@ -35,10 +38,16 @@ class NewDiagramPage : public ConfigPage {
 	Q_OBJECT
 	// constructors, destructor
 	public:
-	NewDiagramPage(QETProject *project = 0, QWidget * = 0);
+	NewDiagramPage(QETProject *project = 0, QWidget * = 0, ProjectPropertiesDialog *teste = NULL);
 	virtual ~NewDiagramPage();
 	private:
 	NewDiagramPage(const NewDiagramPage &);
+public slots:
+	void changeToAutoFolioTab();
+	void setFolioAutonum(QString);
+	void saveCurrentTbp();
+	void loadSavedTbp();
+
 	
 	// methods
 	public:
@@ -48,12 +57,14 @@ class NewDiagramPage : public ConfigPage {
 	
 	// attributes
 	private:
+	ProjectPropertiesDialog    *ppd_;
 	QETProject                 *m_project; ///< Project to edit propertie
 	BorderPropertiesWidget     *bpw;       ///< Widget to edit default diagram dimensions
 	TitleBlockPropertiesWidget *ipw;       ///< Widget to edit default title block properties
-	ConductorPropertiesWidget  *cpw;       ///< Widget to edit default conductor properties
+	ConductorPropertiesWidget  *m_cpw;       ///< Widget to edit default conductor properties
 	ReportPropertieWidget      *rpw;       ///< Widget to edit default report label
 	XRefPropertiesWidget       *xrefpw;	   ///< Widget to edit default xref properties
+	TitleBlockProperties       savedTbp;   ///< Used to save current TBP and retrieve later
 
 };
 
@@ -86,13 +97,15 @@ class GeneralConfigurationPage : public ConfigPage {
 	QGroupBox *appearance_;
 	QCheckBox *use_system_colors_;
 	QCheckBox *use_trackpad_;
+	QCheckBox *save_label_paste_;
+	QCheckBox *folio_panel_;
+	QCheckBox *terminal_exportlist_;
 	QGroupBox *projects_view_mode_;
 	QRadioButton *windowed_mode_;
 	QRadioButton *tabbed_mode_;
 	QCheckBox *m_zoom_out_beyond_folio;
 	QLabel *warning_view_mode_;
 	QGroupBox *elements_management_;
-	QCheckBox *integrate_elements_;
 	QCheckBox *highlight_integrated_elements_;
 	QLabel    *default_element_infos_label_;
 	QTextEdit *default_element_infos_textfield_;
