@@ -1,5 +1,5 @@
-/*
-	Copyright 2006-2015 The QElectroTech Team
+﻿/*
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -34,6 +34,10 @@
 #include "terminal.h"
 #include "elementtextsmover.h"
 #include "diagrameventinterface.h"
+#include "qetapp.h"
+#include "elementcollectionhandler.h"
+#include "element.h"
+#include "diagramview.h"
 
 const int   Diagram::xGrid  = 10;
 const int   Diagram::yGrid  = 10;
@@ -49,14 +53,25 @@ QColor		Diagram::background_color = Qt::white;
  */
 Diagram::Diagram(QETProject *project) :
 	QGraphicsScene           (project),
-	project_                 (nullptr),
+	m_project                 (nullptr),
 	diagram_qet_version_     (-1),
 	draw_grid_               (true),
 	use_border_              (true),
 	draw_terminals_          (true),
 	draw_colored_conductors_ (true),
-	m_event_interface (nullptr)
+	m_event_interface (nullptr),
+	m_freeze_new_elements   (false),
+	m_freeze_new_conductors_ (false)
 {
+	
+	setItemIndexMethod(QGraphicsScene::NoIndex);
+		//Set to no index, because they can be the source of the crash with conductor and shape ghost.
+		//https://forum.qt.io/topic/71316/qgraphicsscenefinditembsptreevisitor-visit-crashes-due-to-an-obsolete-paintevent-after-qgraphicsscene-removeitem
+		//https://stackoverflow.com/questions/38458830/crash-after-qgraphicssceneremoveitem-with-custom-item-class
+		//http://www.qtcentre.org/archive/index.php/t-33730.html
+		//http://tech-artists.org/t/qt-properly-removing-qgraphicitems/3063
+	
+	
 	setProject(project);
 	qgi_manager_ = new QGIManager(this);
 	setBackgroundBrush(Qt::white);
@@ -73,7 +88,11 @@ Diagram::Diagram(QETProject *project) :
 
 	connect(&border_and_titleblock, SIGNAL(needTitleBlockTemplate(const QString &)), this, SLOT(setTitleBlockTemplate(const QString &)));
 	connect(&border_and_titleblock, SIGNAL(diagramTitleChanged(const QString &)),    this, SLOT(titleChanged(const QString &)));
+	connect(&border_and_titleblock, SIGNAL(titleBlockFolioChanged(const QString &)),    this, SLOT(titleChanged(const QString &)));
 	connect(&border_and_titleblock, SIGNAL(borderChanged(QRectF,QRectF)), this, SLOT(adjustSceneRect()));
+	connect(&border_and_titleblock, SIGNAL(titleBlockFolioChanged(const QString &)), this, SLOT(updateLabels()));
+	connect(this, SIGNAL (diagramActivated()), this, SLOT(loadElmtFolioSeq()));
+	connect(this, SIGNAL (diagramActivated()), this, SLOT(loadCndFolioSeq()));
 	adjustSceneRect();
 }
 
@@ -97,9 +116,15 @@ Diagram::~Diagram() {
 	
 	// list removable items
 	QList<QGraphicsItem *> deletable_items;
-	foreach(QGraphicsItem *qgi, items()) {
-		if (qgi -> parentItem()) continue;
-		if (qgraphicsitem_cast<Conductor *>(qgi)) continue;
+	for(QGraphicsItem *qgi : items())
+	{
+		if (qgi->parentItem())
+			continue;
+		if (qgi->type() == Conductor::Type)
+			continue;
+		if (qgi->type() == QetGraphicsHandlerItem::Type)
+			continue;
+		
 		deletable_items << qgi;
 	}
 
@@ -169,7 +194,15 @@ void Diagram::drawBackground(QPainter *p, const QRectF &r) {
  */
 void Diagram::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event)
 {
-	if (m_event_interface && m_event_interface->mouseDoubleClickEvent(event)) return;
+	if (m_event_interface)
+		if(m_event_interface->mouseDoubleClickEvent(event))
+		{
+			if(!m_event_interface->isRunning())
+			{
+				delete m_event_interface; m_event_interface = nullptr;
+			}
+			return;
+		}
 
 	QGraphicsScene::mouseDoubleClickEvent(event);
 }
@@ -181,7 +214,15 @@ void Diagram::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event)
  */
 void Diagram::mousePressEvent(QGraphicsSceneMouseEvent *event)
 {
-	if (m_event_interface && m_event_interface->mousePressEvent(event)) return;
+	if (m_event_interface)
+		if(m_event_interface->mousePressEvent(event))
+		{
+			if(!m_event_interface->isRunning())
+			{
+				delete m_event_interface; m_event_interface = nullptr;
+			}
+			return;
+		}
 
 	QGraphicsScene::mousePressEvent(event);
 }
@@ -193,7 +234,15 @@ void Diagram::mousePressEvent(QGraphicsSceneMouseEvent *event)
  */
 void Diagram::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
 {
-	if (m_event_interface && m_event_interface->mouseMoveEvent(event)) return;
+	if (m_event_interface)
+		if(m_event_interface->mouseMoveEvent(event))
+		{
+			if(!m_event_interface->isRunning())
+			{
+				delete m_event_interface; m_event_interface = nullptr;
+			}
+			return;
+		}
 
 	QGraphicsScene::mouseMoveEvent(event);
 }
@@ -205,7 +254,15 @@ void Diagram::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
  */
 void Diagram::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 {
-	if (m_event_interface && m_event_interface->mouseReleaseEvent(event)) return;
+	if (m_event_interface)
+		if(m_event_interface->mouseReleaseEvent(event))
+		{
+			if(!m_event_interface->isRunning())
+			{
+				delete m_event_interface; m_event_interface = nullptr;
+			}
+			return;
+		}
 
 	QGraphicsScene::mouseReleaseEvent(event);
 }
@@ -217,7 +274,15 @@ void Diagram::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
  */
 void Diagram::wheelEvent(QGraphicsSceneWheelEvent *event)
 {
-	if (m_event_interface && m_event_interface->wheelEvent(event)) return;
+	if (m_event_interface)
+		if(m_event_interface->wheelEvent(event))
+		{
+			if(!m_event_interface->isRunning())
+			{
+				delete m_event_interface; m_event_interface = nullptr;
+			}
+			return;
+		}
 
 	QGraphicsScene::wheelEvent(event);
 }
@@ -230,16 +295,42 @@ void Diagram::wheelEvent(QGraphicsSceneWheelEvent *event)
  */
 void Diagram::keyPressEvent(QKeyEvent *e)
 {
-	if (m_event_interface && m_event_interface->keyPressEvent(e)) return;
+	if (m_event_interface)
+		if(m_event_interface->keyPressEvent(e))
+		{
+			if(!m_event_interface->isRunning())
+			{
+				delete m_event_interface; m_event_interface = nullptr;
+			}
+			return;
+		}
 
 	bool transmit_event = true;
 	if (!isReadOnly()) {
 		QPointF movement;
+		qreal top_position = 0;
+		qreal left_position = 0;
+		QList<QGraphicsItem*> selected_elmts = this->selectedContent().items();
+		if (!this->selectedContent().items(255).isEmpty()) {
 		switch(e -> key()) {
-			case Qt::Key_Left:  movement = QPointF(-xGrid, 0.0); break;
+			case Qt::Key_Left:
+				foreach (Element *item, selectedContent().elements) {
+					left_position = item->mapRectFromScene(item->boundingRect()).x();
+					if (left_position >= this->sceneRect().left() - item->boundingRect().width())
+					return;
+				}
+				movement = QPointF(-xGrid, 0.0);
+				break;
 			case Qt::Key_Right: movement = QPointF(+xGrid, 0.0); break;
-			case Qt::Key_Up:    movement = QPointF(0.0, -yGrid); break;
-			case Qt::Key_Down:  movement = QPointF(0.0, +yGrid); break;
+			case Qt::Key_Up:
+				foreach (Element *item, selectedContent().elements) {
+					top_position = item->mapRectFromScene(item->boundingRect()).y();
+					if (top_position >= this->sceneRect().top() - item->boundingRect().height())
+						return;
+				}
+				movement = QPointF(0.0, -yGrid);
+				break;
+			case Qt::Key_Down: movement = QPointF(0.0, +yGrid); break;
 		}
 		if (!movement.isNull() && !focusItem()) {
 			beginMoveElements();
@@ -250,6 +341,7 @@ void Diagram::keyPressEvent(QKeyEvent *e)
 	}
 	if (transmit_event) {
 		QGraphicsScene::keyPressEvent(e);
+		}
 	}
 }
 
@@ -261,8 +353,16 @@ void Diagram::keyPressEvent(QKeyEvent *e)
  */
 void Diagram::keyReleaseEvent(QKeyEvent *e)
 {
-	if (m_event_interface && m_event_interface->KeyReleaseEvent(e)) return;
-
+	if (m_event_interface)
+		if(m_event_interface->keyReleaseEvent(e))
+		{
+			if(!m_event_interface->isRunning())
+			{
+				delete m_event_interface; m_event_interface = nullptr;
+			}
+			return;
+		}
+	
 	bool transmit_event = true;
 	if (!isReadOnly()) {
 		// detecte le relachement d'une touche de direction ( = deplacement d'elements)
@@ -299,7 +399,19 @@ void Diagram::setEventInterface(DiagramEventInterface *event_interface)
 		event_interface -> init();
 	}
 	m_event_interface = event_interface;
-	connect (m_event_interface, &DiagramEventInterface::finish, this, [this]() { delete this->m_event_interface; this->m_event_interface = nullptr;}, Qt::QueuedConnection);
+}
+
+/**
+ * @brief Diagram::clearEventInterface
+ * Clear the current event interface.
+ */
+void Diagram::clearEventInterface()
+{
+	if(m_event_interface)
+	{
+		delete m_event_interface;
+		m_event_interface = nullptr;
+	}
 }
 
 /**
@@ -446,6 +558,60 @@ QDomDocument Diagram::toXml(bool whole_content) {
 		if (!m_conductors_autonum_name.isEmpty()) {
 			racine.setAttribute("conductorAutonum", m_conductors_autonum_name);
 		}
+
+		//Default New Element
+		racine.setAttribute("freezeNewElement", m_freeze_new_elements ? "true" : "false");
+
+		//Default New Conductor
+		racine.setAttribute("freezeNewConductor", m_freeze_new_conductors_ ? "true" : "false");
+
+		//Element Folio Sequential Variables
+		if (!m_elmt_unitfolio_max.isEmpty() || !m_elmt_tenfolio_max.isEmpty() || !m_elmt_hundredfolio_max.isEmpty()) {
+			QDomElement elmtfoliosequential = document.createElement("elementautonumfoliosequentials");
+			if (!m_elmt_unitfolio_max.isEmpty()) {
+				QDomElement elmtfolioseq = document.createElement("elementunitfolioseq");
+				folioSequentialsToXml(&m_elmt_unitfolio_max, &elmtfolioseq, "sequf_", "unitfolioseq", &document);
+				elmtfoliosequential.appendChild(elmtfolioseq);
+			}
+			if (!m_elmt_tenfolio_max.isEmpty()) {
+				QDomElement elmtfolioseq = document.createElement("elementtenfolioseq");
+				folioSequentialsToXml(&m_elmt_tenfolio_max, &elmtfolioseq, "seqtf_", "tenfolioseq", &document);
+				elmtfoliosequential.appendChild(elmtfolioseq);
+			}
+			if (!m_elmt_hundredfolio_max.isEmpty()) {
+				QDomElement elmtfolioseq = document.createElement("elementhundredfolioseq");
+				folioSequentialsToXml(&m_elmt_hundredfolio_max, &elmtfolioseq, "seqhf_", "hundredfolioseq", &document);
+				elmtfoliosequential.appendChild(elmtfolioseq);
+			}
+			racine.appendChild(elmtfoliosequential);
+		}
+		//Conductor Folio Sequential Variables
+		if (!m_cnd_unitfolio_max.isEmpty() || !m_cnd_tenfolio_max.isEmpty() || !m_cnd_hundredfolio_max.isEmpty()) {
+			QDomElement cndfoliosequential = document.createElement("conductorautonumfoliosequentials");
+			QHash<QString, QStringList>::iterator i;
+			if (!m_cnd_unitfolio_max.isEmpty()) {
+				QDomElement cndfolioseq = document.createElement("conductorunitfolioseq");
+				folioSequentialsToXml(&m_cnd_unitfolio_max, &cndfolioseq, "sequf_", "unitfolioseq", &document);
+				cndfoliosequential.appendChild(cndfolioseq);
+			}
+			if (!m_cnd_tenfolio_max.isEmpty()) {
+				QDomElement cndfolioseq = document.createElement("conductortenfolioseq");
+				folioSequentialsToXml(&m_cnd_tenfolio_max, &cndfolioseq, "seqtf_", "tenfolioseq", &document);
+				cndfoliosequential.appendChild(cndfolioseq);
+			}
+			if (!m_cnd_hundredfolio_max.isEmpty()) {
+				QDomElement cndfolioseq = document.createElement("conductorhundredfolioseq");
+				folioSequentialsToXml(&m_cnd_hundredfolio_max, &cndfolioseq, "seqhf_", "hundredfolioseq", &document);
+				cndfoliosequential.appendChild(cndfolioseq);
+			}
+			racine.appendChild(cndfoliosequential);
+		}
+	}
+	else {
+			//this method with whole_content to false,
+			//is often use to copy and paste the current selection
+			//so we add the id of the project where copy occur.
+		racine.setAttribute("projectId", QETApp::projectId(m_project));
 	}
 	document.appendChild(racine);
 	
@@ -536,6 +702,25 @@ QDomDocument Diagram::toXml(bool whole_content) {
 	return(document);
 }
 
+/**
++ * @brief Diagram::folioSequentialsToXml
++ * Add folio sequential to QDomElement
++ * @param domElement to add attributes
++ * @param hash to retrieve content with content
++ * @param sequential type
++ */
+void Diagram::folioSequentialsToXml(QHash<QString, QStringList> *hash, QDomElement *domElement, QString seq_type, QString type, QDomDocument *doc) {
+	QHash<QString, QStringList>::iterator i;
+	for (i = hash->begin(); i != hash->end(); i++) {
+		QDomElement folioseq = doc->createElement(type);
+		folioseq.setAttribute("title", i.key());
+		for (int j = 0; j < i.value().size(); j++) {
+			folioseq.setAttribute(seq_type + QString::number(j+1), i.value().at(j));
+		}
+		domElement->appendChild(folioseq);
+	}
+}
+
 /**
 	Importe le schema decrit dans un document XML. Si une position est
 	precisee, les elements importes sont positionnes de maniere a ce que le
@@ -573,12 +758,6 @@ bool Diagram::initFromXml(QDomElement &document, QPointF position, bool consider
 	// import le contenu et les proprietes du schema depuis l'element XML fourni en parametre
 	bool from_xml = fromXml(document, position, consider_informations, content_ptr);
 	
-	// initialise le document XML interne a partir de l'element XML fourni en parametre
-	if (from_xml) {
-		xml_document_.clear();
-		xml_document_.appendChild(xml_document_.importNode(document, true));
-		// a ce stade, le document XML interne contient le code XML qui a ete importe, et non pas une version re-exporte par la methode toXml()
-	}
 	return(from_xml);
 }
 
@@ -622,11 +801,26 @@ bool Diagram::fromXml(QDomElement &document, QPointF position, bool consider_inf
 
 		// Load the autonum
 		m_conductors_autonum_name = root.attribute("conductorAutonum");
+
+		// Load Freeze New Element
+		m_freeze_new_elements = root.attribute("freezeNewElement").toInt();
+
+		// Load Freeze New Conductor
+		m_freeze_new_conductors_ = root.attribute("freezeNewConductor").toInt();
+
+		//Load Element Folio Sequential
+		folioSequentialsFromXml(root, &m_elmt_unitfolio_max, "elementunitfolioseq","sequf_","unitfolioseq", "elementautonumfoliosequentials");
+		folioSequentialsFromXml(root, &m_elmt_tenfolio_max, "elementtenfolioseq","seqtf_", "tenfolioseq", "elementautonumfoliosequentials");
+		folioSequentialsFromXml(root, &m_elmt_hundredfolio_max, "elementhundredfolioseq","seqhf_", "hundredfolioseq", "elementautonumfoliosequentials");
+
+		//Load Conductor Folio Sequential
+		folioSequentialsFromXml(root, &m_cnd_unitfolio_max, "conductorunitfolioseq","sequf_","unitfolioseq", "conductorautonumfoliosequentials");
+		folioSequentialsFromXml(root, &m_cnd_tenfolio_max, "conductortenfolioseq","seqtf_","tenfolioseq", "conductorautonumfoliosequentials");
+		folioSequentialsFromXml(root, &m_cnd_hundredfolio_max, "conductorhundredfolioseq","seqhf_","hundredfolioseq", "conductorautonumfoliosequentials");
 	}
-	
+
 	// if child haven't got a child, loading is finish (diagram is empty)
 	if (root.firstChild().isNull()) {
-		write(document);
 		return(true);
 	}
 	
@@ -638,9 +832,30 @@ bool Diagram::fromXml(QDomElement &document, QPointF position, bool consider_inf
 	qreal project_qet_version = declaredQElectroTechVersion(true);
 	bool handle_inputs_rotation = (
 		project_qet_version != -1 && project_qet_version < 0.3 &&
-		project_ -> state() == QETProject::ProjectParsingRunning
+		m_project -> state() == QETProject::ProjectParsingRunning
 	);
-	
+
+		//If paste from another project
+	if (root.hasAttribute("projectId")) {
+		QETProject *other_project = QETApp::project(root.attribute("projectId", "-1").toInt());
+
+			//We try to paste from another project, then befor paste elements,
+			//we must to import the definition of the pasted elements (owned by other project)
+			//in the embedded collection of this project
+		if (other_project && other_project != m_project) {
+			ElementCollectionHandler ech;
+			foreach (QDomElement element_xml, QET::findInDomElement(root, "elements", "element")) {
+				if (!Element::valideXml(element_xml)) continue;
+
+				QString type_id = element_xml.attribute("type");
+
+				if (type_id.startsWith("embed://")) {
+					ElementsLocation location(type_id, other_project);
+					ech.importFromProject(m_project, location);
+				}
+			}
+		}
+	}
 		//Load all elements from the XML
 	QList<Element *> added_elements;
 	QHash<int, Terminal *> table_adr_id;
@@ -650,8 +865,13 @@ bool Diagram::fromXml(QDomElement &document, QPointF position, bool consider_inf
 		
 		// cree un element dont le type correspond a l'id type
 		QString type_id = element_xml.attribute("type");
-		ElementsLocation element_location = ElementsLocation(type_id);
-		if (type_id.startsWith("embed://")) element_location.setProject(project_);
+		ElementsLocation element_location;
+		if (type_id.startsWith("embed://")) {
+			element_location = ElementsLocation(type_id, m_project);
+		}
+		else {
+			element_location = ElementsLocation(type_id);
+		}
 		
 		int state = 0;
 		Element *nvel_elmt = ElementFactory::Instance() -> createElement(element_location, 0, &state);
@@ -770,50 +990,42 @@ bool Diagram::fromXml(QDomElement &document, QPointF position, bool consider_inf
 }
 
 /**
-	Enregistre le schema XML dans son document XML interne et emet le signal
-	written().
-*/
-void Diagram::write()
-{
-	qDebug() << qPrintable(QString("Diagram::write() : saving changes from diagram \"%1\"").arg(title())) << "[" << this << "]";
-	write(toXml().documentElement());
+ * @brief Diagram::folioSequentialsFromXml
+ * Load folio sequential from QDomElement
+ * @param root containing all folio sequentials
+ * @param hash to be loaded with content
+ * @param folioSeq type
+ * @param seq type
+ * @param type of sequential
+ */
+void Diagram::folioSequentialsFromXml(const QDomElement &root, QHash<QString, QStringList>* hash, QString folioSeq, QString seq, QString type, QString autonumFolioSeqType) {
+	foreach (QDomElement folioSeqAutoNum, QET::findInDomElement(root, autonumFolioSeqType, folioSeq)) {
+		for(QDomElement folioseq = folioSeqAutoNum.firstChildElement(type); !folioseq.isNull(); folioseq = folioseq.nextSiblingElement(type)) {
+			QString title = folioseq.attribute("title");
+			QStringList list;
+			int i = 1;
+			while (folioseq.hasAttribute(seq + QString::number(i))) {
+				list << folioseq.attribute(seq + QString::number(i));
+				i++;
+			}
+			hash->insert(title,list);
+		}
+	}
 }
 
 /**
-	Enregistre un element XML dans son document XML interne et emet le signal
-	written().
-	@param element xml a enregistrer
-*/
-void Diagram::write(const QDomElement &element) {
-	xml_document_.clear();
-	xml_document_.appendChild(xml_document_.importNode(element, true));
-	emit(written());
-}
+ * @brief Diagram::refreshContents
+ * refresh all content of diagram.
+ * - refresh conductor text.
+ * - linking the elements waiting to be linked
+ */
+void Diagram::refreshContents() {
 
-/**
-	@return true si la fonction write a deja ete appele (pour etre plus exact :
-	si le document XML utilise en interne n'est pas vide), false sinon
-*/
-bool Diagram::wasWritten() const {
-	return(!xml_document_.isNull());
-}
-
-/**
-	@return le schema en XML tel qu'il doit etre enregistre dans le fichier projet
-	@param xml_doc document XML a utiliser pour creer l'element
-*/
-QDomElement Diagram::writeXml(QDomDocument &xml_doc) const {
-	// si le schema n'a pas ete enregistre explicitement, on n'ecrit rien
-	if (!wasWritten()) return(QDomElement());
-	
-	QDomElement diagram_elmt = xml_document_.documentElement();
-	QDomNode new_node = xml_doc.importNode(diagram_elmt, true);
-	return(new_node.toElement());
-}
-
-void Diagram::initElementsLinks() {
 	foreach (Element *elmt, elements())
 		elmt->initLink(project());
+
+	foreach (Conductor *conductor, conductors())
+		conductor->refreshText();
 }
 
 /**
@@ -829,14 +1041,6 @@ void Diagram::addItem(QGraphicsItem *item)
 
 	switch (item->type())
 	{
-		case Element::Type:
-		{
-			const Element *elmt = static_cast<const Element*>(item);
-			foreach(ElementTextItem *eti, elmt->texts())
-				connect (eti, &ElementTextItem::diagramTextChanged, this, &Diagram::diagramTextChanged);
-		}
-			break;
-
 		case Conductor::Type:
 		{
 			Conductor *conductor = static_cast<Conductor *>(item);
@@ -868,13 +1072,10 @@ void Diagram::removeItem(QGraphicsItem *item)
 	{
 		case Element::Type:
 		{
-			Element *elmt = static_cast<Element *>(item);
+			Element *elmt = static_cast<Element*>(item);
 			elmt->unlinkAllElements();
-			foreach(ElementTextItem *text, elmt->texts())
-				disconnect(text, &ElementTextItem::diagramTextChanged, this, &Diagram::diagramTextChanged);
 		}
 			break;
-
 		case Conductor::Type:
 		{
 			Conductor *conductor = static_cast<Conductor *>(item);
@@ -932,7 +1133,7 @@ void Diagram::titleBlockTemplateChanged(const QString &template_name) {
 void Diagram::titleBlockTemplateRemoved(const QString &template_name, const QString &new_template)
 {
 	if (border_and_titleblock.titleBlockTemplateName() != template_name) return;	
-	const TitleBlockTemplate *final_template = project_->embeddedTitleBlockTemplatesCollection()->getTemplate(new_template);
+	const TitleBlockTemplate *final_template = m_project->embeddedTitleBlockTemplatesCollection()->getTemplate(new_template);
 	border_and_titleblock.titleBlockTemplateRemoved(template_name, final_template);
 	update();
 }
@@ -943,10 +1144,10 @@ void Diagram::titleBlockTemplateRemoved(const QString &template_name, const QStr
 */
 void Diagram::setTitleBlockTemplate(const QString &template_name)
 {
-	if (!project_) return;
+	if (!m_project) return;
 	
 	QString current_name = border_and_titleblock.titleBlockTemplateName();
-	const TitleBlockTemplate *titleblock_template = project_->embeddedTitleBlockTemplatesCollection()->getTemplate(template_name);
+	const TitleBlockTemplate *titleblock_template = m_project->embeddedTitleBlockTemplatesCollection()->getTemplate(template_name);
 	border_and_titleblock.titleBlockTemplateRemoved(current_name, titleblock_template);
 	
 	if (template_name != current_name)
@@ -986,6 +1187,182 @@ void Diagram::invertSelection() {
 	emit(selectionChanged());
 }
 
+/**
+ * @brief Diagram::updateLabels
+ * Update elements and conductors that reference folio field
+ * in their labels.
+ */
+void Diagram::updateLabels() {
+	foreach (Element *elmt, elements()) {
+		if (elmt->elementInformations()["label"].toString().contains(("%F")))
+			elmt->updateLabel();
+	}
+	foreach (Conductor *cnd, content().conductors()) {
+		cnd->refreshText();
+	}
+}
+
+/**
+ * @brief Diagram::insertFolioSeqHash
+ * This class inserts a stringlist containing all
+ * sequential variables related to an autonum in a QHash
+ * @param Hash to be accessed
+ * @param autonum title
+ * @param sequential to be treated
+ * @param type to be treated
+ * @param Numerotation Context to be manipulated
+ */
+void Diagram::insertFolioSeqHash(QHash<QString, QStringList> *hash, QString title, QString type, NumerotationContext *nc) {
+	QStringList max;
+	for (int i = 0; i < nc->size(); i++) {
+		if (nc->itemAt(i).at(0) == type) {
+			nc->replaceValue(i, QString::number(nc->itemAt(i).at(3).toInt()));
+			max.append(QString::number(nc->itemAt(i).at(3).toInt() - nc->itemAt(i).at(2).toInt()));
+		}
+	}
+	hash->insert(title,max);
+}
+
+/**
+ * @brief Diagram::loadFolioSeqHash
+ * This class loads all folio sequential variables
+ * related to the current autonum
+ * @param Hash to be accessed
+ * @param autonum title
+ * @param sequential to be treated
+ * @param type to be treated
+ * @param Numerotation Context to be manipulated
+ */
+void Diagram::loadFolioSeqHash(QHash<QString, QStringList> *hash, QString title, QString type, NumerotationContext *nc) {
+		int j = 0;
+		for (int i = 0; i < nc->size(); i++) {
+			if (nc->itemAt(i).at(0) == type) {
+				QString new_value;
+				new_value = QString::number(hash->value(title).at(j).toInt() + nc->itemAt(i).at(2).toInt());
+				nc->replaceValue(i,new_value);
+				j++;
+			}
+		}
+}
+
+/**
+ * @brief Diagram::loadElmtFolioSeq
+ * This class loads all folio sequential variables related
+ * to the current autonum
+ */
+void Diagram::loadElmtFolioSeq() {
+	QString title = project()->elementCurrentAutoNum();
+	NumerotationContext nc = project()->elementAutoNum(title);
+
+	//Unit Folio
+	if (m_elmt_unitfolio_max.isEmpty() || !m_elmt_unitfolio_max.contains(title)) {
+		//Insert Initial Value
+		if (project()->elementAutoNumCurrentFormula().contains("%sequf_")) {
+			insertFolioSeqHash(&m_elmt_unitfolio_max,title,"unitfolio",&nc);
+			project()->addElementAutoNum(title,nc);
+		}
+	}
+	else if (m_elmt_unitfolio_max.contains(title)) {
+		//Load Folio Current Value
+		if (project()->elementAutoNumCurrentFormula().contains("%sequf_")) {
+			loadFolioSeqHash(&m_elmt_unitfolio_max,title,"unitfolio",&nc);
+			project()->addElementAutoNum(title,nc);
+		}
+	}
+
+	//Ten Folio
+	if (m_elmt_tenfolio_max.isEmpty() || !m_elmt_tenfolio_max.contains(title)) {
+		//Insert Initial Value
+		if (project()->elementAutoNumCurrentFormula().contains("%seqtf_")) {
+			insertFolioSeqHash(&m_elmt_tenfolio_max,title,"tenfolio",&nc);
+			project()->addElementAutoNum(title,nc);
+		}
+	}
+	else if (m_elmt_tenfolio_max.contains(title)) {
+		//Load Folio Current Value
+		if (project()->elementAutoNumCurrentFormula().contains("%seqtf_")) {
+			loadFolioSeqHash(&m_elmt_tenfolio_max,title,"tenfolio",&nc);
+			project()->addElementAutoNum(title,nc);
+		}
+	}
+
+	//Hundred Folio
+	if (m_elmt_hundredfolio_max.isEmpty() || !m_elmt_hundredfolio_max.contains(title)) {
+		//Insert Initial Value
+		if (project()->elementAutoNumCurrentFormula().contains("%seqhf_")) {
+			insertFolioSeqHash(&m_elmt_hundredfolio_max,title,"hundredfolio",&nc);
+			project()->addElementAutoNum(title,nc);
+		}
+	}
+	else if (m_elmt_hundredfolio_max.contains(title)) {
+		//Load Folio Current Value
+		if (project()->elementAutoNumCurrentFormula().contains("%seqhf_")) {
+			loadFolioSeqHash(&m_elmt_hundredfolio_max,title,"hundredfolio",&nc);
+			project()->addElementAutoNum(title,nc);
+		}
+	}
+}
+
+/**
+ * @brief Diagram::loadCndFolioSeq
+ * This class loads all conductor folio sequential variables related
+ * to the current autonum
+ */
+void Diagram::loadCndFolioSeq() {
+	//Conductor
+	QString title = project()->conductorCurrentAutoNum();
+	NumerotationContext nc = project()->conductorAutoNum(title);
+	QString formula = autonum::numerotationContextToFormula(nc);
+
+	//Unit Folio
+	if (m_cnd_unitfolio_max.isEmpty() || !m_cnd_unitfolio_max.contains(title)) {
+		//Insert Initial Value
+		if (formula.contains("%sequf_")) {
+			insertFolioSeqHash(&m_cnd_unitfolio_max,title,"unitfolio",&nc);
+			project()->addConductorAutoNum(title,nc);
+		}
+	}
+	else if (m_cnd_unitfolio_max.contains(title)) {
+		//Load Folio Current Value
+		if (formula.contains("%sequf_")) {
+			loadFolioSeqHash(&m_cnd_unitfolio_max,title,"unitfolio",&nc);
+			project()->addConductorAutoNum(title,nc);
+		}
+	}
+
+	//Ten Folio
+	if (m_cnd_tenfolio_max.isEmpty() || !m_cnd_tenfolio_max.contains(title)) {
+		//Insert Initial Value
+		if (formula.contains("%seqtf_")) {
+			insertFolioSeqHash(&m_cnd_tenfolio_max,title,"tenfolio",&nc);
+			project()->addConductorAutoNum(title,nc);
+		}
+	}
+	else if (m_cnd_tenfolio_max.contains(title)) {
+		//Load Folio Current Value
+		if (formula.contains("%seqtf_")) {
+			loadFolioSeqHash(&m_cnd_tenfolio_max,title,"tenfolio",&nc);
+			project()->addConductorAutoNum(title,nc);
+		}
+	}
+
+	//Hundred Folio
+	if (m_cnd_hundredfolio_max.isEmpty() || !m_cnd_hundredfolio_max.contains(title)) {
+		//Insert Initial Value
+		if (formula.contains("%seqhf_")) {
+			insertFolioSeqHash(&m_cnd_hundredfolio_max,title,"hundredfolio",&nc);
+			project()->addConductorAutoNum(title,nc);
+		}
+	}
+	else if (m_cnd_hundredfolio_max.contains(title)) {
+		//Load Folio Current Value
+		if (formula.contains("%seqhf_")) {
+			loadFolioSeqHash(&m_cnd_hundredfolio_max,title,"hundredfolio",&nc);
+			project()->addConductorAutoNum(title,nc);
+		}
+	}
+}
+
 /**
 	@return le titre du cartouche
 */
@@ -1015,6 +1392,19 @@ QList <Element *> Diagram::elements() const {
 	return (element_list);
 }
 
+/**
+ * @brief Diagram::conductors
+ * Return the list containing all conductors
+ */
+QList <Conductor *> Diagram::conductors() const {
+	QList<Conductor *> cnd_list;
+	foreach (QGraphicsItem *qgi, items()) {
+		if (Conductor *cnd = qgraphicsitem_cast<Conductor *>(qgi))
+			cnd_list <<cnd;
+	}
+	return (cnd_list);
+}
+
 /**
 	Initialise un deplacement d'elements, conducteurs et champs de texte sur le
 	schema.
@@ -1094,6 +1484,68 @@ bool Diagram::usesTitleBlockTemplate(const QString &name) {
 	return(name == border_and_titleblock.titleBlockTemplateName());
 }
 
+/**
+ * @brief Diagram::freezeElements
+ * Freeze every existent element label.
+ */
+void Diagram::freezeElements(bool freeze) {
+	foreach (Element *elmt, elements()) {
+		elmt->freezeLabel(freeze);
+	}
+}
+
+/**
+ * @brief Diagram::unfreezeElements
+ * Unfreeze every existent element label.
+ */
+void Diagram::unfreezeElements() {
+	foreach (Element *elmt, elements()) {
+		elmt->freezeLabel(false);
+	}
+}
+
+/**
+ * @brief Diagram::freezeNewElements
+ * Set new element label to be frozen.
+ */
+void Diagram::setFreezeNewElements(bool b) {
+	m_freeze_new_elements = b;
+}
+
+/**
+ * @brief Diagram::freezeNewElements
+ * @return current freeze new element status .
+ */
+bool Diagram::freezeNewElements() {
+	return m_freeze_new_elements;
+}
+
+/**
+ * @brief Diagram::freezeConductors
+ * Freeze every existent conductor label.
+ */
+void Diagram::freezeConductors(bool freeze) {
+	foreach (Conductor *cnd, conductors()) {
+		cnd->setFreezeLabel(freeze);
+	}
+}
+
+/**
+ * @brief Diagram::setfreezeNewConductors
+ * Set new conductor label to be frozen.
+ */
+void Diagram::setFreezeNewConductors(bool b) {
+	m_freeze_new_conductors_ = b;
+}
+
+/**
+ * @brief Diagram::freezeNewConductors
+ * @return current freeze new conductor status .
+ */
+bool Diagram::freezeNewConductors() {
+	return m_freeze_new_conductors_;
+}
+
 /**
  * @brief Diagram::adjustSceneRect
  * Recalcul and adjust the size of the scene
@@ -1266,7 +1718,7 @@ bool Diagram::clipboardMayContainDiagram() {
 	independant.
 */
 QETProject *Diagram::project() const {
-	return(project_);
+	return(m_project);
 }
 
 /**
@@ -1276,19 +1728,11 @@ QETProject *Diagram::project() const {
  */
 void Diagram::setProject(QETProject *project)
 {
-	if (project_ == project) return;
+	if (m_project == project)
+		return;
 
-	if (project_)
-	{
-		disconnect (project_, SIGNAL(reportPropertiesChanged(QString)), this, SIGNAL(reportPropertiesChanged(QString)));
-		disconnect (project_, SIGNAL(XRefPropertiesChanged()),          this, SIGNAL(XRefPropertiesChanged()));
-	}
-
-	project_ = project;
+	m_project = project;
 	setParent (project);
-
-	connect (project_, SIGNAL(reportPropertiesChanged(QString)), this, SIGNAL(reportPropertiesChanged(QString)));
-	connect (project_, SIGNAL(XRefPropertiesChanged()),          this, SIGNAL(XRefPropertiesChanged()));
 }
 
 /**
@@ -1296,8 +1740,8 @@ void Diagram::setProject(QETProject *project)
 	if it is has no parent project
 */
 int Diagram::folioIndex() const {
-	if (!project_) return(-1);
-	return(project_ -> folioIndex(this));
+	if (!m_project) return(-1);
+	return(m_project -> folioIndex(this));
 }
 
 /**
@@ -1310,8 +1754,8 @@ qreal Diagram::declaredQElectroTechVersion(bool fallback_to_project) const {
 	if (diagram_qet_version_ != -1) {
 		return diagram_qet_version_;
 	}
-	if (fallback_to_project && project_) {
-		return(project_ -> declaredQElectroTechVersion());
+	if (fallback_to_project && m_project) {
+		return(m_project -> declaredQElectroTechVersion());
 	}
 	return(-1);
 }
@@ -1323,7 +1767,7 @@ qreal Diagram::declaredQElectroTechVersion(bool fallback_to_project) const {
  */
 bool Diagram::isReadOnly() const
 {
-	return project_ -> isReadOnly();
+	return m_project -> isReadOnly();
 }
 
 /**
