@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -83,13 +83,22 @@ class Diagram : public QGraphicsScene
 		static const qreal margin;
 		/// background color of diagram
 		static QColor background_color;
+		/// Hash containing max values for folio sequential autonums in this diagram
+		QHash <QString, QStringList> m_elmt_unitfolio_max;
+		QHash <QString, QStringList> m_elmt_tenfolio_max;
+		QHash <QString, QStringList> m_elmt_hundredfolio_max;
+		/// Hash containing max values for folio sequential autonums in this diagram
+		QHash <QString, QStringList> m_cnd_unitfolio_max;
+		QHash <QString, QStringList> m_cnd_tenfolio_max;
+		QHash <QString, QStringList> m_cnd_hundredfolio_max;
+		bool item_paste;
 
 	private:
 		QGraphicsLineItem *conductor_setter_;
 		ElementsMover     *elements_mover_;
 		ElementTextsMover *element_texts_mover_;
 		QGIManager        *qgi_manager_;
-		QETProject        *project_;
+		QETProject        *m_project;
 
 		QDomDocument xml_document_;
 
@@ -102,6 +111,9 @@ class Diagram : public QGraphicsScene
 
 		QString m_conductors_autonum_name;
 		DiagramEventInterface *m_event_interface;
+
+		bool m_freeze_new_elements;
+		bool m_freeze_new_conductors_;
 	
 	// METHODS
 	protected:
@@ -117,18 +129,15 @@ class Diagram : public QGraphicsScene
 	
 	public:
 		void setEventInterface (DiagramEventInterface *event_interface);
-
-		//methods related to xref properties
-		QString		   defaultReportProperties () const {return project_ -> defaultReportProperties();}
-		XRefProperties defaultXRefProperties   (const QString &str) const {return project_ -> defaultXRefProperties(str);}
-
-		//methods related to autonum
+		void clearEventInterface();
+			
+			//methods related to autonum
 		QString conductorsAutonumName() const;
 		void setConductorsAutonumName(const QString &name);
 
 		static bool clipboardMayContainDiagram();
 	
-		// methods related to parent project
+			// methods related to parent project
 		QETProject *project() const;
 		void        setProject(QETProject *);
 		int         folioIndex() const;
@@ -136,70 +145,86 @@ class Diagram : public QGraphicsScene
 		void        showMe() {emit showDiagram(this);}
 		bool        isReadOnly() const;
 	
-	// methods related to conductor creation
-	void setConductor(bool);
-	void setConductorStart (QPointF);
-	void setConductorStop(QPointF);
-	QList < QSet <Conductor *> > potentials();
+			// methods related to conductor creation
+		void setConductor(bool);
+		void setConductorStart (QPointF);
+		void setConductorStop(QPointF);
+		QList < QSet <Conductor *> > potentials();
 	
-	// methods related to XML import/export
-	QDomDocument toXml(bool = true);
-	bool initFromXml(QDomElement &, QPointF = QPointF(), bool = true, DiagramContent * = 0);
-	bool fromXml(QDomDocument &, QPointF = QPointF(), bool = true, DiagramContent * = 0);
-	bool fromXml(QDomElement &, QPointF = QPointF(), bool = true, DiagramContent * = 0);
-	void write();
-	void write(const QDomElement &);
-	bool wasWritten() const;
-	QDomElement writeXml(QDomDocument &) const;
+		// methods related to XML import/export
+		QDomDocument toXml(bool = true);
+		bool initFromXml(QDomElement &, QPointF = QPointF(), bool = true, DiagramContent * = 0);
+		bool fromXml(QDomDocument &, QPointF = QPointF(), bool = true, DiagramContent * = 0);
+		bool fromXml(QDomElement &, QPointF = QPointF(), bool = true, DiagramContent * = 0);
+		void folioSequentialsToXml(QHash<QString, QStringList>*, QDomElement *, QString, QString, QDomDocument *);
+		void folioSequentialsFromXml(const QDomElement&, QHash<QString, QStringList>*, QString, QString, QString, QString);
 	
-		// methods related to graphics items addition/removal on the diagram
-	void initElementsLinks();
-	virtual void addItem    (QGraphicsItem *item);
-	virtual void removeItem (QGraphicsItem *item);
+		void refreshContents();
 	
-	// methods related to graphics options
-	ExportProperties applyProperties(const ExportProperties &);
-	void setDisplayGrid(bool);
-	bool displayGrid();
-	void setUseBorder(bool);
-	bool useBorder();
-	void setBorderOptions(BorderOptions);
-	BorderOptions borderOptions();
-	DiagramPosition convertPosition(const QPointF &);
-	static QPointF snapToGrid(const QPointF &p);
+			// methods related to graphics items addition/removal on the diagram
+		virtual void addItem    (QGraphicsItem *item);
+		virtual void removeItem (QGraphicsItem *item);
 	
-	bool drawTerminals() const;
-	void setDrawTerminals(bool);
-	bool drawColoredConductors() const;
-	void setDrawColoredConductors(bool);
+			// methods related to graphics options
+		ExportProperties applyProperties(const ExportProperties &);
+		void setDisplayGrid(bool);
+		bool displayGrid();
+		void setUseBorder(bool);
+		bool useBorder();
+		void setBorderOptions(BorderOptions);
+		BorderOptions borderOptions();
+		DiagramPosition convertPosition(const QPointF &);
+		static QPointF snapToGrid(const QPointF &p);
+	
+		bool drawTerminals() const;
+		void setDrawTerminals(bool);
+		bool drawColoredConductors() const;
+		void setDrawColoredConductors(bool);
+	
+		QString title() const;
+		bool toPaintDevice(QPaintDevice &, int = -1, int = -1, Qt::AspectRatioMode = Qt::KeepAspectRatio);
+		QSize imageSize() const;
+		
+		bool isEmpty() const;
+	
+		QList<CustomElement *> customElements() const;
+		QList<Element *> elements() const;
+		QList<Conductor *> conductors() const;
+		QSet<DiagramTextItem *> selectedTexts() const;
+		QSet<ConductorTextItem *> selectedConductorTexts() const;
+		QSet<ElementTextItem*> selectedElementTexts() const;
+		QSet<Conductor *> selectedConductors() const;
+		DiagramContent content() const;
+		DiagramContent selectedContent();
+		bool canRotateSelection() const;
+		int  beginMoveElements(QGraphicsItem * = 0);
+		void continueMoveElements(const QPointF &);
+		void endMoveElements();
+		int  beginMoveElementTexts(QGraphicsItem * = 0);
+		void continueMoveElementTexts(const QPointF &);
+		void endMoveElementTexts();
+		bool usesElement(const ElementsLocation &);
+		bool usesTitleBlockTemplate(const QString &);
+		
+		QUndoStack &undoStack();
+		QGIManager &qgiManager();
+	
+			//methods related to element label Update Policy
+		void freezeElements(bool freeze);
+		void unfreezeElements();
+		void setFreezeNewElements(bool);
+		bool freezeNewElements();
+	
+			//methods related to conductor label Update Policy
+		void freezeConductors(bool freeze);
+		void setFreezeNewConductors(bool);
+		bool freezeNewConductors();
+	
+			//methods related to insertion and loading of folio sequential
+		void insertFolioSeqHash (QHash<QString, QStringList> *hash, QString title, QString seq, NumerotationContext *nc);
+		void loadFolioSeqHash (QHash<QString, QStringList> *hash, QString title, QString seq, NumerotationContext *nc);
+
 
-	QString title() const;
-	bool toPaintDevice(QPaintDevice &, int = -1, int = -1, Qt::AspectRatioMode = Qt::KeepAspectRatio);
-	QSize imageSize() const;
-	
-	bool isEmpty() const;
-	
-	QList<CustomElement *> customElements() const;
-	QList<Element *> elements() const;
-	QSet<DiagramTextItem *> selectedTexts() const;
-	QSet<ConductorTextItem *> selectedConductorTexts() const;
-	QSet<ElementTextItem*> selectedElementTexts() const;
-	QSet<Conductor *> selectedConductors() const;
-	DiagramContent content() const;
-	DiagramContent selectedContent();
-	bool canRotateSelection() const;
-	int  beginMoveElements(QGraphicsItem * = 0);
-	void continueMoveElements(const QPointF &);
-	void endMoveElements();
-	int  beginMoveElementTexts(QGraphicsItem * = 0);
-	void continueMoveElementTexts(const QPointF &);
-	void endMoveElementTexts();
-	bool usesElement(const ElementsLocation &);
-	bool usesTitleBlockTemplate(const QString &);
-	
-	QUndoStack &undoStack();
-	QGIManager &qgiManager();
-	
 	public slots:
 		void adjustSceneRect ();
 		void titleChanged(const QString &);
@@ -207,21 +232,22 @@ class Diagram : public QGraphicsScene
 		void titleBlockTemplateChanged(const QString &);
 		void titleBlockTemplateRemoved(const QString &, const QString & = QString());
 		void setTitleBlockTemplate(const QString &);
+		void updateLabels();
+		void loadElmtFolioSeq();
+		void loadCndFolioSeq();
 	
-		// methods related to graphics items selection
+			// methods related to graphics items selection
 		void selectAll();
 		void deselectAll();
 		void invertSelection();
-	
+
 	signals:
 		void showDiagram (Diagram *);
-		void written();
 		void usedTitleBlockTemplateChanged(const QString &);
 		void diagramTitleChanged(Diagram *, const QString &);
 		void findElementRequired(const ElementsLocation &);		/// Signal emitted when users wish to locate an element from the diagram within elements collection
 		void editElementRequired(const ElementsLocation &);		/// Signal emitted when users wish to edit an element from the diagram
-		void reportPropertiesChanged(QString);
-		void XRefPropertiesChanged();
+		void diagramActivated();
 };
 Q_DECLARE_METATYPE(Diagram *)
 
