@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -89,16 +89,27 @@ int DiagramContent::removeNonMovableItems()
 {
 	int count_ = 0;
 
-	foreach(Element *elmt, elements)
-		if (!elmt->isMovable()) elements.remove(elmt); ++count_;
-	foreach(DiagramImageItem *img, images)
-		if (!img->isMovable()) images.remove(img); ++count_;
-	foreach (QetShapeItem *shape, shapes)
-		if (!shape->isMovable()) shapes.remove(shape); ++count_;
+	foreach(Element *elmt, elements) {
+		if (!elmt->isMovable()) {
+			elements.remove(elmt);
+			++count_;
+		}
+	}
+	foreach(DiagramImageItem *img, images) {
+		if (!img->isMovable()) {
+			images.remove(img);
+			++count_;
+		}
+	}
+	foreach (QetShapeItem *shape, shapes) {
+		if (!shape->isMovable()) {
+			shapes.remove(shape);
+			++count_;
+		}
+	}
 
 	return count_;
 }
-
 /**
 	@param filter Types desires
 	@return la liste des items formant le contenu du schema
