@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -19,7 +19,7 @@
 #include <QPainter>
 #include "qetapp.h"
 
-qreal DiagramFolioList::colWidths[4] = {0.1, 0.55, 0.2, 0.15};
+qreal DiagramFolioList::colWidths[7] = {0.05, 0.50, 0.10, 0.10, 0.05, 0.10, 0.10};
 
 /**
  * @brief DiagramFolioList::DiagramFolioList
@@ -54,7 +54,7 @@ DiagramFolioList::~DiagramFolioList()
 void DiagramFolioList::drawBackground(QPainter *p, const QRectF &r)
 {
 	p -> save();
-
+	QSettings settings;
 	// disable all antialiasing, except for the texts
 	p -> setRenderHint(QPainter::Antialiasing, false);
 	p -> setRenderHint(QPainter::TextAntialiasing, true);
@@ -74,42 +74,39 @@ void DiagramFolioList::drawBackground(QPainter *p, const QRectF &r)
 	qreal y0 = border_and_titleblock.columnsHeaderHeight();
 	QRectF row_RectBorder(x0, y0, width, height);
 
-	buildGrid(p, row_RectBorder,30,2,colWidths);
+	buildGrid(p, row_RectBorder,30,1,colWidths);
 
 	x0 = list_rectangles_[0] -> topLeft().x();
 	y0 = list_rectangles_[0] -> topLeft().y();
+
 	qreal rowHeight = (list_rectangles_[0] -> height())/30;
 	QRectF row_RectF(x0, y0, list_rectangles_[0] -> width(), rowHeight);
 
 	fillHeader(p, row_RectF);
 	QList<Diagram *> diagram_list = project() -> diagrams();
 
-	int startDiagram = id * 58;
-
+	int startDiagram = id * 29;
 	for (int i = startDiagram; i < startDiagram+29 && i < diagram_list.size(); ++i) {
 		y0 += rowHeight;
 		QRectF row_rect(x0, y0, list_rectangles_[0] -> width(), rowHeight);
+		if (settings.value("genericpanel/folio", true).toBool()){
 		fillRow(p, row_rect, diagram_list[i] -> border_and_titleblock.author(),
+				diagram_list[i] -> title(),
+				diagram_list[i] -> border_and_titleblock.finalfolio(),
+				diagram_list[i] -> border_and_titleblock.machine(),
+				diagram_list[i] -> border_and_titleblock.locmach(),
+				diagram_list[i] -> border_and_titleblock.indexrev(),
+				diagram_list[i] -> border_and_titleblock.date().toString(Qt::SystemLocaleShortDate));
+	}else{
+			fillRow(p, row_rect, diagram_list[i] -> border_and_titleblock.author(),
 				diagram_list[i] -> title(),
 				QString::number(diagram_list[i] ->folioIndex()+1),
+				diagram_list[i] -> border_and_titleblock.machine(),
+				diagram_list[i] -> border_and_titleblock.locmach(),
+				diagram_list[i] -> border_and_titleblock.indexrev(),
 				diagram_list[i] -> border_and_titleblock.date().toString(Qt::SystemLocaleShortDate));
 	}
 
-	x0 = list_rectangles_[1] -> topLeft().x();
-	y0 = list_rectangles_[1] -> topLeft().y();
-	rowHeight = (list_rectangles_[1] -> height())/30;
-	QRectF row_RectF2(x0, y0, list_rectangles_[1] -> width(), rowHeight);
-	fillHeader(p, row_RectF2);
-
-	startDiagram += 29;
-
-	for (int i = startDiagram; i < startDiagram+29 && i < diagram_list.size(); ++i) {
-		y0 += rowHeight;
-		QRectF row_rect(x0, y0, list_rectangles_[1] -> width(), rowHeight);
-		fillRow(p, row_rect, diagram_list[i] -> border_and_titleblock.author(),
-				diagram_list[i] -> title(),
-				QString::number(diagram_list[i] ->folioIndex()+1),
-				diagram_list[i] -> border_and_titleblock.date().toString(Qt::SystemLocaleShortDate));
 	}
 
 	border_and_titleblock.draw(p);
@@ -123,16 +120,18 @@ void DiagramFolioList::drawBackground(QPainter *p, const QRectF &r)
  * @param row_rect rectangle where we must draw the new row
  */
 void DiagramFolioList::fillRow(QPainter *qp, const QRectF &row_rect, QString author, QString title,
-							   QString folio, QString date)
+							   QString folio, QString machine, QString loc, QString indexrev, QString date)
 {
 	qreal x = row_rect.topLeft().x();
 	qreal y = row_rect.topLeft().y();
+	QSettings settings;
 
 
 	QFontMetrics origFontMetrics(QETApp::diagramTextsFont());
 	qreal origFontSize = QETApp::diagramTextsFont().pointSizeF();
 	QFont workingFont(QETApp::diagramTextsFont());
 
+	if (settings.value("genericpanel/folio", true).toBool()){
 	// reduce the font size if the text entry is long
 	if (origFontMetrics.width(folio) > 0.95*colWidths[0]*row_rect.width())
 		workingFont.setPointSizeF(origFontSize * 0.95*colWidths[0]*row_rect.width() / origFontMetrics.width(folio));
@@ -140,7 +139,18 @@ void DiagramFolioList::fillRow(QPainter *qp, const QRectF &row_rect, QString aut
 		workingFont.setPointSizeF(origFontSize);
 	qp -> setFont(workingFont);
 	qp -> drawText(QRectF(x, y, colWidths[0]*row_rect.width(), row_rect.height()), Qt::AlignCenter, folio);
+	
 	x += colWidths[0]*row_rect.width();
+	}else{
+	if (origFontMetrics.width(folio) > 0.95*colWidths[0]*row_rect.width())
+		workingFont.setPointSizeF(origFontSize * 0.95*colWidths[0]*row_rect.width() / origFontMetrics.width(folio));
+	else
+		workingFont.setPointSizeF(origFontSize);
+	qp -> setFont(workingFont);
+	qp -> drawText(QRectF(x, y, colWidths[0]*row_rect.width(), row_rect.height()), Qt::AlignCenter, folio);
+	x += colWidths[0]*row_rect.width();
+	}
+
 
 	if (origFontMetrics.width(title) > 0.95*colWidths[1]*row_rect.width())
 		workingFont.setPointSizeF(origFontSize * 0.95*colWidths[1]*row_rect.width() / origFontMetrics.width(title));
@@ -151,24 +161,55 @@ void DiagramFolioList::fillRow(QPainter *qp, const QRectF &row_rect, QString aut
 	if (title == heading)
 		qp -> drawText(QRectF(x, y, colWidths[1]*row_rect.width(),row_rect.height()), Qt::AlignCenter, title);
 	else
-		qp -> drawText(QRectF(x+0.01*row_rect.width(), y, colWidths[1]*row_rect.width()*0.99,
+		qp -> drawText(QRectF(x+0.01*row_rect.width(), y, colWidths[1]*row_rect.width()*10.2,
 					   row_rect.height()), Qt::AlignLeft | Qt::AlignVCenter, title);
 	x += colWidths[1]*row_rect.width();
-
-	if (origFontMetrics.width(author) > 0.95*colWidths[2]*row_rect.width())
-		workingFont.setPointSizeF(origFontSize * 0.95*colWidths[2]*row_rect.width() / origFontMetrics.width(author));
+	
+	
+	if (origFontMetrics.width(machine) > 0.95*colWidths[2]*row_rect.width())
+		workingFont.setPointSizeF(origFontSize * 0.95*colWidths[2]*row_rect.width() / origFontMetrics.width(machine));
 	else
 		workingFont.setPointSizeF(origFontSize);
 	qp -> setFont(workingFont);
-	qp -> drawText(QRectF(x, y, colWidths[2]*row_rect.width(), row_rect.height()), Qt::AlignCenter, author);
+	qp -> drawText(QRectF(x, y, colWidths[3]*row_rect.width(), row_rect.height()), Qt::AlignCenter, machine);
 	x += colWidths[2]*row_rect.width();
-
-	if (origFontMetrics.width(date) > 0.95*colWidths[3]*row_rect.width())
-		workingFont.setPointSizeF(origFontSize * 0.95*colWidths[3]*row_rect.width() / origFontMetrics.width(date));
+	
+	
+	if (origFontMetrics.width(loc) > 0.95*colWidths[3]*row_rect.width())
+		workingFont.setPointSizeF(origFontSize * 0.95*colWidths[3]*row_rect.width() / origFontMetrics.width(loc));
 	else
 		workingFont.setPointSizeF(origFontSize);
 	qp -> setFont(workingFont);
-	qp -> drawText(QRectF(x, y, colWidths[3]*row_rect.width(), row_rect.height()), Qt::AlignCenter, date);
+	qp -> drawText(QRectF(x, y, colWidths[3]*row_rect.width(), row_rect.height()), Qt::AlignCenter, loc);
+	x += colWidths[3]*row_rect.width();
+	
+	
+	if (origFontMetrics.width(indexrev) > 0.95*colWidths[4]*row_rect.width())
+		workingFont.setPointSizeF(origFontSize * 0.95*colWidths[4]*row_rect.width() / origFontMetrics.width(indexrev));
+	else
+		workingFont.setPointSizeF(origFontSize);
+	qp -> setFont(workingFont);
+	qp -> drawText(QRectF(x, y, colWidths[4]*row_rect.width(), row_rect.height()), Qt::AlignCenter, indexrev);
+	x += colWidths[4]*row_rect.width();
+	
+	
+	
+
+	if (origFontMetrics.width(author) > 0.95*colWidths[5]*row_rect.width())
+		workingFont.setPointSizeF(origFontSize * 0.95*colWidths[5]*row_rect.width() / origFontMetrics.width(author));
+	else
+		workingFont.setPointSizeF(origFontSize);
+	qp -> setFont(workingFont);
+	qp -> drawText(QRectF(x, y, colWidths[6]*row_rect.width(), row_rect.height()), Qt::AlignCenter, author);
+	x += colWidths[5]*row_rect.width();
+	
+
+	if (origFontMetrics.width(date) > 0.95*colWidths[6]*row_rect.width())
+		workingFont.setPointSizeF(origFontSize * 0.95*colWidths[6]*row_rect.width() / origFontMetrics.width(date));
+	else
+		workingFont.setPointSizeF(origFontSize);
+	qp -> setFont(workingFont);
+	qp -> drawText(QRectF(x, y, colWidths[6]*row_rect.width(), row_rect.height()), Qt::AlignCenter, date);
 }
 
 void DiagramFolioList::buildGrid(QPainter *qp, const QRectF &rect, int rows, int tables, qreal colWidths[])
@@ -178,18 +219,18 @@ void DiagramFolioList::buildGrid(QPainter *qp, const QRectF &rect, int rows, int
 	qDeleteAll (list_rectangles_);
 	list_rectangles_.clear();
 
-	qreal sum = 0;
-	for (int i = 0; i < 4; i++ )
-		sum += colWidths[i];
-	if ( sum < 0.99 || sum > 1.01 ) {
-		qDebug() << "Invalid input: Column widths do not sum to 1";
-		return;
-	}
+    qreal sum = 0;
+    for (int i = 0; i < 7; i++ )
+        sum += colWidths[i];
+    if ( sum < 0.99 || sum > 1.01 ) {
+        qDebug() << "Invalid input: Column widths do not sum to 1";
+        return;
+    }
 
-	qreal tablesSpacing = rect.height() * 0.02;
+    qreal tablesSpacing = rect.height() * 0.02;
 	qreal tableWidth = (rect.width() - tablesSpacing*(tables+1) ) / tables;
 	qreal rowHeight = (rect.height() - 2*tablesSpacing) / rows;
-	int cols = 4;//colWidths.size();
+	int cols = 7;//colWidths.size();
 
 	qreal x0 = tablesSpacing + rect.topLeft().x();
 	qreal y0 = tablesSpacing + rect.topLeft().y();
@@ -223,10 +264,13 @@ void DiagramFolioList::fillHeader(QPainter *qp, const QRectF &row_RectF) {
 	QString authorTranslatable(QObject::tr("Auteur"));
 	QString titleTranslatable(QObject::tr("Titre"));
 	QString folioTranslatable(QObject::tr("Folio"));
+	QString machineTranslatable(QObject::tr("Installation"));
+	QString locTranslatable(QObject::tr("Localisation"));
+	QString indexrevTranslatable(QObject::tr("Rev"));
 	QString dateTranslatable(QObject::tr("Date"));
 
 	qp->save();
 	qp->setFont(QETApp::diagramTextsFont(13));
-	fillRow(qp, row_RectF, authorTranslatable, titleTranslatable, folioTranslatable, dateTranslatable);
+	fillRow(qp, row_RectF, authorTranslatable, titleTranslatable, folioTranslatable, machineTranslatable, locTranslatable, indexrevTranslatable, dateTranslatable);
 	qp->restore();
 }
