@@ -1,17 +1,17 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
-	
+
 	QElectroTech is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
 	the Free Software Foundation, either version 2 of the License, or
 	(at your option) any later version.
-	
+
 	QElectroTech is distributed in the hope that it will be useful,
 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 	GNU General Public License for more details.
-	
+
 	You should have received a copy of the GNU General Public License
 	along with QElectroTech.  If not, see <http://www.gnu.org/licenses/>.
 */
@@ -30,7 +30,7 @@
 #include "templatelocation.h"
 #include "qetapp.h"
 #include "qetproject.h"
-#include "integrationmoveelementshandler.h"
+#include "projectview.h"
 #include "integrationmovetemplateshandler.h"
 #include "qetdiagrameditor.h"
 #include "qeticons.h"
@@ -44,6 +44,7 @@
 #include "dveventinterface.h"
 #include "diagrameventaddelement.h"
 #include "QPropertyUndoCommand/qpropertyundocommand.h"
+#include "qetshapeitem.h"
 
 /**
 	Constructeur
@@ -67,12 +68,12 @@ DiagramView::DiagramView(Diagram *diagram, QWidget *parent) :
 		"\"What's this?\" tip"
 	);
 	setWhatsThis(whatsthis);
-	
+
 	// active l'antialiasing
 	setRenderHint(QPainter::Antialiasing, true);
 	setRenderHint(QPainter::TextAntialiasing, true);
 	setRenderHint(QPainter::SmoothPixmapTransform, true);
-	
+
 	setScene(scene);
 	scene -> undoStack().setClean();
 	setWindowIcon(QET::Icons::QETLogo);
@@ -82,23 +83,20 @@ DiagramView::DiagramView(Diagram *diagram, QWidget *parent) :
 	setSelectionMode();
 	adjustSceneRect();
 	updateWindowTitle();
-	
+	scene->loadElmtFolioSeq();
+	scene->loadCndFolioSeq();
+
 	context_menu = new QMenu(this);
 	paste_here = new QAction(QET::Icons::EditPaste, tr("Coller ici", "context menu action"), this);
 	connect(paste_here, SIGNAL(triggered()), this, SLOT(pasteHere()));
-	
+
 	connect(scene, SIGNAL(showDiagram(Diagram*)), this, SIGNAL(showDiagram(Diagram*)));
 	connect(scene, SIGNAL(selectionChanged()), this, SIGNAL(selectionChanged()));
 	connect(scene, SIGNAL(sceneRectChanged(QRectF)), this, SLOT(adjustSceneRect()));
 	connect(&(scene -> border_and_titleblock), SIGNAL(diagramTitleChanged(const QString &)), this, SLOT(updateWindowTitle()));
 	connect(diagram, SIGNAL(editElementRequired(ElementsLocation)), this, SIGNAL(editElementRequired(ElementsLocation)));
 	connect(diagram, SIGNAL(findElementRequired(ElementsLocation)), this, SIGNAL(findElementRequired(ElementsLocation)));
-	
-	connect(
-		this, SIGNAL(aboutToSetDroppedTitleBlockTemplate(const TitleBlockTemplateLocation &)),
-		this, SLOT(setDroppedTitleBlockTemplate(const TitleBlockTemplateLocation &)),
-		Qt::QueuedConnection
-	);
+
 	QShortcut *edit_conductor_color_shortcut = new QShortcut(QKeySequence(Qt::Key_F2), this);
 	connect(edit_conductor_color_shortcut, SIGNAL(activated()), this, SLOT(editSelectedConductorColor()));
 }
@@ -146,7 +144,7 @@ void DiagramView::deleteSelection() {
 */
 void DiagramView::rotateSelection() {
 	if (scene -> isReadOnly()) return;
-	
+
 	// recupere les elements et les champs de texte a pivoter
 	QList<Element *> elements_to_rotate;
 	QList<DiagramTextItem *> texts_to_rotate;
@@ -167,7 +165,7 @@ void DiagramView::rotateSelection() {
 			images_to_rotate << dii;
 		}
 	}
-	
+
 	// effectue les rotations s'il y a quelque chose a pivoter
 	if (elements_to_rotate.isEmpty() && texts_to_rotate.isEmpty() && images_to_rotate.isEmpty()) return;
 	scene -> undoStack().push(new RotateElementsCommand(elements_to_rotate, texts_to_rotate, images_to_rotate));
@@ -175,7 +173,7 @@ void DiagramView::rotateSelection() {
 
 void DiagramView::rotateTexts() {
 	if (scene -> isReadOnly()) return;
-	
+
 	// recupere les champs de texte a orienter
 	QList<DiagramTextItem *> texts_to_rotate;
 	foreach (QGraphicsItem *item, scene -> selectedItems()) {
@@ -188,10 +186,10 @@ void DiagramView::rotateTexts() {
 			texts_to_rotate << eti;
 		}
 	}
-	
+
 	// effectue les rotations s'il y a quelque chose a pivoter
 	if (texts_to_rotate.isEmpty()) return;
-	
+
 	// demande un angle a l'utilisateur
 	QDialog ori_text_dialog(diagramEditor());
 	ori_text_dialog.setSizeGripEnabled(false);
@@ -200,27 +198,27 @@ void DiagramView::rotateTexts() {
 #endif
 	ori_text_dialog.setWindowTitle(tr("Orienter les textes sélectionnés", "window title"));
 // 	ori_text_dialog.setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);
-	
-	
+
+
 	QTextOrientationSpinBoxWidget *ori_widget = QETApp::createTextOrientationSpinBoxWidget();
 	ori_widget -> setParent(&ori_text_dialog);
 	if (texts_to_rotate.count() == 1) {
 		ori_widget -> setOrientation(texts_to_rotate.at(0) -> rotationAngle());
 	}
 	ori_widget -> spinBox() -> selectAll();
-	
+
 	// boutons
 	QDialogButtonBox buttons(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
 	connect(&buttons, SIGNAL(accepted()), &ori_text_dialog, SLOT(accept()));
 	connect(&buttons, SIGNAL(rejected()), &ori_text_dialog, SLOT(reject()));
-	
+
 	// ajout dans une disposition verticale
 	QVBoxLayout layout_v(&ori_text_dialog);
 	layout_v.setSizeConstraint(QLayout::SetFixedSize);
 	layout_v.addWidget(ori_widget);
 	layout_v.addStretch();
 	layout_v.addWidget(&buttons);
-	
+
 	// si le dialogue est accepte
 	if (ori_text_dialog.exec() == QDialog::Accepted) {
 		scene -> undoStack().push(new RotateTextsCommand(texts_to_rotate, ori_widget -> orientation()));
@@ -261,7 +259,7 @@ void DiagramView::dragMoveEvent(QDragMoveEvent *e) {
 }
 
 /**
-	Handle the drops accepted on diagram (elements and title block templates). 
+	Handle the drops accepted on diagram (elements and title block templates).
 	@param e the QDropEvent describing the current drag'n drop
 */
 void DiagramView::dropEvent(QDropEvent *e) {
@@ -279,31 +277,68 @@ void DiagramView::dropEvent(QDropEvent *e) {
 	Handle the drop of an element.
 	@param e the QDropEvent describing the current drag'n drop
 */
-void DiagramView::handleElementDrop(QDropEvent *e) {
-	// fetch the element location from the drop event
-	QString elmt_path = e -> mimeData() -> text();
-	
-	ElementsLocation location(ElementsLocation::locationFromString(elmt_path));
-	
-	// verifie qu'il existe un element correspondant a cet emplacement
-	ElementsCollectionItem *dropped_item = QETApp::collectionItem(location);
-	if (!dropped_item) return;
+void DiagramView::handleElementDrop(QDropEvent *event)
+{
+		//Build an element from the text of the mime data
+	ElementsLocation location(event->mimeData()->text());
 
-	diagram()->setEventInterface(new DiagramEventAddElement(location, diagram(), mapToScene(e->pos())));
+	if ( !(location.isElement() && location.exist()) )
+	{
+		qDebug() << "DiagramView::handleElementDrop, location can't be use : " << location;
+		return;
+	}
+
+	diagram()->setEventInterface(new DiagramEventAddElement(location, diagram(), mapToScene(event->pos())));
 		//Set focus to the view to get event
 	this->setFocus();
 }
 
 /**
-	Handle the drop of an element.
-	@param e the QDropEvent describing the current drag'n drop
-*/
+ * @brief DiagramView::handleTitleBlockDrop
+ * Handle the dropEvent that contain data of a titleblock
+ * @param e
+ */
 void DiagramView::handleTitleBlockDrop(QDropEvent *e) {
-	// fetch the title block template location from the drop event
+		// fetch the title block template location from the drop event
 	TitleBlockTemplateLocation tbt_loc;
-	tbt_loc.fromString(e -> mimeData() -> text());
-	if (tbt_loc.isValid()) {
-		emit(aboutToSetDroppedTitleBlockTemplate(tbt_loc));
+	tbt_loc.fromString(e->mimeData()->text());
+
+
+	if (tbt_loc.isValid())
+	{
+			// fetch the current title block properties
+		TitleBlockProperties titleblock_properties_before = scene->border_and_titleblock.exportTitleBlock();
+
+			// check the provided template is not already applied
+		QETProject *tbt_parent_project = tbt_loc.parentProject();
+		if (tbt_parent_project && tbt_parent_project == scene -> project())
+		{
+				// same parent project and same name = same title block template
+			if (tbt_loc.name() == titleblock_properties_before.template_name)
+				return;
+		}
+
+			// integrate the provided template into the project if needed
+		QString integrated_template_name = tbt_loc.name();
+		if (mustIntegrateTitleBlockTemplate(tbt_loc))
+		{
+			IntegrationMoveTitleBlockTemplatesHandler *handler = new IntegrationMoveTitleBlockTemplatesHandler(this);
+			//QString error_message;
+			integrated_template_name = scene->project()->integrateTitleBlockTemplate(tbt_loc, handler);
+
+			if (integrated_template_name.isEmpty())
+				return;
+		}
+
+			// apply the provided title block template
+		if (titleblock_properties_before.template_name == integrated_template_name)
+			return;
+
+		TitleBlockProperties titleblock_properties_after = titleblock_properties_before;
+		titleblock_properties_after.template_name = integrated_template_name;
+		scene->undoStack().push(new ChangeTitleBlockCommand(scene, titleblock_properties_before, titleblock_properties_after));
+
+		adjustSceneRect();
 	}
 }
 
@@ -353,8 +388,9 @@ void DiagramView::setSelectionMode() {
  */
 void DiagramView::zoom(const qreal zoom_factor)
 {
-	if (zoom_factor >= 1)
+	if (zoom_factor >= 1){
 		scale(zoom_factor, zoom_factor);
+	}
 	else
 	{
 		QSettings settings;
@@ -362,6 +398,7 @@ void DiagramView::zoom(const qreal zoom_factor)
 			(horizontalScrollBar()->maximum() || verticalScrollBar()->maximum()) )
 			scale(zoom_factor, zoom_factor);
 	}
+	scene->adjustSceneRect();
 	adjustGridToZoom();
 }
 
@@ -420,23 +457,25 @@ void DiagramView::copy() {
 */
 void DiagramView::paste(const QPointF &pos, QClipboard::Mode clipboard_mode) {
 	if (!isInteractive() || scene -> isReadOnly()) return;
-	
+
 	QString texte_presse_papier = QApplication::clipboard() -> text(clipboard_mode);
 	if ((texte_presse_papier).isEmpty()) return;
-	
+
 	QDomDocument document_xml;
 	if (!document_xml.setContent(texte_presse_papier)) return;
-	
+
 	// objet pour recuperer le contenu ajoute au schema par le coller
 	DiagramContent content_pasted;
+	this->diagram()->item_paste = true;
 	scene -> fromXml(document_xml, pos, false, &content_pasted);
-	
+
 	// si quelque chose a effectivement ete ajoute au schema, on cree un objet d'annulation
 	if (content_pasted.count()) {
 		scene -> clearSelection();
 		scene -> undoStack().push(new PasteDiagramCommand(scene, content_pasted));
 		adjustSceneRect();
 	}
+	this->diagram()->item_paste = false;
 }
 
 /**
@@ -588,7 +627,70 @@ void DiagramView::focusInEvent(QFocusEvent *e) {
 */
 void DiagramView::keyPressEvent(QKeyEvent *e) {
 	if (m_event_interface && m_event_interface->keyPressEvent(e)) return;
-
+	ProjectView *current_project = this->diagramEditor()->acessCurrentProject();
+switch(e -> key())
+	{
+		case Qt::Key_PageUp:
+			current_project->changeTabUp();
+			return;
+		case Qt::Key_PageDown:
+			current_project->changeTabDown();
+			return;
+		case Qt::Key_Home:
+			if (!hasTextItems()) {
+				if (
+					qgraphicsitem_cast<IndependentTextItem *>(scene->focusItem()) ||
+					qgraphicsitem_cast<ElementTextItem *>(scene->focusItem()) ||
+					qgraphicsitem_cast<ConductorTextItem *>(scene->focusItem()) ||
+					qgraphicsitem_cast<DiagramTextItem *>(scene->focusItem())
+					)
+					break;
+				current_project->changeFirstTab();
+				return;
+			}
+			else break;
+		case Qt::Key_End:
+			if (!hasTextItems()) {
+				if (
+					qgraphicsitem_cast<IndependentTextItem *>(scene->focusItem()) ||
+					qgraphicsitem_cast<ElementTextItem *>(scene->focusItem()) ||
+					qgraphicsitem_cast<ConductorTextItem *>(scene->focusItem()) ||
+					qgraphicsitem_cast<DiagramTextItem *>(scene->focusItem())
+					)
+					break;
+				current_project->changeLastTab();
+				return;
+			}
+			else break;
+		case Qt::Key_ZoomOut:
+			zoom(0.85);
+			return;
+		case Qt::Key_ZoomIn:
+			zoom(1.15);
+			return;
+		case Qt::Key_Minus:
+			if (e->modifiers() & Qt::ControlModifier)
+				zoom(0.85);
+		case Qt::Key_Plus:
+			if (e->modifiers() & Qt::ControlModifier)
+				zoom(1.15);
+		case Qt::Key_Up:
+			if(!(scene->selectedContent().items(255).isEmpty())){
+				scrollOnMovement(e);
+			}
+		case Qt::Key_Down:
+			if(!(scene->selectedContent().items(255).isEmpty())){
+				scrollOnMovement(e);
+			}
+		case Qt::Key_Left:
+			if(!(scene->selectedContent().items(255).isEmpty())){
+				scrollOnMovement(e);
+			}
+		case Qt::Key_Right:
+			if(!(scene->selectedContent().items(255).isEmpty())){
+				scrollOnMovement(e);
+			}
+	}
 	switchToVisualisationModeIfNeeded(e);
 	QGraphicsView::keyPressEvent(e);
 }
@@ -604,6 +706,65 @@ void DiagramView::keyReleaseEvent(QKeyEvent *e) {
 	QGraphicsView::keyReleaseEvent(e);
 }
 
+/**
+	Handles element movement when editor is zoomed in and scrolls vertical
+	and horizontal bar. If element is moved to the right side of the editor
+	or below the editor SceneRect is expanded
+*/
+void DiagramView::scrollOnMovement(QKeyEvent *e){
+			QList<QGraphicsItem *> selected_elmts = scene->selectedContent().items(255);
+			QRectF viewed_scene = viewedSceneRect();
+			foreach (QGraphicsItem *qgi, selected_elmts){
+				if (qgraphicsitem_cast<Conductor *>(qgi)) continue;
+				if (qgraphicsitem_cast<QetShapeItem *>(qgi)) continue;
+				qreal x = qgi->pos().x();
+				qreal y = qgi->pos().y();
+				qreal bottom = viewed_scene.bottom();
+				qreal top = viewed_scene.top();
+				qreal left = viewed_scene.left();
+				qreal right = viewed_scene.right();
+				qreal elmt_top = y + qgi->boundingRect().top();
+				qreal elmt_bottom = y + qgi->boundingRect().bottom();
+				qreal elmt_right = x + qgi->boundingRect().right();
+				qreal elmt_left = x + qgi->boundingRect().left();
+				bool elmt_right_of_left_margin = elmt_left>=left;
+				bool elmt_left_of_right_margin = elmt_right<=right;
+				bool elmt_below_top_margin = elmt_top>=top;
+				bool elmt_above_bottom_margin = elmt_bottom<=bottom;
+				if (!(elmt_right_of_left_margin && elmt_left_of_right_margin) ||
+					!(elmt_below_top_margin    && elmt_above_bottom_margin )  ) {
+						QScrollBar *h = horizontalScrollBar();
+						QScrollBar *v = verticalScrollBar();
+						int h_increment=0;
+						int v_increment=0;
+						if (e->key()==Qt::Key_Up && elmt_above_bottom_margin) {
+							v_increment = 2*qgi->boundingRect().top();
+							if (v_increment == 0) v_increment = -2*qgi->boundingRect().height();
+						}
+						else if(e->key()==Qt::Key_Down && elmt_below_top_margin) {
+							v_increment = 2*qgi->boundingRect().bottom();
+							if (v_increment == 0) v_increment = -2*qgi->boundingRect().height();
+						}
+						else if (e->key()==Qt::Key_Left && elmt_left_of_right_margin) {
+							h_increment = 2*qgi->boundingRect().left();
+							if (h_increment == 0) h_increment = -2*qgi->boundingRect().width();
+						}
+						else if (e->key()==Qt::Key_Right && elmt_right_of_left_margin) {
+							h_increment = 2*qgi->boundingRect().right();
+							if (h_increment == 0) h_increment = -2*qgi->boundingRect().width();
+						}
+						if (((elmt_right  >= scene->sceneRect().right() -  qgi->boundingRect().right())  ||
+							(elmt_bottom >= scene->sceneRect().bottom() - qgi->boundingRect().bottom())) &&
+							(e->key()==Qt::Key_Right || e->key()==Qt::Key_Down)){
+							scene->adjustSceneRect();
+						}
+						h -> setValue(h -> value() + h_increment);
+						v -> setValue(v -> value() + v_increment);
+				}
+			}
+}
+
+
 /**
 	@return le titre de cette vue ; cela correspond au titre du schema
 	visualise precede de la mention "Schema". Si le titre du schema est vide,
@@ -654,6 +815,23 @@ bool DiagramView::hasCopiableItems() {
 	return(false);
 }
 
+/**
+	@return true if there is any Text Item selected
+*/
+bool DiagramView::hasTextItems() {
+	foreach(QGraphicsItem *qgi, scene -> selectedItems()) {
+		if (
+			qgraphicsitem_cast<IndependentTextItem *>(qgi) ||
+			qgraphicsitem_cast<ElementTextItem *>(qgi) ||
+			qgraphicsitem_cast<ConductorTextItem *>(qgi) ||
+			qgraphicsitem_cast<DiagramTextItem *>(qgi)
+		) {
+			return(true);
+		}
+	}
+	return(false);
+}
+
 /**
 	@return true s'il y a des items selectionnes sur le schema et que ceux-ci
 	peuvent etre supprimes, false sinon
@@ -741,7 +919,10 @@ void DiagramView::updateWindowTitle() {
 */
 void DiagramView::adjustGridToZoom() {
 	QRectF viewed_scene = viewedSceneRect();
-	scene -> setDisplayGrid(viewed_scene.width() < 2000 || viewed_scene.height() < 2000);
+	if (diagramEditor()->drawGrid())
+		scene->setDisplayGrid(viewed_scene.width() < 2000 || viewed_scene.height() < 2000);
+	else
+		scene->setDisplayGrid(false);
 }
 
 /**
@@ -750,14 +931,14 @@ void DiagramView::adjustGridToZoom() {
 QRectF DiagramView::viewedSceneRect() const {
 	// recupere la taille du widget viewport
 	QSize viewport_size = viewport() -> size();
-	
+
 	// recupere la transformation viewport -> scene
 	QTransform view_to_scene   = viewportTransform().inverted();
-	
+
 	// mappe le coin superieur gauche et le coin inferieur droit de la viewport sur la scene
 	QPointF scene_left_top     = view_to_scene.map(QPointF(0.0, 0.0));
 	QPointF scene_right_bottom = view_to_scene.map(QPointF(viewport_size.width(), viewport_size.height()));
-	
+
 	// en deduit le rectangle visualise par la scene
 	return(QRectF(scene_left_top, scene_right_bottom));
 }
@@ -772,7 +953,7 @@ bool DiagramView::mustIntegrateTitleBlockTemplate(const TitleBlockTemplateLocati
 	// unlike elements, the integration of title block templates is mandatory, so we simply check whether the parent project of the template is also the parent project of the diagram
 	QETProject *tbt_parent_project = tbt_loc.parentProject();
 	if (!tbt_parent_project) return(true);
-	
+
 	return(tbt_parent_project != scene -> project());
 }
 
@@ -782,7 +963,7 @@ bool DiagramView::mustIntegrateTitleBlockTemplate(const TitleBlockTemplateLocati
 */
 void DiagramView::applyReadOnly() {
 	if (!scene) return;
-	
+
 	bool is_writable = !scene -> isReadOnly();
 	setInteractive(is_writable);
 	setAcceptDrops(is_writable);
@@ -794,11 +975,11 @@ void DiagramView::applyReadOnly() {
 void DiagramView::editSelectionProperties() {
 	// get selection
 	DiagramContent selection = scene -> selectedContent();
-	
+
 	// if selection contains nothing return
 	int selected_items_count = selection.count(DiagramContent::All | DiagramContent::SelectedOnly);
 	if (!selected_items_count) return;
-	
+
 	// if selection contains one item and this item can be editable, edit this item with an appropriate dialog
 	if (selected_items_count == 1 && selection.items(DiagramContent::Elements |
 													 DiagramContent::AnyConductor |
@@ -810,7 +991,7 @@ void DiagramView::editSelectionProperties() {
 		else if (selection.elements.size())
 			selection.elements.toList().first() -> editProperty();
 	}
-	
+
 	else {
 		QET::QetMessageBox::information(
 			this,
@@ -831,7 +1012,7 @@ void DiagramView::editSelectionProperties() {
 void DiagramView::editSelectedConductorColor() {
 	// retrieve selected content
 	DiagramContent selection = scene -> selectedContent();
-	
+
 	// we'll focus on the selected conductor (we do not handle multiple conductors edition)
 	QList<Conductor *> selected_conductors = selection.conductors(DiagramContent::AnyConductor | DiagramContent::SelectedOnly);
 	if (selected_conductors.count() == 1) {
@@ -846,10 +1027,10 @@ void DiagramView::editSelectedConductorColor() {
 void DiagramView::editConductorColor(Conductor *edited_conductor)
 {
 	if (scene -> isReadOnly() || !edited_conductor) return;
-	
+
 		// store the initial properties of the provided conductor
 	ConductorProperties initial_properties = edited_conductor -> properties();
-	
+
 		// prepare a color dialog showing the initial conductor color
 	QColorDialog *color_dialog = new QColorDialog(this);
 	color_dialog -> setWindowTitle(tr("Choisir la nouvelle couleur de ce conducteur"));
@@ -857,7 +1038,7 @@ void DiagramView::editConductorColor(Conductor *edited_conductor)
 	color_dialog -> setWindowFlags(Qt::Sheet);
 #endif
 	color_dialog -> setCurrentColor(initial_properties.color);
-	
+
 		// asks the user what color he wishes to apply
 	if (color_dialog -> exec() == QDialog::Accepted)
 	{
@@ -884,7 +1065,7 @@ void DiagramView::resetConductors() {
 	if (scene -> isReadOnly()) return;
 	// recupere les conducteurs selectionnes
 	QSet<Conductor *> selected_conductors = scene -> selectedConductors();
-	
+
 	// repere les conducteurs modifies (= profil non nul)
 	QHash<Conductor *, ConductorProfilesGroup> conductors_and_profiles;
 	foreach(Conductor *conductor, selected_conductors) {
@@ -898,7 +1079,7 @@ void DiagramView::resetConductors() {
 			conductors_and_profiles.insert(conductor, profile);
 		}
 	}
-	
+
 	if (conductors_and_profiles.isEmpty()) return;
 	scene -> undoStack().push(new ResetConductorCommand(conductors_and_profiles));
 }
@@ -1042,7 +1223,7 @@ void DiagramView::contextMenuEvent(QContextMenuEvent *e) {
 		if (!qgi -> isSelected()) scene -> clearSelection();
 		qgi -> setSelected(true);
 	}
-	
+
 	if (QETDiagramEditor *qde = diagramEditor()) {
 		context_menu -> clear();
 		if (scene -> selectedItems().isEmpty()) {
@@ -1060,7 +1241,7 @@ void DiagramView::contextMenuEvent(QContextMenuEvent *e) {
 			context_menu -> addSeparator();
 			context_menu -> addActions(qde -> m_selection_actions_group.actions());
 		}
-		
+
 		// affiche le menu contextuel
 		context_menu -> popup(e -> globalPos());
 	}
@@ -1089,10 +1270,10 @@ void DiagramView::mouseDoubleClickEvent(QMouseEvent *e)
 	if (m_event_interface && m_event_interface -> mouseDoubleClickEvent(e)) return;
 
 	BorderTitleBlock &bi = scene -> border_and_titleblock;
-	
+
 	//Get the click pos on the diagram
 	QPointF click_pos = viewportTransform().inverted().map(e -> pos());
-	
+
 	if (bi.titleBlockRect().contains(click_pos) || bi.columnsRect().contains(click_pos) || bi.rowsRect().contains(click_pos)) {
 		e->accept();
 		editDiagramProperties();
@@ -1100,34 +1281,3 @@ void DiagramView::mouseDoubleClickEvent(QMouseEvent *e)
 	}
 	QGraphicsView::mouseDoubleClickEvent(e);
 }
-
-/**
-	@param tbt TitleBlockTemplateLocation
-*/
-void DiagramView::setDroppedTitleBlockTemplate(const TitleBlockTemplateLocation &tbt) {
-	// fetch the current title block properties
-	TitleBlockProperties titleblock_properties_before = scene -> border_and_titleblock.exportTitleBlock();
-	
-	// check the provided template is not already applied
-	QETProject *tbt_parent_project = tbt.parentProject();
-	if (tbt_parent_project && tbt_parent_project == scene -> project()) {
-		// same parent project and same name = same title block template
-		if (tbt.name() == titleblock_properties_before.template_name) return;
-	}
-	
-	// integrate the provided template into the project if needed
-	QString integrated_template_name = tbt.name();
-	if (mustIntegrateTitleBlockTemplate(tbt)) {
-		IntegrationMoveTitleBlockTemplatesHandler *handler = new IntegrationMoveTitleBlockTemplatesHandler(this);
-		//QString error_message;
-		integrated_template_name = scene -> project() -> integrateTitleBlockTemplate(tbt, handler);
-		if (integrated_template_name.isEmpty()) return;
-	}
-	
-	// apply the provided title block template
-	if (titleblock_properties_before.template_name == integrated_template_name) return;
-	TitleBlockProperties titleblock_properties_after = titleblock_properties_before;
-	titleblock_properties_after.template_name = integrated_template_name;
-	scene -> undoStack().push(new ChangeTitleBlockCommand(scene, titleblock_properties_before, titleblock_properties_after));
-	adjustSceneRect();
-}
