@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -42,10 +42,10 @@ ArcEditor::ArcEditor(QETElementEditor *editor, PartArc *arc, QWidget *parent) :
 	start_angle -> setRange(-360, 360);
 	angle       -> setRange(-360, 360);
 	
-	x->setRange(-1000, 1000);
-	y->setRange(-1000, 1000);
-	h->setRange(-1000, 1000);
-	v->setRange(-1000, 1000);
+	x->setRange(-5000, 5000);
+	y->setRange(-5000, 5000);
+	h->setRange(-5000, 5000);
+	v->setRange(-5000, 5000);
 	
 	QVBoxLayout *v_layout = new QVBoxLayout(this);
 	
@@ -135,7 +135,7 @@ void ArcEditor::updateArcS()
 {
 	if (m_locked) return;
 	m_locked = true;
-	double value = ((start_angle -> value() * -1) + 90) * 16;
+	double value = start_angle->value() * 16;
 
 	if (value != part->property("startAngle"))
 	{
@@ -156,7 +156,7 @@ void ArcEditor::updateArcA()
 {
 	if (m_locked) return;
 	m_locked = true;
-	double value = angle -> value() * -16;
+	double value = angle->value() * 16;
 
 	if (value != part->property("spanAngle"))
 	{
@@ -204,8 +204,8 @@ void ArcEditor::updateForm()
 	y->setValue(part->mapToScene(rect.topLeft()).y() + (rect.height()/2));
 	h->setValue(rect.width());
 	v->setValue(rect.height());
-	start_angle -> setValue(((part->property("startAngle").toInt() / 16) - 90) * -1);
-	angle -> setValue(part->property("spanAngle").toInt() / -16);
+	start_angle->setValue(part->property("startAngle").toInt()/16);
+	angle->setValue(part->property("spanAngle").toInt()/16);
 	activeConnections(true);
 }
 
