@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -32,7 +32,9 @@
 #include "nameslist.h"
 #include "ui/elementpropertieseditorwidget.h"
 #include "eseventinterface.h"
+#include "QetGraphicsItemModeler/qetgraphicshandleritem.h"
 
+#include <algorithm>
 #include <QKeyEvent>
 
 /**
@@ -43,25 +45,41 @@
 ElementScene::ElementScene(QETElementEditor *editor, QObject *parent) :
 	QGraphicsScene(parent),
 	m_elmt_type("simple"),
-	qgi_manager(this),
-	m_event_interface(nullptr),
-	element_editor(editor),
-	decorator_(0)
+	m_qgi_manager(this),
+	m_element_editor(editor)
 {
-	behavior = Normal;
+	
+	setItemIndexMethod(QGraphicsScene::NoIndex);
+		//Set to no index, because they can be the source of the crash with conductor and shape ghost.
+		//https://forum.qt.io/topic/71316/qgraphicsscenefinditembsptreevisitor-visit-crashes-due-to-an-obsolete-paintevent-after-qgraphicsscene-removeitem
+		//https://stackoverflow.com/questions/38458830/crash-after-qgraphicssceneremoveitem-with-custom-item-class
+		//http://www.qtcentre.org/archive/index.php/t-33730.html
+		//http://tech-artists.org/t/qt-properly-removing-qgraphicitems/3063
+	
+	m_behavior = Normal;
 	setItemIndexMethod(NoIndex);
 	setGrid(1, 1);
 	initPasteArea();
-	undo_stack.setClean();
-	decorator_lock_ = new QMutex(QMutex::NonRecursive);
-	connect(&undo_stack, SIGNAL(indexChanged(int)), this, SLOT(managePrimitivesGroups()));
+	m_undo_stack.setClean();
+	m_decorator_lock = new QMutex(QMutex::NonRecursive);
+	connect(&m_undo_stack, SIGNAL(indexChanged(int)), this, SLOT(managePrimitivesGroups()));
 	connect(this, SIGNAL(selectionChanged()), this, SLOT(managePrimitivesGroups()));
 }
 
-/// Destructeur
-ElementScene::~ElementScene() {
-	delete decorator_lock_;
-	if (m_event_interface) delete m_event_interface;
+/**
+ * @brief ElementScene::~ElementScene
+ */
+ElementScene::~ElementScene()
+{
+		//Disconnect to avoid crash, see bug report N° 122.
+	disconnect(&m_undo_stack, SIGNAL(indexChanged(int)), this, SLOT(managePrimitivesGroups()));
+	delete m_decorator_lock;
+
+	if (m_event_interface)
+		delete m_event_interface;
+
+	if (m_decorator)
+		delete m_decorator;
 }
 
 /**
@@ -83,10 +101,10 @@ void ElementScene::mouseMoveEvent(QGraphicsSceneMouseEvent *e) {
 	if (!(e -> modifiers() & Qt::ControlModifier))
 		event_pos = snapToGrid(event_pos);
 	
-	if (behavior == PasteArea) {
-		QRectF current_rect(paste_area_ -> rect());
+	if (m_behavior == PasteArea) {
+		QRectF current_rect(m_paste_area -> rect());
 		current_rect.moveCenter(event_pos);
-		paste_area_ -> setRect(current_rect);
+		m_paste_area -> setRect(current_rect);
 		return;
 	}
 
@@ -126,11 +144,11 @@ void ElementScene::mouseReleaseEvent(QGraphicsSceneMouseEvent *e) {
 		}
 	}
 	
-	if (behavior == PasteArea) {
-		defined_paste_area_ = paste_area_ -> rect();
-		removeItem(paste_area_);
-		emit(pasteAreaDefined(defined_paste_area_));
-		behavior = Normal;
+	if (m_behavior == PasteArea) {
+		m_defined_paste_area = m_paste_area -> rect();
+		removeItem(m_paste_area);
+		emit(pasteAreaDefined(m_defined_paste_area));
+		m_behavior = Normal;
 		return;
 	}
 
@@ -180,8 +198,8 @@ void ElementScene::keyPressEvent(QKeyEvent *event) {
  */
 void ElementScene::contextMenuEvent(QGraphicsSceneContextMenuEvent *event)
 {
-	if (behavior == ElementScene::Normal)
-		element_editor -> contextMenu(event->screenPos());
+	if (m_behavior == ElementScene::Normal)
+		m_element_editor -> contextMenu(event->screenPos());
 }
 
 /**
@@ -212,8 +230,10 @@ void ElementScene::drawForeground(QPainter *p, const QRectF &rect) {
  * Set a new event interface
  * @param interface
  */
-void ElementScene::setEventInterface(ESEventInterface *event_interface) {
-	if (m_event_interface) {
+void ElementScene::setEventInterface(ESEventInterface *event_interface)
+{
+	if (m_event_interface)
+	{
 		delete m_event_interface;
 		//We must to re-init because previous interface
 		//Reset his own init when deleted
@@ -222,6 +242,19 @@ void ElementScene::setEventInterface(ESEventInterface *event_interface) {
 	m_event_interface = event_interface;
 }
 
+/**
+ * @brief ElementScene::clearEventInterface
+ * Clear the current event interface
+ */
+void ElementScene::clearEventInterface()
+{
+	if(m_event_interface)
+	{
+		delete m_event_interface;
+		m_event_interface = nullptr;
+	}
+}
+
 /**
  * @brief ElementScene::setBehavior
  * Modifie the current behavior of this scene
@@ -229,21 +262,21 @@ void ElementScene::setEventInterface(ESEventInterface *event_interface) {
  */
 void ElementScene::setBehavior(ElementScene::Behavior b)
 {
-	behavior = b;
+	m_behavior = b;
 }
 
 /**
 	@return la taille horizontale de la grille
 */
 int ElementScene::xGrid() const {
-	return(x_grid);
+	return(m_x_grid);
 }
 
 /**
 	@return la taille verticale de la grille
 */
 int ElementScene::yGrid() const {
-	return(y_grid);
+	return(m_y_grid);
 }
 
 /**
@@ -251,8 +284,8 @@ int ElementScene::yGrid() const {
 	@param y_g Taille verticale de la grille
 */
 void ElementScene::setGrid(int x_g, int y_g) {
-	x_grid = x_g ? x_g : 1;
-	y_grid = y_g ? y_g : 1;
+	m_x_grid = x_g ? x_g : 1;
+	m_y_grid = y_g ? y_g : 1;
 }
 
 /**
@@ -306,7 +339,7 @@ const QDomDocument ElementScene::toXml(bool all_parts)
 	root.appendChild(uuid);
 	
 		//names of element
-	root.appendChild(_names.toXml(xml_document));
+	root.appendChild(m_names_list.toXml(xml_document));
 
 	if (m_elmt_type == "slave" || m_elmt_type == "master")
 	{
@@ -435,14 +468,14 @@ bool ElementScene::containsTerminals() const {
 	@return la pile d'annulations de cet editeur d'element
 */
 QUndoStack &ElementScene::undoStack() {
-	return(undo_stack);
+	return(m_undo_stack);
 }
 
 /**
 	@return le gestionnaire de QGraphicsItem de cet editeur d'element
 */
 QGIManager &ElementScene::qgiManager() {
-	return(qgi_manager);
+	return(m_qgi_manager);
 }
 
 /**
@@ -460,7 +493,7 @@ bool ElementScene::clipboardMayContainElement() {
 	@return true si clipboard_content a ete copie depuis cet element.
 */
 bool ElementScene::wasCopiedFromThisElement(const QString &clipboard_content) {
-	return(clipboard_content == last_copied_);
+	return(clipboard_content == m_last_copied);
 }
 
 /**
@@ -492,35 +525,53 @@ void ElementScene::copy() {
 	clipboard -> setText(clipboard_content);
 	
 	// retient le dernier contenu copie
-	last_copied_ = clipboard_content;
+	m_last_copied = clipboard_content;
 }
 
 QETElementEditor* ElementScene::editor() const {
-	return element_editor;
+	return m_element_editor;
 }
 
 /**
-	Selectionne une liste de parties
-	@param content liste des parties a selectionner
-*/
-void ElementScene::slot_select(const ElementContent &content) {
+ * @brief ElementScene::slot_select
+ * Select the item in content, every others items in the scene are deselected
+ * @param content
+ */
+void ElementScene::slot_select(const ElementContent &content)
+{
 	blockSignals(true);
+	
+	//Befor clear selection, we must to remove the handlers items in @content,
+	//because if in @content there are a selected item, but also its handlers items,
+	//When item is deselected, the item delete its handlers items,
+	//then handlers in content doesn't exist anymore and cause segfault
+	QList<QGraphicsItem*> items_list;
+	for (QGraphicsItem *qgi : content)
+	{
+		if(qgi->type() != QetGraphicsHandlerItem::Type)
+			items_list << qgi;
+	}
 	clearSelection();
-	foreach(QGraphicsItem *qgi, content) qgi -> setSelected(true);
+
+	foreach(QGraphicsItem *qgi, items_list)
+		qgi -> setSelected(true);
+	
 	blockSignals(false);
 	emit(selectionChanged());
 }
 
 /**
-	Selectionne tout
-*/
+ * @brief ElementScene::slot_selectAll
+ * Select all items
+ */
 void ElementScene::slot_selectAll() {
 	slot_select(items());
 }
 
 /**
-	Deselectionne tout
-*/
+ * @brief ElementScene::slot_deselectAll
+ * deselect all item
+ */
 void ElementScene::slot_deselectAll() {
 	slot_select(ElementContent());
 }
@@ -544,7 +595,7 @@ void ElementScene::slot_delete() {
 	if (selected_items.isEmpty()) return;
 	
 	// efface tout ce qui est selectionne
-	undo_stack.push(new DeletePartsCommand(this, selected_items));
+	m_undo_stack.push(new DeletePartsCommand(this, selected_items));
 	
 	// removing items does not trigger QGraphicsScene::selectionChanged()
 	emit(partsRemoved());
@@ -557,10 +608,10 @@ void ElementScene::slot_delete() {
 	sur l'auteur de l'element, sa licence, etc.
 */
 void ElementScene::slot_editAuthorInformations() {
-	bool is_read_only = element_editor && element_editor -> isReadOnly();
+	bool is_read_only = m_element_editor && m_element_editor -> isReadOnly();
 	
 	// cree un dialogue
-	QDialog dialog_author(element_editor);
+	QDialog dialog_author(m_element_editor);
 	dialog_author.setModal(true);
 #ifdef Q_OS_MAC
 	dialog_author.setWindowFlags(Qt::Sheet);
@@ -614,10 +665,10 @@ void  ElementScene::slot_editProperties() {
 	Lance un dialogue pour editer les noms de cet element
 */
 void ElementScene::slot_editNames() {
-	bool is_read_only = element_editor && element_editor -> isReadOnly();
+	bool is_read_only = m_element_editor && m_element_editor -> isReadOnly();
 	
 	// cree un dialogue
-	QDialog dialog(element_editor);
+	QDialog dialog(m_element_editor);
 #ifdef Q_OS_MAC
 	dialog.setWindowFlags(Qt::Sheet);
 #endif
@@ -634,7 +685,7 @@ void ElementScene::slot_editNames() {
 	
 	// ajoute un NamesListWidget au dialogue
 	NamesListWidget *names_widget = new NamesListWidget();
-	names_widget -> setNames(_names);
+	names_widget -> setNames(m_names_list);
 	names_widget -> setReadOnly(is_read_only);
 	dialog_layout -> addWidget(names_widget);
 	
@@ -648,7 +699,7 @@ void ElementScene::slot_editNames() {
 	// lance le dialogue
 	if (dialog.exec() == QDialog::Accepted && !is_read_only) {
 		NamesList new_names(names_widget -> names());
-		if (new_names != _names) undoStack().push(new ChangeNamesCommand(this, _names, new_names));
+		if (new_names != m_names_list) undoStack().push(new ChangeNamesCommand(this, m_names_list, new_names));
 	}
 }
 
@@ -741,7 +792,7 @@ QList<QGraphicsItem *> ElementScene::zItems(ItemOptions options) const {
 	
 	// ordonne les parties par leur zValue
 	if (options & SortByZValue) {
-		qSort(all_items_list.begin(), all_items_list.end(), ElementScene::zValueLessThan);
+		std::sort (all_items_list.begin(), all_items_list.end(), ElementScene::zValueLessThan);
 	}
 	
 	// rajoute eventuellement les bornes
@@ -771,27 +822,38 @@ ElementContent ElementScene::selectedContent() const {
 */
 void ElementScene::getPasteArea(const QRectF &to_paste) {
 	// on le dessine sur la scene
-	paste_area_ -> setRect(to_paste);
-	addItem(paste_area_);
+	m_paste_area -> setRect(to_paste);
+	addItem(m_paste_area);
 	
 	// on passe la scene en mode "recherche de zone pour copier/coller"
-	behavior = PasteArea;
+	m_behavior = PasteArea;
 }
 
 /**
-	Supprime les parties de l'element et les objets d'annulations.
-	Les autres caracteristiques sont conservees.
-*/
-void ElementScene::reset() {
-	// supprime les objets d'annulation
+ * @brief ElementScene::reset
+ * Remove all QGraphicsItems in the scene and clear the undo stack.
+ */
+void ElementScene::reset()
+{
+	clearSelection();
 	undoStack().clear();
 
-	// enleve les elements de la scene
-	foreach (QGraphicsItem *qgi, items()) {	
+		//We don't add handlers, because it's the role of the primitive or decorator to remove it.
+	QList<QGraphicsItem*> items_list;
+	for (QGraphicsItem *qgi : items())
+	{
+		if(qgi->type() != QetGraphicsHandlerItem::Type)
+			items_list << qgi;
+	}
+	
+	for (QGraphicsItem *qgi : items_list)
+	{
 		removeItem(qgi);
 		qgiManager().release(qgi);
 	}
-	decorator_ = 0;
+
+	delete m_decorator;
+	m_decorator = nullptr;
 }
 
 /**
@@ -834,7 +896,7 @@ bool ElementScene::applyInformations(const QDomDocument &xml_document, QString *
 	m_elmt_kindInfo.fromXml(root.firstChildElement("kindInformations"), "kindInformation");
 
 	//Extract names of xml definition
-	_names.fromXml(root);
+	m_names_list.fromXml(root);
 	
 	//extract additional informations
 	setInformations(QString());
@@ -881,15 +943,15 @@ ElementContent ElementScene::loadContent(const QDomDocument &xml_document, QStri
 				QDomElement qde = n.toElement();
 				if (qde.isNull()) continue;
 				CustomElementPart *cep;
-				if      (qde.tagName() == "line")     cep = new PartLine     (element_editor);
-				else if (qde.tagName() == "rect")     cep = new PartRectangle(element_editor);
-				else if (qde.tagName() == "ellipse")  cep = new PartEllipse  (element_editor);
-				else if (qde.tagName() == "circle")   cep = new PartEllipse  (element_editor);
-				else if (qde.tagName() == "polygon")  cep = new PartPolygon  (element_editor);
-				else if (qde.tagName() == "terminal") cep = new PartTerminal (element_editor);
-				else if (qde.tagName() == "text")     cep = new PartText     (element_editor);
-				else if (qde.tagName() == "input")    cep = new PartTextField(element_editor);
-				else if (qde.tagName() == "arc")      cep = new PartArc      (element_editor);
+				if      (qde.tagName() == "line")     cep = new PartLine     (m_element_editor);
+				else if (qde.tagName() == "rect")     cep = new PartRectangle(m_element_editor);
+				else if (qde.tagName() == "ellipse")  cep = new PartEllipse  (m_element_editor);
+				else if (qde.tagName() == "circle")   cep = new PartEllipse  (m_element_editor);
+				else if (qde.tagName() == "polygon")  cep = new PartPolygon  (m_element_editor);
+				else if (qde.tagName() == "terminal") cep = new PartTerminal (m_element_editor);
+				else if (qde.tagName() == "text")     cep = new PartText     (m_element_editor);
+				else if (qde.tagName() == "input")    cep = new PartTextField(m_element_editor);
+				else if (qde.tagName() == "arc")      cep = new PartArc      (m_element_editor);
 				else continue;
 				if (QGraphicsItem *qgi = dynamic_cast<QGraphicsItem *>(cep)) {
 					if (!qgi -> zValue()) qgi -> setZValue(z++);
@@ -955,8 +1017,8 @@ void ElementScene::addPrimitive(QGraphicsItem *primitive) {
 	Initialise la zone de collage
 */
 void ElementScene::initPasteArea() {
-	paste_area_ = new QGraphicsRectItem();
-	paste_area_ -> setZValue(1000000);
+	m_paste_area = new QGraphicsRectItem();
+	m_paste_area -> setZValue(1000000);
 	
 	QPen paste_area_pen;
 	paste_area_pen.setStyle(Qt::DashDotLine);
@@ -966,8 +1028,8 @@ void ElementScene::initPasteArea() {
 	paste_area_brush.setStyle(Qt::SolidPattern);
 	paste_area_brush.setColor(QColor(90, 167, 255, 64));
 	
-	paste_area_ -> setPen(paste_area_pen);
-	paste_area_ -> setBrush(paste_area_brush);
+	m_paste_area -> setPen(paste_area_pen);
+	m_paste_area -> setBrush(paste_area_brush);
 }
 
 /**
@@ -977,8 +1039,8 @@ void ElementScene::initPasteArea() {
 	
 */
 QPointF ElementScene::snapToGrid(QPointF point) {
-	point.rx() = qRound(point.x() / x_grid) * x_grid;
-	point.ry() = qRound(point.y() / y_grid) * y_grid;
+	point.rx() = qRound(point.x() / m_x_grid) * m_x_grid;
+	point.ry() = qRound(point.y() / m_y_grid) * m_y_grid;
 	return point;
 }
 
@@ -1017,35 +1079,42 @@ void ElementScene::centerElementToOrigine() {
 }
 
 /**
-	Ensure the decorator is adequately shown, hidden or updated so it always
-	represents the current selection.
-*/
-void ElementScene::managePrimitivesGroups() {
-	// this function is not supposed to be reentrant
-	if (!decorator_lock_ -> tryLock()) return;
+ * @brief ElementScene::managePrimitivesGroups
+ * Ensure the decorator is adequately shown, hidden or updated so it always
+ * represents the current selection.
+ */
+void ElementScene::managePrimitivesGroups()
+{
+		//this function is not supposed to be reentrant
+	if (!m_decorator_lock->tryLock())
+		return;
 	
-	if (!decorator_) {
-		decorator_ = new ElementPrimitiveDecorator();
-		connect(decorator_, SIGNAL(actionFinished(ElementEditionCommand*)), this, SLOT(stackAction(ElementEditionCommand *)));
-		addItem(decorator_);
-		decorator_ -> hide();
+	if (!m_decorator)
+	{
+		m_decorator = new ElementPrimitiveDecorator();
+		connect(m_decorator, SIGNAL(actionFinished(ElementEditionCommand*)), this, SLOT(stackAction(ElementEditionCommand *)));
+		addItem(m_decorator);
+		m_decorator -> hide();
 	}
 	
 		// should we hide the decorator?
 	QList<QGraphicsItem *> selected_items = zItems(ElementScene::Selected | ElementScene::IncludeTerminals);
-	if (selected_items.size() == 0)
-		decorator_ -> hide();
-	else if (selected_items.size() == 1 &&
-			 selected_items.first()->type() != PartText::Type &&
-			 selected_items.first()->type() != PartTextField::Type)
-		decorator_->hide();
+    if (selected_items.size() <= 1)
+	{
+		m_decorator -> hide();
+	}
 	else
 	{
-		decorator_ -> setZValue(1000000);
-		decorator_ -> setPos(0, 0);
-		decorator_ -> setItems(selected_items);
+		for(QGraphicsItem *qgi : selected_items)
+		{
+				//We recall set selected, then every primitive will remove there handler because there are several item selected
+			qgi->setSelected(true);
+		}
+		m_decorator -> setZValue(1000000);
+		m_decorator -> setPos(0, 0);
+		m_decorator -> setItems(selected_items);
 	}
-	decorator_lock_ -> unlock();
+	m_decorator_lock -> unlock();
 }
 
 /**
