@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -118,7 +118,7 @@ class CustomElementGraphicPart : public QGraphicsObject, public CustomElementPar
 		Filling _filling ;
 		Color _color;
 		bool _antialiased;
-		QPointF m_origin_pos, m_mouse_to_origin_pos;
+        QPointF m_origin_pos;
 };
 
 typedef CustomElementGraphicPart CEGP;
