@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -23,7 +23,6 @@
 #include "customelementpart.h"
 #include "newelementwizard.h"
 #include "elementitemeditor.h"
-#include "elementdefinition.h"
 #include "elementdialog.h"
 #include "recentfiles.h"
 #include "qeticons.h"
@@ -52,6 +51,11 @@
 #include "eseventaddterminal.h"
 
 #include <QMessageBox>
+#include <QTextStream>
+#include <QFileDialog>
+#include <QFile>
+#include <QModelIndex>
+
 /*
 	Nombre maximum de primitives affichees par la "liste des parties"
 	Au-dela, un petit message est affiche, indiquant que ce nombre a ete depasse
@@ -102,17 +106,15 @@ QETElementEditor::~QETElementEditor() {
 }
 
 /**
-	@param el Le nouvel emplacement de l'element edite
-*/
-void QETElementEditor::setLocation(const ElementsLocation &el) {
+ * @brief QETElementEditor::setLocation
+ * The new location to edit
+ * @param el
+ */
+void QETElementEditor::setLocation(const ElementsLocation &el)
+{
 	location_ = el;
 	opened_from_file = false;
-	// modifie le mode lecture seule si besoin
-	ElementsCollectionItem *item = QETApp::collectionItem(location_);
-	bool must_be_read_only = item && !item -> isWritable();
-	if (isReadOnly() != must_be_read_only) {
-		setReadOnly(must_be_read_only);
-	}
+	setReadOnly(!location_.isWritable());
 	slot_updateTitle();
 }
 
@@ -136,29 +138,30 @@ void QETElementEditor::setFileName(const QString &fn) {
  */
 void QETElementEditor::setupActions() {
 	new_element       = new QAction(QET::Icons::DocumentNew,          tr("&Nouveau"),                                  this);
-	open              = new QAction(QET::Icons::DocumentOpen,         tr("&Ouvrir"),                                   this);
-	open_file         = new QAction(QET::Icons::DocumentOpen,         tr("&Ouvrir depuis un fichier"),                 this);
+    open              = new QAction(QET::Icons::FolderOpen,         tr("&Ouvrir"),                                   this);
+    open_file         = new QAction(QET::Icons::FolderOpen,         tr("&Ouvrir depuis un fichier"),                 this);
+    open_dxf          = new QAction(QET::Icons::RunDxf,         tr("&Lancer le plugin convertisseur DXF"),       this);
 	save              = new QAction(QET::Icons::DocumentSave,         tr("&Enregistrer"),                              this);
 	save_as           = new QAction(QET::Icons::DocumentSaveAs,       tr("Enregistrer sous"),                          this);
 	save_as_file      = new QAction(QET::Icons::DocumentSaveAs,       tr("Enregistrer dans un fichier"),               this);
 	reload            = new QAction(QET::Icons::ViewRefresh,          tr("Recharger"),                                 this);
 	quit              = new QAction(QET::Icons::ApplicationExit,      tr("&Quitter"),                                  this);
-	selectall         = new QAction(QET::Icons::EditSelectAll,        tr("Tout sélectionner"),                      this);
-	deselectall       = new QAction(                                  tr("Désélectionner tout"),                 this);
+	selectall         = new QAction(QET::Icons::EditSelectAll,        tr("Tout sélectionner"),                         this);
+    deselectall       = new QAction(QET::Icons::EditSelectNone,       tr("Désélectionner tout"),                       this);
 	cut               = new QAction(QET::Icons::EditCut,              tr("Co&uper"),                                   this);
 	copy              = new QAction(QET::Icons::EditCopy,             tr("Cop&ier"),                                   this);
 	paste             = new QAction(QET::Icons::EditPaste,            tr("C&oller"),                                   this);
 	paste_in_area     = new QAction(QET::Icons::EditPaste,            tr("C&oller dans la zone..."),                   this);
 	paste_from_file   = new QAction(QET::Icons::XmlTextFile,          tr("un fichier"),                                this);
-	paste_from_elmt   = new QAction(QET::Icons::Element,              tr("un élément"),                          this);
-	inv_select        = new QAction(                                  tr("Inverser la sélection"),                  this);
+	paste_from_elmt   = new QAction(QET::Icons::Element,              tr("un élément"),                                this);
+    inv_select        = new QAction(QET::Icons::EditSelectInvert,     tr("Inverser la sélection"),                     this);
 	edit_delete       = new QAction(QET::Icons::EditDelete,           tr("&Supprimer"),                                this);
 	edit_names        = new QAction(QET::Icons::Names,                tr("Éditer le nom et les traductions de l'élément"), this);
-	edit_author       = new QAction(QET::Icons::UserInformations,     tr("Éditer les informations sur l'auteur"),   this);
-	m_edit_properties = new QAction(QET::Icons::ElementEdit,          tr("Éditer les propriétés de l'élément"), this);
+	edit_author       = new QAction(QET::Icons::UserInformations,     tr("Éditer les informations sur l'auteur"),      this);
+	m_edit_properties = new QAction(QET::Icons::ElementEdit,          tr("Éditer les propriétés de l'élément"),        this);
 	
-	undo = ce_scene -> undoStack().createUndoAction(this, tr("Annuler"));
-	redo = ce_scene -> undoStack().createRedoAction(this, tr("Refaire"));
+	undo = m_elmt_scene -> undoStack().createUndoAction(this, tr("Annuler"));
+	redo = m_elmt_scene -> undoStack().createRedoAction(this, tr("Refaire"));
 	undo -> setIcon(QET::Icons::EditUndo);
 	redo -> setIcon(QET::Icons::EditRedo);
 	undo -> setShortcuts(QKeySequence::Undo);
@@ -189,25 +192,26 @@ void QETElementEditor::setupActions() {
 	
 	connect(new_element,     SIGNAL(triggered()), this,     SLOT(slot_new()));
 	connect(open,            SIGNAL(triggered()), this,     SLOT(slot_open()));
+	connect(open_dxf,       SIGNAL(triggered()), this,     SLOT(slot_openDxf()));
 	connect(open_file,       SIGNAL(triggered()), this,     SLOT(slot_openFile()));
 	connect(save,            SIGNAL(triggered()), this,     SLOT(slot_save()));
 	connect(save_as,         SIGNAL(triggered()), this,     SLOT(slot_saveAs()));
 	connect(save_as_file,    SIGNAL(triggered()), this,     SLOT(slot_saveAsFile()));
 	connect(reload,          SIGNAL(triggered()), this,     SLOT(slot_reload()));
 	connect(quit,            SIGNAL(triggered()), this,     SLOT(close()));
-	connect(selectall,       SIGNAL(triggered()), ce_scene, SLOT(slot_selectAll()));
-	connect(deselectall,     SIGNAL(triggered()), ce_scene, SLOT(slot_deselectAll()));
-	connect(inv_select,      SIGNAL(triggered()), ce_scene, SLOT(slot_invertSelection()));
+	connect(selectall,       SIGNAL(triggered()), m_elmt_scene, SLOT(slot_selectAll()));
+	connect(deselectall,     SIGNAL(triggered()), m_elmt_scene, SLOT(slot_deselectAll()));
+	connect(inv_select,      SIGNAL(triggered()), m_elmt_scene, SLOT(slot_invertSelection()));
 	connect(cut,             SIGNAL(triggered()), ce_view,  SLOT(cut()));
 	connect(copy,            SIGNAL(triggered()), ce_view,  SLOT(copy()));
 	connect(paste,           SIGNAL(triggered()), ce_view,  SLOT(paste()));
 	connect(paste_in_area,   SIGNAL(triggered()), ce_view,  SLOT(pasteInArea()));
 	connect(paste_from_file, SIGNAL(triggered()), this,     SLOT(pasteFromFile()));
 	connect(paste_from_elmt, SIGNAL(triggered()), this,     SLOT(pasteFromElement()));
-	connect(edit_delete,     SIGNAL(triggered()), ce_scene, SLOT(slot_delete()));
-	connect(edit_names,      SIGNAL(triggered()), ce_scene, SLOT(slot_editNames()));
-	connect(edit_author,     SIGNAL(triggered()), ce_scene, SLOT(slot_editAuthorInformations()));
-	connect(m_edit_properties, SIGNAL(triggered()), ce_scene, SLOT(slot_editProperties()));
+	connect(edit_delete,     SIGNAL(triggered()), m_elmt_scene, SLOT(slot_delete()));
+	connect(edit_names,      SIGNAL(triggered()), m_elmt_scene, SLOT(slot_editNames()));
+	connect(edit_author,     SIGNAL(triggered()), m_elmt_scene, SLOT(slot_editAuthorInformations()));
+	connect(m_edit_properties, SIGNAL(triggered()), m_elmt_scene, SLOT(slot_editProperties()));
 
 
 	/*
@@ -225,10 +229,10 @@ void QETElementEditor::setupActions() {
 	edit_backward -> setShortcut(QKeySequence(tr("Ctrl+Shift+End")));
 	edit_forward  -> setShortcut(QKeySequence(tr("Ctrl+Shift+Home")));
 
-	connect(edit_forward,  SIGNAL(triggered()), ce_scene, SLOT(slot_bringForward() ));
-	connect(edit_raise,    SIGNAL(triggered()), ce_scene, SLOT(slot_raise()        ));
-	connect(edit_lower,    SIGNAL(triggered()), ce_scene, SLOT(slot_lower()        ));
-	connect(edit_backward, SIGNAL(triggered()), ce_scene, SLOT(slot_sendBackward() ));
+	connect(edit_forward,  SIGNAL(triggered()), m_elmt_scene, SLOT(slot_bringForward() ));
+	connect(edit_raise,    SIGNAL(triggered()), m_elmt_scene, SLOT(slot_raise()        ));
+	connect(edit_lower,    SIGNAL(triggered()), m_elmt_scene, SLOT(slot_lower()        ));
+	connect(edit_backward, SIGNAL(triggered()), m_elmt_scene, SLOT(slot_sendBackward() ));
 
 	depth_toolbar = addToolBar(tr("Profondeur", "toolbar title"));
 	depth_toolbar -> setObjectName("depth_toolbar");
@@ -260,7 +264,7 @@ void QETElementEditor::setupActions() {
 	/*
 	 * Action related to primitive creation
 	 */
-	connect (ce_scene, SIGNAL(partsAdded()), this, SLOT(UncheckAddPrimitive()));
+	connect (m_elmt_scene, SIGNAL(partsAdded()), this, SLOT(UncheckAddPrimitive()));
 	parts = new QActionGroup(this);
 
 	QAction *add_line      = new QAction(QET::Icons::PartLine,      tr("Ajouter une ligne"),         parts);
@@ -319,19 +323,19 @@ void QETElementEditor::setupActions() {
 	addToolBar(Qt::TopToolBarArea, view_toolbar);
 	addToolBar(Qt::TopToolBarArea, element_toolbar);
 	
-	connect(ce_scene, SIGNAL(selectionChanged()), this, SLOT(slot_updateInformations()));
-	connect(ce_scene, SIGNAL(selectionChanged()), this, SLOT(slot_updateMenus()));
+	connect(m_elmt_scene, SIGNAL(selectionChanged()), this, SLOT(slot_updateInformations()), Qt::QueuedConnection);
+	connect(m_elmt_scene, SIGNAL(selectionChanged()), this, SLOT(slot_updateMenus()));
 	connect(QApplication::clipboard(),  SIGNAL(dataChanged()),      this, SLOT(slot_updateMenus()));
-	connect(&(ce_scene -> undoStack()), SIGNAL(cleanChanged(bool)), this, SLOT(slot_updateMenus()));
-	connect(&(ce_scene -> undoStack()), SIGNAL(cleanChanged(bool)), this, SLOT(slot_updateTitle()));
+	connect(&(m_elmt_scene -> undoStack()), SIGNAL(cleanChanged(bool)), this, SLOT(slot_updateMenus()));
+	connect(&(m_elmt_scene -> undoStack()), SIGNAL(cleanChanged(bool)), this, SLOT(slot_updateTitle()));
 	
 	// Annuler ou refaire une action met a jour la liste des primitives ; cela sert notamment pour les
 	// ajouts et suppressions de primitives ainsi que pour les actions entrainant un change
-	connect(&(ce_scene -> undoStack()), SIGNAL(indexChanged(int)),  this, SLOT(slot_updatePartsList()));
+	connect(&(m_elmt_scene -> undoStack()), SIGNAL(indexChanged(int)),  this, SLOT(slot_updatePartsList()));
 	
 	// Annuler ou refaire une action met a jour les informations affichees sur les primitives selectionnees,
 	// celles-ci etant potentiellement impactees
-	connect(&(ce_scene -> undoStack()), SIGNAL(indexChanged(int)),  this, SLOT(slot_updateInformations()));
+	connect(&(m_elmt_scene -> undoStack()), SIGNAL(indexChanged(int)),  this, SLOT(slot_updateInformations()));
 }
 
 /**
@@ -351,6 +355,7 @@ void QETElementEditor::setupMenus() {
 	file_menu    -> addAction(new_element);
 	file_menu    -> addAction(open);
 	file_menu    -> addAction(open_file);
+	file_menu    -> addAction(open_dxf);
 	QMenu *recentfile = file_menu -> addMenu(QET::Icons::DocumentOpenRecent, tr("&Récemment ouverts"));
 	recentfile->addActions(QETApp::elementsRecentFiles()->menu()->actions());
 	connect(QETApp::elementsRecentFiles(), SIGNAL(fileOpeningRequested(const QString &)), this, SLOT(openRecentFile(const QString &)));
@@ -424,7 +429,7 @@ void QETElementEditor::contextMenu(QPoint p) {
 	Met a jour les menus
 */
 void QETElementEditor::slot_updateMenus() {
-	bool selected_items = !read_only && !ce_scene -> selectedItems().isEmpty();
+	bool selected_items = !read_only && !m_elmt_scene -> selectedItems().isEmpty();
 	bool clipboard_elmt = !read_only && ElementScene::clipboardMayContainElement();
 	
 	// actions dependant seulement de l'etat "lecture seule" de l'editeur
@@ -450,9 +455,9 @@ void QETElementEditor::slot_updateMenus() {
 	paste_in_area   -> setEnabled(clipboard_elmt);
 	
 	// actions dependant de l'etat de la pile d'annulation
-	save            -> setEnabled(!read_only && !ce_scene -> undoStack().isClean());
-	undo            -> setEnabled(!read_only && ce_scene -> undoStack().canUndo());
-	redo            -> setEnabled(!read_only && ce_scene -> undoStack().canRedo());
+	save            -> setEnabled(!read_only && !m_elmt_scene -> undoStack().isClean());
+	undo            -> setEnabled(!read_only && m_elmt_scene -> undoStack().canUndo());
+	redo            -> setEnabled(!read_only && m_elmt_scene -> undoStack().canRedo());
 }
 
 /**
@@ -460,9 +465,9 @@ void QETElementEditor::slot_updateMenus() {
 */
 void QETElementEditor::slot_updateTitle() {
 	QString title = min_title;
-	title += " - " + ce_scene -> names().name() + " ";
+	title += " - " + m_elmt_scene -> names().name() + " ";
 	if (!filename_.isEmpty() || !location_.isNull()) {
-		if (!ce_scene -> undoStack().isClean()) title += tr("[Modifié]", "window title tag");
+		if (!m_elmt_scene -> undoStack().isClean()) title += tr("[Modifié]", "window title tag");
 	}
 	if (isReadOnly()) title += tr(" [lecture seule]", "window title tag");
 	setWindowTitle(title);
@@ -473,8 +478,8 @@ void QETElementEditor::slot_updateTitle() {
 */
 void QETElementEditor::setupInterface() {
 	// editeur
-	ce_scene = new ElementScene(this, this);
-	ce_view = new ElementView(ce_scene, this);
+	m_elmt_scene = new ElementScene(this, this);
+	ce_view = new ElementView(m_elmt_scene, this);
 	slot_setRubberBandToView();
 	setCentralWidget(ce_view);
 	
@@ -518,17 +523,17 @@ void QETElementEditor::setupInterface() {
 	undo_dock -> setFeatures(QDockWidget::AllDockWidgetFeatures);
 	undo_dock -> setMinimumWidth(290);
 	addDockWidget(Qt::RightDockWidgetArea, undo_dock);
-	QUndoView* undo_view = new QUndoView(&(ce_scene -> undoStack()), this);
+	QUndoView* undo_view = new QUndoView(&(m_elmt_scene -> undoStack()), this);
 	undo_view -> setEmptyLabel(tr("Aucune modification"));
 	undo_dock -> setWidget(undo_view);
 	
 	// panel sur le cote pour la liste des parties
 	parts_list = new QListWidget(this);
 	parts_list -> setSelectionMode(QAbstractItemView::ExtendedSelection);
-	connect(ce_scene,   SIGNAL(partsAdded()),           this, SLOT(slot_createPartsList()));
-	connect(ce_scene,   SIGNAL(partsRemoved()),         this, SLOT(slot_createPartsList()));
-	connect(ce_scene,   SIGNAL(partsZValueChanged()),   this, SLOT(slot_createPartsList()));
-	connect(ce_scene,   SIGNAL(selectionChanged()),     this, SLOT(slot_updatePartsList()));
+	connect(m_elmt_scene,   SIGNAL(partsAdded()),           this, SLOT(slot_createPartsList()));
+	connect(m_elmt_scene,   SIGNAL(partsRemoved()),         this, SLOT(slot_createPartsList()));
+	connect(m_elmt_scene,   SIGNAL(partsZValueChanged()),   this, SLOT(slot_createPartsList()));
+	connect(m_elmt_scene,   SIGNAL(selectionChanged()),     this, SLOT(slot_updatePartsList()));
 	connect(parts_list, SIGNAL(itemSelectionChanged()), this, SLOT(slot_updateSelectionFromPartsList()));
 	parts_dock = new QDockWidget(tr("Parties", "dock title"), this);
 	parts_dock -> setObjectName("parts_list");
@@ -566,7 +571,7 @@ void QETElementEditor::slot_setNoDragToView() {
 	affichee. Sinon, un widget d'edition approprie est mis en place.
 */
 void QETElementEditor::slot_updateInformations() {
-	QList<QGraphicsItem *> selected_qgis = ce_scene -> selectedItems();
+	QList<QGraphicsItem *> selected_qgis = m_elmt_scene -> selectedItems();
 	QList<CustomElementPart *> cep_list;
 	bool style_editable = false;
 
@@ -647,7 +652,7 @@ void QETElementEditor::xmlPreview() {
 	QET::QetMessageBox::information(
 		this,
 		"Export XML",
-		ce_scene -> toXml().toString(4)
+		m_elmt_scene -> toXml().toString(4)
 	);
 }
 
@@ -665,7 +670,7 @@ bool QETElementEditor::checkElement()
 
 		/// Warning #1: Element haven't got terminal
 		/// (except for report, because report must have one terminal and this checking is do below)
-	if (!ce_scene -> containsTerminals() && !ce_scene -> elementType().contains("report"))
+	if (!m_elmt_scene -> containsTerminals() && !m_elmt_scene -> elementType().contains("report"))
 	{
 		warnings << qMakePair(
 			tr("Absence de borne", "warning title"),
@@ -678,13 +683,13 @@ bool QETElementEditor::checkElement()
 	}
 
 		/// Check master, slave, simple and report element
-	if(ce_scene -> elementType() == "master" ||
-	   ce_scene -> elementType() == "slave"  ||
-	   ce_scene -> elementType() == "simple")
+	if(m_elmt_scene -> elementType() == "master" ||
+	   m_elmt_scene -> elementType() == "slave"  ||
+	   m_elmt_scene -> elementType() == "simple")
 
 	{
 		bool wrng = true;
-		foreach (CustomElementPart *cep, ce_scene->primitives())
+		foreach (CustomElementPart *cep, m_elmt_scene->primitives())
 			if (cep->property("tagg").toString() == "label") wrng = false;
 
 			///Error #1: element is master, slave or simple but havent got input tagged 'label'
@@ -699,11 +704,11 @@ bool QETElementEditor::checkElement()
 	}
 
 		/// Check folio report element
-	if (ce_scene -> elementType().contains("report"))
+	if (m_elmt_scene -> elementType().contains("report"))
 	{
 		int text =0, terminal =0;
 
-		foreach(QGraphicsItem *qgi, ce_scene->items())
+		foreach(QGraphicsItem *qgi, m_elmt_scene->items())
 		{
 			if		(qgraphicsitem_cast<PartTerminal *>(qgi))  terminal ++;
 			else if (qgraphicsitem_cast<PartTextField *>(qgi)) text ++;
@@ -798,7 +803,7 @@ void QETElementEditor::fromFile(const QString &filepath) {
 	}
 	
 	// chargement de l'element
-	ce_scene -> fromXml(document_xml);
+	m_elmt_scene -> fromXml(document_xml);
 	slot_createPartsList();
 	
 	// gestion de la lecture seule
@@ -820,12 +825,18 @@ void QETElementEditor::fromFile(const QString &filepath) {
 }
 
 /**
-	Enregistre l'element vers un fichier
-	@param fn Chemin du fichier a enregistrer
-	@return true en cas de reussite, false sinon
-*/
-bool QETElementEditor::toFile(const QString &fn) {
-	QDomDocument element_xml = ce_scene -> toXml();
+ * @brief QETElementEditor::toFile
+ * Save to file the drawed element.
+ * @param fn : path of the file
+ * @return : true if succesfully save.
+ */
+bool QETElementEditor::toFile(const QString &fn)
+{
+	m_elmt_scene->clearEventInterface();
+	m_elmt_scene->clearSelection();
+	UncheckAddPrimitive();
+	
+	QDomDocument element_xml = m_elmt_scene->toXml();
 	bool writing = QET::writeXmlFile(element_xml, fn);
 	if (!writing) {
 		QET::QetMessageBox::warning(
@@ -837,42 +848,26 @@ bool QETElementEditor::toFile(const QString &fn) {
 	return(writing);
 }
 
+
 /**
-	Enregistre l'element vers un emplacement
-	@param location Emplacement de l'element a enregistrer
-	@return true en cas de reussite, false sinon
-*/
-bool QETElementEditor::toLocation(const ElementsLocation &location) {
-	ElementsCollectionItem *item = QETApp::collectionItem(location);
-	ElementDefinition *element;
-	if (item) {
-		// l'element existe deja
-		element = qobject_cast<ElementDefinition *>(item);
-	} else {
-		// l'element n'existe pas encore, on demande sa creation
-		element = QETApp::createElement(location);
-	}
+ * @brief QETElementEditor::toLocation
+ * Save the element to Location
+ * @param location : location where we must save the current element
+ * @return true if succesfully saved
+ */
+bool QETElementEditor::toLocation(const ElementsLocation &location)
+{
+	m_elmt_scene->clearEventInterface();
+	m_elmt_scene->clearSelection();
+	UncheckAddPrimitive();
 	
-	if (!element) {
-		QET::QetMessageBox::critical(
-			this,
-			tr("Erreur", "message box title"),
-			tr("Impossible d'atteindre l'élément", "message box content")
-		);
+	if (!location.setXml(m_elmt_scene->toXml()))
+	{
+		QET::QetMessageBox::critical(this,
+									 tr("Erreur", "message box title"),
+									 tr("Impossible d'enregistrer l'élément", "message box content"));
 		return(false);
 	}
-	
-	// enregistre l'element
-	element -> setXml(ce_scene -> toXml().documentElement());
-	if (!element -> write()) {
-		QET::QetMessageBox::critical(
-			this,
-			tr("Erreur", "message box title"),
-			tr("Impossible d'enregistrer l'élément", "message box content")
-		);
-		return(false);
-	}
-	
 	return(true);
 }
 
@@ -941,7 +936,7 @@ bool QETElementEditor::isReadOnly() const {
  * Set line creation interface to scene
  */
 void QETElementEditor::addLine() {
-	ce_scene -> setEventInterface(new ESEventAddLine(ce_scene));
+	m_elmt_scene -> setEventInterface(new ESEventAddLine(m_elmt_scene));
 }
 
 /**
@@ -949,7 +944,7 @@ void QETElementEditor::addLine() {
  * Set rectangle creation interface to scene
  */
 void QETElementEditor::addRect() {
-	ce_scene -> setEventInterface(new ESEventAddRect(ce_scene));
+	m_elmt_scene -> setEventInterface(new ESEventAddRect(m_elmt_scene));
 }
 
 /**
@@ -957,7 +952,7 @@ void QETElementEditor::addRect() {
  * Set ellipse creation interface to scene
  */
 void QETElementEditor::addEllipse() {
-	ce_scene -> setEventInterface(new ESEventAddEllipse(ce_scene));
+	m_elmt_scene -> setEventInterface(new ESEventAddEllipse(m_elmt_scene));
 }
 
 /**
@@ -965,7 +960,7 @@ void QETElementEditor::addEllipse() {
  * Set polygon creation interface to scene
  */
 void QETElementEditor::addPolygon() {
-	ce_scene -> setEventInterface(new ESEventAddPolygon(ce_scene));
+	m_elmt_scene -> setEventInterface(new ESEventAddPolygon(m_elmt_scene));
 }
 
 /**
@@ -973,7 +968,7 @@ void QETElementEditor::addPolygon() {
  * Set arc creation interface to scene
  */
 void QETElementEditor::addArc() {
-	ce_scene -> setEventInterface(new ESEventAddArc(ce_scene));
+	m_elmt_scene -> setEventInterface(new ESEventAddArc(m_elmt_scene));
 }
 
 /**
@@ -981,7 +976,7 @@ void QETElementEditor::addArc() {
  * Set text creation interface to scene
  */
 void QETElementEditor::addText() {
-	ce_scene -> setEventInterface(new ESEventAddText(ce_scene));
+	m_elmt_scene -> setEventInterface(new ESEventAddText(m_elmt_scene));
 }
 
 /**
@@ -989,7 +984,7 @@ void QETElementEditor::addText() {
  * Set text field creation interface to scene
  */
 void QETElementEditor::addTextField() {
-	ce_scene -> setEventInterface(new ESEventAddTextField(ce_scene));
+	m_elmt_scene -> setEventInterface(new ESEventAddTextField(m_elmt_scene));
 }
 
 /**
@@ -997,7 +992,7 @@ void QETElementEditor::addTextField() {
  * Set terminal creation interface to scene
  */
 void QETElementEditor::addTerminal() {
-	ce_scene -> setEventInterface(new ESEventAddTerminal(ce_scene));
+	m_elmt_scene -> setEventInterface(new ESEventAddTerminal(m_elmt_scene));
 }
 
 /**
@@ -1054,6 +1049,24 @@ void QETElementEditor::openRecentFile(const QString &filepath) {
 	openElement(filepath);
 }
 
+/**
+ * @brief QETElementEditor::slot_openDxf
+ */
+void QETElementEditor::slot_openDxf (){
+
+#if defined(Q_OS_WIN32)
+QString program = (QDir::homePath() + "/Application Data/qet/DXFtoQET.exe");
+#elif defined(Q_OS_MAC)
+QString program = (QDir::homePath() + "/.qet/DXFtoQET.app");
+#else
+QString program = (QDir::homePath() + "/.qet/DXFtoQET");
+#endif
+QStringList arguments;
+QProcess *DXF = new QProcess(qApp);
+DXF->start(program,arguments);
+
+}
+
 /**
 	Ouvre un fichier element dans un nouvel editeur
 	Cette methode ne controle pas si le fichier est deja ouvert
@@ -1079,84 +1092,95 @@ void QETElementEditor::openElement(const QString &filepath) {
 }
 
 /**
-	Recharge l'element edite
-*/
-void QETElementEditor::slot_reload() {
-	// s'il ya des modifications, on demande a l'utilisateur s'il est certain
-	// de vouloir recharger
-	if (!ce_scene -> undoStack().isClean()) {
-		QMessageBox::StandardButton answer = QET::QetMessageBox::question(
-			this,
-			tr("Recharger l'élément", "dialog title"),
-			tr("Vous avez efffectué des modifications sur cet élément. Si vous le rechargez, ces modifications seront perdues. Voulez-vous vraiment recharger l'élément ?", "dialog content"),
-			QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel,
-			QMessageBox::Cancel
-		);
+ * @brief QETElementEditor::slot_reload
+ * Reload the element from the file or location
+ */
+void QETElementEditor::slot_reload()
+{
+		//If user already edit the element, ask confirmation to reload
+	if (!m_elmt_scene -> undoStack().isClean())
+	{
+		QMessageBox::StandardButton answer = QET::QetMessageBox::question(this,
+																		  tr("Recharger l'élément", "dialog title"),
+																		  tr("Vous avez efffectué des modifications sur cet élément. Si vous le rechargez, ces modifications seront perdues. Voulez-vous vraiment recharger l'élément ?", "dialog content"),
+																		  QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel,
+																		  QMessageBox::Cancel);
 		if (answer != QMessageBox::Yes) return;
 	}
-	
-	// recharge l'element
-	if (opened_from_file) {
-		// l'element a ete ouvert a partir d'un chemin de fichier
-		ce_scene -> reset();
+
+		//Reload the element
+	m_elmt_scene -> reset();
+	if (opened_from_file)
 		fromFile(filename_);
-	} else {
-		// l'element a ete ouvert a partir d'un emplacement (ElementsLocation)
-		// il peut s'agir aussi bien d'un fichier que d'un element XML
-		if (ElementsCollectionItem *item = QETApp::collectionItem(location_)) {
-			item -> reload();
-			ce_scene -> reset();
-			fromLocation(location_);
-		}
-	}
+	else
+		fromLocation(location_);
 }
 
 /**
-	Enregistre l'element en cours d'edition.
-	Si le nom du fichier en cours n'est pas connu, cette methode equivaut a
-	l'action "Enregistrer sous"
-	@see slot_saveAs()
-*/
-bool QETElementEditor::slot_save() {
-	// Check element befor writing
-	if (checkElement()) {
-		// si on ne connait pas le nom du fichier en cours, enregistrer revient a enregistrer sous
-		if (opened_from_file) {
-			if (filename_.isEmpty()) return(slot_saveAsFile());
-			// sinon on enregistre dans le nom de fichier connu
+ * @brief QETElementEditor::slot_save
+ * Save the current editing element.
+ * If the filepath or location is unknow, use save_as instead
+ * @return true if save with success
+ */
+bool QETElementEditor::slot_save()
+{
+		// Check element befor writing
+	if (checkElement())
+	{
+			//If we don't know the name of the current file, use save as instead
+		if (opened_from_file)
+		{
+			if (filename_.isEmpty())
+				return(slot_saveAsFile());
+
+				//Else wa save to the file at filename_ path
 			bool result_save = toFile(filename_);
-			if (result_save) ce_scene -> undoStack().setClean();
+			if (result_save) m_elmt_scene -> undoStack().setClean();
 			return(result_save);
-		} else {
-			if (location_.isNull()) return(slot_saveAs());
-			// sinon on enregistre a l'emplacement connu
+		}
+		else
+		{
+			if (location_.isNull())
+				return(slot_saveAs());
+
+				//Else save to the known location
 			bool result_save = toLocation(location_);
-			if (result_save) ce_scene -> undoStack().setClean();
+			if (result_save) {
+				m_elmt_scene -> undoStack().setClean();
+				emit saveToLocation(location_);
+			}
 			return(result_save);
 		}
 	}
+
 	QMessageBox::critical(this, tr("Echec de l'enregistrement"), tr("L'enregistrement à échoué,\nles conditions requises ne sont pas valides"));
 	return false;
 }
 
 /**
-	Demande une localisation a l'utilisateur et enregistre l'element
-*/
-bool QETElementEditor::slot_saveAs() {
-	// Check element befor writing
-	if (checkElement()) {
-		// demande une localisation a l'utilisateur
+ * @brief QETElementEditor::slot_saveAs
+ * Ask a location to user and save the current edited element
+ * to this location
+ * @return true if save with success
+ */
+bool QETElementEditor::slot_saveAs()
+{
+		// Check element befor writing
+	if (checkElement())
+	{
+			//Ask a location to user
 		ElementsLocation location = ElementDialog::getSaveElementLocation(this);
-		if (location.isNull()) return(false);
-	
-		// tente l'enregistrement
+		if (location.isNull())
+			return(false);
+
 		bool result_save = toLocation(location);
-		if (result_save) {
+		if (result_save)
+		{
 			setLocation(location);
-			ce_scene -> undoStack().setClean();
+			m_elmt_scene->undoStack().setClean();
+			emit saveToLocation(location);
 		}
-	
-		// retourne un booleen representatif de la reussite de l'enregistrement
+
 		return(result_save);
 	}
 	QMessageBox::critical(this, tr("Echec de l'enregistrement"), tr("L'enregistrement à échoué,\nles conditions requises ne sont pas valides"));
@@ -1164,12 +1188,16 @@ bool QETElementEditor::slot_saveAs() {
 }
 
 /**
-	Demande un nom de fichier a l'utilisateur et enregistre l'element
-*/
-bool QETElementEditor::slot_saveAsFile() {
-	// Check element befor writing
-	if (checkElement()) {
-		// demande un nom de fichier a l'utilisateur pour enregistrer l'element
+ * @brief QETElementEditor::slot_saveAsFile
+ * Ask a file to user and save the current edited element to this file
+ * @return true if save with success
+ */
+bool QETElementEditor::slot_saveAsFile()
+{
+		// Check element befor writing
+	if (checkElement())
+	{
+			//Ask a filename to user, for save the element
 		QString fn = QFileDialog::getSaveFileName(
 			this,
 			tr("Enregistrer sous", "dialog title"),
@@ -1179,19 +1207,23 @@ bool QETElementEditor::slot_saveAsFile() {
 				"filetypes allowed when saving an element file"
 			)
 		);
-		// si aucun nom n'est entre, renvoie faux.
-		if (fn.isEmpty()) return(false);
-		// si le nom ne se termine pas par l'extension .elmt, celle-ci est ajoutee
-		if (!fn.endsWith(".elmt", Qt::CaseInsensitive)) fn += ".elmt";
-		// tente d'enregistrer le fichier
+
+		if (fn.isEmpty())
+			return(false);
+
+			//If the name doesn't end by .elmt, we add it
+		if (!fn.endsWith(".elmt", Qt::CaseInsensitive))
+			fn += ".elmt";
+
 		bool result_save = toFile(fn);
-		// si l'enregistrement reussit, le nom du fichier est conserve
-		if (result_save) {
+			//If the save success, the filename is keep
+		if (result_save)
+		{
 			setFileName(fn);
 			QETApp::elementsRecentFiles() -> fileWasOpened(fn);
-			ce_scene -> undoStack().setClean();
+			m_elmt_scene -> undoStack().setClean();
 		}
-		// retourne un booleen representatif de la reussite de l'enregistrement
+
 		return(result_save);
 	}
 	QMessageBox::critical(this, tr("Echec de l'enregistrement"), tr("L'enregistrement à échoué,\nles conditions requises ne sont pas valides"));
@@ -1205,7 +1237,7 @@ bool QETElementEditor::slot_saveAsFile() {
 	l'utilisateur.
 */
 bool QETElementEditor::canClose() {
-	if (ce_scene -> undoStack().isClean()) return(true);
+	if (m_elmt_scene -> undoStack().isClean()) return(true);
 	// demande d'abord a l'utilisateur s'il veut enregistrer l'element en cours
 	QMessageBox::StandardButton answer = QET::QetMessageBox::question(
 		this,
@@ -1215,7 +1247,7 @@ bool QETElementEditor::canClose() {
 				"Voulez-vous enregistrer l'élément %1 ?",
 				"dialog content - %1 is an element name"
 			)
-		).arg(ce_scene -> names().name()),
+		).arg(m_elmt_scene -> names().name()),
 		QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel,
 		QMessageBox::Cancel
 	);
@@ -1272,7 +1304,7 @@ void QETElementEditor::closeEvent(QCloseEvent *qce) {
 	if (canClose()) {
 		writeSettings();
 		setAttribute(Qt::WA_DeleteOnClose);
-		ce_scene -> reset();
+		m_elmt_scene -> reset();
 		qce -> accept();
 	} else qce -> ignore();
 }
@@ -1291,7 +1323,7 @@ void QETElementEditor::firstActivation(QEvent *event) {
 void QETElementEditor::slot_createPartsList() {
 	parts_list -> blockSignals(true);
 	parts_list -> clear();
-	QList<QGraphicsItem *> qgis = ce_scene -> zItems();
+	QList<QGraphicsItem *> qgis = m_elmt_scene -> zItems();
 	
 	// on ne construit plus la liste a partir de 200 primitives
 	// c'est ingerable : la maj de la liste prend trop de temps et le resultat
@@ -1319,13 +1351,13 @@ void QETElementEditor::slot_createPartsList() {
 	Met a jour la selection dans la liste des parties
 */
 void QETElementEditor::slot_updatePartsList() {
-	int items_count = ce_scene -> items().count();
+	int items_count = m_elmt_scene -> items().count();
 	if (parts_list -> count() != items_count) {
 		slot_createPartsList();
 	} else if (items_count <= QET_MAX_PARTS_IN_ELEMENT_EDITOR_LIST) {
 		parts_list -> blockSignals(true);
 		int i = 0;
-		QList<QGraphicsItem *> items = ce_scene -> zItems();
+		QList<QGraphicsItem *> items = m_elmt_scene -> zItems();
 		for (int j = items.count() - 1 ; j >= 0 ; -- j) {
 			QGraphicsItem *qgi = items[j];
 			QListWidgetItem *qlwi = parts_list -> item(i);
@@ -1341,7 +1373,7 @@ void QETElementEditor::slot_updatePartsList() {
 	parties
 */
 void QETElementEditor::slot_updateSelectionFromPartsList() {
-	ce_scene  -> blockSignals(true);
+	m_elmt_scene  -> blockSignals(true);
 	parts_list -> blockSignals(true);
 	for (int i = 0 ; i < parts_list -> count() ; ++ i) {
 		QListWidgetItem *qlwi = parts_list -> item(i);
@@ -1351,7 +1383,7 @@ void QETElementEditor::slot_updateSelectionFromPartsList() {
 		}
 	}
 	parts_list -> blockSignals(false);
-	ce_scene -> blockSignals(false);
+	m_elmt_scene -> blockSignals(false);
 	slot_updateInformations();
 	slot_updateMenus();
 }
@@ -1373,7 +1405,7 @@ void QETElementEditor::readSettings()
 	if (state.isValid()) restoreState(state.toByteArray());
 	
 	// informations complementaires de l'element : valeur par defaut
-	ce_scene -> setInformations(settings.value("elementeditor/default-informations", "").toString());
+	m_elmt_scene -> setInformations(settings.value("elementeditor/default-informations", "").toString());
 }
 
 /**
@@ -1422,53 +1454,48 @@ QString QETElementEditor::getOpenElementFileName(QWidget *parent, const QString
 }
 
 /**
-	@param location Emplacement de l'element a editer
-*/
-void QETElementEditor::fromLocation(const ElementsLocation &location) {
-	
-	// l'element doit exister
-	ElementsCollectionItem *item = QETApp::collectionItem(location);
-	ElementDefinition *element = 0;
-	if (!item) {
-		QET::QetMessageBox::critical(
-			this,
-			tr("Élément inexistant.", "message box title"),
-			tr("L'élément n'existe pas.", "message box content")
-		);
+ * @brief QETElementEditor::fromLocation
+ * Location of the element to edit
+ * @param location
+ */
+void QETElementEditor::fromLocation(const ElementsLocation &location)
+{
+	if (!location.isElement())
+	{
+		QET::QetMessageBox::critical(this,
+									 tr("Élément inexistant.", "message box title"),
+									 tr("Le chemin virtuel choisi ne correspond pas à un élément.", "message box content"));
 		return;
 	}
-	
-	if (!item -> isElement() || !(element = qobject_cast<ElementDefinition *>(item)) || element -> isNull()) {
-		QET::QetMessageBox::critical(
-			this,
-			tr("Élément inexistant.", "message box title"),
-			tr("Le chemin virtuel choisi ne correspond pas à un élément.", "message box content")
-		);
+	if (!location.exist())
+	{
+		QET::QetMessageBox::critical(this,
+									 tr("Élément inexistant.", "message box title"),
+									 tr("L'élément n'existe pas.", "message box content"));
 		return;
 	}
-	
-	// le fichier doit etre un document XML
+
+		//The file must be an xml document
 	QDomDocument document_xml;
-	QDomNode node = document_xml.importNode(element -> xml(), true);
+	QDomNode node = document_xml.importNode(location.xml(), true);
 	document_xml.appendChild(node);
-	
-	// chargement de l'element
-	ce_scene -> fromXml(document_xml);
+
+		//Load the element
+	m_elmt_scene -> fromXml(document_xml);
 	slot_createPartsList();
-	
-	// gestion de la lecture seule
-	if (!element -> isWritable()) {
-		QET::QetMessageBox::warning(
-			this,
-			tr("Édition en lecture seule", "message box title"),
-			tr("Vous n'avez pas les privilèges nécessaires pour modifier cet élement. Il sera donc ouvert en lecture seule.", "message box content")
-		);
+
+		//location is read only
+	if (!location.isWritable())
+	{
+		QET::QetMessageBox::warning(this,
+									tr("Édition en lecture seule", "message box title"),
+									tr("Vous n'avez pas les privilèges nécessaires pour modifier cet élement. Il sera donc ouvert en lecture seule.", "message box content"));
 		setReadOnly(true);
-	} else {
+	}
+	else {
 		setReadOnly(false);
 	}
-	
-	// memorise le fichier
+
 	setLocation(location);
 	slot_updateMenus();
 }
@@ -1503,40 +1530,37 @@ void QETElementEditor::pasteFromFile() {
 }
 
 /**
-	Denande un element a l'utilisateur, met son contenu dans le presse-papiers,
-	et appelle ElementView::PasteInArea
-*/
-void QETElementEditor::pasteFromElement() {
-	// demande le chemin virtuel de l'element a ouvrir a l'utilisateur
+ * @brief QETElementEditor::pasteFromElement
+ * Ask an element to user, copy the xml definition of the element
+ * to the clipboard and call ElementView::PasteInArea
+ */
+void QETElementEditor::pasteFromElement()
+{
+		//Ask for a location
 	ElementsLocation location = ElementDialog::getOpenElementLocation(this);
-	if (location.isNull()) return;
-	
-	// verifie l'existence de l'element choisi
-	ElementsCollectionItem *item = QETApp::collectionItem(location);
-	ElementDefinition *element = 0;
-	if (!item) {
-		QET::QetMessageBox::critical(
-			this,
-			tr("Élément inexistant.", "message box title"),
-			tr("L'élément n'existe pas.", "message box content")
-		);
+	if (location.isNull())
+		return;
+
+	if (!location.isElement())
+	{
+		QET::QetMessageBox::critical(this,
+									 tr("Élément inexistant.", "message box title"),
+									 tr("Le chemin virtuel choisi ne correspond pas à un élément.", "message box content"));
 		return;
 	}
-	
-	if (!item -> isElement() || !(element = qobject_cast<ElementDefinition *>(item)) || element -> isNull()) {
-		QET::QetMessageBox::critical(
-			this,
-			tr("Élément inexistant.", "message box title"),
-			tr("Le chemin virtuel choisi ne correspond pas à un élément.", "message box content")
-		);
+	if (!location.exist())
+	{
+		QET::QetMessageBox::critical(this,
+									 tr("Élément inexistant.", "message box title"),
+									 tr("L'élément n'existe pas.", "message box content"));
 		return;
 	}
-	
-	// creation d'un document XML a partir de la description XML de l'element
+
+		//Create an xml document from the location xml
 	QDomDocument document_xml;
-	QDomNode node = document_xml.importNode(element -> xml(), true);
+	QDomNode node = document_xml.importNode(location.xml(), true);
 	document_xml.appendChild(node);
-	
+
 	copyAndPasteXml(document_xml);
 }
 
