@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -21,9 +21,9 @@
 #include "qetmainwindow.h"
 #include "qet.h"
 #include "elementscene.h"
-#include "orientationset.h"
 #include "elementslocation.h"
 
+
 class ElementItemEditor;
 class ElementView;
 
@@ -53,7 +53,7 @@ class QETElementEditor : public QETMainWindow {
 	/// view widget for the editing scene
 	ElementView *ce_view;
 	/// editing scene
-	ElementScene *ce_scene;
+	ElementScene *m_elmt_scene;
 	/// container for widgets dedicated to primitive edition
 	QDockWidget *tools_dock;
 	/// Stack of widgets for tools_dock
@@ -71,7 +71,7 @@ class QETElementEditor : public QETMainWindow {
 	/// List of primitives
 	QListWidget *parts_list;
 	/// actions for the "file" menu
-	QAction *new_element, *open, *open_file, *save, *save_as, *save_as_file, *reload, *quit;
+	QAction *new_element, *open, *open_dxf, *open_file, *save, *save_as, *save_as_file, *reload, *quit;
 	/// actions for the "edit" menu
 	QAction *selectall, *deselectall, *inv_select;
 	QAction *cut, *copy, *paste, *paste_in_area, *paste_from_file, *paste_from_elmt;
@@ -93,7 +93,6 @@ class QETElementEditor : public QETMainWindow {
 	// methods
 	public:
 	void setNames(const NamesList &);
-	OrientationSet orientations() const;
 	void setLocation(const ElementsLocation &);
 	ElementsLocation location() const;
 	void setFileName(const QString &);
@@ -103,7 +102,7 @@ class QETElementEditor : public QETMainWindow {
 	void fromFile(const QString &);
 	void fromLocation(const ElementsLocation &);
 	bool toFile(const QString &);
-	bool toLocation(const ElementsLocation &);
+	bool toLocation(const ElementsLocation &location);
 	bool isEditing(const ElementsLocation &);
 	bool isEditing(const QString &);
 	ElementScene *elementScene() const;
@@ -113,6 +112,9 @@ class QETElementEditor : public QETMainWindow {
 	static QString getOpenElementFileName(QWidget * = 0, const QString & = QString());
 	void contextMenu(QPoint p);
 
+	signals:
+		void saveToLocation(ElementsLocation loc);
+
 	protected:
 	void closeEvent(QCloseEvent *);
 	virtual void firstActivation(QEvent *);
@@ -135,6 +137,7 @@ class QETElementEditor : public QETMainWindow {
 
 	void slot_new();
 	void slot_open();
+	void slot_openDxf();
 	void slot_openFile();
 	void openRecentFile(const QString &);
 	void openElement(const QString &);
@@ -161,7 +164,7 @@ class QETElementEditor : public QETMainWindow {
 	@param nameslist the new list of names for the currently edited element
 */
 inline void QETElementEditor::setNames(const NamesList &nameslist) {
-	ce_scene -> setNames(nameslist);
+	m_elmt_scene -> setNames(nameslist);
 }
 
 /**
@@ -182,7 +185,7 @@ inline QString QETElementEditor::fileName() const {
 	@return the editing scene
 */
 inline ElementScene *QETElementEditor::elementScene() const {
-	return(ce_scene);
+	return(m_elmt_scene);
 }
 
 #endif
