@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -16,14 +16,14 @@
 	along with QElectroTech.  If not, see <http://www.gnu.org/licenses/>.
 */
 #include "elementscollectioncache.h"
-#include "elementscollection.h"
-#include "elementscategory.h"
-#include "elementdefinition.h"
 #include "factory/elementfactory.h"
 #include "element.h"
-#include <QImageWriter>
 #include "qet.h"
 
+#include <QImageWriter>
+#include <QSqlQuery>
+#include <QSqlError>
+
 /**
 	Construct a cache for elements collections.
 	@param database_path Path of the SQLite database to open.
@@ -149,67 +149,37 @@ QString ElementsCollectionCache::pixmapStorageFormat() const {
 }
 
 /**
-	Indicate the cache a new collection is about to be browsed. This is mainly
-	used to delimit database transactions.
-	@param collection The elements collection about to be browsed.
-*/
-void ElementsCollectionCache::beginCollection(ElementsCollection *collection) {
-	bool use_cache = cache_db_.isOpen() && collection -> isCacheable();
-	if (use_cache) {
-		bool transaction_started = cache_db_.transaction();
-		qDebug() << (transaction_started ? "transaction began for " : "transaction not started for ") << collection -> protocol();
-	}
-}
-
-/**
-	Indicate the cache the currently browsed collection end has been reached. This
-	is mainly used to delimit database transactions.
-	@param collection The elements collection being browsed.
-*/
-void ElementsCollectionCache::endCollection(ElementsCollection *collection) {
-	bool use_cache = cache_db_.isOpen() && collection -> isCacheable();
-	if (use_cache) {
-		bool transaction_commited = cache_db_.commit();
-		if (transaction_commited) {
-			qDebug() << "transaction commited for " << collection -> protocol();
-		} else {
-			qDebug() << "transaction not commited for " << collection -> protocol() << ":" << cache_db_.lastError();
-		}
-	}
-}
-
-/**
-	Retrieve the data for a given element, using the cache if available,
-	filling it otherwise. Data are then available through pixmap() and name()
-	methods.
-	@param element The definition of an element.
-	@see pixmap()
-	@see name()
-	@return True if the retrieval succeeded, false otherwise.
-*/
-bool ElementsCollectionCache::fetchElement(ElementDefinition *element)
+ * @brief ElementsCollectionCache::fetchElement
+ * Retrieve the data for a given element, using the cache if available,
+ * filling it otherwise. Data are then available through pixmap() and name() methods.
+ * @param location The definition of an element.
+ * @see pixmap()
+ * @see name()
+ * @return True if the retrieval succeeded, false otherwise.
+ */
+bool ElementsCollectionCache::fetchElement(ElementsLocation &location)
 {
 		// can we use the cache with this element?
-	bool use_cache = cache_db_.isOpen() && element -> parentCollection() -> isCacheable();
-	
+	bool use_cache = cache_db_.isOpen() && !location.isProject();
+
 		// attempt to fetch the element name from the cache database
-	if (!use_cache)
-	{
-		return(fetchData(element -> location()));
+	if (!use_cache) {
+		return(fetchData(location));
 	}
 	else
 	{
-		QString element_path = element -> location().toString();
-		bool got_name   = fetchNameFromCache(element_path, element->uuid());
-		bool got_pixmap = fetchPixmapFromCache(element_path, element->uuid());
-		if (got_name && got_pixmap)
-		{
+		QString element_path = location.toString();
+		bool got_name   = fetchNameFromCache(element_path, location.uuid());
+		bool got_pixmap = fetchPixmapFromCache(element_path, location.uuid());
+
+		if (got_name && got_pixmap) {
 			return(true);
 		}
-		if (fetchData(element -> location()))
+
+		if (fetchData(location))
 		{
-			cacheName(element_path, element->uuid());
-			cachePixmap(element_path, element->uuid());
+			cacheName(element_path, location.uuid());
+			cachePixmap(element_path, location.uuid());
 		}
 		return(true);
 	}
