@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -17,12 +17,10 @@
 */
 #ifndef ELEMENTS_COLLECTION_CACHE_H
 #define ELEMENTS_COLLECTION_CACHE_H
-#include <QtCore>
-#include <QtSql>
+
+#include <QSqlDatabase>
 #include "elementslocation.h"
-class ElementsCollection;
-class ElementsCategory;
-class ElementDefinition;
+
 /**
 	This class implements a SQLite cache for data related to elements
 	collections, mainly names and pixmaps. This avoids the cost of parsing XML
@@ -42,9 +40,7 @@ class ElementsCollectionCache : public QObject
 	QString locale() const;
 	bool setPixmapStorageFormat(const QString &);
 	QString pixmapStorageFormat() const;
-	void beginCollection(ElementsCollection *);
-	void endCollection(ElementsCollection *);
-	bool fetchElement(ElementDefinition *);
+	bool fetchElement(ElementsLocation &location);
 	QString name() const;
 	QPixmap pixmap() const;
 	bool fetchData(const ElementsLocation &);
