@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -17,8 +17,9 @@
 */
 #ifndef ELEMENTS_PANEL_WIDGET_H
 #define ELEMENTS_PANEL_WIDGET_H
-#include <QtWidgets>
+
 #include "elementspanel.h"
+
 /**
 	This class embeds an elements panel under a toolbar providing various actions
 	to manage elements.
@@ -38,19 +39,11 @@ class ElementsPanelWidget : public QWidget {
 	// attributes
 	private:
 	ElementsPanel *elements_panel;
-	QToolBar *toolbar;
 	QAction *open_directory, *copy_path;
-	QAction *reload;
-	QAction *new_category, *edit_category, *delete_category;
-	QAction *delete_collection;
-	QAction *new_element, *edit_element, *delete_element, *open_element;
 	QAction *prj_activate, *prj_close, *prj_edit_prop, *prj_prop_diagram, *prj_add_diagram, *prj_del_diagram, *prj_move_diagram_up, *prj_move_diagram_top, *prj_move_diagram_down, *prj_move_diagram_upx10, *prj_move_diagram_downx10;
 	QAction *tbt_add, *tbt_edit, *tbt_remove;
-	QAction *copy_elements_, *move_elements_, *cancel_elements_;
 	QMenu *context_menu;
 	QLineEdit *filter_textfield;
-	ElementsCollectionItem *dnd_item_src_, *dnd_item_dst_;
-	QProgressBar *progress_bar_;
 	
 	// methods
 	public:
@@ -88,33 +81,14 @@ class ElementsPanelWidget : public QWidget {
 	void addTitleBlockTemplate();
 	void editTitleBlockTemplate();
 	void removeTitleBlockTemplate();
-	void newCategory();
-	void newElement();
-	void openElementFromFile();
-	void editCategory();
-	void editElement();
-	void deleteCategory();
-	void deleteElement();
 	void updateButtons();
-	void setElementsActionEnabled(bool);
-	int  launchCategoriesManager();
 	void handleContextMenu(const QPoint &);
-	void handleCollectionRequest(const ElementsLocation &);
-	void handleMoveElementsRequest(ElementsCollectionItem *, ElementsCollectionItem *, const QPoint & = QPoint());
-	void moveElements();
-	void moveElements(ElementsCollectionItem *, ElementsCollectionItem *);
-	void copyElements();
-	void copyElements(ElementsCollectionItem *, ElementsCollectionItem *);
-	void collectionsRead();
-	void collectionsReadFinished();
-	void updateProgressBar(int, int);
-	void loadingFinished();
 	void filterEdited(const QString &);
+
+	protected:
+	virtual void keyPressEvent   (QKeyEvent *e);
 	
 	private:
-	void launchElementEditor(const ElementsLocation &);
-	void launchCategoryEditor(const ElementsLocation &);
-	ElementsCategory *writableSelectedCategory();
 	QString previous_filter_;
 };
 
