@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -55,9 +55,9 @@ ExportDialog::ExportDialog(QETProject *project, QWidget *parent) : QDialog(paren
 	}
 	
 	// la taille minimale du dialogue est fixee
-	setMinimumSize(800, 390);
+	setMinimumSize(800, 590);
 	resize(minimumSize());
-    setWindowTitle(tr("Exporter les folios du projet", "window title"));
+	setWindowTitle(tr("Exporter les folios du projet", "window title"));
 
 	// options d'export, dans le widget epw
 	epw = new ExportPropertiesWidget(default_export_properties);
@@ -72,7 +72,7 @@ ExportDialog::ExportDialog(QETProject *project, QWidget *parent) : QDialog(paren
 	// disposition des elements
 
 	QHBoxLayout *hLayout = new QHBoxLayout();
-    hLayout -> addWidget(new QLabel(tr("Choisissez les folios que vous désirez exporter ainsi que leurs dimensions :")));
+	hLayout -> addWidget(new QLabel(tr("Choisissez les folios que vous désirez exporter ainsi que leurs dimensions :")));
 	selectAll   = new QPushButton();
 	deSelectAll = new QPushButton();
 	selectAll   -> setText(tr("Tout cocher"));
@@ -138,7 +138,7 @@ QWidget *ExportDialog::initDiagramsListPart() {
 	diagrams_list_layout_ = new QGridLayout();
 	
 	int line_count = 0;
-    diagrams_list_layout_ -> addWidget(new QLabel(tr("Titre du folio")),        line_count, 1, Qt::AlignHCenter | Qt::AlignVCenter);
+	diagrams_list_layout_ -> addWidget(new QLabel(tr("Titre du folio")),        line_count, 1, Qt::AlignHCenter | Qt::AlignVCenter);
 	diagrams_list_layout_ -> addWidget(new QLabel(tr("Nom de fichier")),   line_count, 2, Qt::AlignHCenter | Qt::AlignVCenter);
 	diagrams_list_layout_ -> addWidget(new QLabel(tr("Dimensions")),       line_count, 3, Qt::AlignHCenter | Qt::AlignVCenter);
 	
@@ -423,10 +423,11 @@ void ExportDialog::generateDxf(Diagram *diagram, int width, int height, bool kee
 	//QList<QRectF *> list_ellipses;
 	QList <QetShapeItem *> list_shapes;
 
-	DiagramFolioList *ptr;
-	if ((ptr = dynamic_cast<DiagramFolioList *>(diagram))) {
+	DiagramFolioList *ptr = dynamic_cast<DiagramFolioList *>(diagram);
+	if (ptr) {
 		list_lines = ptr -> lines();
 		list_rectangles = ptr -> rectangles();
+		QSettings settings;
 
 		// fill the rows with text.
 		QString authorTranslatable = tr("Auteur");
@@ -442,33 +443,25 @@ void ExportDialog::generateDxf(Diagram *diagram, int width, int height, bool kee
 		fillRow(file_path, row_RectF, authorTranslatable, titleTranslatable, folioTranslatable, dateTranslatable);
 		QList<Diagram *> diagram_list = ptr -> project() -> diagrams();
 
-		int startDiagram = (ptr -> getId()) * 58;
+		int startDiagram = (ptr -> getId()) *29;
 
 		for (int i = startDiagram; i < startDiagram+29 && i < diagram_list.size(); ++i) {
 			y0 += rowHeight;
 			QRectF row_rect(x0, y0, list_rectangles[0] -> width(), rowHeight);
+			if (settings.value("genericpanel/folio", true).toBool()){
 			fillRow(file_path, row_rect, diagram_list[i] -> border_and_titleblock.author(),
 					diagram_list[i] -> title(),
-					QString::number(diagram_list[i] ->folioIndex()+1),
-					diagram_list[i] -> border_and_titleblock.date().toString("dd/MM/yyyy"));
-		}
-
-		x0 = list_rectangles[1] -> topLeft().x();
-		y0 = list_rectangles[1] -> topLeft().y();
-		rowHeight = (list_rectangles[1] -> height())/30;
-		QRectF row_RectF2(x0, y0, list_rectangles[1] -> width(), rowHeight);
-		fillRow(file_path, row_RectF2, authorTranslatable, titleTranslatable, folioTranslatable, dateTranslatable);
-
-		startDiagram += 29;
-
-		for (int i = startDiagram; i < startDiagram+29 && i < diagram_list.size(); ++i) {
-			y0 += rowHeight;
-			QRectF row_rect(x0, y0, list_rectangles[1] -> width(), rowHeight);
-			fillRow(file_path, row_rect, diagram_list[i] -> border_and_titleblock.author(),
+					diagram_list[i] -> border_and_titleblock.finalfolio(),
+					diagram_list[i] -> border_and_titleblock.date().toString("dd/MM/yy"));
+					
+		}else{
+				fillRow(file_path, row_rect, diagram_list[i] -> border_and_titleblock.author(),
 					diagram_list[i] -> title(),
 					QString::number(diagram_list[i] ->folioIndex()+1),
-					diagram_list[i] -> border_and_titleblock.date().toString("dd/MM/yyyy"));
+					diagram_list[i] -> border_and_titleblock.date().toString("dd/MM/yy"));
+					
 		}
+}
 
 	} else {
 		// Determine les elements a "XMLiser"
@@ -698,29 +691,29 @@ void ExportDialog::fillRow(QString file_path, const QRectF &row_rect, QString au
 	y += height*0.2;
 
 	Createdxf::drawTextAligned(file_path, folio,
-							   x + 0.05*DiagramFolioList::colWidths[0]*row_rect.width()*Createdxf::xScale, y, height, 0, 0, 5, 0,
+							   x + 0.02*DiagramFolioList::colWidths[0]*row_rect.width()*Createdxf::xScale, y, height, 0, 0, 5, 0,
 							   x + 0.95*DiagramFolioList::colWidths[0]*row_rect.width()*Createdxf::xScale, 0);
 
 	x += DiagramFolioList::colWidths[0]*row_rect.width()*Createdxf::xScale;
 	QString heading = tr("Titre");
 	if (title == heading)
 		Createdxf::drawTextAligned(file_path, title,
-								   x + 0.05*DiagramFolioList::colWidths[1]*row_rect.width()*Createdxf::xScale, y, height, 0, 0, 5, 0,
-								   x + 0.95*DiagramFolioList::colWidths[1]*row_rect.width()*Createdxf::xScale, 0);
+								   x + 0.02*DiagramFolioList::colWidths[1]*row_rect.width()*Createdxf::xScale, y, height, 0, 0, 5, 0,
+								   x + 0.02*DiagramFolioList::colWidths[1]*row_rect.width()*Createdxf::xScale, 0);
 	else
 		Createdxf::drawTextAligned(file_path, title,
-								   x + 0.05*DiagramFolioList::colWidths[1]*row_rect.width()*Createdxf::xScale, y, height, 0, 0, 5, 0,
-								   x + 0.95*DiagramFolioList::colWidths[1]*row_rect.width()*Createdxf::xScale, 0, true);
+								   x + 0.02*DiagramFolioList::colWidths[1]*row_rect.width()*Createdxf::xScale, y, height, 0, 0, 5, 0,
+								   x + 0.02*DiagramFolioList::colWidths[1]*row_rect.width()*Createdxf::xScale, 0, true);
 
 	x += DiagramFolioList::colWidths[1]*row_rect.width()*Createdxf::xScale;
 	Createdxf::drawTextAligned(file_path, author,
-							   x + 0.05*DiagramFolioList::colWidths[2]*row_rect.width()*Createdxf::xScale, y, height, 0, 0, 5, 0,
-							   x + 0.95*DiagramFolioList::colWidths[2]*row_rect.width()*Createdxf::xScale, 0);
+							   x + 0.02*DiagramFolioList::colWidths[2]*row_rect.width()*Createdxf::xScale, y, height, 0, 0, 5, 0,
+							   x + 3.02*DiagramFolioList::colWidths[2]*row_rect.width()*Createdxf::xScale, 0);
 
 	x += DiagramFolioList::colWidths[2]*row_rect.width()*Createdxf::xScale;
 	Createdxf::drawTextAligned(file_path, date,
-							   x + 0.05*DiagramFolioList::colWidths[3]*row_rect.width()*Createdxf::xScale, y, height, 0, 0, 5, 0,
-							   x + 0.95*DiagramFolioList::colWidths[3]*row_rect.width()*Createdxf::xScale, 0);
+							   x + 0.02*DiagramFolioList::colWidths[3]*row_rect.width()*Createdxf::xScale, y, height, 0, 0, 5, 0,
+							   x + 5.02*DiagramFolioList::colWidths[3]*row_rect.width()*Createdxf::xScale, 0);
 }
 
 QPointF ExportDialog::rotation_transformed(qreal px, qreal py , qreal origin_x, qreal origin_y, qreal angle) {
@@ -769,7 +762,7 @@ void ExportDialog::slot_export() {
 			tr("Noms des fichiers cibles", "message box title"),
 			tr(
 				"Vous devez entrer un nom de fichier non vide et unique pour chaque "
-                "folio à exporter.",
+				"folio à exporter.",
 				"message box content"
 			)
 		);
@@ -1031,16 +1024,18 @@ ExportDialog::ExportDiagramLine::ExportDiagramLine(Diagram *dia, QSize diagram_s
 	
 	// titre et nom de fichier du schema
 	QString diagram_title = diagram -> title();
-    if (diagram_title.isEmpty()) diagram_title = QObject::tr("Folio sans titre");
+	QString diagram_index = QString::number(diagram -> folioIndex()+1);
+	//QString diagram_folio_label = diagram -> border_and_titleblock.finalfolio();
+	if (diagram_title.isEmpty()) diagram_title = QObject::tr("Folio sans titre");
 	QString diagram_filename = diagram -> title();
 	if (diagram_filename.isEmpty()) diagram_filename = QObject::tr("schema");
-	diagram_filename = QET::stringToFileName(diagram_filename);
+	diagram_filename = QET::stringToFileName(diagram_index + "_" + diagram_filename);
 	
 	title_label = new QLabel(diagram_title);
 	
 	file_name = new QLineEdit();
 	file_name -> setText(diagram_filename);
-	file_name -> setMinimumWidth(180);
+	file_name -> setMinimumWidth(280);
 	
 	width = new QSpinBox();
 	width -> setRange(1, 10000);
