@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -17,11 +17,15 @@
 */
 #ifndef NEW_ELEMENT_WIZARD_H
 #define NEW_ELEMENT_WIZARD_H
-#include <QtWidgets>
-class ElementsCategoriesWidget;
-class ElementsCategory;
+
+#include <QWizard>
+#include "elementslocation.h"
+
 class NamesListWidget;
 class QFileNameEdit;
+class QTreeView;
+class ElementsCollectionModel;
+
 /**
 	This class provides a wizard dialog enabling users to to specify the basic
 	parameters of the electrical elements they intend to draw.
@@ -31,40 +35,38 @@ class QFileNameEdit;
 	  - the filename the element should be saved to
 	  - localized names
 */
-class NewElementWizard : public QWizard {
+class NewElementWizard : public QWizard
+{
 	Q_OBJECT
 	
-	// constructors, destructor
+		// constructors, destructor
 	public:
-	NewElementWizard(QWidget * = 0, Qt::WindowFlags = 0);
-	virtual ~NewElementWizard();
+		NewElementWizard(QWidget * = 0, Qt::WindowFlags = 0);
+		virtual ~NewElementWizard();
+
+		void preselectedLocation(const ElementsLocation &location);
 	
 	private:
-	NewElementWizard(const NewElementWizard &);
+		NewElementWizard(const NewElementWizard &);
 	
-	// methods
-	public:
-	ElementsCategory *selectedCategory() const;
-	bool preselectCategory(ElementsCategory *);
-	
-	// attributes
+		// attributes
 	private:
-	enum WizardState { Category, Filename, Names };
-	ElementsCategoriesWidget *categories_list;
-	QFileNameEdit *qle_filename;
-	NamesListWidget *element_names;
-	WizardState current_state;
-	QString chosen_file;
-	ElementsCategory *chosen_category;
+		enum WizardState { Category, Filename, Names };
+		QFileNameEdit *m_qle_filename;
+		NamesListWidget *m_names_list;
+		QString m_chosen_file;
+		QTreeView *m_tree_view = nullptr;
+		ElementsLocation m_chosen_location;
+		ElementsCollectionModel *m_model = nullptr;
 	
-	// methods
+		// methods
 	private:
-	QWizardPage *buildStep1();
-	QWizardPage *buildStep2();
-	QWizardPage *buildStep3();
-	bool validStep1();
-	bool validStep2();
-	bool validateCurrentPage();
-	void createNewElement();
+		QWizardPage *buildStep1();
+		QWizardPage *buildStep2();
+		QWizardPage *buildStep3();
+		bool validStep1();
+		bool validStep2();
+		bool validateCurrentPage();
+		void createNewElement();
 };
 #endif
