@@ -1,5 +1,5 @@
 /*
-		Copyright 2006-2015 The QElectroTech Team
+		Copyright 2006-2017 The QElectroTech Team
 		This file is part of QElectroTech.
 		
 		QElectroTech is free software: you can redistribute it and/or modify
@@ -19,6 +19,8 @@
 
 #include "nomenclature.h"
 #include "elementprovider.h"
+#include "assignvariables.h"
+
 #define PR(x) qDebug() << #x " = " << x;
 
 /**
@@ -84,6 +86,7 @@ QString nomenclature::getNomenclature()
 	QString data = QObject::tr("NOMENCLATURE : ") + m_project -> title() + "\n\n";
 	data += QObject::tr("N° de folio") +";"
 	""+ QObject::tr("Titre de folio") +";"
+	""+ QObject::tr("Label de folio") +";"
 	""+ QObject::tr("Désignation qet") +";"
 	""+ QObject::tr("Position") +";"
 	""+ QObject::tr("Label") +";"
@@ -103,8 +106,18 @@ QString nomenclature::getNomenclature()
 	foreach (Diagram *d, m_list_diagram) {
 		//Get only simple, master and unlinked slave element.
 		ElementProvider ep(d);
+		QSettings settings;
 		QList <Element *> list_elements;
+		
+		if (settings.value("nomenclature/terminal-exportlist", true).toBool()){
+		list_elements << ep.find(Element::Simple | Element::Master | Element::Terminale);
+		
+		}else{
+		
 		list_elements << ep.find(Element::Simple | Element::Master);
+		
+		}
+		
 		list_elements << ep.freeElement(Element::Slave);
 
 		foreach (Element *elmt, list_elements) {
@@ -120,26 +133,28 @@ QString nomenclature::getNomenclature()
  * @param elmt : the element to getinfo
  * @return : QString with information about element formated to csv file
  */
-QString nomenclature::getElementInfo(const Element *elmt) {
+QString nomenclature::getElementInfo(Element *elmt) {
 	QString info;
 
 	Diagram *diagram = elmt -> diagram();
 	DiagramContext elmt_info = elmt -> elementInformations();
+	autonum::sequentialNumbers empty_seq;
 
 	info += QString::number(diagram -> folioIndex()+1) + ";";
 	info += diagram -> title() + ";";
+	info += autonum::AssignVariables::formulaToLabel(diagram->border_and_titleblock.folio(), empty_seq, diagram) + ";";
 	info += elmt -> name() + ";";
 	info += elmt-> diagram()-> convertPosition(elmt -> scenePos()).toString() + ";";
-	info += elmt_info["label"].toString() + ";";
-	info += elmt_info["designation"].toString() + ";";
-	info += elmt_info["comment"].toString() + ";";
-	info += elmt_info["manufacturer"].toString() + ";";
-	info += elmt_info["manufacturer-reference"].toString() + ";";
-	info += elmt_info["auxiliary1"].toString() + ";";
-	info += elmt_info["auxiliary2"].toString() + ";";
-	info += elmt_info["machine-manufacturer-reference"].toString() + ";";
-	info += elmt_info["location"].toString() + ";";
-	info += elmt_info["function"].toString() + "\n";
+	info += autonum::AssignVariables::formulaToLabel(elmt_info["label"].toString(), elmt->rSequenceStruct(), elmt->diagram(), elmt) + ";";
+	info += autonum::AssignVariables::formulaToLabel(elmt_info["designation"].toString(), elmt->rSequenceStruct(), elmt->diagram(), elmt) + ";";
+	info += autonum::AssignVariables::formulaToLabel(elmt_info["comment"].toString(), elmt->rSequenceStruct(), elmt->diagram(), elmt) + ";";
+	info += autonum::AssignVariables::formulaToLabel(elmt_info["manufacturer"].toString(), elmt->rSequenceStruct(), elmt->diagram(), elmt) + ";";
+	info += autonum::AssignVariables::formulaToLabel(elmt_info["manufacturer-reference"].toString(), elmt->rSequenceStruct(), elmt->diagram(), elmt) + ";";
+	info += autonum::AssignVariables::formulaToLabel(elmt_info["auxiliary1"].toString(), elmt->rSequenceStruct(), elmt->diagram(), elmt) + ";";
+	info += autonum::AssignVariables::formulaToLabel(elmt_info["auxiliary2"].toString(), elmt->rSequenceStruct(), elmt->diagram(), elmt) + ";";
+	info += autonum::AssignVariables::formulaToLabel(elmt_info["machine-manufacturer-reference"].toString(), elmt->rSequenceStruct(), elmt->diagram(), elmt) + ";";
+	info += autonum::AssignVariables::formulaToLabel(elmt_info["location"].toString(), elmt->rSequenceStruct(), elmt->diagram(), elmt) + ";";
+	info += autonum::AssignVariables::formulaToLabel(elmt_info["function"].toString(), elmt->rSequenceStruct(), elmt->diagram(), elmt) + "\n";
 
 	return info;
 }
