@@ -1,17 +1,17 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
-	
+
 	QElectroTech is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
 	the Free Software Foundation, either version 2 of the License, or
 	(at your option) any later version.
-	
+
 	QElectroTech is distributed in the hope that it will be useful,
 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 	GNU General Public License for more details.
-	
+
 	You should have received a copy of the GNU General Public License
 	along with QElectroTech.  If not, see <http://www.gnu.org/licenses/>.
 */
@@ -23,7 +23,6 @@
 #include "exportdialog.h"
 #include "qetapp.h"
 #include "qetelementeditor.h"
-#include "interactivemoveelementshandler.h"
 #include "borderpropertieswidget.h"
 #include "titleblockpropertieswidget.h"
 #include "conductorpropertieswidget.h"
@@ -32,8 +31,8 @@
 #include "qettemplateeditor.h"
 #include "diagramfoliolist.h"
 #include "projectpropertiesdialog.h"
-
-#include <QTabWidget>
+#include "xmlelementcollection.h"
+#include "autoNum/assignvariables.h"
 
 /**
 	Constructeur
@@ -42,12 +41,12 @@
 */
 ProjectView::ProjectView(QETProject *project, QWidget *parent) :
 	QWidget(parent),
-	project_(0)
+	m_project(0)
 {
 	initActions();
 	initWidgets();
 	initLayout();
-	
+
 	setProject(project);
 }
 
@@ -57,8 +56,8 @@ ProjectView::ProjectView(QETProject *project, QWidget *parent) :
 */
 ProjectView::~ProjectView() {
 	// qDebug() << "Suppression du ProjectView" << ((void *)this);
-	foreach(int id, diagram_ids_.keys()) {
-		DiagramView *diagram_view = diagram_ids_.take(id);
+	foreach(int id, m_diagram_ids.keys()) {
+		DiagramView *diagram_view = m_diagram_ids.take(id);
 		delete diagram_view;
 	}
 }
@@ -67,7 +66,7 @@ ProjectView::~ProjectView() {
 	@return le projet actuellement visualise par le ProjectView
 */
 QETProject *ProjectView::project() {
-	return(project_);
+	return(m_project);
 }
 
 /**
@@ -76,11 +75,12 @@ QETProject *ProjectView::project() {
 	@param project projet a visualiser
 */
 void ProjectView::setProject(QETProject *project) {
-	if (!project_) {
-		project_ = project;
-		connect(project_, SIGNAL(projectTitleChanged(QETProject *, const QString &)), this, SLOT(updateWindowTitle()));
-		connect(project_, SIGNAL(projectModified    (QETProject *, bool)),            this, SLOT(updateWindowTitle()));
-		connect(project_, SIGNAL(readOnlyChanged    (QETProject *, bool)),            this, SLOT(adjustReadOnlyState()));
+	if (!m_project) {
+		m_project = project;
+		connect(m_project, SIGNAL(projectTitleChanged(QETProject *, const QString &)),	this, SLOT(updateWindowTitle()));
+		connect(m_project, SIGNAL(projectModified	(QETProject *, bool)),				this, SLOT(updateWindowTitle()));
+		connect(m_project, SIGNAL(readOnlyChanged	(QETProject *, bool)),				this, SLOT(adjustReadOnlyState()));
+		connect(m_project, SIGNAL(addAutoNumDiagram()),									this, SLOT(addNewDiagram()));
 		adjustReadOnlyState();
 		loadDiagrams();
 	}
@@ -89,39 +89,19 @@ void ProjectView::setProject(QETProject *project) {
 /**
 	@return la liste des schemas ouverts dans le projet
 */
-QList<DiagramView *> ProjectView::diagrams() const {
-	return(diagrams_);
+QList<DiagramView *> ProjectView::diagram_views() const {
+	return(m_diagram_view_list);
 }
 
 /**
-	@return A list containing child diagrams matching provided \a options.
-*/
-QList<Diagram *> ProjectView::getDiagrams(ProjectSaveOptions options) {
-	QList<Diagram *> selection;
-	if ((options & AllDiagrams) == AllDiagrams) {
-		selection << project_ -> diagrams();
-	} else {
-		Diagram *current = 0;
-		if (DiagramView *view = currentDiagram()) {
-			current = view -> diagram();
-		}
-		if (options & CurrentDiagram) {
-			if (current) selection << current;
-		} else if (options & AllDiagramsButCurrent) {
-			selection = project_ -> diagrams();
-			selection.removeOne(current);
-		}
-	}
-	
-	return(selection);
-}
-
-/**
-	@return le schema actuellement active
-*/
+ * @brief ProjectView::currentDiagram
+ * @return The current active diagram view or nullptr if there isn't diagramView in this project view.
+ */
 DiagramView *ProjectView::currentDiagram() const {
 	int current_tab_index = m_tab -> currentIndex();
-	return(diagram_ids_[current_tab_index]);
+	if (current_tab_index == -1)
+		return nullptr;
+	return(m_diagram_ids[current_tab_index]);
 }
 
 /**
@@ -138,6 +118,83 @@ void ProjectView::closeEvent(QCloseEvent *qce) {
 	}
 }
 
+/**
+	@brief change current diagramview to next folio
+*/
+void ProjectView::changeTabDown(){
+	DiagramView *nextDiagramView = this->nextDiagram();
+	if (nextDiagramView!=NULL){
+		rebuildDiagramsMap();
+		m_tab -> setCurrentWidget(nextDiagramView);
+	}
+}
+
+/**
+	@return next folio of current diagramview
+*/
+DiagramView *ProjectView::nextDiagram() {
+	int current_tab_index = m_tab -> currentIndex();
+	int next_tab_index = current_tab_index + 1;	//get next tab index
+	if (next_tab_index<m_diagram_ids.count()) //if next tab index >= greatest tab the last tab is activated so no need to change tab.
+		return(m_diagram_ids[next_tab_index]);
+	else
+		return NULL;
+}
+
+/**
+	@brief change current diagramview to previous tab
+*/
+void ProjectView::changeTabUp(){
+	DiagramView *previousDiagramView = this->previousDiagram();
+	if (previousDiagramView!=NULL){
+		rebuildDiagramsMap();
+		m_tab -> setCurrentWidget(previousDiagramView);
+	}
+}
+
+/**
+	@return previous folio of current diagramview
+*/
+DiagramView *ProjectView::previousDiagram() {
+	int current_tab_index = m_tab -> currentIndex();
+	int previous_tab_index = current_tab_index - 1;	//get previous tab index
+	if (previous_tab_index>=0) //if previous tab index = 0 then the first tab is activated so no need to change tab.
+		return(m_diagram_ids[previous_tab_index]);
+	else
+		return NULL;
+}
+
+/**
+	@brief change current diagramview to last tab
+*/
+void ProjectView::changeLastTab(){
+	DiagramView *lastDiagramView = this->lastDiagram();
+	m_tab->setCurrentWidget(lastDiagramView);
+}
+
+/**
+	@return last folio of current project
+*/
+DiagramView *ProjectView::lastDiagram(){
+	return(m_diagram_ids.last());
+}
+
+/**
+	@brief change current diagramview to first tab
+*/
+void ProjectView::changeFirstTab(){
+	DiagramView *firstDiagramView = this->firstDiagram();
+	m_tab->setCurrentWidget(firstDiagramView);
+}
+
+/**
+	@return first folio of current project
+*/
+DiagramView *ProjectView::firstDiagram(){
+	return(m_diagram_ids.first());
+}
+
+
 /**
 	Cette methode essaye de fermer successivement les editeurs d'element puis
 	les schemas du projet. L'utilisateur peut refuser de fermer un schema ou un
@@ -147,20 +204,20 @@ void ProjectView::closeEvent(QCloseEvent *qce) {
 	@see tryClosingDiagrams()
 */
 bool ProjectView::tryClosing() {
-	if (!project_) return(true);
-	
+	if (!m_project) return(true);
+
 	// First step: require external editors closing -- users may either cancel
 	// the whole closing process or save (and therefore add) content into this
 	// project. Of course, they may also discard them.
 	if (!tryClosingElementEditors()) {
 		return(false);
 	}
-	
+
 	// Check how different the current situation is from a brand new, untouched project
-	if (project_ -> filePath().isEmpty() && !project_ -> projectWasModified()) {
+	if (m_project -> filePath().isEmpty() && !m_project -> projectWasModified()) {
 		return(true);
 	}
-	
+
 	// Second step: users are presented with a dialog that enables them to
 	// choose whether they want to:
 	//   - cancel the closing process,
@@ -173,17 +230,17 @@ bool ProjectView::tryClosing() {
 	} else if (user_input == QMessageBox::Discard) {
 		return(true); // all modifications were discarded
 	}
-	
+
 	// Check how different the current situation is from a brand new, untouched project (yes , again)
-	if (project_ -> filePath().isEmpty() && !project_ -> projectWasModified()) {
+	if (m_project -> filePath().isEmpty() && !m_project -> projectWasModified()) {
 		return(true);
 	}
-	
-	if (project_ -> filePath().isEmpty()) {
+
+	if (m_project -> filePath().isEmpty()) {
 		QString filepath = askUserForFilePath();
 		if (filepath.isEmpty()) return(false); // users may cancel the closing
 	}
-	QETResult result = project_ -> write();
+	QETResult result = m_project -> write();
 	updateWindowTitle();
 	if (!result.isOk()) emit(errorEncountered(result.errorMessage()));
 	return(result.isOk());
@@ -196,17 +253,17 @@ bool ProjectView::tryClosing() {
 	@return true si tous les editeurs d'element ont pu etre fermes, false sinon
 */
 bool ProjectView::tryClosingElementEditors() {
-	if (!project_) return(true);
+	if (!m_project) return(true);
 	/*
 		La QETApp permet d'acceder rapidement aux editeurs d'element
 		editant un element du projet.
 	*/
-	QList<QETElementEditor *> editors = QETApp::elementEditors(project_);
+	QList<QETElementEditor *> editors = QETApp::elementEditors(m_project);
 	foreach(QETElementEditor *editor, editors) {
 		if (!editor -> close()) return(false);
 	}
-	
-	QList<QETTitleBlockTemplateEditor *> template_editors = QETApp::titleBlockTemplateEditors(project_);
+
+	QList<QETTitleBlockTemplateEditor *> template_editors = QETApp::titleBlockTemplateEditors(m_project);
 	foreach(QETTitleBlockTemplateEditor *template_editor, template_editors) {
 		if (!template_editor -> close()) return(false);
 	}
@@ -220,7 +277,7 @@ bool ProjectView::tryClosingElementEditors() {
  * @return the answer of dialog or discard if no change.
  */
 int ProjectView::tryClosingDiagrams() {
-	if (!project_) return(QMessageBox::Discard);
+	if (!m_project) return(QMessageBox::Discard);
 
 	if (!project()->projectOptionsWereModified() &&
 		project()->undoStack()->isClean() &&
@@ -240,10 +297,6 @@ int ProjectView::tryClosingDiagrams() {
 								   | QMessageBox::Cancel,
 								   QMessageBox::Save);
 
-	if (close_dialog == QMessageBox::Save) {
-		saveDiagrams(project()->diagrams());
-	}
-	
 	return(close_dialog);
 }
 
@@ -259,21 +312,21 @@ QString ProjectView::askUserForFilePath(bool assign) {
 	QString filepath = QFileDialog::getSaveFileName(
 		this,
 		tr("Enregistrer sous", "dialog title"),
-		project_ -> currentDir(),
-        tr("Projet QElectroTech (*.qet)", "filetypes allowed when saving a project file")
+		m_project -> currentDir(),
+		tr("Projet QElectroTech (*.qet)", "filetypes allowed when saving a project file")
 	);
-	
+
 	// if no filepath is provided, return an empty string
 	if (filepath.isEmpty()) return(filepath);
-	
+
 	// if the name does not end with the .qet extension, append it
 	if (!filepath.endsWith(".qet", Qt::CaseInsensitive)) filepath += ".qet";
-	
+
 	if (assign) {
 		// assign the provided filepath to the currently edited project
-		project_ -> setFilePath(filepath);
+		m_project -> setFilePath(filepath);
 	}
-	
+
 	return(filepath);
 }
 
@@ -291,13 +344,13 @@ QETResult ProjectView::noProjectResult() const {
  * Add new diagram to project view
  */
 void ProjectView::addNewDiagram() {
-	if (project_ -> isReadOnly()) return;
-	
-	Diagram *new_diagram = project_ -> addNewDiagram();
+	if (m_project -> isReadOnly()) return;
+
+	Diagram *new_diagram = m_project -> addNewDiagram();
 	DiagramView *new_diagram_view = new DiagramView(new_diagram);
 	addDiagram(new_diagram_view);
 
-	if (project_ -> diagrams().size() % 58 == 1 && project_ -> getFolioSheetsQuantity() != 0)
+	if (m_project -> diagrams().size() % 58 == 1 && m_project -> getFolioSheetsQuantity() != 0)
 		addNewDiagramFolioList();
 	showDiagram(new_diagram_view);
 }
@@ -307,91 +360,92 @@ void ProjectView::addNewDiagram() {
  * Add new diagram folio list to project
  */
 void ProjectView::addNewDiagramFolioList() {
-	if (project_ -> isReadOnly()) return;
+	if (m_project -> isReadOnly()) return;
 	int i = 1; //< Each new diagram is added  to the end of the project.
 			   //< We use @i to move the folio list at second position in the project
-	foreach (Diagram *d, project_ -> addNewDiagramFolioList()) {
+	foreach (Diagram *d, m_project -> addNewDiagramFolioList()) {
 		DiagramView *new_diagram_view = new DiagramView(d);
 		addDiagram(new_diagram_view);
 		showDiagram(new_diagram_view);
-		m_tab->tabBar()->moveTab(diagrams().size()-1, i);
+		m_tab->tabBar()->moveTab(diagram_views().size()-1, i);
 		i++;
 	}
 }
 
-/**
-	Ajoute un schema au ProjectView
-	@param diagram Schema a ajouter
-*/
 /**
  * @brief ProjectView::addDiagram
- * Add new digram to this project view
- * @param diagram added diagram
- * @param front: true add page at front
- *				 false add page at back
+ * Add diagram view to this project view
+ * @param diagram_view
  */
-void ProjectView::addDiagram(DiagramView *diagram) {
-	if (!diagram) return;
+void ProjectView::addDiagram(DiagramView *diagram_view)
+{
+	if (!diagram_view) 
+		return;
 
-	// check diagram isn't present in the project
-	if (diagram_ids_.values().contains(diagram)) return;
-	
-	// Add new tab for the diagram
-	m_tab -> addTab(diagram, QET::Icons::Diagram, diagram -> title());
-	diagram -> setFrameStyle(QFrame::Plain | QFrame::NoFrame);
+		//Check if diagram isn't present in the project
+	if (m_diagram_ids.values().contains(diagram_view))
+		return;
 
-	diagrams_ << diagram;
+		// Add new tab for the diagram
+    m_tab->addTab(diagram_view, QET::Icons::Diagram, diagram_view -> title());
+	diagram_view->setFrameStyle(QFrame::Plain | QFrame::NoFrame);
+
+	m_diagram_view_list << diagram_view;
 
 	rebuildDiagramsMap();
-	connect(diagram, SIGNAL(showDiagram(Diagram*)), this, SLOT(showDiagram(Diagram*)));
-	connect(diagram, SIGNAL(titleChanged(DiagramView *, const QString &)), this, SLOT(updateTabTitle(DiagramView *, const QString &)));
-	connect(diagram, SIGNAL(findElementRequired(const ElementsLocation &)), this, SIGNAL(findElementRequired(const ElementsLocation &)));
-	connect(diagram, SIGNAL(editElementRequired(const ElementsLocation &)), this, SIGNAL(editElementRequired(const ElementsLocation &)));
-	connect(diagram, SIGNAL(editTitleBlockTemplate(const QString &, bool)), this, SLOT(editTitleBlockTemplateRequired(const QString &, bool)));
+	updateAllTabsTitle();
 	
-	// signal diagram was added
-	emit(diagramAdded(diagram));
+	connect(diagram_view, SIGNAL(showDiagram(Diagram*)), this, SLOT(showDiagram(Diagram*)));
+	connect(diagram_view, SIGNAL(titleChanged(DiagramView *, const QString &)), this, SLOT(updateTabTitle(DiagramView *)));
+	connect(diagram_view, SIGNAL(findElementRequired(const ElementsLocation &)), this, SIGNAL(findElementRequired(const ElementsLocation &)));
+	connect(diagram_view, SIGNAL(editElementRequired(const ElementsLocation &)), this, SIGNAL(editElementRequired(const ElementsLocation &)));
+	connect(&diagram_view->diagram()->border_and_titleblock , &BorderTitleBlock::titleBlockFolioChanged, [this, diagram_view]() {this->updateTabTitle(diagram_view);});
+
+		// signal diagram view was added
+	emit(diagramAdded(diagram_view));
 }
 
 /**
-	Enleve un schema du ProjectView
-	@param diagram_view Schema a enlever
-*/
-void ProjectView::removeDiagram(DiagramView *diagram_view) {
-	if (!diagram_view) return;
-	if (project_ -> isReadOnly()) return;
-	
-	// verifie que le schema est bien present dans le projet
-	if (!diagram_ids_.values().contains(diagram_view)) return;
-	
+ * @brief ProjectView::removeDiagram
+ * Remove a diagram (folio) of the project
+ * @param diagram_view : diagram view to remove
+ */
+void ProjectView::removeDiagram(DiagramView *diagram_view)
+{
+	if (!diagram_view)
+        return;
+	if (m_project -> isReadOnly())
+        return;
+	if (!m_diagram_ids.values().contains(diagram_view))
+        return;
 
-	//Ask confirmation to user.
+
+        //Ask confirmation to user.
 	int answer = QET::QetMessageBox::question(
 		this,
-        tr("Supprimer le folio ?", "message box title"),
-        tr("Êtes-vous sûr  de vouloir supprimer ce folio du projet ? Ce changement est irréversible.", "message box content"),
+		tr("Supprimer le folio ?", "message box title"),
+		tr("Êtes-vous sûr  de vouloir supprimer ce folio du projet ? Ce changement est irréversible.", "message box content"),
 		QMessageBox::Yes | QMessageBox::No | QMessageBox::Cancel,
 		QMessageBox::No
 	);
 	if (answer != QMessageBox::Yes) {
 		return;
 	}
-	
-	// enleve le DiagramView des onglets
-	int diagram_tab_id = diagram_ids_.key(diagram_view);
-	m_tab -> removeTab(diagram_tab_id);
-	diagrams_.removeAll(diagram_view);
+
+        //Remove the diagram view of the tabs widget
+	int index_to_remove = m_diagram_ids.key(diagram_view);
+	m_tab->removeTab(index_to_remove);
+	m_diagram_view_list.removeAll(diagram_view);
 	rebuildDiagramsMap();
-	
-	// supprime le DiagramView, puis le Diagram
-	project_ -> removeDiagram(diagram_view -> diagram());
+    
+	m_project -> removeDiagram(diagram_view -> diagram());
 	delete diagram_view;
-	
-	// signale le retrait du schema
+
 	emit(diagramRemoved(diagram_view));
-	
-	// rend definitif le retrait du schema
-	project_ -> write();
+
+        //Make definitve the withdrawal
+	m_project -> write();
+    updateAllTabsTitle();
 }
 
 /**
@@ -400,7 +454,7 @@ void ProjectView::removeDiagram(DiagramView *diagram_view) {
 */
 void ProjectView::removeDiagram(Diagram *diagram) {
 	if (!diagram) return;
-	
+
 	if (DiagramView *diagram_view = findDiagram(diagram)) {
 		removeDiagram(diagram_view);
 	}
@@ -431,8 +485,8 @@ void ProjectView::showDiagram(Diagram *diagram) {
 	configuration dialog.
 */
 void ProjectView::editProjectProperties() {
-	if (!project_) return;
-	ProjectPropertiesDialog dialog(project_, parentWidget());
+	if (!m_project) return;
+	ProjectPropertiesDialog dialog(m_project, parentWidget());
 	dialog.exec();
 }
 
@@ -464,8 +518,8 @@ void ProjectView::editDiagramProperties(Diagram *diagram) {
 */
 void ProjectView::moveDiagramUp(DiagramView *diagram_view) {
 	if (!diagram_view) return;
-	
-	int diagram_view_position = diagram_ids_.key(diagram_view);
+
+	int diagram_view_position = m_diagram_ids.key(diagram_view);
 	if (!diagram_view_position) {
 		// le schema est le premier du projet
 		return;
@@ -485,9 +539,9 @@ void ProjectView::moveDiagramUp(Diagram *diagram) {
 */
 void ProjectView::moveDiagramDown(DiagramView *diagram_view) {
 	if (!diagram_view) return;
-	
-	int diagram_view_position = diagram_ids_.key(diagram_view);
-	if (diagram_view_position + 1 == diagram_ids_.count()) {
+
+	int diagram_view_position = m_diagram_ids.key(diagram_view);
+	if (diagram_view_position + 1 == m_diagram_ids.count()) {
 		// le schema est le dernier du projet
 		return;
 	}
@@ -508,12 +562,12 @@ void ProjectView::moveDiagramUpTop(DiagramView *diagram_view)
 {
 	if (!diagram_view) return;
 
-	int diagram_view_position = diagram_ids_.key(diagram_view);
+	int diagram_view_position = m_diagram_ids.key(diagram_view);
 	if (!diagram_view_position) {
 		// le schema est le premier du projet
 		return;
 	}
-	m_tab -> tabBar() -> moveTab(diagram_view_position, (diagrams().size(), 0));
+	m_tab -> tabBar() -> moveTab(diagram_view_position, (diagram_views().size(), 0));
 }
 
 /*
@@ -530,7 +584,7 @@ void ProjectView::moveDiagramUpTop(Diagram *diagram)
 void ProjectView::moveDiagramUpx10(DiagramView *diagram_view) {
 	if (!diagram_view) return;
 
-	int diagram_view_position = diagram_ids_.key(diagram_view);
+	int diagram_view_position = m_diagram_ids.key(diagram_view);
 	if (!diagram_view_position) {
 		// le schema est le premier du projet
 		return;
@@ -551,8 +605,8 @@ void ProjectView::moveDiagramUpx10(Diagram *diagram) {
 void ProjectView::moveDiagramDownx10(DiagramView *diagram_view) {
 	if (!diagram_view) return;
 
-	int diagram_view_position = diagram_ids_.key(diagram_view);
-	if (diagram_view_position + 1 == diagram_ids_.count()) {
+	int diagram_view_position = m_diagram_ids.key(diagram_view);
+	if (diagram_view_position + 1 == m_diagram_ids.count()) {
 		// le schema est le dernier du projet
 		return;
 	}
@@ -571,27 +625,27 @@ void ProjectView::moveDiagramDownx10(Diagram *diagram) {
 	lancer l'impression de toute ou partie du projet.
 */
 void ProjectView::printProject() {
-	if (!project_) return;
-	
+	if (!m_project) return;
+
 	// transforme le titre du projet en nom utilisable pour le document
 	QString doc_name;
-	if (!(project_ -> title().isEmpty())) {
-		doc_name = project_ -> title();
-	} else if (!project_ -> filePath().isEmpty()) {
-		doc_name = QFileInfo(project_ -> filePath()).baseName();
+	if (!(m_project -> title().isEmpty())) {
+		doc_name = m_project -> title();
+	} else if (!m_project -> filePath().isEmpty()) {
+		doc_name = QFileInfo(m_project -> filePath()).baseName();
 	}
 	doc_name = QET::stringToFileName(doc_name);
 	if (doc_name.isEmpty()) {
 		doc_name = tr("projet", "string used to generate a filename");
 	}
-	
+
 	// recupere le dossier contenant le fichier courant
-	QString dir_path = project_ -> currentDir();
-	
+	QString dir_path = m_project -> currentDir();
+
 	// determine un chemin pour le pdf / ps
 	QString file_name = QDir::toNativeSeparators(QDir::cleanPath(dir_path + "/" + doc_name));
-	
-	DiagramPrintDialog print_dialog(project_, this);
+
+	DiagramPrintDialog print_dialog(m_project, this);
 	print_dialog.setDocName(doc_name);
 	print_dialog.setFileName(file_name);
 	print_dialog.exec();
@@ -601,9 +655,9 @@ void ProjectView::printProject() {
 	Exporte le schema.
 */
 void ProjectView::exportProject() {
-	if (!project_) return;
-	
-	ExportDialog ed(project_, parentWidget());
+	if (!m_project) return;
+
+	ExportDialog ed(m_project, parentWidget());
 #ifdef Q_OS_MAC
 	ed.setWindowFlags(Qt::Sheet);
 #endif
@@ -617,7 +671,7 @@ void ProjectView::exportProject() {
 	@return a QETResult object reflecting the situation
 */
 QETResult ProjectView::save() {
-	return(doSave(AllDiagrams));
+	return(doSave());
 }
 
 /**
@@ -627,55 +681,36 @@ QETResult ProjectView::save() {
 	@return a QETResult object reflecting the situation; note that a valid
 	QETResult object is returned if the operation was cancelled.
 */
-QETResult ProjectView::saveAs(ProjectSaveOptions options) {
-	if (!project_) return(noProjectResult());
-	
+QETResult ProjectView::saveAs()
+{
+	if (!m_project) return(noProjectResult());
+
 	QString filepath = askUserForFilePath();
 	if (filepath.isEmpty()) return(QETResult());
-	return(doSave(options));
+	return(doSave());
 }
 
 /**
-	Save project content according to \a options, then write the project file. May
+	Save project content, then write the project file. May
 	call saveAs if no filepath was provided before.
-	@param options May be used to specify what should be saved (e.g. modified
-	diagrams only).
 	@return a QETResult object reflecting the situation; note that a valid
 	QETResult object is returned if the operation was cancelled.
 */
-QETResult ProjectView::doSave(ProjectSaveOptions options) {
-	if (!project_) return(noProjectResult());
-	
-	if (project_ -> filePath().isEmpty()) {
+QETResult ProjectView::doSave()
+{
+	if (!m_project) return(noProjectResult());
+
+	if (m_project -> filePath().isEmpty()) {
 		// The project has not been saved to a file yet,
 		// so save() actually means saveAs().
-		return(saveAs(options));
+		return(saveAs());
 	}
-	
-	// look for diagrams matching the required save options
-	saveDiagrams(getDiagrams(options));
-	
-	// write to file
-	QETResult result = project_ -> write();
-	updateWindowTitle();
-	if (options == AllDiagrams) project()->undoStack()->clear();
-	return(result);
-}
 
-/**
-	Save \a diagrams without emitting the written() signal and without writing
-	the project file itself.
-*/
-void ProjectView::saveDiagrams(const QList<Diagram *> &diagrams) {
-	foreach (Diagram *diagram, diagrams) {
-		// Diagram::write() emits the written() signal, which is connected
-		// to QETProject::write() through QETProject::componentWritten().
-		// We do not want to write the project immediately, so we block
-		// this signal.
-		diagram -> blockSignals(true);
-		diagram -> write();
-		diagram -> blockSignals(false);
-	}
+	// write to file
+	QETResult result = m_project -> write();
+	updateWindowTitle();
+	project()->undoStack()->clear();
+	return(result);
 }
 
 /**
@@ -687,10 +722,10 @@ void ProjectView::saveDiagrams(const QList<Diagram *> &diagrams) {
 	cleaned.
 */
 int ProjectView::cleanProject() {
-	if (!project_) return(0);
-	
+	if (!m_project) return(0);
+
 	// s'assure que le schema n'est pas en lecture seule
-	if (project_ -> isReadOnly()) {
+	if (m_project -> isReadOnly()) {
 		QET::QetMessageBox::critical(
 			this,
 			tr("Projet en lecture seule", "message box title"),
@@ -698,22 +733,22 @@ int ProjectView::cleanProject() {
 		);
 		return(0);
 	}
-	
+
 	// construit un petit dialogue pour parametrer le nettoyage
-	QCheckBox *clean_tbt        = new QCheckBox(tr("Supprimer les modèles de cartouche inutilisés dans le projet"));
+	QCheckBox *clean_tbt		= new QCheckBox(tr("Supprimer les modèles de cartouche inutilisés dans le projet"));
 	QCheckBox *clean_elements   = new QCheckBox(tr("Supprimer les éléments inutilisés dans le projet"));
 	QCheckBox *clean_categories = new QCheckBox(tr("Supprimer les catégories vides"));
 	QDialogButtonBox *buttons = new QDialogButtonBox(QDialogButtonBox::Ok | QDialogButtonBox::Cancel);
-	
-	clean_tbt        -> setChecked(true);
+
+	clean_tbt		-> setChecked(true);
 	clean_elements   -> setChecked(true);
 	clean_categories -> setChecked(true);
-	
+
 	QDialog clean_dialog(parentWidget());
 #ifdef Q_OS_MAC
 	clean_dialog.setWindowFlags(Qt::Sheet);
 #endif
-	
+
 	clean_dialog.setWindowTitle(tr("Nettoyer le projet", "window title"));
 	QVBoxLayout *clean_dialog_layout = new QVBoxLayout();
 	clean_dialog_layout -> addWidget(clean_tbt);
@@ -721,29 +756,24 @@ int ProjectView::cleanProject() {
 	clean_dialog_layout -> addWidget(clean_categories);
 	clean_dialog_layout -> addWidget(buttons);
 	clean_dialog.setLayout(clean_dialog_layout);
-	
+
 	connect(buttons, SIGNAL(accepted()), &clean_dialog, SLOT(accept()));
 	connect(buttons, SIGNAL(rejected()), &clean_dialog, SLOT(reject()));
-	
+
 	int clean_count = 0;
 	if (clean_dialog.exec() == QDialog::Accepted)
 	{
 		if (clean_tbt -> isChecked()) {
-			project_->embeddedTitleBlockTemplatesCollection()->deleteUnusedTitleBlocKTemplates();
+			m_project->embeddedTitleBlockTemplatesCollection()->deleteUnusedTitleBlocKTemplates();
 		}
-		if (clean_elements -> isChecked()) {
-			InteractiveMoveElementsHandler *handler = new InteractiveMoveElementsHandler(this);
-			project_ -> cleanUnusedElements(handler);
-			delete handler;
-			++ clean_count;
+		if (clean_elements->isChecked()) {
+			m_project->embeddedElementCollection()->cleanUnusedElement();
 		}
-		if (clean_categories -> isChecked()) {
-			InteractiveMoveElementsHandler *handler = new InteractiveMoveElementsHandler(this);
-			project_ -> cleanEmptyCategories(handler);
-			delete handler;
-			++ clean_count;
+		if (clean_categories->isChecked()) {
+			m_project->embeddedElementCollection()->cleanUnusedDirectory();
 		}
 	}
+
 	return(clean_count);
 }
 
@@ -751,7 +781,7 @@ int ProjectView::cleanProject() {
 	Initialize actions for this widget.
 */
 void ProjectView::initActions() {
-    add_new_diagram_ = new QAction(QET::Icons::AddFolio, tr("Ajouter un folio"), this);
+	add_new_diagram_ = new QAction(QET::Icons::AddFolio, tr("Ajouter un folio"), this);
 	connect(add_new_diagram_, SIGNAL(triggered()), this, SLOT(addNewDiagram()));
 }
 
@@ -761,30 +791,30 @@ void ProjectView::initActions() {
 void ProjectView::initWidgets() {
 	setObjectName("ProjectView");
 	setWindowIcon(QET::Icons::ProjectFileGP);
-	
+
 	// initialize the "fallback" widget
 	fallback_widget_ = new QWidget();
 	fallback_label_ = new QLabel(
 		tr(
-            "Ce projet ne contient aucun folio",
+			"Ce projet ne contient aucun folio",
 			"label displayed when a project contains no diagram"
 		)
 	);
 	fallback_label_ -> setAlignment(Qt::AlignVCenter | Qt::AlignHCenter);
-	
+
 	// initialize tabs
 	m_tab = new QTabWidget(this);
 	m_tab -> setMovable(true);
-	
+
 	QToolButton *add_new_diagram_button = new QToolButton;
 	add_new_diagram_button -> setDefaultAction(add_new_diagram_);
 	add_new_diagram_button -> setAutoRaise(true);
 	m_tab -> setCornerWidget(add_new_diagram_button, Qt::TopRightCorner);
-	
+
 	connect(m_tab, SIGNAL(currentChanged(int)), this, SLOT(tabChanged(int)));
 	connect(m_tab, SIGNAL(tabBarDoubleClicked(int)), this, SLOT(tabDoubleClicked(int)));
 	connect(m_tab->tabBar(), SIGNAL(tabMoved(int, int)), this, SLOT(tabMoved(int, int)));
-	
+
 	fallback_widget_ -> setVisible(false);
 	m_tab -> setVisible(false);
 }
@@ -795,7 +825,7 @@ void ProjectView::initWidgets() {
 void ProjectView::initLayout() {
 	QVBoxLayout *fallback_widget_layout_ = new QVBoxLayout(fallback_widget_);
 	fallback_widget_layout_ -> addWidget(fallback_label_);
-	
+
 	layout_ = new QVBoxLayout(this);
 #ifdef Q_OS_MAC
 	layout_ -> setContentsMargins(0, 8, 0, 0);
@@ -815,19 +845,22 @@ void ProjectView::initLayout() {
  * and add it to the project view.
  */
 void ProjectView::loadDiagrams() {
-	if (!project_) return;
-	
-	setDisplayFallbackWidget(project_ -> diagrams().isEmpty());
-	
-	foreach(Diagram *diagram, project_ -> diagrams()) {
+	if (!m_project) return;
+
+	setDisplayFallbackWidget(m_project -> diagrams().isEmpty());
+
+	foreach(Diagram *diagram, m_project -> diagrams()) {
 		DiagramView *sv = new DiagramView(diagram);
 		addDiagram(sv);
 	}
 
+	this->currentDiagram()->diagram()->loadElmtFolioSeq();
+	this->currentDiagram()->diagram()->loadCndFolioSeq();
+
 	// If project have the folios list, move it at the beginning of the project
-	if (project_ -> getFolioSheetsQuantity()) {
-		for (int i = 0; i < project_->getFolioSheetsQuantity(); i++)
-		m_tab -> tabBar() -> moveTab(diagrams().size()-1, + 1);
+	if (m_project -> getFolioSheetsQuantity()) {
+		for (int i = 0; i < m_project->getFolioSheetsQuantity(); i++)
+		m_tab -> tabBar() -> moveTab(diagram_views().size()-1, + 1);
 	}
 }
 
@@ -837,8 +870,8 @@ void ProjectView::loadDiagrams() {
  */
 void ProjectView::updateWindowTitle() {
 	QString title;
-	if (project_) {
-		title = project_ -> pathNameTitle();
+	if (m_project) {
+		title = m_project -> pathNameTitle();
 	} else {
 		title = tr("Projet", "window title for a project-less ProjectView");
 	}
@@ -850,60 +883,75 @@ void ProjectView::updateWindowTitle() {
 	du mode lecture seule.
 */
 void ProjectView::adjustReadOnlyState() {
-	bool editable = !(project_ -> isReadOnly());
-	
+	bool editable = !(m_project -> isReadOnly());
+
 	// prevent users from moving existing diagrams
 	m_tab -> setMovable(editable);
 	// prevent users from adding new diagrams
 	add_new_diagram_ -> setEnabled(editable);
-	
+
 	// on met a jour le titre du widget, qui reflete l'etat de lecture seule
 	updateWindowTitle();
 }
 
 /**
-	Met a jour le titre d'un onglet
-	@param diagram Schema
-	@param diagram_title Titre du schema
-*/
-void ProjectView::updateTabTitle(DiagramView *diagram, const QString &diagram_title) {
-	int diagram_tab_id = diagram_ids_.key(diagram, -1);
-	if (diagram_tab_id != -1) {
-		m_tab -> setTabText(diagram_tab_id, diagram_title);
-	}
+ * @brief ProjectView::updateTabTitle
+ * Update the title of the tab which display the diagram view @diagram_view.
+ * @param diagram : The diagram view.
+ */
+void ProjectView::updateTabTitle(DiagramView *diagram_view)
+{
+    int diagram_tab_id = m_diagram_ids.key(diagram_view, -1);
+    
+    if (diagram_tab_id != -1)
+    {
+        QSettings settings;
+        QString title;
+        Diagram *diagram = diagram_view->diagram();
+        
+        if (settings.value("genericpanel/folio", false).toBool())
+        {
+            QString formula = diagram->border_and_titleblock.folio();
+            autonum::sequentialNumbers seq;
+            title = autonum::AssignVariables::formulaToLabel(formula, seq, diagram);
+        }
+        else
+            title = QString::number(diagram->folioIndex() + 1);
+        
+        title += " - ";
+        title += diagram->title();
+        m_tab->setTabText(diagram_tab_id ,title);
+    }
+}
+
+/**
+ * @brief ProjectView::updateAllTabsTitle
+ * Update all tabs title
+ */
+void ProjectView::updateAllTabsTitle()
+{
+	for (DiagramView *dv : m_diagram_ids.values())
+		updateTabTitle(dv);
 }
 
 /**
 	@param from Index de l'onglet avant le deplacement
 	@param to   Index de l'onglet apres le deplacement
 */
-void ProjectView::tabMoved(int from, int to) {
-	if (!project_) return;
+void ProjectView::tabMoved(int from, int to)
+{
+	if (!m_project)
+		return;
 	
-	// signale au QETProject le changement d'ordre des schemas
-	project_ -> diagramOrderChanged(from, to);
-	
-	// reconstruit la liste associant les index des onglets aux schemas
+	m_project->diagramOrderChanged(from, to);
 	rebuildDiagramsMap();
 	
-	// emet un signal pour informer le reste du monde que l'ordre des schemas a change
-	emit(diagramOrderChanged(this, from, to));
-}
-
-/**
-	Require the edition of the \a template_name title blocke template.
-	@param template_name Name of the tempalte to be edited
-	@param duplicate If true, this methd will ask the user for a template name
-	in order to duplicate the \a template_name template
-*/
-void ProjectView::editTitleBlockTemplateRequired(const QString &template_name, bool duplicate) {
-	if (!project_) return;
-	emit(
-		editTitleBlockTemplate(
-			project_ -> embeddedTitleBlockTemplatesCollection() -> location(template_name),
-			duplicate
-		)
-	);
+		//Rebuild the title of each diagram in range from - to
+	for (int i= qMin(from,to) ; i< qMax(from,to)+1 ; ++i)
+	{
+		DiagramView *dv = m_diagram_ids.value(i);
+		updateTabTitle(dv);
+	}
 }
 
 /**
@@ -912,7 +960,7 @@ void ProjectView::editTitleBlockTemplateRequired(const QString &template_name, b
 	le schema n'est pas trouve
 */
 DiagramView *ProjectView::findDiagram(Diagram *diagram) {
-	foreach(DiagramView *diagram_view, diagrams()) {
+	foreach(DiagramView *diagram_view, diagram_views()) {
 		if (diagram_view -> diagram() == diagram) {
 			return(diagram_view);
 		}
@@ -925,12 +973,12 @@ DiagramView *ProjectView::findDiagram(Diagram *diagram) {
 */
 void ProjectView::rebuildDiagramsMap() {
 	// vide la map
-	diagram_ids_.clear();
-	
-	foreach(DiagramView *diagram_view, diagrams_) {
+	m_diagram_ids.clear();
+
+	foreach(DiagramView *diagram_view, m_diagram_view_list) {
 		int dv_idx = m_tab -> indexOf(diagram_view);
 		if (dv_idx == -1) continue;
-		diagram_ids_.insert(dv_idx, diagram_view);
+		m_diagram_ids.insert(dv_idx, diagram_view);
 	}
 }
 
@@ -941,13 +989,22 @@ void ProjectView::rebuildDiagramsMap() {
  * we display the fallback widget.
  * @param tab_id
  */
-void ProjectView::tabChanged(int tab_id) {
+void ProjectView::tabChanged(int tab_id)
+{
 	if (tab_id == -1)
 		setDisplayFallbackWidget(true);
 	else if(m_tab->count() == 1)
 		setDisplayFallbackWidget(false);
+	
+	emit(diagramActivated(m_diagram_ids[tab_id]));
+	
+	if (m_diagram_ids[tab_id] != nullptr)
+		m_diagram_ids[tab_id]->diagram()->diagramActivated();
 
-	emit(diagramActivated(diagram_ids_[tab_id]));
+		//Clear the event interface of the previous diagram
+	if (DiagramView *dv = m_diagram_ids[m_previous_tab_index])
+		dv->diagram()->clearEventInterface();
+	m_previous_tab_index = tab_id;
 }
 
 /**
@@ -956,9 +1013,9 @@ void ProjectView::tabChanged(int tab_id) {
 */
 void ProjectView::tabDoubleClicked(int tab_id) {
 	// repere le schema concerne
-	DiagramView *diagram_view = diagram_ids_[tab_id];
+	DiagramView *diagram_view = m_diagram_ids[tab_id];
 	if (!diagram_view) return;
-	
+
 	diagram_view -> editDiagramProperties();
 }
 
