@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -28,6 +28,9 @@ XRefProperties::XRefProperties()
 	m_display = Cross;
 	m_snap_to = Bottom;
 	m_prefix_keys << "power" << "delay" << "switch";
+	m_master_label = "%f-%l%c";
+	m_slave_label = "(%f-%l%c)";
+	m_offset = 0;
 }
 
 /**
@@ -42,6 +45,12 @@ void XRefProperties::toSettings(QSettings &settings, const QString prefix) const
 	settings.setValue(prefix + "displayhas", display);
 	QString snap = m_snap_to == Bottom? "bottom" : "label";
 	settings.setValue(prefix + "snapto", snap);
+	int offset = m_offset;
+	settings.setValue(prefix + "offset", offset);
+	QString master_label = m_master_label;
+	settings.setValue(prefix + "master_label", master_label);
+	QString slave_label = m_slave_label;
+	settings.setValue(prefix + "slave_label", slave_label);
 	foreach (QString key, m_prefix.keys()) {
 		settings.setValue(prefix + key + "prefix", m_prefix.value(key));
 	}
@@ -59,6 +68,9 @@ void XRefProperties::fromSettings(const QSettings &settings, const QString prefi
 	display == "cross"? m_display = Cross : m_display = Contacts;
 	QString snap = settings.value(prefix + "snapto", "label").toString();
 	snap == "bottom"? m_snap_to = Bottom : m_snap_to = Label;
+	m_offset = settings.value(prefix + "offset", "0").toInt();
+	m_master_label = settings.value(prefix + "master_label", "%f-%l%c").toString();
+	m_slave_label = settings.value(prefix + "slave_label", "(%f-%l%c)").toString();
 	foreach (QString key, m_prefix_keys) {
 		m_prefix.insert(key, settings.value(prefix + key + "prefix").toString());
 	}
@@ -75,6 +87,12 @@ void XRefProperties::toXml(QDomElement &xml_element) const {
 	xml_element.setAttribute("displayhas", display);
 	QString snap = m_snap_to == Bottom? "bottom" : "label";
 	xml_element.setAttribute("snapto", snap);
+	int offset = m_offset;
+	xml_element.setAttribute("offset", QString::number(offset));
+	QString master_label = m_master_label;
+	xml_element.setAttribute("master_label", master_label);
+	QString slave_label = m_slave_label;
+	xml_element.setAttribute("slave_label", slave_label);
 	foreach (QString key, m_prefix.keys()) {
 		xml_element.setAttribute(key + "prefix", m_prefix.value(key));
 	}
@@ -91,6 +109,9 @@ void XRefProperties::fromXml(const QDomElement &xml_element) {
 	display == "cross"? m_display = Cross : m_display = Contacts;
 	QString snap = xml_element.attribute("snapto", "label");
 	snap == "bottom"? m_snap_to = Bottom : m_snap_to = Label;
+	m_offset = xml_element.attribute("offset", "0").toInt();
+	m_master_label = xml_element.attribute("master_label", "%f-%l%c");
+	m_slave_label = xml_element.attribute("slave_label","(%f-%l%c)");
 	foreach (QString key, m_prefix_keys) {
 		m_prefix.insert(key, xml_element.attribute(key + "prefix"));
 	}
@@ -126,7 +147,10 @@ bool XRefProperties::operator ==(const XRefProperties &xrp) const{
 	return (m_show_power_ctc == xrp.m_show_power_ctc &&
 			m_display == xrp.m_display &&
 			m_snap_to == xrp.m_snap_to &&
-			m_prefix == xrp.m_prefix);
+			m_prefix == xrp.m_prefix &&
+			m_master_label == xrp.m_master_label &&
+			m_slave_label == xrp.m_slave_label &&
+			m_offset == xrp.m_offset);
 }
 
 bool XRefProperties::operator !=(const XRefProperties &xrp) const {
