@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -21,9 +21,7 @@
 #include "configpages.h"
 #include "qetdiagrameditor.h"
 #include "qetelementeditor.h"
-#include "elementscollectionitem.h"
 #include "elementscollectioncache.h"
-#include "fileelementscollection.h"
 #include "titleblocktemplate.h"
 #include "qettemplateeditor.h"
 #include "qetproject.h"
@@ -48,17 +46,14 @@ QString QETApp::common_tbt_dir_ = QString();
 QString QETApp::config_dir = QString();
 #endif
 QString QETApp::lang_dir = QString();
-FileElementsCollection *QETApp::common_collection = 0;
-FileElementsCollection *QETApp::custom_collection = 0;
 TitleBlockTemplatesFilesCollection *QETApp::common_tbt_collection_;
 TitleBlockTemplatesFilesCollection *QETApp::custom_tbt_collection_;
-ElementsCollectionCache *QETApp::collections_cache_ = 0;
+ElementsCollectionCache *QETApp::collections_cache_ = nullptr;
 QMap<uint, QETProject *> QETApp::registered_projects_ = QMap<uint, QETProject *>();
 uint QETApp::next_project_id = 0;
-RecentFiles *QETApp::projects_recent_files_ = 0;
-RecentFiles *QETApp::elements_recent_files_ = 0;
-AboutQET *QETApp::about_dialog_ = 0;
-TitleBlockTemplate *QETApp::default_titleblock_template_ = 0;
+RecentFiles *QETApp::projects_recent_files_ = nullptr;
+RecentFiles *QETApp::elements_recent_files_ = nullptr;
+TitleBlockTemplate *QETApp::default_titleblock_template_ = nullptr;
 
 /**
 	Constructeur
@@ -110,12 +105,6 @@ QETApp::QETApp(int &argc, char **argv) :
 		collections_cache_->setLocale(langFromSetting());
 	}
 
-	// loads known collections into memory (this does not include items rendering made in elements panels)
-	setSplashScreenStep(tr("Chargement... Lecture des collections d'éléments", "splash screen caption"));
-	foreach(ElementsCollection *collection, availableCollections()) {
-		collection -> reload();
-	}
-
 	// on ouvre soit les fichiers passes en parametre soit un nouvel editeur de projet
 	if (qet_arguments_.files().isEmpty()) {
 		setSplashScreenStep(tr("Chargement... Éditeur de schéma", "splash screen caption"));
@@ -135,12 +124,7 @@ QETApp::~QETApp() {
 	delete splash_screen_;
 	delete elements_recent_files_;
 	delete projects_recent_files_;
-	if (about_dialog_) {
-		delete about_dialog_;
-	}
 	delete qsti;
-	delete custom_collection;
-	delete common_collection;
 	if (custom_tbt_collection_) delete custom_tbt_collection_;
 	if (common_tbt_collection_) delete common_tbt_collection_;
 	ElementFactory::dropInstance();
@@ -283,56 +267,6 @@ void QETApp::newElementEditor() {
 	new QETElementEditor();
 }
 
-/**
-	@return la collection commune
-*/
-ElementsCollection *QETApp::commonElementsCollection() {
-	if (!common_collection) {
-		common_collection = new FileElementsCollection(QETApp::commonElementsDir());
-		common_collection -> setTitle(tr("Collection QET"));
-		common_collection -> setIcon(QIcon(":/ico/16x16/qet.png"));
-		common_collection -> setProtocol("common");
-		common_collection -> setCache(collections_cache_);
-	}
-	return(common_collection);
-}
-
-/**
-	@return la collection utilisateur
-*/
-ElementsCollection *QETApp::customElementsCollection() {
-	if (!custom_collection) {
-		custom_collection = new FileElementsCollection(QETApp::customElementsDir());
-		custom_collection -> setTitle(tr("Collection utilisateur"));
-		custom_collection -> setIcon(QIcon(":/ico/16x16/go-home.png"));
-		custom_collection -> setProtocol("custom");
-		custom_collection -> setCache(collections_cache_);
-	}
-	return(custom_collection);
-}
-
-/**
-	@return la liste des collections disponibles
-	Cela inclut typiquement la collection commune, la collection perso
-	ainsi que les collections embarquees dans les projets.
-*/
-QList<ElementsCollection *> QETApp::availableCollections() {
-	QList<ElementsCollection *> coll_list;
-
-	// collection commune
-	coll_list << commonElementsCollection();
-
-	// collection perso
-	coll_list << customElementsCollection();
-
-	// collections embarquees
-	foreach(QETProject *opened_project, registered_projects_.values()) {
-		coll_list << opened_project -> embeddedCollection();
-	}
-
-	return(coll_list);
-}
-
 /**
 	@return the collection cache provided by the application itself.
 */
@@ -344,9 +278,11 @@ ElementsCollectionCache *QETApp::collectionCache() {
  * @brief QETApp::elementInfoKeys
  * @return all available key for describe an element
  */
-QStringList QETApp::elementInfoKeys() {
+QStringList QETApp::elementInfoKeys()
+{
 	QStringList info_list;
-	info_list << "label"
+	info_list << "formula"
+			  << "label"
 			  << "comment"
 			  << "designation"
 			  << "manufacturer"
@@ -366,8 +302,10 @@ QStringList QETApp::elementInfoKeys() {
  * @param info the key to be translated
  * @return
  */
-QString QETApp::elementTranslatedInfoKey(QString &info) {
-	if (info == "label") return tr("Label");
+QString QETApp::elementTranslatedInfoKey(QString &info)
+{
+	if (info == "formula") return tr("formule du label");
+	else if (info == "label") return tr("Label");
 	else if (info == "comment") return tr("Commentaire");
 	else if (info == "designation") return tr("Désignation");
 	else if (info == "manufacturer") return tr("Fabricant");
@@ -495,6 +433,30 @@ QString QETApp::customElementsDir() {
 	return(configDir() + "elements/");
 }
 
+/**
+ * @brief QETApp::commonElementsDirN
+ * like QString QETApp::commonElementsDir but without "/" at the end
+ * @return
+ */
+QString QETApp::commonElementsDirN()
+{
+	QString path = commonElementsDir();
+	if (path.endsWith("/")) path.remove(path.length()-1, 1);
+	return path;
+}
+
+/**
+ * @brief QETApp::customElementsDirN
+ * like QString QETApp::customElementsDir but without "/" at the end
+ * @return
+ */
+QString QETApp::customElementsDirN()
+{
+	QString path = customElementsDir();
+	if (path.endsWith("/")) path.remove(path.length()-1, 1);
+	return path;
+}
+
 /**
 	@return the path of the directory containing the common title block
 	templates collection.
@@ -647,6 +609,23 @@ QETDiagramEditor *QETApp::diagramEditorForFile(const QString &filepath) {
 	return(0);
 }
 
+/**
+ * @brief QETApp::diagramEditorAncestorOf
+ * @param child
+ * @return the parent QETDiagramEditor (or grandparent and so on to any level) of the given child.
+ * If not return nullptr;
+ */
+QETDiagramEditor *QETApp::diagramEditorAncestorOf (const QWidget *child)
+{
+	foreach (QETDiagramEditor *qde, QETApp::diagramEditors()) {
+		if (qde->isAncestorOf(child)) {
+			return qde;
+		}
+	}
+
+	return nullptr;
+}
+
 #ifdef QET_ALLOW_OVERRIDE_CED_OPTION
 /**
 	Redefinit le chemin du dossier des elements communs
@@ -1232,6 +1211,7 @@ void QETApp::configureQET() {
 	// cree le dialogue
 	ConfigDialog cd;
 	cd.setWindowTitle(tr("Configurer QElectroTech", "window title"));
+	cd.setWindowModality(Qt::WindowModal);
 	cd.addPage(new GeneralConfigurationPage());
 	cd.addPage(new NewDiagramPage());
 	cd.addPage(new ExportConfigPage());
@@ -1249,32 +1229,17 @@ void QETApp::configureQET() {
 }
 
 /**
-	Dialogue "A propos de QElectroTech"
-	Le dialogue en question est cree lors du premier appel de cette fonction.
-	En consequence, sa premiere apparition n'est pas immediate. Par la suite,
-	le dialogue n'a pas a etre recree et il apparait instantanement. Il est
-	detruit en meme temps que l'application.
-*/
-void QETApp::aboutQET() {
-	// determine le widget parent a utiliser pour le dialogue
-	QWidget *parent_widget = activeWindow();
-
-	// cree le dialogue si cela n'a pas deja ete fait
-	if (!about_dialog_) {
-		about_dialog_ = new AboutQET();
-	}
-
-	// associe le dialogue a un eventuel widget parent
-	if (parent_widget) {
-#ifdef Q_OS_MAC
-		about_dialog_ -> setWindowFlags(Qt::Sheet);
+ * @brief QETApp::aboutQET
+ * Open the dialog about qet.
+ */
+void QETApp::aboutQET()
+{
+	AboutQET aq(activeWindow());
+	
+#ifdef Q_OS_MACOS
+	aq.setWindowFlags(Qt::Sheet);
 #endif
-		about_dialog_ -> setParent(parent_widget, about_dialog_ -> windowFlags());
-	}
-
-	// affiche le dialogue puis evite de le lier a un quelconque widget parent
-	about_dialog_ -> exec();
-	about_dialog_ -> setParent(0, about_dialog_ -> windowFlags());
+	aq.exec();
 }
 
 /**
@@ -1354,7 +1319,7 @@ void QETApp::parseArguments() {
 */
 void QETApp::initSplashScreen() {
 	if (non_interactive_execution_) return;
-	splash_screen_ = new QSplashScreen(QPixmap(":/ico/splash.png"), Qt::WindowStaysOnTopHint);
+	splash_screen_ = new QSplashScreen(QPixmap(":/ico/splash.png"));
 	splash_screen_ -> show();
 	setSplashScreenStep(tr("Chargement...", "splash screen caption"));
 }
@@ -1386,12 +1351,7 @@ void QETApp::initLanguage() {
 void QETApp::initStyle() {
 	initial_palette_ = palette();
 
-	//@TODO remove the code below
-//	// lorsque le style Plastique est active, on le remplace par une version amelioree
-//	if (qobject_cast<QPlastiqueStyle *>(style())) {
-//		setStyle(new QETStyle());
-//	}
-		//Apply or not the system style
+	//Apply or not the system style
 	QSettings settings;
 	useSystemPalette(settings.value("usesystemcolors", true).toBool());
 }
@@ -1647,108 +1607,6 @@ void QETApp::printLicense() {
 	std::cout << qPrintable(QET::license()) << std::endl;
 }
 
-//@TODO remove code below
-///// Constructeur
-//QETStyle::QETStyle() : QPlastiqueStyle() {
-//}
-
-///// Destructeur
-//QETStyle::~QETStyle() {
-//}
-
-///// Gere les parametres de style
-//int QETStyle::styleHint(StyleHint hint, const QStyleOption *option, const QWidget *widget, QStyleHintReturn *returndata) const {
-//	if (hint == QStyle::SH_DialogButtonBox_ButtonsHaveIcons) {
-//		return(int(true));
-//	} else {
-//		return(QPlastiqueStyle::styleHint(hint, option, widget, returndata));
-//	}
-//}
-
-///// Gere les icones standard
-//QIcon QETStyle::standardIconImplementation(StandardPixmap standardIcon, const QStyleOption *option, const QWidget* widget) const {
-//	switch(standardIcon) {
-//		case QStyle::SP_DialogSaveButton:
-//			return(QET::Icons::DocumentSave);
-//		case QStyle::SP_DialogOpenButton:
-//			return(QET::Icons::DocumentOpen);
-//		case QStyle::SP_DialogCancelButton:
-//			return(QET::Icons::DialogCancel);
-//		case QStyle::SP_DialogOkButton:
-//		case QStyle::SP_DialogApplyButton:
-//			return(QET::Icons::DialogOk);
-//		case QStyle::SP_DialogCloseButton:
-//			return(QET::Icons::DocumentClose);
-//		case QStyle::SP_DialogYesButton:
-//			return(QET::Icons::Allowed);
-//		case QStyle::SP_DialogNoButton:
-//			return(QET::Icons::Forbidden);
-//		case QStyle::SP_DialogResetButton:
-//			return(QET::Icons::EditUndo);
-//		case QStyle::SP_DialogHelpButton:
-//		case QStyle::SP_DialogDiscardButton:
-//			return(QIcon());
-//		default:
-//			return(QPlastiqueStyle::standardIconImplementation(standardIcon, option, widget));
-//	}
-//}
-
-/**
-	@param location adresse virtuelle d'un item (collection, categorie, element, ...)
-	@param prefer_collections true pour renvoyer la collection lorsque le
-	chemin correspond aussi bien a une collection qu'a sa categorie racine
-	@return l'item correspondant a l'adresse virtuelle path, ou 0 si celui-ci n'a pas ete trouve
-*/
-ElementsCollectionItem *QETApp::collectionItem(const ElementsLocation &location, bool prefer_collections) {
-	if (QETProject *target_project = location.project()) {
-		return(target_project -> embeddedCollection() -> item(location.path(), prefer_collections));
-	} else {
-		QString path(location.path());
-		if (path.startsWith("common://")) {
-			return(common_collection -> item(path, prefer_collections));
-		} else if (path.startsWith("custom://")) {
-			return(custom_collection -> item(path, prefer_collections));
-		}
-	}
-	return(0);
-}
-
-/**
-	@param location adresse virtuelle de la categorie a creer
-	@return la categorie creee, ou 0 en cas d'echec
-*/
-ElementsCategory *QETApp::createCategory(const ElementsLocation &location) {
-	if (QETProject *target_project = location.project()) {
-		return(target_project -> embeddedCollection() -> createCategory(location.path()));
-	} else {
-		QString path(location.path());
-		if (path.startsWith("common://")) {
-			return(common_collection -> createCategory(path));
-		} else if (path.startsWith("custom://")) {
-			return(custom_collection -> createCategory(path));
-		}
-	}
-	return(0);
-}
-
-/**
-	@param location adresse virtuelle de l'element a creer
-	@return l'element cree, ou 0 en cas d'echec
-*/
-ElementDefinition *QETApp::createElement(const ElementsLocation &location) {
-	if (QETProject *target_project = location.project()) {
-		return(target_project -> embeddedCollection() -> createElement(location.path()));
-	} else {
-		QString path(location.path());
-		if (path.startsWith("common://")) {
-			return(common_collection -> createElement(path));
-		} else if (path.startsWith("custom://")) {
-			return(custom_collection -> createElement(path));
-		}
-	}
-	return(0);
-}
-
 /**
 	@return la liste des projets avec leurs ids associes
 */
