@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -17,25 +17,28 @@
 */
 #ifndef QET_APP_H
 #define QET_APP_H
-#include "qetsingleapplication.h"
+
 #include <QTranslator>
-#include <QtWidgets>
+#include <QSystemTrayIcon>
+#include <QPalette>
+
+#include "qetsingleapplication.h"
 #include "elementslocation.h"
 #include "templatelocation.h"
 #include "qetarguments.h"
 
+class QSplashScreen;
+class QMenu;
+class QAction;
+class QMainWindow;
+
 #define QETAPP_COMMON_TBT_PROTOCOL "commontbt"
 #define QETAPP_CUSTOM_TBT_PROTOCOL "customtbt"
 
 class AboutQET;
 class QETDiagramEditor;
 class QETElementEditor;
-class ElementsCollection;
 class ElementsCollectionCache;
-class ElementsCollectionItem;
-class FileElementsCollection;
-class ElementsCategory;
-class ElementDefinition;
 class TitleBlockTemplate;
 class TitleBlockTemplatesCollection;
 class TitleBlockTemplatesFilesCollection;
@@ -67,12 +70,6 @@ class QETApp : public QETSingleApplication {
 	static void printVersion();
 	static void printLicense();
 	
-	static ElementsCollectionItem *collectionItem(const ElementsLocation &, bool = true);
-	static ElementsCategory *createCategory(const ElementsLocation &);
-	static ElementDefinition *createElement(const ElementsLocation &);
-	static ElementsCollection *commonElementsCollection();
-	static ElementsCollection *customElementsCollection();
-	static QList<ElementsCollection *> availableCollections();
 	static ElementsCollectionCache *collectionCache();
 	static QStringList elementInfoKeys();
 	static QString elementTranslatedInfoKey(QString &);
@@ -85,6 +82,8 @@ class QETApp : public QETSingleApplication {
 	static QString userName();
 	static QString commonElementsDir();
 	static QString customElementsDir();
+	static QString commonElementsDirN();
+	static QString customElementsDirN();
 	static QString commonTitleBlockTemplatesDir();
 	static QString customTitleBlockTemplatesDir();
 	static bool registerProject(QETProject *);
@@ -123,6 +122,7 @@ class QETApp : public QETSingleApplication {
 	static QString lang_dir; ///< Directory containing localization files.
 	static QFont diagramTextsFont(qreal = -1.0);
 	static QETDiagramEditor *diagramEditorForFile(const QString &);
+	static QETDiagramEditor *diagramEditorAncestorOf (const QWidget *child);
 	static QList<QETDiagramEditor *> diagramEditors();
 	static QList<QETElementEditor *> elementEditors();
 	static QList<QETElementEditor *> elementEditors(QETProject *);
@@ -168,8 +168,6 @@ class QETApp : public QETSingleApplication {
 	bool non_interactive_execution_;    ///< Whether the application will end without any user interaction
 	QPalette initial_palette_;          ///< System color palette
 	
-	static FileElementsCollection *common_collection;
-	static FileElementsCollection *custom_collection;
 	static TitleBlockTemplatesFilesCollection *common_tbt_collection_;
 	static TitleBlockTemplatesFilesCollection *custom_tbt_collection_;
 	static ElementsCollectionCache *collections_cache_;
@@ -177,7 +175,6 @@ class QETApp : public QETSingleApplication {
 	static uint next_project_id;
 	static RecentFiles *projects_recent_files_;
 	static RecentFiles *elements_recent_files_;
-	static AboutQET *about_dialog_;
 	static TitleBlockTemplate *default_titleblock_template_;
 	
 	public slots:
@@ -234,19 +231,4 @@ class QETApp : public QETSingleApplication {
 	static QETProject *projectFromString(const QString &);
 };
 
-//TODO remove code below
-///**
-//	This class represents the custom QElectroTech style.
-//	It implements simple modification such as extra standard icons.
-//*/
-//class QETStyle : public QPlastiqueStyle {
-//	Q_OBJECT
-//	public:
-//	QETStyle();
-//	virtual ~QETStyle();
-//	virtual int styleHint(StyleHint hint, const QStyleOption * = 0, const QWidget * = 0, QStyleHintReturn * = 0) const;
-	
-//	protected slots:
-//	virtual QIcon standardIconImplementation(StandardPixmap, const QStyleOption * = 0, const QWidget * = 0) const;
-//};
 #endif
