@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -40,12 +40,14 @@
 #include "diagrameventaddshape.h"
 #include "diagrameventaddimage.h"
 #include "diagrameventaddtext.h"
-
-#include "ui/dialogautonum.h"
+#include "elementscollectionwidget.h"
+#include "autonumberingdockwidget.h"
 
 #include <QMessageBox>
 #include <QStandardPaths>
 
+#include "elementscollectionmodel.h"
+
 
 /**
  * @brief QETDiagramEditor::QETDiagramEditor
@@ -58,12 +60,13 @@ QETDiagramEditor::QETDiagramEditor(const QStringList &files, QWidget *parent) :
 	m_add_item_actions_group   (this),
 	m_zoom_actions_group       (this),
 	m_select_actions_group     (this),
-	m_selection_actions_group  (this),
 	m_row_column_actions_group (this),
+	m_selection_actions_group  (this),
 	m_file_actions_group       (this),
 	open_dialog_dir            (QStandardPaths::writableLocation(QStandardPaths::DesktopLocation))
 {
-		//Setup the mdi area at center of application
+	activeSubWindowIndex = 0;
+	//Setup the mdi area at center of application
 	setCentralWidget(&workspace);
 	
 		//Set object name to be retrieved by the stylesheets
@@ -79,8 +82,11 @@ QETDiagramEditor::QETDiagramEditor(const QStringList &files, QWidget *parent) :
 	statusBar() -> showMessage(tr("QElectroTech", "status bar message"));
 	
 	setUpElementsPanel();
+	setUpElementsCollectionWidget();
 	setUpUndoStack();
 	setUpSelectionPropertiesEditor();
+	setUpAutonumberingWidget();
+
 	setUpActions();
 	setUpToolBar();
 	setUpMenu();
@@ -93,8 +99,8 @@ QETDiagramEditor::QETDiagramEditor(const QStringList &files, QWidget *parent) :
 	
 	connect (&workspace,                SIGNAL(subWindowActivated(QMdiSubWindow *)), this, SLOT(subWindowActivated(QMdiSubWindow*)));
 	connect (QApplication::clipboard(), SIGNAL(dataChanged()),                       this, SLOT(slot_updatePasteAction()));
-	connect (&undo_group,               SIGNAL(cleanChanged(bool)),                  this, SLOT(activeUndoStackCleanChanged(bool)));
-	
+	//connect (&undo_group,               SIGNAL(cleanChanged(bool)),                  this, SLOT(activeUndoStackCleanChanged(bool)));
+
 	readSettings();
 	show();
 	
@@ -123,9 +129,9 @@ QETDiagramEditor::~QETDiagramEditor() {
  */
 void QETDiagramEditor::setUpElementsPanel() {
 	//Add the element panel as a QDockWidget
-	qdw_pa = new QDockWidget(tr("Panel d'éléments", "dock title"), this);
+	qdw_pa = new QDockWidget(tr("Projets", "dock title"), this);
 
-	qdw_pa -> setObjectName   ("elements panel");
+	qdw_pa -> setObjectName   ("projects panel");
 	qdw_pa -> setAllowedAreas (Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
 	qdw_pa -> setFeatures     (QDockWidget::AllDockWidgetFeatures);
 	qdw_pa -> setMinimumWidth (160);
@@ -148,6 +154,24 @@ void QETDiagramEditor::setUpElementsPanel() {
 	connect(pa, SIGNAL(requestForDiagramMoveDownx10       (Diagram *)), this, SLOT(moveDiagramDownx10(Diagram *)));
 }
 
+/**
+ * @brief QETDiagramEditor::setUpElementsCollectionWidget
+ * Set up the dock widget of element collection
+ */
+void QETDiagramEditor::setUpElementsCollectionWidget()
+{
+	m_qdw_elmt_collection = new QDockWidget(tr("Collections"), this);
+	m_qdw_elmt_collection->setObjectName("elements_collection_widget");
+	m_qdw_elmt_collection->setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
+	m_qdw_elmt_collection->setFeatures(QDockWidget::AllDockWidgetFeatures);
+
+	m_element_collection_widget = new ElementsCollectionWidget(m_qdw_elmt_collection);
+	m_qdw_elmt_collection->setWidget(m_element_collection_widget);
+	m_element_collection_widget->expandFirstItems();
+
+	addDockWidget(Qt::RightDockWidgetArea, m_qdw_elmt_collection);
+}
+
 /**
  * @brief QETDiagramEditor::setUpUndoStack
  * Setup the undostack and undo stack widget
@@ -182,6 +206,18 @@ void QETDiagramEditor::setUpSelectionPropertiesEditor()
 	addDockWidget(Qt::RightDockWidgetArea, m_selection_properties_editor);
 }
 
+/**
+ * @brief QETDiagramEditor::setUpAutonumberingWidget
+ * Setup the dock for AutoNumbering Selection
+ */
+void QETDiagramEditor::setUpAutonumberingWidget()
+{
+	m_autonumbering_dock = new AutoNumberingDockWidget(this);
+	m_autonumbering_dock -> setAllowedAreas(Qt::LeftDockWidgetArea | Qt::RightDockWidgetArea);
+	m_autonumbering_dock -> setFeatures(QDockWidget::AllDockWidgetFeatures);
+	addDockWidget(Qt::RightDockWidgetArea, m_autonumbering_dock);
+}
+
 /**
  * @brief QETDiagramEditor::setUpActions
  * Set up all Qaction
@@ -239,14 +275,27 @@ void QETDiagramEditor::setUpActions()
 			this->currentDiagram()->diagram()->update();
 	});
 
-	infos_diagram     = new QAction(QET::Icons::DialogInformation,     tr("Propriétés du folio"),                 this);
+	m_draw_grid = new QAction ( QET::Icons::Grid, tr("Afficher la grille"), this);
+	m_draw_grid->setStatusTip(tr("Affiche ou masque la grille des folios"));
+	m_draw_grid->setCheckable(true);
+	m_draw_grid->setChecked(true);
+	connect(m_draw_grid, &QAction::triggered, [this](bool checked) {
+		foreach (ProjectView *prjv, this->openedProjects())
+			foreach (Diagram *d, prjv->project()->diagrams()) {
+				d->setDisplayGrid(checked);
+				d->update();
+			}
+	});
+
+	infos_diagram     = new QAction(QET::Icons::DialogInformation,     tr("Propriétés du folio"),                  this);
 	infos_diagram    -> setShortcut( QKeySequence( tr("Ctrl+L")		) );
-	prj_edit_prop     = new QAction(QET::Icons::DialogInformation,     tr("Propriétés du projet"),                 this);
-	prj_add_diagram   = new QAction(QET::Icons::DiagramAdd,            tr("Ajouter un folio"),                    this);
-	prj_del_diagram   = new QAction(QET::Icons::DiagramDelete,         tr("Supprimer le folio"),                  this);
+    prj_edit_prop     = new QAction(QET::Icons::ProjectProperties,     tr("Propriétés du projet"),                 this);
+	prj_add_diagram   = new QAction(QET::Icons::DiagramAdd,            tr("Ajouter un folio"),                     this);
+	prj_del_diagram   = new QAction(QET::Icons::DiagramDelete,         tr("Supprimer le folio"),                   this);
 	prj_clean         = new QAction(QET::Icons::EditClear,             tr("Nettoyer le projet"),                   this);
-	prj_diagramList   = new QAction(QET::Icons::listDrawings,          tr("Ajouter un sommaire"),                  this);
+    prj_diagramList   = new QAction(QET::Icons::TableOfContent,        tr("Ajouter un sommaire"),                  this);
 	prj_nomenclature  = new QAction(QET::Icons::DocumentSpreadsheet,   tr("Exporter une nomenclature"),            this);
+	prj_terminalBloc  = new QAction(QET::Icons::TerminalStrip,         tr("Lancer le plugin de creation de bornier"), this);
 	tabbed_view_mode  = new QAction(                                   tr("en utilisant des onglets"),             this);
 	windowed_view_mode= new QAction(                                   tr("en utilisant des fenêtres"),            this);
 	mode_selection    = new QAction(QET::Icons::PartSelect,            tr("Mode Selection"),                       this);
@@ -261,16 +310,16 @@ void QETDiagramEditor::setUpActions()
 	QAction *open_file = m_file_actions_group.addAction( QET::Icons::DocumentOpen,    tr("&Ouvrir")							  );
 	save_file          = m_file_actions_group.addAction( QET::Icons::DocumentSave,    tr("&Enregistrer")					  );
 	save_file_as       = m_file_actions_group.addAction( QET::Icons::DocumentSaveAs,  tr("Enregistrer sous")				  );
-	close_file         = m_file_actions_group.addAction( QET::Icons::ProjectClose,   tr("&Fermer")							  );
+	m_close_file         = m_file_actions_group.addAction( QET::Icons::ProjectClose,   tr("&Fermer")							  );
 
 	new_file   -> setShortcut( QKeySequence::New   );
 	open_file  -> setShortcut( QKeySequence::Open  );
-	close_file -> setShortcut( QKeySequence::Close );
+	m_close_file -> setShortcut( QKeySequence::Close );
 	save_file  -> setShortcut( QKeySequence::Save  );
 
 	new_file         -> setStatusTip( tr("Crée un nouveau projet", "status bar tip")								 );
 	open_file        -> setStatusTip( tr("Ouvre un projet existant", "status bar tip")								 );
-	close_file       -> setStatusTip( tr("Ferme le projet courant", "status bar tip")								 );
+	m_close_file       -> setStatusTip( tr("Ferme le projet courant", "status bar tip")								 );
 	save_file        -> setStatusTip( tr("Enregistre le projet courant et tous ses folios", "status bar tip")		 );
 	save_file_as     -> setStatusTip( tr("Enregistre le projet courant avec un autre nom de fichier", "status bar tip") );
 
@@ -278,13 +327,13 @@ void QETDiagramEditor::setUpActions()
 	connect(save_file,        SIGNAL( triggered() ), this, SLOT( save()				   ) );
 	connect(new_file,         SIGNAL( triggered() ), this, SLOT( newProject()		   ) );
 	connect(open_file,        SIGNAL( triggered() ), this, SLOT( openProject()		   ) );
-	connect(close_file,       SIGNAL( triggered() ), this, SLOT( closeCurrentProject() ) );
+	connect(m_close_file,       SIGNAL( triggered() ), this, SLOT( closeCurrentProject() ) );
 
 		//Row and Column actions
 	QAction *add_column    = m_row_column_actions_group.addAction( QET::Icons::EditTableInsertColumnRight, tr("Ajouter une colonne") );
 	QAction *remove_column = m_row_column_actions_group.addAction( QET::Icons::EditTableDeleteColumn,      tr("Enlever une colonne") );
-	QAction *add_row       = m_row_column_actions_group.addAction( QET::Icons::EditTableInsertRowUnder,    tr("Ajouter une ligne")   );
-	QAction *remove_row    = m_row_column_actions_group.addAction( QET::Icons::EditTableDeleteRow,         tr("Enlever une ligne")   );
+	QAction *add_row       = m_row_column_actions_group.addAction( QET::Icons::EditTableInsertRowUnder,    tr("Ajouter une ligne", "Add row") );
+	QAction *remove_row    = m_row_column_actions_group.addAction( QET::Icons::EditTableDeleteRow,         tr("Enlever une ligne","Remove row") );
 
 	add_column    -> setStatusTip( tr("Ajoute une colonne au folio", "status bar tip"));
 	remove_column -> setStatusTip( tr("Enlève une colonne au folio", "status bar tip"));
@@ -300,9 +349,9 @@ void QETDiagramEditor::setUpActions()
 
 		//Selections Actions (related to a selected item)
 	delete_selection  = m_selection_actions_group.addAction( QET::Icons::EditDelete,        tr("Supprimer")							  );
-	rotate_selection  = m_selection_actions_group.addAction( QET::Icons::ObjectRotateRight, tr("Pivoter")							  );
+	rotate_selection  = m_selection_actions_group.addAction( QET::Icons::TransformRotate, tr("Pivoter")							  );
 	rotate_texts      = m_selection_actions_group.addAction( QET::Icons::ObjectRotateRight, tr("Orienter les textes")				  );
-	find_element      = m_selection_actions_group.addAction(                                tr("Retrouver dans le panel")			  );
+	find_element      = m_selection_actions_group.addAction(   QET::Icons::ZoomDraw,        tr("Retrouver dans le panel")			  );
 	edit_selection    = m_selection_actions_group.addAction( QET::Icons::ElementEdit,       tr("Éditer l'item sélectionné")  );
 
 	delete_selection -> setShortcut( QKeySequence::Delete);
@@ -324,9 +373,9 @@ void QETDiagramEditor::setUpActions()
 	connect(&m_selection_actions_group, &QActionGroup::triggered, this, &QETDiagramEditor::selectionGroupTriggered);
 
 		//Select Action
-	QAction *select_all     = m_select_actions_group.addAction( QET::Icons::EditSelectAll, tr("Tout sélectionner")	   );
-	QAction *select_nothing = m_select_actions_group.addAction(                            tr("Désélectionner tout") );
-	QAction *select_invert  = m_select_actions_group.addAction(                            tr("Inverser la sélection")  );
+    QAction *select_all     = m_select_actions_group.addAction( QET::Icons::EditSelectAll,      tr("Tout sélectionner") );
+    QAction *select_nothing = m_select_actions_group.addAction( QET::Icons::EditSelectNone,     tr("Désélectionner tout") );
+    QAction *select_invert  = m_select_actions_group.addAction( QET::Icons::EditSelectInvert,   tr("Inverser la sélection") );
 
 	select_all     -> setShortcut(QKeySequence::SelectAll);
 	select_nothing -> setShortcut(QKeySequence::Deselect);
@@ -373,7 +422,7 @@ void QETDiagramEditor::setUpActions()
 		//Adding action (add text, image, shape...)
 	QAction *add_text      = m_add_item_actions_group.addAction(QET::Icons::PartTextField, tr("Ajouter un champ de texte"));
 	QAction *add_image	   = m_add_item_actions_group.addAction(QET::Icons::adding_image,  tr("Ajouter une image"));
-	QAction *add_line	   = m_add_item_actions_group.addAction(QET::Icons::PartLine,      tr("Ajouter une ligne"));
+	QAction *add_line	   = m_add_item_actions_group.addAction(QET::Icons::PartLine,      tr("Ajouter une ligne", "Draw line"));
 	QAction *add_rectangle = m_add_item_actions_group.addAction(QET::Icons::PartRectangle, tr("Ajouter un rectangle"));
 	QAction *add_ellipse   = m_add_item_actions_group.addAction(QET::Icons::PartEllipse,   tr("Ajouter une ellipse"));
 	QAction *add_polyline  = m_add_item_actions_group.addAction(QET::Icons::PartPolygon,   tr("Ajouter une polyligne"));
@@ -447,6 +496,7 @@ void QETDiagramEditor::setUpActions()
 	connect(prj_clean,          SIGNAL(triggered()), this,       SLOT(cleanCurrentProject())       );
 	connect(prj_diagramList,    SIGNAL(triggered()), this,       SLOT(addDiagramFolioListToProject()));
 	connect(prj_nomenclature,   SIGNAL(triggered()), this,       SLOT(nomenclatureProject())       );
+	connect(prj_terminalBloc,   SIGNAL(triggered()), this,       SLOT(slot_generateTerminalBlock()));
 	connect(print,              SIGNAL(triggered()), this,       SLOT(printDialog())               );
 	connect(export_diagram,     SIGNAL(triggered()), this,       SLOT(exportDialog())              );
 	connect(tile_window,        SIGNAL(triggered()), &workspace, SLOT(tileSubWindows())            );
@@ -487,6 +537,7 @@ void QETDiagramEditor::setUpToolBar() {
 	view_bar -> addAction(mode_selection);
 	view_bar -> addAction(mode_visualise);
 	view_bar -> addSeparator();
+	view_bar -> addAction(m_draw_grid);
 	view_bar -> addAction (m_grey_background);
 	view_bar -> addSeparator();
 	view_bar -> addActions(m_zoom_action_toolBar);
@@ -562,15 +613,17 @@ void QETDiagramEditor::setUpMenu() {
 	menu_project -> addSeparator();
 	menu_project -> addAction(prj_diagramList);
 	menu_project -> addAction(prj_nomenclature);
+	menu_project -> addAction(prj_terminalBloc);
 
-	main_bar    -> toggleViewAction() -> setStatusTip(tr("Affiche ou non la barre d'outils principale"));
-	view_bar    -> toggleViewAction() -> setStatusTip(tr("Affiche ou non la barre d'outils Affichage"));
-	diagram_bar -> toggleViewAction() -> setStatusTip(tr("Affiche ou non la barre d'outils Schéma"));
-	qdw_pa      -> toggleViewAction() -> setStatusTip(tr("Affiche ou non le panel d'appareils"));
-	qdw_undo    -> toggleViewAction() -> setStatusTip(tr("Affiche ou non la liste des modifications"));
+	main_bar         -> toggleViewAction() -> setStatusTip(tr("Affiche ou non la barre d'outils principale"));
+	view_bar         -> toggleViewAction() -> setStatusTip(tr("Affiche ou non la barre d'outils Affichage"));
+	diagram_bar      -> toggleViewAction() -> setStatusTip(tr("Affiche ou non la barre d'outils Schéma"));
+	qdw_pa           -> toggleViewAction() -> setStatusTip(tr("Affiche ou non le panel d'appareils"));
+	qdw_undo         -> toggleViewAction() -> setStatusTip(tr("Affiche ou non la liste des modifications"));
+	
 
 	// menu Affichage
-	QMenu *projects_view_mode = menu_affichage -> addMenu(tr("Afficher les projets"));
+    QMenu *projects_view_mode = menu_affichage -> addMenu(QET::Icons::ConfigureToolbars, tr("Afficher les projets"));
 	projects_view_mode -> setTearOffEnabled(true);
 	projects_view_mode -> addAction(windowed_view_mode);
 	projects_view_mode -> addAction(tabbed_view_mode);
@@ -579,6 +632,7 @@ void QETDiagramEditor::setUpMenu() {
 	menu_affichage -> addAction(mode_selection);
 	menu_affichage -> addAction(mode_visualise);
 	menu_affichage -> addSeparator();
+	menu_affichage -> addAction(m_draw_grid);
 	menu_affichage -> addAction(m_grey_background);
 	menu_affichage -> addSeparator();
 	menu_affichage -> addActions(m_zoom_actions_group.actions());
@@ -617,19 +671,18 @@ void QETDiagramEditor::closeEvent(QCloseEvent *qce) {
 }
 
 /**
-	Gere les evenements du l'editeur de schema
-	Reimplemente ici pour :
-	  * eviter un conflit sur le raccourci clavier "Ctrl+W" (QKeySequence::Close)
-	@param e Evenement
-*/
-bool QETDiagramEditor::event(QEvent *e) {
-	if (e -> type() == QEvent::ShortcutOverride) {
-		QKeyEvent *shortcut_event = static_cast<QKeyEvent *>(e);
-		if (shortcut_event && shortcut_event -> matches(QKeySequence::Close)) {
-			close_file -> trigger();
-			e -> accept();
-			return(true);
-		}
+ * @brief QETDiagramEditor::event
+ * Reimplemented to :
+ * -Load elements collection when WindowActivate.
+ * @param e
+ * @return 
+ */
+bool QETDiagramEditor::event(QEvent *e)
+{
+	if (m_first_show && e->type() == QEvent::WindowActivate)
+	{
+		m_first_show = false;
+		QTimer::singleShot(250, m_element_collection_widget, SLOT(reload()));
 	}
 	return(QETMainWindow::event(e));
 }
@@ -661,13 +714,14 @@ void QETDiagramEditor::save() {
 		QETResult saved = project_view -> save();
 
 		if (saved.isOk()) {
-			save_file -> setDisabled(true);
+			//save_file -> setDisabled(true);
 			QETApp::projectsRecentFiles() -> fileWasOpened(project_view -> project() -> filePath());
 
 			QString title = (project_view -> project() -> title ());
 			if (title.isEmpty()) title = "QElectroTech ";
 			QString filePath = (project_view -> project() -> filePath ());
 			statusBar()-> showMessage(tr("Projet %1 enregistré dans le repertoire: %2.").arg(title).arg (filePath), 2000);
+			m_element_collection_widget->highlightUnusedElement();
 		}
 		else {
 			showError(saved);
@@ -689,6 +743,7 @@ void QETDiagramEditor::saveAs() {
 			if (title.isEmpty()) title = "QElectroTech ";
 			QString filePath = (project_view -> project() -> filePath ());
 			statusBar()->showMessage(tr("Projet %1 enregistré dans le repertoire: %2.").arg(title).arg (filePath), 2000);
+			m_element_collection_widget->highlightUnusedElement();
 		}
 		else {
 			showError(save_file);
@@ -908,10 +963,14 @@ bool QETDiagramEditor::addProject(QETProject *project, bool update_panel) {
 	addProjectView(project_view);
 
 	undo_group.addStack(project -> undoStack());
+
+	m_element_collection_widget->addProject(project);
 	
 	// met a jour le panel d'elements
 	if (update_panel) {
 		pa -> elementsPanel().projectWasOpened(project);
+		if (currentDiagram() != NULL)
+		m_autonumbering_dock->setProject(project, project_view);
 	}
 	
 	return(true);
@@ -993,7 +1052,7 @@ CustomElement *QETDiagramEditor::currentCustomElement() const {
 */
 ProjectView *QETDiagramEditor::findProject(DiagramView *diagram_view) const {
 	foreach(ProjectView *project_view, openedProjects()) {
-		if (project_view -> diagrams().contains(diagram_view)) {
+		if (project_view -> diagram_views().contains(diagram_view)) {
 			return(project_view);
 		}
 	}
@@ -1007,7 +1066,7 @@ ProjectView *QETDiagramEditor::findProject(DiagramView *diagram_view) const {
 */
 ProjectView *QETDiagramEditor::findProject(Diagram *diagram) const {
 	foreach(ProjectView *project_view, openedProjects()) {
-		foreach(DiagramView *diagram_view, project_view -> diagrams()) {
+		foreach(DiagramView *diagram_view, project_view -> diagram_views()) {
 			if (diagram_view -> diagram() == diagram) {
 				return(project_view);
 			}
@@ -1222,7 +1281,7 @@ void QETDiagramEditor::rowColumnGroupTriggered(QAction *action)
 void QETDiagramEditor::slot_setSelectionMode()
 {
 	if (ProjectView *pv = currentProject())
-		foreach(DiagramView *dv, pv -> diagrams())
+		foreach(DiagramView *dv, pv -> diagram_views())
 			dv -> setSelectionMode();
 }
 
@@ -1233,7 +1292,7 @@ void QETDiagramEditor::slot_setSelectionMode()
 void QETDiagramEditor::slot_setVisualisationMode()
 {
 	if (ProjectView *pv = currentProject())
-		foreach(DiagramView *dv, pv -> diagrams())
+		foreach(DiagramView *dv, pv -> diagram_views())
 			dv -> setVisualisationMode();
 }
 
@@ -1250,7 +1309,8 @@ void QETDiagramEditor::slot_updateActions()
 	bool opened_diagram = dv;
 	bool editable_project = (pv && !pv -> project() -> isReadOnly());
 
-	close_file       -> setEnabled(opened_project);
+	m_close_file       -> setEnabled(opened_project);
+	save_file        -> setEnabled(opened_project);
 	save_file_as     -> setEnabled(opened_project);
 	prj_edit_prop    -> setEnabled(opened_project);
 	prj_add_diagram  -> setEnabled(editable_project);
@@ -1273,6 +1333,20 @@ void QETDiagramEditor::slot_updateActions()
 	slot_updateModeActions();
 	slot_updatePasteAction();
 	slot_updateComplexActions();
+	slot_updateAutoNumDock();
+}
+
+/**
+ * @brief QETDiagramEditor::slot_updateAutoNumDock
+ * Update Auto Num Dock Widget when changing Project
+ */
+void QETDiagramEditor::slot_updateAutoNumDock() {
+	if ( workspace.subWindowList().indexOf(workspace.activeSubWindow()) != activeSubWindowIndex) {
+			activeSubWindowIndex = workspace.subWindowList().indexOf(workspace.activeSubWindow());
+			if (currentProject() != NULL && currentDiagram() != NULL) {
+				m_autonumbering_dock->setProject(currentProject()->project(),currentProject());
+			}
+	}
 }
 
 /**
@@ -1285,11 +1359,11 @@ void QETDiagramEditor::slot_updateUndoStack()
 	if (pv)
 	{
 		undo_group.setActiveStack(pv->project()->undoStack());
-		save_file -> setEnabled (undo_group.activeStack() -> count() && !pv -> project() -> isReadOnly());
-	}
-	else
-	{
-		save_file -> setDisabled(true);
+//		save_file -> setEnabled (undo_group.activeStack() -> count() && !pv -> project() -> isReadOnly());
+//	}
+//	else
+//	{
+//		//save_file -> setDisabled(true);
 	}
 }
 
@@ -1429,7 +1503,7 @@ void QETDiagramEditor::addProjectView(ProjectView *project_view)
 {
 	if (!project_view) return;
 
-	foreach(DiagramView *dv, project_view -> diagrams())
+	foreach(DiagramView *dv, project_view -> diagram_views())
 		diagramWasAdded(dv);
 	
 		//Manage the close event of project
@@ -1441,9 +1515,8 @@ void QETDiagramEditor::addProjectView(ProjectView *project_view)
 		connect(project, SIGNAL(readOnlyChanged(QETProject *, bool)), this, SLOT(slot_updateActions()));
 	
 		//Manage request for edit or find element and titleblock
-	connect(project_view, SIGNAL(findElementRequired(const ElementsLocation &)),                    this,               SLOT(findElementInPanel(const ElementsLocation &)));
-	connect(project_view, SIGNAL(editElementRequired(const ElementsLocation &)),                    this,               SLOT(editElementInEditor(const ElementsLocation &)));
-	connect(project_view, SIGNAL(editTitleBlockTemplate(const TitleBlockTemplateLocation &, bool)), QETApp::instance(), SLOT(openTitleBlockTemplate(TitleBlockTemplateLocation, bool)));
+	connect (project_view, &ProjectView::findElementRequired, this, &QETDiagramEditor::findElementInPanel);
+	connect (project_view, &ProjectView::editElementRequired, this, &QETDiagramEditor::editElementInEditor);
 	
 		// display error messages sent by the project view
 	connect(project_view, SIGNAL(errorEncountered(QString)), this, SLOT(showError(const QString &)));
@@ -1456,6 +1529,15 @@ void QETDiagramEditor::addProjectView(ProjectView *project_view)
 	QMdiSubWindow *sub_window = workspace.addSubWindow(project_view);
 	sub_window -> setWindowIcon(project_view -> windowIcon());
 	sub_window -> systemMenu() -> clear();
+	
+		//By defaut QMdiSubWindow have a QAction "close" with shortcut QKeySequence::Close
+		//But the QAction m_close_file of this class have the same shortcut too.
+		//We remove the shortcut of the QAction of QMdiSubWindow for avoid conflic
+	for(QAction *act : sub_window->actions())
+	{
+		if(act->shortcut() == QKeySequence::Close)
+			act->setShortcut(QKeySequence());
+	}
 
 		//Display the new window
 	if (maximise) project_view -> showMaximized();
@@ -1499,6 +1581,42 @@ ProjectView *QETDiagramEditor::viewForFile(const QString &filepath) const {
 	return(0);
 }
 
+/**
+ * @brief QETDiagramEditor::acessCurrentProject
+ * Retrieve current Project open in diagram editor
+ */
+ProjectView *QETDiagramEditor::acessCurrentProject (){
+	QMdiSubWindow *current_window = workspace.activeSubWindow();
+	if (!current_window) return(0);
+
+	QWidget *current_widget = current_window -> widget();
+	if (!current_widget) return(0);
+
+	if (ProjectView *project_view = qobject_cast<ProjectView *>(current_widget)) {
+	return(project_view);
+	}
+	return(0);
+}
+
+/**
+ * @brief QETDiagramEditor::drawGrid
+ * @return true if the grid of folio must be displayed
+ */
+bool QETDiagramEditor::drawGrid() const {
+	return m_draw_grid->isChecked();
+}
+
+/**
+ * @brief QETDiagramEditor::acessCurrentDiagramView
+ * Retrieve current DiagramView used in diagram editor
+ */
+DiagramView *QETDiagramEditor::acessCurrentDiagramView () {
+	if (ProjectView *project_view = currentProject()) {
+		return(project_view -> currentDiagram());
+	}
+	return(0);
+}
+
 /**
 	met a jour le menu "Fenetres"
 */
@@ -1507,7 +1625,7 @@ void QETDiagramEditor::slot_updateWindowsMenu() {
 	foreach(QAction *a, windows_menu -> actions()) windows_menu -> removeAction(a);
 	
 	// actions de fermeture
-	windows_menu -> addAction(close_file);
+	windows_menu -> addAction(m_close_file);
 	//windows_menu -> addAction(closeAllAct);
 	
 	// actions de reorganisation des fenetres
@@ -1697,6 +1815,7 @@ void QETDiagramEditor::projectWasClosed(ProjectView *project_view) {
 	QETProject *project = project_view -> project();
 	if (project) {
 		pa -> elementsPanel().projectWasClosed(project);
+		m_element_collection_widget->removeProject(project);
 		undo_group.removeStack(project -> undoStack());
 		QETApp::unregisterProject(project);
 	}
@@ -1893,6 +2012,10 @@ void QETDiagramEditor::cleanCurrentProject() {
 	}
 }
 
+void QETDiagramEditor::reloadOldElementPanel() {
+	pa->reloadAndFilter();
+}
+
 /**
  * @brief export nomemclature of schema
  */
@@ -1918,7 +2041,7 @@ void QETDiagramEditor::removeDiagramFromProject() {
 
 			// if the removed diagram was a folio sheet, then delete all the remaining folio sheets also.
 			if (isFolioList) {
-				foreach (DiagramView *diag, current_project -> diagrams()) {
+				foreach (DiagramView *diag, current_project -> diagram_views()) {
 					if (dynamic_cast<DiagramFolioList *>(diag -> diagram())) {
 						current_project -> removeDiagram(diag);
 					}
@@ -1926,8 +2049,8 @@ void QETDiagramEditor::removeDiagramFromProject() {
 
 			  // else if after diagram removal, the total diagram quantity becomes a factor of 58, then
 			  // remove one (last) folio sheet.
-			} else if (current_project -> diagrams().size() % 58 == 0) {
-				foreach (DiagramView *diag, current_project -> diagrams()) {
+			} else if (current_project -> diagram_views().size() % 58 == 0) {
+				foreach (DiagramView *diag, current_project -> diagram_views()) {
 					DiagramFolioList *ptr = dynamic_cast<DiagramFolioList *>(diag -> diagram());
 					if (ptr && ptr -> getId() == current_project -> project() -> getFolioSheetsQuantity() - 1) {
 						current_project -> removeDiagram(diag);
@@ -1950,43 +2073,13 @@ void QETDiagramEditor::diagramWasAdded(DiagramView *dv)
 }
 
 /**
-	@param location Emplacement de l'element a retrouver dans le panel
-	d'elements.
-*/
-void QETDiagramEditor::findElementInPanel(const ElementsLocation &location) {
-	bool element_found = pa -> elementsPanel().scrollToElement(location);
-	if (!element_found) {
-		// l'element n'a pas ete trouve
-		
-		ElementsCollectionItem *element = QETApp::collectionItem(location);
-		if (element) {
-			// mais il semble exister tout de meme
-			
-			// peut-etre vient-il d'un projet ouvert dans un autre editeur ?
-			if (location.project() && !findProject(location.project())) {
-				statusBar() -> showMessage(
-					tr("Impossible de retrouver cet élément dans le panel car il semble édité dans une autre fenêtre"),
-					10000
-				);
-			} else {
-				// il devrait etre affiche : on tente de recharger le panel
-				statusBar() -> showMessage(
-					tr("Impossible de retrouver cet élément dans le panel... rechargement du panel..."),
-					10000
-				);
-				pa -> reloadAndFilter();
-				statusBar() -> clearMessage();
-				element_found = pa -> elementsPanel().scrollToElement(location);
-			}
-		}
-	}
-	
-	if (!element_found) {
-		statusBar() -> showMessage(
-			tr("Impossible de retrouver cet élément dans le panel"),
-			10000
-		);
-	}
+ * @brief QETDiagramEditor::findElementInPanel
+ * Find the item for @location in the element panel
+ * @param location
+ */
+void QETDiagramEditor::findElementInPanel(const ElementsLocation &location)
+{
+	m_element_collection_widget->setCurrentLocation(location);
 }
 
 /**
@@ -2049,14 +2142,64 @@ void QETDiagramEditor::selectionChanged()
 		m_selection_properties_editor->setDiagram(dv->diagram());
 }
 
+///**
+// * @brief QETDiagramEditor::activeUndoStackCleanChanged
+// * Enable the QAction save_file when @clean is set to false
+// * @clean at true do nothing;
+// * @param clean
+// */
+//void QETDiagramEditor::activeUndoStackCleanChanged(bool clean) {
+//	if (!clean) {
+//		//save_file -> setEnabled(true);
+//	}
+//}
+
+
 /**
- * @brief QETDiagramEditor::activeUndoStackCleanChanged
- * Enable the QAction save_file when @clean is set to false
- * @clean at true do nothing;
- * @param clean
+ * @brief QETDiagramEditor::slot_generateTerminalBlock
  */
-void QETDiagramEditor::activeUndoStackCleanChanged(bool clean) {
-	if (!clean) {
-		save_file -> setEnabled(true);
-	}
+void QETDiagramEditor::slot_generateTerminalBlock() {
+bool success;
+QProcess *process = new QProcess(qApp);
+
+// If launched under control:
+//connect(process, SIGNAL(errorOcurred(int error)), this, SLOT(slot_generateTerminalBlock_error()));
+//process->start("qet_tb_generator");
+
+#ifdef Q_OS_MAC
+success = process->startDetached("/Library/Frameworks/Python.framework/Versions/3.5/bin/qet_tb_generator");
+#else
+success = process->startDetached("qet_tb_generator");
+#endif
+if ( !success ) {
+QMessageBox::warning(0,
+"Error launching plugin", 
+"To install the plugin qet_tb_generator\nVisit https://pypi.python.org/pypi/qet-tb-generator/\n"
+					 "\n"
+					 "Requires python 3.5 or above.\n"
+					 ">> First install on Linux\n"
+					 "1. check you have pip3 installed: pip3 --version\n"
+					 "If not install with: sudo apt-get install python3-pip\n"
+					 "2. Install the program: sudo pip3 install qet_tb_generator\n"
+					 "3. Run the program: qet_tb_generator\n"
+					 ">> Update on Linux\n"
+					 "sudo pip3 install --upgrade qet_tb_generator \n"
+					 "\n"
+					 ">> First install on Windows\n"
+					 "1. Install, if required, python 3.5 or above \n"
+					 "2. pip install qet_tb_generator\n"
+					 ">> Update on Windows\n"
+					 "python -m pip install --upgrade qet_tb_generator\n"
+					 ">>user could launch in a terminal this script in this directory \n"
+					 " C:\\users\\XXXX\\AppData\\Local\\Programs\\Python\\Python36-32\\Scripts \n"
+					 "\n"
+					 ">> First install on macOSX \n"
+					 "1. Install, if required, python 3.5 or above \n"
+					 " Visit https://qelectrotech.org/forum/viewtopic.php?pid=5674#p5674 \n"
+					 "2. pip3 install qet_tb_generator \n"
+					 ">> Update on macOSX \n"
+					 " pip3 install --upgrade qet_tb_generator \n"
+					 );
+}
+
 }
