@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -31,6 +31,9 @@ class ElementsPanelWidget;
 class ElementsLocation;
 class RecentFiles;
 class DiagramPropertiesEditorDockWidget;
+class ElementsCollectionWidget;
+class AutoNumberingDockWidget;
+
 /**
 	This class represents the main window of the QElectroTech diagram editor and,
 	ipso facto, the most important part of the QElectroTech user interface.
@@ -48,8 +51,10 @@ class QETDiagramEditor : public QETMainWindow {
 
 	private:
 		void setUpElementsPanel ();
+		void setUpElementsCollectionWidget();
 		void setUpUndoStack     ();
 		void setUpSelectionPropertiesEditor();
+		void setUpAutonumberingWidget();
 		void setUpActions       ();
 		void setUpToolBar       ();
 		void setUpMenu          ();
@@ -62,9 +67,12 @@ class QETDiagramEditor : public QETMainWindow {
 		bool                 openAndAddProject (const QString &, bool = true, bool = true);
 		QList<QString>       editedFiles       () const;
 		ProjectView         *viewForFile       (const QString &) const;
-	
+		ProjectView         *acessCurrentProject ();
+		DiagramView         *acessCurrentDiagramView ();
+		bool drawGrid() const;
+
 	protected:
-	virtual bool event(QEvent *);
+		virtual bool event(QEvent *);
 	
 	private:
 	bool addProject(QETProject *, bool = true);
@@ -105,9 +113,11 @@ class QETDiagramEditor : public QETMainWindow {
 		void slot_updateComplexActions();
 		void slot_updatePasteAction();
 		void slot_updateWindowsMenu();
+		void slot_updateAutoNumDock();
 		void editSelectionProperties();
 		void slot_resetConductors();
 		void slot_autoConductor(bool ac);
+		void slot_generateTerminalBlock();
 		void setWindowedMode();
 		void setTabbedMode();
 		void readSettings();
@@ -134,6 +144,7 @@ class QETDiagramEditor : public QETMainWindow {
 		void moveDiagramUpx10(Diagram *);
 		void moveDiagramDownx10(Diagram *);
 		void cleanCurrentProject();
+		void reloadOldElementPanel();
 		void nomenclatureProject();
 		void diagramWasAdded(DiagramView *);
 		void findElementInPanel(const ElementsLocation &);
@@ -145,10 +156,10 @@ class QETDiagramEditor : public QETMainWindow {
 
 	private slots:
 		void selectionChanged();
-		void activeUndoStackCleanChanged (bool clean);
-	
+		//void activeUndoStackCleanChanged (bool clean);
+
 		// attributes
-	public:
+	private:
 		// Actions reachable through menus within QElectroTech
 		QActionGroup *grp_visu_sel;  ///< Action group for visualisation vs edition mode
 		QActionGroup *grp_view_mode; ///< Action group for project
@@ -161,20 +172,24 @@ class QETDiagramEditor : public QETMainWindow {
 		QAction *quit_editor;        ///< Quit the diagram editor
 		QAction *undo;               ///< Cancel the latest action
 		QAction *redo;               ///< Redo the latest cancelled operation
+	public:
+		QAction *infos_diagram;      ///< Show a dialog to edit diagram properties
+		QAction *conductor_reset;    ///< Reset paths of selected conductors
 		QAction *cut;                ///< Cut selection to clipboard
 		QAction *copy;               ///< Copy selection to clipboard
+	private:
 		QAction *paste;              ///< Paste clipboard content on the current diagram
-		QAction *conductor_reset;    ///< Reset paths of selected conductors
 		QAction *m_auto_conductor;   ///< Enable/Disable the use of auto conductor
 		QAction *conductor_default;  ///< Show a dialog to edit default conductor properties
 		QAction *m_grey_background;  ///< Switch the background color in white or grey
-		QAction *infos_diagram;      ///< Show a dialog to edit diagram properties
+		QAction *m_draw_grid;        ///< Switch the background grid display or not
 		QAction *prj_edit_prop;      ///< Edit the properties of the current project.
 		QAction *prj_add_diagram;    ///< Add a diagram to the current project.
 		QAction *prj_del_diagram;    ///< Delete a diagram from the current project
 		QAction *prj_clean;          ///< Clean the content of the curent project by removing useless items
 		QAction *prj_diagramList;    ///< Sommaire des schemas
 		QAction *prj_nomenclature;   ///< generate nomenclature
+		QAction *prj_terminalBloc;   ///< generate terminal block
 		QAction *tile_window;        ///< Show MDI subwindows as tile
 		QAction *cascade_window;     ///< Show MDI subwindows as cascade
 		QAction *prev_window;        ///< Switch to the previous document
@@ -188,26 +203,28 @@ class QETDiagramEditor : public QETMainWindow {
 
 		QActionGroup m_select_actions_group; ///Action related to global selections
 
+	public:
+		QActionGroup m_row_column_actions_group; /// Action related to add/remove rows/column in diagram
 		QActionGroup m_selection_actions_group; ///Action related to edit a selected item
+	private:
 		QAction *delete_selection;				///< Delete selection
 		QAction *rotate_selection;				///< Rotate selected elements and text items by 90 degrees
 		QAction *rotate_texts;					///< Direct selected text items to a specific angle
 		QAction *find_element;					///< Find the selected element in the panel
 
-		QActionGroup m_row_column_actions_group; /// Action related to add/remove rows/column in diagram
-
 		QActionGroup m_file_actions_group; ///Actions related to file (open, close, save...)
-		QAction *close_file;			   ///< Close current project file
+		QAction *m_close_file;			   ///< Close current project file
 		QAction *save_file;				   ///< Save current project
 		QAction *save_file_as;			   ///< Save current project as a specific file
 
-	private:
 		QMdiArea workspace;
 		QSignalMapper windowMapper;
 		/// Directory to use for file dialogs such as File > save
 		QDir open_dialog_dir;
 		/// Dock for the elements panel
 		QDockWidget *qdw_pa;
+		QDockWidget *m_qdw_elmt_collection;
+		ElementsCollectionWidget *m_element_collection_widget;
 		/// Dock for the undo list
 		QDockWidget *qdw_undo;
 		DiagramPropertiesEditorDockWidget *m_selection_properties_editor;
@@ -219,5 +236,9 @@ class QETDiagramEditor : public QETMainWindow {
 		QToolBar *diagram_bar;
 		QToolBar *m_add_item_toolBar;
 		QUndoGroup undo_group;
+		// AutoNumbering Selection Dock
+		AutoNumberingDockWidget *m_autonumbering_dock;
+		int activeSubWindowIndex;
+		bool m_first_show = true;
 };
 #endif
