@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -54,11 +54,15 @@ QRectF CommentItem::boundingRect() const {
  * @brief CommentItem::autoPos
  * Adjust the position of this item.
  */
-void CommentItem::autoPos() {
+void CommentItem::autoPos()
+{
 	if (m_text_parent)
 		centerToParentBottom(this);
 	else
-		centerToBottomDiagram(this, m_element);
+	{
+		XRefProperties xrp = m_element->diagram()->project()->defaultXRefProperties(m_element->kindInformations()["type"].toString());
+		centerToBottomDiagram(this, m_element, xrp.offset());
+	}
 }
 
 /**
@@ -107,31 +111,77 @@ bool CommentItem::setTextParent() {
  */
 void CommentItem::updateLabel()
 {
-	QString comment = m_element -> elementInformations()["comment"].toString();
+	QString comment  = m_element -> elementInformations()["comment"]. toString();
 
-	if (comment == m_comment && !m_text_parent) return;
+	QString location = m_element -> elementInformations()["location"].toString();
+
+	prepareGeometryChange();
+	m_bounding_rect = QRectF();
+
+	QPainter painter_;
+	painter_.begin(&m_picture);
+
+	if (comment == m_comment && !m_text_parent && location == m_location)
+		return;
 
 	if (comment != m_comment)
 	{
 		m_comment = comment;
-
-		QPen pen(Qt::black);
-			 pen.setWidthF (0.5);
-
-		QPainter painter(&m_picture);
-				 painter.setPen  (pen);
-				 painter.setFont (QETApp::diagramTextsFont(6));
-
-		QRectF text_bounding = painter.boundingRect(QRectF(QPointF(0,0), QSizeF(70, 1)), Qt::TextWordWrap | Qt::AlignHCenter, m_comment);
-
-		painter.drawText(text_bounding, Qt::TextWordWrap | Qt::AlignHCenter, m_comment);
-
-		text_bounding.adjust(-1,0,1,0); //adjust only for better visual
-		painter.drawRoundedRect(text_bounding, 2, 2);
-
-		prepareGeometryChange();
-		m_bounding_rect = text_bounding;
+		addInfo(painter_, "comment");
 	}
+	else if (comment == m_comment)
+		addInfo(painter_, "comment");
+
+	if (location != m_location)
+	{
+		m_location = location;
+		addInfo(painter_, "location");
+	}
+	else if (location == m_location){
+		addInfo(painter_, "location");
+	}
+	painter_.end();
 
 	autoPos();
 }
+
+/**
+ * @brief CommentItem::addInfo
+ * @param painter
+ * @param type e.g. comment, location
+ * Draw Info to item text.
+ * (draw this item in a QPicture)
+ */
+void CommentItem::addInfo(QPainter &painter, QString type)
+{
+	QString text = autonum::AssignVariables::formulaToLabel(m_element -> elementInformations()[type].toString(), m_element->rSequenceStruct(), m_element->diagram(), m_element);
+	bool must_show  = m_element -> elementInformations().keyMustShow(type);
+
+	if (!text.isEmpty() && must_show)
+	{
+		painter.save();
+		painter.setFont (QETApp::diagramTextsFont(6));
+
+		QPen pen(Qt::black);
+		pen.setWidthF (0.5);
+
+		painter.setPen  (pen);
+
+		QRectF r, text_bounding;
+		qreal center = boundingRect().center().x();
+
+		r = QRectF(QPointF(center - 35, boundingRect().bottom()),
+				   QPointF(center + 35, boundingRect().bottom() + 1));
+
+		text_bounding = painter.boundingRect(r, Qt::TextWordWrap | Qt::AlignHCenter, text);
+		painter.drawText(text_bounding, Qt::TextWordWrap | Qt::AlignHCenter, text);
+
+		text_bounding.adjust(-1,0,1,0); //adjust only for better visual
+
+		m_shape_path.addRect(text_bounding);
+		prepareGeometryChange();
+		m_bounding_rect = m_bounding_rect.united(text_bounding);
+		if (type == "comment") painter.drawRoundedRect(text_bounding, 2, 2);
+		painter.restore();
+	}
+}
