@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -28,6 +28,7 @@
 #include "conductorautonumerotation.h"
 #include "conductorpropertiesdialog.h"
 #include "QPropertyUndoCommand/qpropertyundocommand.h"
+#include "numerotationcontextcommands.h"
 
 #define PR(x) qDebug() << #x " = " << x;
 
@@ -35,6 +36,36 @@ bool Conductor::pen_and_brush_initialized = false;
 QPen Conductor::conductor_pen = QPen();
 QBrush Conductor::conductor_brush = QBrush();
 
+
+class ConductorXmlRetroCompatibility
+{
+		friend class Conductor;
+
+		static void loadSequential(const QDomElement &dom_element, QString seq, QStringList* list)
+		{
+			int i = 0;
+			while (!dom_element.attribute(seq + QString::number(i+1)).isEmpty())
+			{
+					list->append(dom_element.attribute(seq + QString::number(i+1)));
+					i++;
+			}
+		}
+
+		static void loadSequential(const QDomElement &dom_element, Conductor *conductor)
+		{
+			autonum::sequentialNumbers sn;
+
+			loadSequential(dom_element,"sequ_",&sn.unit);
+			loadSequential(dom_element,"sequf_",&sn.unit_folio);
+			loadSequential(dom_element,"seqt_",&sn.ten);
+			loadSequential(dom_element,"seqtf_",&sn.ten_folio);
+			loadSequential(dom_element,"seqh_",&sn.hundred);
+			loadSequential(dom_element,"seqhf_",&sn.hundred_folio);
+
+			conductor->rSequenceNum() = sn;
+		}
+};
+
 /**
  * @brief Conductor::Conductor
  * Default constructor.
@@ -46,24 +77,17 @@ Conductor::Conductor(Terminal *p1, Terminal* p2) :
 	QGraphicsPathItem(0),
 	terminal1(p1),
 	terminal2(p2),
-	bMouseOver(false),
-	m_handler(10),
-	text_item(0),
+	m_mouse_over(false),
+	m_text_item(0),
 	segments(NULL),
-	moving_segment(false),
+	m_moving_segment(false),
 	modified_path(false),
 	has_to_save_profile(false),
 	must_highlight_(Conductor::None)
 {
-		//Set the default conductor properties.
-	if (p1->diagram())
-		properties_ = p1->diagram()->defaultConductorProperties;
-	else if (p2->diagram())
-		properties_ = p2->diagram()->defaultConductorProperties;
-
-		//set Zvalue at 9 to be upper than the DiagramImageItem and bottom of element(10)
-	setZValue(9);
-	previous_z_value = zValue();
+		//set Zvalue at 11 to be upper than the DiagramImageItem and element
+	setZValue(11);
+	m_previous_z_value = zValue();
 
 		//Add this conductor to the list of conductor of each of the two terminal
 	bool ajout_p1 = terminal1 -> addConductor(this);
@@ -92,14 +116,18 @@ Conductor::Conductor(Terminal *p1, Terminal* p2) :
 
 		//Generate the path of this conductor.
 	generateConductorPath(terminal1 -> dockConductor(), terminal1 -> orientation(), terminal2 -> dockConductor(), terminal2 -> orientation());
-	setFlags(QGraphicsItem::ItemIsSelectable);
+	setFlags(QGraphicsItem::ItemIsSelectable | QGraphicsItem::ItemSendsScenePositionChanges);
 	setAcceptHoverEvents(true);
 	
 		// Add the text field
-	text_item = new ConductorTextItem(properties_.text, this);
-	text_item -> setFlag(QGraphicsItem::ItemStacksBehindParent);
+	m_text_item = new ConductorTextItem(m_properties.text, this);
+	connect(m_text_item, &ConductorTextItem::diagramTextChanged, this, &Conductor::displayedTextChanged);
 
-	connect(text_item, &ConductorTextItem::diagramTextChanged, this, &Conductor::displayedTextChanged);
+		//Set the default conductor properties.
+	if (p1->diagram())
+		setProperties(p1->diagram()->defaultConductorProperties);
+	else if (p2->diagram())
+		setProperties(p2->diagram()->defaultConductorProperties);
 }
 
 /**
@@ -108,6 +136,7 @@ Conductor::Conductor(Terminal *p1, Terminal* p2) :
  */
 Conductor::~Conductor()
 {
+	removeHandler();
 	terminal1->removeConductor(this);
 	terminal2->removeConductor(this);
 	deleteSegments();
@@ -142,30 +171,39 @@ void Conductor::updatePath(const QRectF &rect) {
 }
 
 /**
-	Genere le QPainterPath a partir de la liste des points
-*/
-void Conductor::segmentsToPath() {
-	// chemin qui sera dessine
+ * @brief Conductor::segmentsToPath
+ * Generate the QPainterPath from the list of points
+ */
+void Conductor::segmentsToPath()
+{
 	QPainterPath path;
 	
-	// s'il n'y a pa des segments, on arrete la
-	if (segments == NULL) setPath(path);
+	if (segments == NULL)
+		setPath(path);
 	
-	// demarre le chemin
+		//Start the path
 	path.moveTo(segments -> firstPoint());
-	
-	// parcourt les segments pour dessiner le chemin
+		//Each segments
 	ConductorSegment *segment = segments;
 	while(segment -> hasNextSegment()) {
 		path.lineTo(segment -> secondPoint());
 		segment = segment -> nextSegment();
 	}
-	
-	// termine le chemin
+		//Finish the path
 	path.lineTo(segment -> secondPoint());
 	
-	// affecte le chemin au conducteur
 	setPath(path);
+	
+		//If conductor is selected and he's not being modified
+		//we update the position of the handlers
+	if (isSelected() && !m_moving_segment)
+	{
+		if(handlerPoints().size() == m_handler_vector.size())
+			adjusteHandlerPos();
+		else
+			removeHandler();
+			addHandler();
+	}
 }
 
 /**
@@ -438,8 +476,8 @@ void Conductor::paint(QPainter *qp, const QStyleOptionGraphicsItem *options, QWi
 	qp -> save();
 	qp -> setRenderHint(QPainter::Antialiasing, false);
 	
-	// determine la couleur du conducteur
-	QColor final_conductor_color(properties_.color);
+		// Set the color of conductor
+	QColor final_conductor_color(m_properties.color);
 	if (must_highlight_ == Normal) {
 		final_conductor_color = QColor::fromRgb(69, 137, 255, 255);
 	} else if (must_highlight_ == Alert) {
@@ -455,29 +493,30 @@ void Conductor::paint(QPainter *qp, const QStyleOptionGraphicsItem *options, QWi
 	}
 	
 		//Draw the conductor bigger when is hovered
-	conductor_pen.setWidth(bMouseOver? 5 : 1);
+	conductor_pen.setWidthF(m_mouse_over? (m_properties.cond_size) +4 : (m_properties.cond_size));
 
-	// affectation du QPen et de la QBrush modifies au QPainter
+		//Set the QPen and QBrush to the QPainter
 	qp -> setBrush(conductor_brush);
 	QPen final_conductor_pen = conductor_pen;
 	
-	// modification du QPen generique pour lui affecter la couleur et le style adequats
+		//Set the conductor style
 	final_conductor_pen.setColor(final_conductor_color);
-	final_conductor_pen.setStyle(properties_.style);
-	final_conductor_pen.setJoinStyle(Qt::SvgMiterJoin); // meilleur rendu des pointilles
+	final_conductor_pen.setStyle(m_properties.style);
+	final_conductor_pen.setJoinStyle(Qt::SvgMiterJoin); // better rendering with dot
 	
-	// utilisation d'un trait "cosmetique" en-dessous d'un certain zoom
+		//Use a cosmetique line, below a certain zoom
 	if (options && options -> levelOfDetail < 1.0) {
 		final_conductor_pen.setCosmetic(true);
 	}
 	
 	qp -> setPen(final_conductor_pen);
 	
-	// dessin du conducteur
+		//Draw the conductor
 	qp -> drawPath(path());
-	if (properties_.type == ConductorProperties::Single) {
+	
+	if (m_properties.type == ConductorProperties::Single) {
 		qp -> setBrush(final_conductor_color);
-		properties_.singleLineProperties.draw(
+		m_properties.singleLineProperties.draw(
 			qp,
 			middleSegment() -> isHorizontal() ? QET::Horizontal : QET::Vertical,
 			QRectF(middleSegment() -> middle() - QPointF(12.0, 12.0), QSizeF(24.0, 24.0))
@@ -485,11 +524,7 @@ void Conductor::paint(QPainter *qp, const QStyleOptionGraphicsItem *options, QWi
 		if (isSelected()) qp -> setBrush(Qt::NoBrush);
 	}
 	
-		//Draw the squares used to modify the path of conductor when he is selected
-	if (isSelected())
-		m_handler.drawHandler(qp, handlerPoints());
-	
-	// dessine les eventuelles jonctions
+		//Draw the junctions
 	QList<QPointF> junctions_list = junctions();
 	if (!junctions_list.isEmpty()) {
 		final_conductor_pen.setStyle(Qt::SolidLine);
@@ -498,9 +533,10 @@ void Conductor::paint(QPainter *qp, const QStyleOptionGraphicsItem *options, QWi
 		qp -> setBrush(junction_brush);
 		qp -> setRenderHint(QPainter::Antialiasing, true);
 		foreach(QPointF point, junctions_list) {
-			qp -> drawEllipse(QRectF(point.x() - 1, point.y() - 1, 2.0, 2.0));
+			qp -> drawEllipse(QRectF(point.x() - 1.5, point.y() - 1.5, 3.0, 3.0));
 		}
 	}
+
 	qp -> restore();
 }
 
@@ -509,11 +545,11 @@ Diagram *Conductor::diagram() const {
 	return(qobject_cast<Diagram *>(scene()));
 }
 
-/**
+/**4
 	@return le champ de texte associe a ce conducteur
 */
 ConductorTextItem *Conductor::textItem() const {
-	return(text_item);
+	return(m_text_item);
 }
 
 /**
@@ -557,70 +593,18 @@ void Conductor::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event) {
  */
 void Conductor::mousePressEvent(QGraphicsSceneMouseEvent *event)
 {
-		//Left clic
-	if (event->buttons() & Qt::LeftButton)
-	{
-			//If user click on a handler (square used to modify the path of conductor),
-			//we get the segment corresponding to the handler
-		int index = m_handler.pointIsHoverHandler(event->pos(), handlerPoints());
-		if (index > -1)
-		{
-			moving_segment = true;
-			moved_segment = segmentsList().at(index+1);
-			before_mov_text_pos_ = text_item -> pos();
-		}
-	}
-
 	QGraphicsPathItem::mousePressEvent(event);
-
-	if (event -> modifiers() & Qt::ControlModifier)
+	
+	if (event->modifiers() & Qt::ControlModifier)
 		setSelected(!isSelected());
 }
 
-/**
- * @brief Conductor::mouseMoveEvent
- * Manage the mouse move event
- * @param event
- */
-void Conductor::mouseMoveEvent(QGraphicsSceneMouseEvent *event)
-{
-		//Left clic
-	if ((event->buttons() & Qt::LeftButton) && moving_segment)
-	{
-			//Snap the mouse pos to grid
-		QPointF pos_ = Diagram::snapToGrid(event->pos());
-
-			//Position of the last point
-		QPointF p = moved_segment -> middle();
-
-			//Calcul the movement
-		moved_segment -> moveX(pos_.x() - p.x());
-		moved_segment -> moveY(pos_.y() - p.y());
-			
-			//Apply the movement
-		modified_path = true;
-		has_to_save_profile = true;
-		segmentsToPath();
-		calculateTextItemPosition();
-	}
-
-	QGraphicsPathItem::mouseMoveEvent(event);
-}
-
 /**
  * @brief Conductor::mouseReleaseEvent
- * Manage the mouse release event
  * @param event
  */
 void Conductor::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
 {
-	moving_segment = false;
-	if (has_to_save_profile)
-	{
-		saveProfile();
-		has_to_save_profile = false;
-	}
-
 	if (!(event -> modifiers() & Qt::ControlModifier))
 		QGraphicsPathItem::mouseReleaseEvent(event);
 }
@@ -632,7 +616,7 @@ void Conductor::mouseReleaseEvent(QGraphicsSceneMouseEvent *event)
  */
 void Conductor::hoverEnterEvent(QGraphicsSceneHoverEvent *event) {
 	Q_UNUSED(event);
-	bMouseOver = true;
+	m_mouse_over = true;
 	update();
 }
 
@@ -644,60 +628,218 @@ void Conductor::hoverEnterEvent(QGraphicsSceneHoverEvent *event) {
 void Conductor::hoverLeaveEvent(QGraphicsSceneHoverEvent *event) {
 	Q_UNUSED(event);
 	update();
-	bMouseOver = false;
+	m_mouse_over = false;
 }
 
 /**
- * @brief Conductor::hoverMoveEvent conductor
- * @param e QGraphicsSceneHoverEvent describing the event
+ * @brief Conductor::itemChange
+ * @param change
+ * @param value
+ * @return 
  */
-void Conductor::hoverMoveEvent(QGraphicsSceneHoverEvent *event)
+QVariant Conductor::itemChange(GraphicsItemChange change, const QVariant &value)
 {
-	if (isSelected())
+	if (change == QGraphicsItem::ItemSelectedChange)
 	{
-			//If user hover an handler (square used to modify the path of conductor),
-			//we get the segment corresponding to the handler
-		int index = m_handler.pointIsHoverHandler(event->pos(), handlerPoints());
-		if (index > -1)
+		if (value.toBool())
 		{
-			ConductorSegment *segment_ = segmentsList().at(index+1);
-			if (m_handler.pointIsInHandler(event->pos(), segment_->secondPoint()))
-				setCursor(Qt::ForbiddenCursor);
-			else if (m_handler.pointIsInHandler(event->pos(), segment_->middle()))
-				setCursor(segmentsList().at(index+1)->isVertical() ? Qt::SplitHCursor : Qt::SplitVCursor);
+			m_previous_z_value = zValue();
+			setZValue(qAbs(m_previous_z_value) + 10000);
+			addHandler();
 		}
 		else
-			setCursor(Qt::ArrowCursor);
+		{
+			setZValue(m_previous_z_value);
+			removeHandler();
+		}
 	}
-
-	QGraphicsPathItem::hoverMoveEvent(event);
+	else if (change == QGraphicsItem::ItemSceneHasChanged)
+	{
+		calculateTextItemPosition();
+		
+		if(!scene())
+			removeHandler();
+		else if (scene() && isSelected())
+			addHandler();
+	}
+	else if (change == QGraphicsItem::ItemVisibleHasChanged) {
+		calculateTextItemPosition();
+	}
+	else if (change == QGraphicsItem::ItemPositionHasChanged && isSelected()) {
+		adjusteHandlerPos();
+	}
+	
+	return(QGraphicsPathItem::itemChange(change, value));
 }
 
 /**
-	Gere les changements relatifs au conducteur
-	Reimplemente ici pour :
-	  * positionner le conducteur en avant-plan lorsqu'il est selectionne
-	@param change Type de changement
-	@param value  Valeur relative au changement
-*/
-QVariant Conductor::itemChange(GraphicsItemChange change, const QVariant &value) {
-	if (change == QGraphicsItem::ItemSelectedChange) {
-		if (value.toBool()) {
-			// le conducteur vient de se faire selectionner
-			previous_z_value = zValue();
-			setZValue(qAbs(previous_z_value) + 10000);
-		} else {
-			// le conducteur vient de se faire deselectionner
-			setZValue(previous_z_value);
+ * @brief Conductor::sceneEventFilter
+ * @param watched
+ * @param event
+ * @return 
+ */
+bool Conductor::sceneEventFilter(QGraphicsItem *watched, QEvent *event)
+{
+		//Watched must be an handler
+	if(watched->type() == QetGraphicsHandlerItem::Type)
+	{
+		QetGraphicsHandlerItem *qghi = qgraphicsitem_cast<QetGraphicsHandlerItem *>(watched);
+		
+		if(m_handler_vector.contains(qghi)) //Handler must be in m_vector_index, then we can start resize
+		{
+			m_vector_index = m_handler_vector.indexOf(qghi);
+			if (m_vector_index != -1)
+			{
+				if(event->type() == QEvent::GraphicsSceneMousePress) //Click
+				{
+					handlerMousePressEvent(qghi, static_cast<QGraphicsSceneMouseEvent *>(event));
+					return true;
+				}
+				else if(event->type() == QEvent::GraphicsSceneMouseMove) //Move
+				{
+					handlerMouseMoveEvent(qghi, static_cast<QGraphicsSceneMouseEvent *>(event));
+					return true;
+				}
+				else if (event->type() == QEvent::GraphicsSceneMouseRelease) //Release
+				{
+					handlerMouseReleaseEvent(qghi, static_cast<QGraphicsSceneMouseEvent *>(event));
+					return true;
+				}
+				else if (event->type() == QEvent::GraphicsSceneMouseDoubleClick) //Double click
+				{
+					editProperty();
+					return true;
+				}
+			}
 		}
-	} else if (change == QGraphicsItem::ItemSceneHasChanged) {
-		// permet de positionner correctement le texte du conducteur lors de son ajout a un schema
-		calculateTextItemPosition();
-	} else if (change == QGraphicsItem::ItemVisibleHasChanged) {
-		// permet de positionner correctement le texte du conducteur lors de son ajout a un schema
-		calculateTextItemPosition();
 	}
-	return(QGraphicsPathItem::itemChange(change, value));
+	
+	return false;
+}
+
+/**
+ * @brief Conductor::adjusteHandlerPos
+ * Adjust the position of the handler item
+ */
+void Conductor::adjusteHandlerPos()
+{
+	if (m_handler_vector.isEmpty())
+		return;
+	
+	if (m_handler_vector.size() == handlerPoints().size())
+	{
+		QVector <QPointF> points_vector = mapToScene(handlerPoints());
+		for (int i = 0 ; i < points_vector.size() ; ++i)
+			m_handler_vector.at(i)->setPos(points_vector.at(i));
+	}
+}
+
+/**
+ * @brief Conductor::handlerMousePressEvent
+ * @param qghi
+ * @param event
+ */
+void Conductor::handlerMousePressEvent(QetGraphicsHandlerItem *qghi, QGraphicsSceneMouseEvent *event)
+{
+	Q_UNUSED(event);
+	
+		//we get the segment corresponding to the handler
+	if (m_vector_index > -1)
+	{
+		qghi->setColor(Qt::cyan);
+		m_moving_segment = true;
+		m_moved_segment = segmentsList().at(m_vector_index+1);
+		before_mov_text_pos_ = m_text_item -> pos();
+		
+		for(QetGraphicsHandlerItem *handler : m_handler_vector)
+			if(handler != qghi)
+				handler->hide();
+	}
+}
+
+/**
+ * @brief Conductor::handlerMouseMoveEvent
+ * @param qghi
+ * @param event
+ */
+void Conductor::handlerMouseMoveEvent(QetGraphicsHandlerItem *qghi, QGraphicsSceneMouseEvent *event)
+{
+	if (m_moving_segment)
+	{
+			//Snap the mouse pos to grid
+		QPointF pos_ = Diagram::snapToGrid(mapFromItem(qghi, event->pos()));
+		
+			//Position of the last point
+		QPointF p = m_moved_segment -> middle();
+		
+			//Calcul the movement
+		m_moved_segment -> moveX(pos_.x() - p.x());
+		m_moved_segment -> moveY(pos_.y() - p.y());
+		
+			//Apply the movement
+		modified_path = true;
+		has_to_save_profile = true;
+		segmentsToPath();
+		calculateTextItemPosition();
+		qghi->setPos(mapToScene(m_moved_segment->middle()));
+	}
+}
+
+/**
+ * @brief Conductor::handlerMouseReleaseEvent
+ * @param qghi
+ * @param event
+ */
+void Conductor::handlerMouseReleaseEvent(QetGraphicsHandlerItem *qghi, QGraphicsSceneMouseEvent *event)
+{
+	Q_UNUSED(event);
+	Q_UNUSED(qghi);
+	
+	m_vector_index = -1;
+	
+	m_moving_segment = false;
+	if (has_to_save_profile)
+	{
+		saveProfile();
+		has_to_save_profile = false;
+	}
+		//When handler is released, the conductor can have more segment than befor the handler was moved
+		//then we remove all handles and new ones are added
+	removeHandler();
+	addHandler();
+}
+
+/**
+ * @brief Conductor::addHandler
+ * Add handlers for this item
+ */
+void Conductor::addHandler()
+{
+	if (m_handler_vector.isEmpty() && scene())
+	{		
+		m_handler_vector = QetGraphicsHandlerItem::handlerForPoint(mapToScene(handlerPoints()));
+		
+		for(QetGraphicsHandlerItem *handler : m_handler_vector)
+		{
+			handler->setColor(Qt::blue);
+			scene()->addItem(handler);
+			handler->installSceneEventFilter(this);
+			handler->setZValue(this->zValue()+1);
+		}
+	}
+}
+
+/**
+ * @brief Conductor::removeHandler
+ * Remove the handlers of this item
+ */
+void Conductor::removeHandler()
+{
+	if (!m_handler_vector.isEmpty())
+	{
+		qDeleteAll(m_handler_vector);
+		m_handler_vector.clear();
+	}
 }
 
 /**
@@ -718,15 +860,11 @@ QRectF Conductor::boundingRect() const
 QPainterPath Conductor::shape() const
 {
 	QPainterPathStroker pps;
-	pps.setWidth(bMouseOver? 5 : 1);
+	pps.setWidth(m_mouse_over? 5 : 1);
 	pps.setJoinStyle(conductor_pen.joinStyle());
 
 	QPainterPath shape_(pps.createStroke(path()));
-
-	if (isSelected())
-		foreach (QRectF rect, m_handler.handlerRect(handlerPoints()))
-			shape_.addRect(rect);
-
+	
 	return shape_;
 }
 
@@ -806,15 +944,25 @@ void Conductor::pointsToSegments(QList<QPointF> points_list) {
  * @param e
  * @return true is loading success else return false
  */
-bool Conductor::fromXml(QDomElement &e) {
-	setPos(e.attribute("x", 0).toDouble(),
-		   e.attribute("y", 0).toDouble());
+bool Conductor::fromXml(QDomElement &dom_element)
+{
+	setPos(dom_element.attribute("x", 0).toDouble(),
+		   dom_element.attribute("y", 0).toDouble());
 
-	bool return_ = pathFromXml(e);
+	bool return_ = pathFromXml(dom_element);
 
-	text_item -> fromXml(e);
+	m_text_item -> fromXml(dom_element);
 	ConductorProperties pr;
-	pr.fromXml(e);
+	pr.fromXml(dom_element);
+
+		//Load Sequential Values
+	if (dom_element.hasAttribute("sequ_1") || dom_element.hasAttribute("sequf_1") || dom_element.hasAttribute("seqt_1") || dom_element.hasAttribute("seqtf_1") || dom_element.hasAttribute("seqh_1") || dom_element.hasAttribute("sequf_1"))
+		ConductorXmlRetroCompatibility::loadSequential(dom_element, this);
+	else
+		m_autoNum_seq.fromXml(dom_element.firstChildElement("sequentialNumbers"));
+
+	m_freeze_label = dom_element.attribute("freezeLabel") == "true"? true : false;
+
 	setProperties(pr);
 
 	return return_;
@@ -827,32 +975,39 @@ bool Conductor::fromXml(QDomElement &e) {
 	bornes dans le document XML et leur adresse en memoire
 	@return Un element XML representant le conducteur
 */
-QDomElement Conductor::toXml(QDomDocument &d, QHash<Terminal *, int> &table_adr_id) const {
-	QDomElement e = d.createElement("conductor");
+QDomElement Conductor::toXml(QDomDocument &dom_document, QHash<Terminal *, int> &table_adr_id) const
+{
+	QDomElement dom_element = dom_document.createElement("conductor");
 
-	e.setAttribute("x", pos().x());
-	e.setAttribute("y", pos().y());
-	e.setAttribute("terminal1", table_adr_id.value(terminal1));
-	e.setAttribute("terminal2", table_adr_id.value(terminal2));
+	dom_element.setAttribute("x", QString::number(pos().x()));
+	dom_element.setAttribute("y", QString::number(pos().y()));
+	dom_element.setAttribute("terminal1", table_adr_id.value(terminal1));
+	dom_element.setAttribute("terminal2", table_adr_id.value(terminal2));
+	dom_element.setAttribute("freezeLabel", m_freeze_label? "true" : "false");
 	
 	// on n'exporte les segments du conducteur que si ceux-ci ont
 	// ete modifies par l'utilisateur
-	if (modified_path) {
+	if (modified_path)
+	{
 		// parcours et export des segments
 		QDomElement current_segment;
-		foreach(ConductorSegment *segment, segmentsList()) {
-			current_segment = d.createElement("segment");
+		foreach(ConductorSegment *segment, segmentsList())
+		{
+			current_segment = dom_document.createElement("segment");
 			current_segment.setAttribute("orientation", segment -> isHorizontal() ? "horizontal" : "vertical");
 			current_segment.setAttribute("length", QString("%1").arg(segment -> length()));
-			e.appendChild(current_segment);
+			dom_element.appendChild(current_segment);
 		}
 	}
-	
-	// Export the properties and text
-	properties_. toXml(e);
-	text_item -> toXml(e);
 
-	return(e);
+	QDomElement dom_seq = m_autoNum_seq.toXml(dom_document);
+	dom_element.appendChild(dom_seq);
+	
+		// Export the properties and text
+	m_properties. toXml(dom_element);
+	m_text_item -> toXml(dom_element);
+
+	return(dom_element);
 }
 
 /**
@@ -1071,7 +1226,7 @@ QPointF Conductor::posForText(Qt::Orientations &flag) {
  * If text was moved by user, this function do nothing, except check if text is near conductor.
  */
 void Conductor::calculateTextItemPosition() {
-	if (!text_item || !diagram() || properties_.type != ConductorProperties::Multi) return;
+	if (!m_text_item || !diagram() || m_properties.type != ConductorProperties::Multi) return;
 
 	if (diagram() -> defaultConductorProperties.m_one_text_per_folio == true &&
 		relatedPotentialConductors(false).size() > 0) {
@@ -1090,37 +1245,37 @@ void Conductor::calculateTextItemPosition() {
 					c -> textItem() -> setVisible(false);
 			}
 		//Make sure text item is visible
-		text_item -> setVisible(true);
+		m_text_item -> setVisible(true);
 	}
 
 	//position
-	if (text_item -> wasMovedByUser()) {
+	if (m_text_item -> wasMovedByUser()) {
 		//Text field was moved by user :
 		//we check if text field is yet  near the conductor
-		QPointF text_item_pos = text_item -> pos();
+		QPointF text_item_pos = m_text_item -> pos();
 		QPainterPath near_shape = nearShape();
 		if (!near_shape.contains(text_item_pos)) {
-			text_item -> setPos(movePointIntoPolygon(text_item_pos, near_shape));
+			m_text_item -> setPos(movePointIntoPolygon(text_item_pos, near_shape));
 		}
 	} else {
 		//Position and rotation of text is calculated.
 		Qt::Orientations rotation;
 		QPointF text_pos = posForText(rotation);
 
-		if (!text_item -> wasRotateByUser()) {
-			rotation == Qt::Vertical ? text_item -> setRotationAngle(properties_.verti_rotate_text):
-									   text_item -> setRotationAngle(properties_.horiz_rotate_text);
+		if (!m_text_item -> wasRotateByUser()) {
+			rotation == Qt::Vertical ? m_text_item -> setRotationAngle(m_properties.verti_rotate_text):
+									   m_text_item -> setRotationAngle(m_properties.horiz_rotate_text);
 		}
 
 		//Adjust the position of text if his rotation
 		//is 0° or 270°, to be exactly centered to the conductor
-		if (text_item -> rotation() == 0)
-			text_pos.rx() -= text_item -> boundingRect().width()/2;
-		else if (text_item -> rotation() == 270)
-			text_pos.ry() += text_item -> boundingRect().width()/2;
+		if (m_text_item -> rotation() == 0)
+			text_pos.rx() -= m_text_item -> boundingRect().width()/2;
+		else if (m_text_item -> rotation() == 270)
+			text_pos.ry() += m_text_item -> boundingRect().width()/2;
 
 		//Finaly set the position of text
-		text_item -> setPos(text_pos);
+		m_text_item -> setPos(text_pos);
 	}
 }
 
@@ -1140,7 +1295,7 @@ void Conductor::saveProfile(bool undo) {
 			conductor_profiles[current_path_type],
 			current_path_type
 		);
-		undo_object -> setConductorTextItemMove(before_mov_text_pos_, text_item -> pos());
+		undo_object -> setConductorTextItemMove(before_mov_text_pos_, m_text_item -> pos());
 		dia -> undoStack().push(undo_object);
 	}
 }
@@ -1189,48 +1344,106 @@ ConductorProfile Conductor::profile(Qt::Corner path_type) const {
 	return(conductor_profiles[path_type]);
 }
 
-/// @return le texte du conducteur
-QString Conductor::text() const {
-	return(text_item -> toPlainText());
+/**
+ * @brief Conductor::refreshText
+ * Refresh the text of this conductor.
+ * recalcule and set the text according to the formula.
+ */
+void Conductor::refreshText()
+{
+	if (m_freeze_label)
+	{
+		m_text_item->setPlainText(m_properties.text);
+	}
+	else
+	{
+		if (!m_properties.m_formula.isEmpty())
+		{
+			if (diagram())
+			{
+				QString text = autonum::AssignVariables::formulaToLabel(m_properties.m_formula, m_autoNum_seq, diagram());
+				m_properties.text = text;
+				m_text_item->setPlainText(text);
+			}
+			else
+			{
+				m_properties.text = m_properties.m_formula;
+				m_text_item->setPlainText(m_properties.text);
+			}
+		}
+		else
+		{
+			m_text_item->setPlainText(m_properties.text);
+		}
+	}
 }
 
 /**
- * @brief Conductor::setText
- * The text of this conductor
- * @param t
+ * @brief Conductor::setPropertiesToPotential
+ * @param properties
+ * @param only_text
+ * Set @propertie to conductor and every conductors in the same potential of @conductor.
+ * If @only_text is true only formula, text, function and tension/protocol is set
+ * to other conductor in the same potential, the other values of property stay unmodified
  */
-void Conductor::setText(const QString &t) {
-	text_item -> setPlainText(t);
+void Conductor::setPropertyToPotential(const ConductorProperties &property, bool only_text)
+{
+	setProperties(property);
+	QSet <Conductor *> potential_list = relatedPotentialConductors();
+
+	foreach(Conductor *other_conductor, potential_list)
+	{
+		if (only_text)
+		{
+			ConductorProperties other_properties = other_conductor->properties();
+			other_properties.m_formula = m_properties.m_formula;
+			other_properties.text = m_properties.text;
+			other_properties.m_function = m_properties.m_function;
+			other_properties.m_tension_protocol = m_properties.m_tension_protocol;
+			other_conductor->setProperties(other_properties);
+		}
+		else
+		{
+			other_conductor->setProperties(property);
+		}
+	}
 }
 
 /**
  * @brief Conductor::setProperties
- * Set new properties for this conductor
- * Also change the common properties for every conductors at the same potential.
- * (text, function and tension/protocol) other value of properties isn't changed.
+ * Set @property as current property of conductor
  * @param properties : properties
  */
-void Conductor::setProperties(const ConductorProperties &properties)
+void Conductor::setProperties(const ConductorProperties &property)
 {
-	if (properties_ == properties) return;
+	if (m_properties == property) return;
 
-	properties_ = properties;
+	QString formula = m_properties.m_formula;
+	m_properties = property;
 
-	foreach(Conductor *other_conductor, relatedPotentialConductors())
+	if (!m_properties.m_formula.isEmpty())
 	{
-		ConductorProperties other_properties = other_conductor->properties();
-		other_properties.text = properties_.text;
-		other_properties.m_function = properties_.m_function;
-		other_properties.m_tension_protocol = properties_.m_tension_protocol;
-		other_conductor->setProperties(other_properties);
+		if (diagram())
+		{
+			QString text = autonum::AssignVariables::formulaToLabel(m_properties.m_formula, m_autoNum_seq, diagram());
+			m_properties.text = text;
+		}
+		else if (m_properties.text.isEmpty())
+		{
+			m_properties.text = m_properties.m_formula;
+		}
+
+		setUpConnectionForFormula(formula, m_properties.m_formula);
 	}
 
-	setText(properties_.text);
-	text_item -> setFontSize(properties_.text_size);
-	if (properties_.type != ConductorProperties::Multi)
-		text_item -> setVisible(false);
+	m_text_item->setPlainText(m_properties.text);
+	m_text_item->setFontSize(m_properties.text_size);
+
+	if (m_properties.type != ConductorProperties::Multi)
+		m_text_item->setVisible(false);
 	else
-		text_item -> setVisible(properties_.m_show_text);
+		m_text_item->setVisible(m_properties.m_show_text);
+
 	calculateTextItemPosition();
 	update();
 
@@ -1241,8 +1454,9 @@ void Conductor::setProperties(const ConductorProperties &properties)
  * @brief Conductor::properties
  * @return the properties of this Conductor
  */
-ConductorProperties Conductor::properties() const {
-	return(properties_);
+ConductorProperties Conductor::properties() const
+{
+	return(m_properties);
 }
 
 /**
@@ -1267,16 +1481,16 @@ void Conductor::setHighlighted(Conductor::Highlight hl) {
  */
 void Conductor::displayedTextChanged()
 {
-	if ((text_item->toPlainText() == properties_.text) || !diagram()) return;
-
 	QVariant old_value, new_value;
-	old_value.setValue(properties_);
-	ConductorProperties new_properties(properties_);
-	new_properties.text = text_item -> toPlainText();
+	old_value.setValue(m_properties);
+	ConductorProperties new_properties(m_properties);
+	new_properties.m_formula = m_text_item->toPlainText();
+	new_properties.text = m_text_item->toPlainText();
 	new_value.setValue(new_properties);
 
-	QPropertyUndoCommand *undo = new QPropertyUndoCommand(this, "properties", old_value, new_value);
-	undo->setText(tr("Modifier les propriétés d'un conducteur", "undo caption"));
+
+	QUndoCommand *undo = new QUndoCommand(tr("Modifier les propriétés d'un conducteur", "undo caption"));
+	new QPropertyUndoCommand(this, "properties", old_value, new_value, undo);
 
 	if (!relatedPotentialConductors().isEmpty())
 	{
@@ -1286,7 +1500,8 @@ void Conductor::displayedTextChanged()
 		{
 			old_value.setValue(potential_conductor->properties());
 			ConductorProperties new_properties = potential_conductor->properties();
-			new_properties.text = text_item->toPlainText();
+			new_properties.m_formula = m_text_item->toPlainText();
+			new_properties.text = m_text_item->toPlainText();
 			new_value.setValue(new_properties);
 			new QPropertyUndoCommand (potential_conductor, "properties", old_value, new_value, undo);
 		}
@@ -1302,12 +1517,14 @@ void Conductor::displayedTextChanged()
  * part of the returned QSet.
  * @param all_diagram : if true search in all diagram of the project,
  * false search only in the parent diagram of this conductor
- * @param t_list, a list of terminal already cheched for the serach of potential.
+ * @param t_list, a list of terminal already found for this potential.
  * @return  a QSet of conductor at the same potential.
  */
-QSet<Conductor *> Conductor::relatedPotentialConductors(const bool all_diagram, QList <Terminal *> *t_list) {
+QSet<Conductor *> Conductor::relatedPotentialConductors(const bool all_diagram, QList <Terminal *> *t_list)
+{
 	bool declar_t_list = false;
-	if (t_list == 0) {
+	if (t_list == nullptr)
+	{
 		declar_t_list = true;
 		t_list = new QList <Terminal *>;
 	}
@@ -1316,23 +1533,29 @@ QSet<Conductor *> Conductor::relatedPotentialConductors(const bool all_diagram,
 	QList <Terminal *> this_terminal;
 	this_terminal << terminal1 << terminal2;
 
-	// Return all conductor of terminal 1 and 2
-	foreach (Terminal *terminal, this_terminal) {
-		if (!t_list -> contains(terminal)) {
-			t_list -> append(terminal);
-			QList <Conductor *> other_conductors_list_t = terminal -> conductors();
+		// Return all conductors of terminal 1 and 2
+	for (Terminal *terminal : this_terminal)
+	{
+		if (!t_list->contains(terminal))
+		{
+			t_list->append(terminal);
+			QList <Conductor *> other_conductors_list_t = terminal->conductors();
 
-			//get terminal share the same potential of @terminal, of parent element
-			Terminal *t1_bis = relatedPotentialTerminal(terminal, all_diagram);
-			if (t1_bis && !t_list->contains(t1_bis)) {
-				t_list -> append(t1_bis);
-				other_conductors_list_t += t1_bis->conductors();
+				//Get the other terminals of the parent element of @terminal, who share the same potential
+				//This is use for element type "folio report" and "terminal element"
+			for (Terminal *t : relatedPotentialTerminal(terminal, all_diagram))
+			{
+				if (!t_list->contains(t))
+				{
+					t_list -> append(t);
+					other_conductors_list_t += t->conductors();
+				}
 			}
 
 			other_conductors_list_t.removeAll(this);
-			// Research the conductors connected to conductors already found
-			foreach (Conductor *c, other_conductors_list_t) {
-				other_conductors += c -> relatedPotentialConductors(all_diagram, t_list);
+				//Get the conductors at the same potential for each conductors of other_conductors_list_t
+			for (Conductor *c : other_conductors_list_t) {
+				other_conductors += c->relatedPotentialConductors(all_diagram, t_list);
 			}
 			other_conductors += other_conductors_list_t.toSet();
 		}
@@ -1366,6 +1589,42 @@ void Conductor::editProperty() {
 	ConductorPropertiesDialog::PropertiesDialog(this, diagramEditor());
 }
 
+void Conductor::setSequenceNum(autonum::sequentialNumbers sn)
+{
+	m_autoNum_seq = sn;
+	refreshText();
+}
+
+/**
+ * @brief Conductor::setUpConnectionForFormula
+ * setup connection according to the variable of formula
+ * @param old_formula
+ * @param new_formula
+ */
+void Conductor::setUpConnectionForFormula(QString old_formula, QString new_formula)
+{
+	if (diagram())
+	{
+			//Because the variable %F is a reference to another text which can contain variables,
+			//we must to replace %F by the real text, to check if the real text contain the variable %id
+		if (old_formula.contains("%F"))
+			old_formula.replace("%F", diagram()->border_and_titleblock.folio());
+		
+		if (old_formula.contains("%id"))
+			disconnect(diagram()->project(), &QETProject::projectDiagramsOrderChanged, this, &Conductor::refreshText);
+		
+			//Label is frozen, so we don't update it.
+		if (m_freeze_label == true)
+			return;
+		
+		if (new_formula.contains("%F"))
+			new_formula.replace("%F", diagram()->border_and_titleblock.folio());
+		
+		if (new_formula.contains("%id"))
+			connect(diagram()->project(), &QETProject::projectDiagramsOrderChanged, this, &Conductor::refreshText);
+	}
+}
+
 /**
 	@param a point
 	@param b point
@@ -1628,3 +1887,21 @@ QList <Conductor *> relatedConductors(const Conductor *conductor) {
 	other_conductors_list.removeAll(const_cast<Conductor *> (conductor));
 	return(other_conductors_list);
 }
+
+/**
+ * @brief Conductor::setFreezeLabel
+ * Freeze this conductor label if true
+ * Unfreeze this conductor label if false
+ * @param freeze
+ */
+void Conductor::setFreezeLabel(bool freeze)
+{
+	m_freeze_label = freeze;
+
+	if (m_freeze_label != freeze)
+	{
+		m_freeze_label = freeze;
+		QString f = m_properties.m_formula;
+		setUpConnectionForFormula(f,f);
+	}
+}
