@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -22,11 +22,12 @@
 #include "elementtextitem.h"
 #include "diagram.h"
 #include "qgraphicsitemutility.h"
+#include "assignvariables.h"
 
 //define the height of the header.
-#define header 5
+static int header = 5;
 //define the minimal height of the cross (without header)
-#define cross_min_heigth 33
+static int cross_min_heigth = 33;
 
 /**
  * @brief CrossRefItem::CrossRefItem
@@ -44,14 +45,17 @@ CrossRefItem::CrossRefItem(Element *elmt) :
 {
 	Q_ASSERT_X(elmt->diagram(), "CrossRefItem constructor", "Parent element is not in a diagram");
 
-	m_properties = elmt->diagram()->defaultXRefProperties(elmt->kindInformations()["type"].toString());
+	m_properties = elmt->diagram()->project()->defaultXRefProperties(elmt->kindInformations()["type"].toString());
+	setAcceptHoverEvents(true);
 
-	connect(elmt -> diagram() -> project(), SIGNAL(projectDiagramsOrderChanged(QETProject*,int,int)), this, SLOT(updateLabel()));
-	connect(elmt -> diagram() -> project(), SIGNAL(diagramRemoved(QETProject*,Diagram*)),             this, SLOT(updateLabel()));
-	connect(elmt -> diagram(),              SIGNAL(XRefPropertiesChanged()),                          this, SLOT(updateProperties()));
+	QETProject *project = elmt->diagram()->project();
+	connect(project, &QETProject::projectDiagramsOrderChanged, this, &CrossRefItem::updateLabel);
+	connect(project, &QETProject::diagramRemoved,              this, &CrossRefItem::updateLabel);
+	connect(project, &QETProject::XRefPropertiesChanged,       this, &CrossRefItem::updateProperties);
 
 	//set specific behavior related to the parent item.
-	if(m_properties.snapTo() == XRefProperties::Bottom) {
+	if(m_properties.snapTo() == XRefProperties::Bottom)
+	{
 		connect(elmt, SIGNAL(yChanged()),        this, SLOT(autoPos()));
 		connect(elmt, SIGNAL(rotationChanged()), this, SLOT(autoPos()));
 	} else {
@@ -88,12 +92,15 @@ QPainterPath CrossRefItem::shape() const{
  * @return the string corresponding to the position of @elmt in the diagram.
  * if @add_prefix is true, prefix (for power and delay contact) is added to the poistion text.
  */
-QString CrossRefItem::elementPositionText(const Element *elmt, const bool &add_prefix) const{
-	QString txt;
-	txt += QString::number(elmt->diagram()->folioIndex() + 1);
-	txt += "-";
-	txt += elmt->diagram()->convertPosition(elmt -> scenePos()).toString();
-	if (add_prefix) {
+QString CrossRefItem::elementPositionText(const Element *elmt, const bool &add_prefix) const
+{
+	XRefProperties xrp = m_element->diagram()->project()->defaultXRefProperties(m_element->kindInformations()["type"].toString());
+	QString formula = xrp.masterLabel();
+	autonum::sequentialNumbers seq;
+	QString txt = autonum::AssignVariables::formulaToLabel(formula, seq, elmt->diagram(), elmt);
+
+	if (add_prefix)
+	{
 		if      (elmt->kindInformations()["type"].toString() == "power")        txt.prepend(m_properties.prefix("power"));
 		else if (elmt->kindInformations()["type"].toString().contains("delay")) txt.prepend(m_properties.prefix("delay"));
 		else if (elmt->kindInformations()["state"].toString() == "SW")          txt.prepend(m_properties.prefix("switch"));
@@ -101,65 +108,26 @@ QString CrossRefItem::elementPositionText(const Element *elmt, const bool &add_p
 	return txt;
 }
 
-/**
- * @brief CrossRefItem::allElementsPositionText
- * Return the text of all elements linked to @m_element, in several QString
- * according to the type of linked elements. Each text of elements are separate by "\n"
- * @param no_str the string of NO contacts
- * @param nc_str the string of NC contacts
- * @param add_prefix must add prefix to text (true) or not (false);
- */
-void CrossRefItem::allElementsPositionText(QString &no_str, QString &nc_str, const bool &add_prefix) const
-{
-	QString *tmp_str = nullptr;
-	foreach (Element *elmt, m_element->linkedElements())
-	{
-			//We continue if element is a power contact and xref propertie
-			//is set to don't show power contact
-		if (m_properties.displayHas() == XRefProperties::Cross &&
-			!m_properties.showPowerContact() &&
-			elmt -> kindInformations()["type"].toString() == "power")
-			continue;
-
-		QString state = elmt->kindInformations()["state"].toString();
-
-		//NO and NC are displayed in single place in the cross
-		if (state == "NO" || state == "NC")
-		{
-			if (state == "NO") tmp_str = &no_str;
-			else if (state == "NC") tmp_str = &nc_str;
-
-			if (!tmp_str->isEmpty()) *tmp_str += "\n";
-			*tmp_str += elementPositionText(elmt, add_prefix);
-		}
-
-		//SW are displayed in NC and NO column in the cross
-		else if (state == "SW")
-		{
-			for (int i = 0; i < 2; i++)
-			{
-				tmp_str = i==0? &no_str : &nc_str;
-				if (!tmp_str->isEmpty()) *tmp_str += "\n";
-				*tmp_str += elementPositionText(elmt, add_prefix);
-			}
-		}
-	}
-}
-
 /**
  * @brief CrossRefItem::updateProperties
  * update the curent properties
  */
-void CrossRefItem::updateProperties() {
-	XRefProperties xrp = m_element->diagram()->defaultXRefProperties(m_element->kindInformations()["type"].toString());
+void CrossRefItem::updateProperties()
+{
+	XRefProperties xrp = m_element->diagram()->project()->defaultXRefProperties(m_element->kindInformations()["type"].toString());
 
-	if (m_properties != xrp) {
-		if (m_properties.snapTo() != xrp.snapTo()) {
-			if (xrp.snapTo() == XRefProperties::Bottom) {
+	if (m_properties != xrp)
+	{
+		if (m_properties.snapTo() != xrp.snapTo())
+		{
+			if (xrp.snapTo() == XRefProperties::Bottom)
+			{
 				setParentItem(m_element);
 				connect(m_element, SIGNAL(yChanged()),        this, SLOT(autoPos()));
 				connect(m_element, SIGNAL(rotationChanged()), this, SLOT(autoPos()));
-			} else {
+			}
+			else
+			{
 				setTextParent();
 				disconnect(m_element, SIGNAL(yChanged()),        this, SLOT(autoPos()));
 				disconnect(m_element, SIGNAL(rotationChanged()), this, SLOT(autoPos()));
@@ -174,7 +142,8 @@ void CrossRefItem::updateProperties() {
  * @brief CrossRefItem::updateLabel
  * Update the content of the item
  */
-void CrossRefItem::updateLabel() {
+void CrossRefItem::updateLabel()
+{
 		//init the shape and bounding rect
 	m_shape_path    = QPainterPath();
 	prepareGeometryChange();
@@ -189,16 +158,18 @@ void CrossRefItem::updateLabel() {
 	qp.setFont(QETApp::diagramTextsFont(5));
 
 		//Draw cross or contact, only if master element is linked.
-	if (! m_element->linkedElements().isEmpty()) {
+	if (! m_element->linkedElements().isEmpty())
+	{
 		XRefProperties::DisplayHas dh = m_properties.displayHas();
 
 		if (dh == XRefProperties::Cross)
-			drawHasCross(qp);
+			drawAsCross(qp);
 		else if (dh == XRefProperties::Contacts)
-			drawHasContacts(qp);
+			drawAsContacts(qp);
 	}
 
-	AddExtraInfo(qp);
+	AddExtraInfo(qp, "comment");
+	AddExtraInfo(qp, "location");
 	qp.end();
 
 	autoPos();
@@ -209,9 +180,9 @@ void CrossRefItem::updateLabel() {
  * Calculate and set position automaticaly.
  */
 void CrossRefItem::autoPos() {
-	//We calcul the position according to the @snapTo of the xrefproperties
+		//We calcul the position according to the @snapTo of the xrefproperties
 	if (m_properties.snapTo() == XRefProperties::Bottom)
-		centerToBottomDiagram(this, m_element);
+		centerToBottomDiagram(this, m_element, m_properties.offset() <= 40 ? 5 : m_properties.offset());
 	else
 		centerToParentBottom(this);
 }
@@ -233,9 +204,93 @@ void CrossRefItem::paint(QPainter *painter, const QStyleOptionGraphicsItem *opti
  * @brief CrossRefItem::mouseDoubleClickEvent
  * @param event
  */
-void CrossRefItem::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event) {
+void CrossRefItem::mouseDoubleClickEvent(QGraphicsSceneMouseEvent *event)
+{
 	event->accept();
-	m_element->editProperty();
+	if (m_hovered_contact && m_hovered_contact->scene())
+	{
+			//Show and select the linked slave element
+		if (scene() != m_hovered_contact->scene())
+		{
+			m_hovered_contact->diagram()->showMe();
+		}
+		m_hovered_contact->setSelected(true);
+
+			//Zoom to the linked slave element
+		foreach(QGraphicsView *view, m_hovered_contact->diagram()->views())
+		{
+			QRectF fit = m_hovered_contact->sceneBoundingRect();
+			fit.adjust(-200, -200, 200, 200);
+			view->fitInView(fit, Qt::KeepAspectRatioByExpanding);
+		}
+	}
+}
+
+void CrossRefItem::hoverEnterEvent(QGraphicsSceneHoverEvent *event)
+{
+	m_hovered_contact = nullptr;
+	QGraphicsObject::hoverEnterEvent(event);
+}
+
+void CrossRefItem::hoverMoveEvent(QGraphicsSceneHoverEvent *event)
+{
+	QPointF pos = event->pos();
+
+	if (m_hovered_contact)
+	{
+		foreach(QRectF rect, m_hovered_contacts_map.values(m_hovered_contact))
+		{
+				//Mouse hover the same rect than previous hover event
+			if (rect.contains(pos))
+			{
+				QGraphicsObject::hoverMoveEvent(event);
+				return;
+			}
+		}
+
+			//At this point, mouse don't hover previous rect
+		m_hovered_contact = nullptr;
+
+		foreach (Element *elmt, m_hovered_contacts_map.keys())
+		{
+			foreach(QRectF rect, m_hovered_contacts_map.values(elmt))
+			{
+					//Mouse hover a contact
+				if (rect.contains(pos))
+				{
+					m_hovered_contact = elmt;
+				}
+			}
+		}
+
+		updateLabel();
+		QGraphicsObject::hoverMoveEvent(event);
+		return;
+	}
+	else
+	{
+		foreach (Element *elmt, m_hovered_contacts_map.keys())
+		{
+			foreach(QRectF rect, m_hovered_contacts_map.values(elmt))
+			{
+					//Mouse hover a contact
+				if (rect.contains(pos))
+				{
+					m_hovered_contact = elmt;
+					updateLabel();
+					QGraphicsObject::hoverMoveEvent(event);
+					return;
+				}
+			}
+		}
+	}
+}
+
+void CrossRefItem::hoverLeaveEvent(QGraphicsSceneHoverEvent *event)
+{
+	m_hovered_contact = nullptr;
+	updateLabel();
+	QGraphicsObject::hoverLeaveEvent(event);
 }
 
 /**
@@ -290,53 +345,68 @@ void CrossRefItem::buildHeaderContact() {
  * for calculate the size of the cross bounding rect.
  * The cross ref item is drawing according to the size of the cross bounding rect.
  */
-void CrossRefItem::setUpCrossBoundingRect(QPainter &painter) {
+void CrossRefItem::setUpCrossBoundingRect(QPainter &painter)
+{
 		//No need to calcul if nothing is linked
-	if (!m_element->isFree()) {
+	if (m_element->isFree()) return;
 
-		QString no_str, nc_str;
-		allElementsPositionText(no_str, nc_str, true);
+	QStringList no_str, nc_str;
 
-			//There is no string to display, we return now
-		if (no_str.isEmpty() && nc_str.isEmpty()) return;
+	foreach (Element *elmt, NOElements())
+		no_str.append(elementPositionText(elmt, true));
+	foreach(Element *elmt, NCElements())
+		nc_str.append(elementPositionText(elmt, true));
 
-			//this is the default size of cross ref item
-		QRectF default_bounding(0, 0, 40, header + cross_min_heigth);
 
-			/*
-			 * Adjust the size of default_bounding if needed.
-			 * We calcule the size by using a single text
-			 * because in the method fillCrossRef, the text is draw like this (aka single text)
-			 */
+		//There is no string to display, we return now
+	if (no_str.isEmpty() && nc_str.isEmpty()) return;
 
-			//Adjust according to the NO
-		QRectF bounding = painter.boundingRect(QRectF (), Qt::AlignCenter, no_str);
-		if (bounding.height() > default_bounding.height() - header)
-			default_bounding.setHeight(bounding.height() + header); //adjust the height
-		if (bounding.width() > default_bounding.width()/2)
-			default_bounding.setWidth(bounding.width()*2);			//adjust the width
+		//this is the default size of cross ref item
+	QRectF default_bounding(0, 0, 40, header + cross_min_heigth);
 
-			//Adjust according to the NC
-		bounding = painter.boundingRect(QRectF (), Qt::AlignCenter, nc_str);
-		if (bounding.height() > default_bounding.height() - header)
-			default_bounding.setHeight(bounding.height() + header); //adjust the heigth
-		if (bounding.width() > default_bounding.width()/2)
-			default_bounding.setWidth(bounding.width()*2);			//adjust the width
-
-		m_shape_path.addRect(default_bounding);
-		prepareGeometryChange();
-		m_bounding_rect = default_bounding;
+		//Bounding rect of the NO text
+	QRectF no_bounding;
+	foreach(QString str, no_str)
+	{
+		QRectF bounding = painter.boundingRect(QRectF (), Qt::AlignCenter, str);
+		no_bounding = no_bounding.united(bounding);
 	}
+		//Adjust according to the NO
+	if (no_bounding.height() > default_bounding.height() - header)
+		default_bounding.setHeight(no_bounding.height() + header); //adjust the height
+	if (no_bounding.width() > default_bounding.width()/2)
+		default_bounding.setWidth(no_bounding.width()*2);			//adjust the width
+
+		//Bounding rect of the NC text
+	QRectF nc_bounding;
+	foreach(QString str, nc_str)
+	{
+		QRectF bounding = painter.boundingRect(QRectF (), Qt::AlignCenter, str);
+		nc_bounding = nc_bounding.united(bounding);
+	}
+		//Adjust according to the NC
+	if (nc_bounding.height() > default_bounding.height() - header)
+		default_bounding.setHeight(nc_bounding.height() + header); //adjust the heigth
+	if (nc_bounding.width() > default_bounding.width()/2)
+		default_bounding.setWidth(nc_bounding.width()*2);			//adjust the width
+
+		//Minor adjustement for better visual
+	default_bounding.adjust(0, 0, 4, 0);
+	m_shape_path.addRect(default_bounding);
+	prepareGeometryChange();
+	m_bounding_rect = default_bounding;
 }
 
 /**
- * @brief CrossRefItem::drawHasCross
+ * @brief CrossRefItem::drawAsCross
  * Draw this crossref with a cross
  * @param painter, painter to use
  */
-void CrossRefItem::drawHasCross(QPainter &painter) {
+void CrossRefItem::drawAsCross(QPainter &painter)
+{
 		//calcul the size of the cross
 	setUpCrossBoundingRect(painter);
+	m_hovered_contacts_map.clear();
 
 		//Bounding rect is empty that mean there's no contact to draw
 	if (boundingRect().isEmpty()) return;
@@ -358,20 +428,26 @@ void CrossRefItem::drawHasCross(QPainter &painter) {
 }
 
 /**
- * @brief CrossRefItem::drawHasContacts
+ * @brief CrossRefItem::drawAsContacts
  * Draw this crossref with symbolic contacts
  * @param painter painter to use
  */
-void CrossRefItem::drawHasContacts(QPainter &painter) {
-	if (m_element -> isFree()) return;
+void CrossRefItem::drawAsContacts(QPainter &painter)
+{
+	if (m_element -> isFree())
+		return;
 
 	m_drawed_contacts = 0;
+	m_hovered_contacts_map.clear();
+	QRectF bounding_rect;
 
 	//Draw each linked contact
-	foreach (Element *elmt,  m_element->linkedElements()) {
+	foreach (Element *elmt,  m_element->linkedElements())
+	{
 		DiagramContext info = elmt->kindInformations();
 
-		for (int i=0; i<info["number"].toInt(); i++) {
+		for (int i=0; i<info["number"].toInt(); i++)
+		{
 			int option = 0;
 
 			QString state = info["state"].toString();
@@ -384,14 +460,15 @@ void CrossRefItem::drawHasContacts(QPainter &painter) {
 			else if (type == "delayOn")  option += DelayOn;
 			else if (type == "delayOff") option += DelayOff;
 
-			drawContact(painter, option, elementPositionText(elmt));
+			QRectF br = drawContact(painter, option, elmt);
+			bounding_rect = bounding_rect.united(br);
 		}
 	}
 
-	QRectF br(0, 0, 50, m_drawed_contacts*10+4);
+	bounding_rect.adjust(-4, -4, 4, 4);
 	prepareGeometryChange();
-	m_bounding_rect = br;
-	m_shape_path.addRect(br);
+	m_bounding_rect = bounding_rect;
+	m_shape_path.addRect(bounding_rect);
 }
 
 /**
@@ -399,13 +476,24 @@ void CrossRefItem::drawHasContacts(QPainter &painter) {
  * Draw one contact, the type of contact to draw is define in @flags.
  * @param painter, painter to use
  * @param flags, define how to draw the contact (see enul CONTACTS)
- * @param str, the text to display for this contact (the position of the contact).
+ * @param elmt, the element to display text (the position of the contact)
+ * @return The bounding rect of the draw (contact + text)
  */
-void CrossRefItem::drawContact(QPainter &painter, int flags, QString str) {
+QRectF CrossRefItem::drawContact(QPainter &painter, int flags, Element *elmt)
+{
+	QString str = elementPositionText(elmt);
 	int offset = m_drawed_contacts*10;
+	QRectF bounding_rect;
+
+	QPen pen = painter.pen();
+	m_hovered_contact == elmt ? pen.setColor(Qt::blue) :pen.setColor(Qt::black);
+	painter.setPen(pen);
 
 	//Draw NO or NC contact
-	if (flags &NOC) {
+	if (flags &NOC)
+	{
+		bounding_rect = QRectF(0, offset, 24, 10);
+
 		//draw the basic line
 		painter.drawLine(0, offset+6, 8, offset+6);
 		painter.drawLine(16, offset+6, 24, offset+6);
@@ -449,37 +537,52 @@ void CrossRefItem::drawContact(QPainter &painter, int flags, QString str) {
 			// for delay on contact
 			if (flags &DelayOn) {
 				if (flags &NO) {
-					painter.drawLine(12, offset+4, 12, offset+6);
-					QRectF r(9.5, offset+1, 5, 3);
-					painter.drawArc(r, 180*16, 180*16);
+                    painter.drawLine(12, offset+8, 12, offset+11);
+                    QRectF r(9.5, offset+9, 5, 3);
+                    painter.drawArc(r, 180*16, 180*16);
 				}
-				if (flags &NC) {
-					painter.drawLine(QPointF(13.5, offset+2), QPointF(13.5, offset+3.5));
-					QRectF r(11, offset-1, 5, 3);
-					painter.drawArc(r, 180*16, 180*16);
+                if (flags &NC) {
+                    painter.drawLine(QPointF(12.5, offset+5), QPointF(12.5, offset+8));
+                    QRectF r(10, offset+6, 5, 3);
+                    painter.drawArc(r, 180*16, 180*16);
 				}
 			}
 			// for delay off contact
 			else {
 				if (flags &NO) {
-					painter.drawLine(12, offset+3, 12, offset+6);
-					QRectF r(9.5, offset+2, 5, 3);
-					painter.drawArc(r, 0, 180*16);
-				}
+                    painter.drawLine(12, offset+8, 12, offset+9.5);
+                    QRectF r(9.5, offset+9.5, 5, 3);
+                    painter.drawArc(r, 0, 180*16);
+                }
 				if (flags &NC) {
-					painter.drawLine(QPointF(13.5, offset+1), QPointF(13.5, offset+3.5));
-					QRectF r(11, offset, 5, 3);
-					painter.drawArc(r, 0, 180*16);
+                    painter.drawLine(QPointF(12.5, offset+5), QPointF(12.5, offset+7));
+                    QRectF r(10, offset+7.5, 5, 3);
+                    painter.drawArc(r, 0, 180*16);
 				}
 			}
 		}
 
-		painter.drawText(20, offset, 30, 10, Qt::AlignRight | Qt::AlignVCenter, str);
+		QRectF text_rect = painter.boundingRect(QRectF(30, offset, 5, 10), Qt::AlignLeft | Qt::AlignVCenter, str);
+		painter.drawText(text_rect, Qt::AlignLeft | Qt::AlignVCenter, str);
+		bounding_rect = bounding_rect.united(text_rect);
+
+		if (m_hovered_contacts_map.contains(elmt))
+		{
+			m_hovered_contacts_map.insertMulti(elmt, bounding_rect);
+		}
+		else
+		{
+			m_hovered_contacts_map.insert(elmt, bounding_rect);
+		}
+
 		++m_drawed_contacts;
 	}
 
 	//Draw a switch contact
-	else if (flags &SW) {
+	else if (flags &SW)
+	{
+		bounding_rect = QRectF(0, offset, 24, 20);
+
 		//draw the NO side
 		painter.drawLine(0, offset+6, 8, offset+6);
 		//Draw the NC side
@@ -489,6 +592,7 @@ void CrossRefItem::drawContact(QPainter &painter, int flags, QString str) {
 			QPointF(8, offset+12)
 		};
 		painter.drawPolyline(p1, 3);
+
 		//Draw the common side
 		QPointF p2[3] = {
 			QPointF(7, offset+14),
@@ -496,11 +600,26 @@ void CrossRefItem::drawContact(QPainter &painter, int flags, QString str) {
 			QPointF(24, offset+11),
 		};
 		painter.drawPolyline(p2, 3);
-		//Draw position text
-		painter.drawText(20, offset+5, 30, 10, Qt::AlignRight | Qt::AlignVCenter, str);
-		//a switch contact take place of two normal contact
+
+			//Draw position text
+		QRectF text_rect = painter.boundingRect(QRectF(30, offset+5, 5, 10), Qt::AlignLeft | Qt::AlignVCenter, str);
+		painter.drawText(text_rect, Qt::AlignLeft | Qt::AlignVCenter, str);
+		bounding_rect = bounding_rect.united(text_rect);
+
+		if (m_hovered_contacts_map.contains(elmt))
+		{
+			m_hovered_contacts_map.insertMulti(elmt, bounding_rect);
+		}
+		else
+		{
+			m_hovered_contacts_map.insert(elmt, bounding_rect);
+		}
+
+			//a switch contact take place of two normal contact
 		m_drawed_contacts += 2;
 	}
+
+	return bounding_rect;
 }
 
 /**
@@ -508,49 +627,93 @@ void CrossRefItem::drawContact(QPainter &painter, int flags, QString str) {
  * Fill the content of the cross ref
  * @param painter painter to use.
  */
-void CrossRefItem::fillCrossRef(QPainter &painter) {
+void CrossRefItem::fillCrossRef(QPainter &painter)
+{
 	if (m_element->isFree()) return;
 
-	QString no_str, nc_str;
-	allElementsPositionText(no_str, nc_str, true);
-
 	qreal middle_cross = m_bounding_rect.width()/2;
 
-	QRectF rect_(0, header, middle_cross, boundingRect().height()-header);
-	painter.drawText(rect_, Qt::AlignTop | Qt::AlignLeft, no_str);
+		//Fill NO
+	QPointF no_top_left(0, header);
+	foreach(Element *elmt, NOElements())
+	{
+		QPen pen = painter.pen();
+		m_hovered_contact == elmt ? pen.setColor(Qt::blue) :pen.setColor(Qt::black);
+		painter.setPen(pen);
 
-	rect_.moveTopLeft(QPointF (middle_cross, header));
-	painter.drawText(rect_, Qt::AlignTop | Qt::AlignRight, nc_str);
+		QString str = elementPositionText(elmt, true);
+		QRectF bounding = painter.boundingRect(QRectF(no_top_left, QSize(middle_cross, 1)), Qt::AlignLeft, str);
+		painter.drawText(bounding, Qt::AlignLeft, str);
+
+		if (m_hovered_contacts_map.contains(elmt))
+		{
+			m_hovered_contacts_map.insertMulti(elmt, bounding);
+		}
+		else
+		{
+			m_hovered_contacts_map.insert(elmt, bounding);
+		}
+
+		no_top_left.ry() += bounding.height();
+	}
+
+		//Fill NC
+	QPointF nc_top_left(middle_cross, header);
+	foreach(Element *elmt, NCElements())
+	{
+		QPen pen = painter.pen();
+		m_hovered_contact == elmt ? pen.setColor(Qt::blue) :pen.setColor(Qt::black);
+		painter.setPen(pen);
+
+		QString str = elementPositionText(elmt, true);
+		QRectF bounding = painter.boundingRect(QRectF(nc_top_left, QSize(middle_cross, 1)), Qt::AlignRight, str);
+		painter.drawText(bounding, Qt::AlignRight, str);
+
+		if (m_hovered_contacts_map.contains(elmt))
+		{
+			m_hovered_contacts_map.insertMulti(elmt, bounding);
+		}
+		else
+		{
+			m_hovered_contacts_map.insert(elmt, bounding);
+		}
+
+		nc_top_left.ry() += bounding.height();
+	}
 }
 
 /**
  * @brief CrossRefItem::AddExtraInfo
  * Add the comment info of the parent item if needed.
  * @param painter painter to use for draw the text
+ * @param type type of Info do be draw e.g. comment, location.
  */
-void CrossRefItem::AddExtraInfo(QPainter &painter)
+void CrossRefItem::AddExtraInfo(QPainter &painter, QString type)
 {
-	QString comment = m_element -> elementInformations()["comment"].toString();
-	bool must_show  = m_element -> elementInformations().keyMustShow("comment");
+	QString text = autonum::AssignVariables::formulaToLabel(m_element -> elementInformations()[type].toString(), m_element->rSequenceStruct(), m_element->diagram(), m_element);
+	bool must_show  = m_element -> elementInformations().keyMustShow(type);
 
-	if (!comment.isEmpty() && must_show)
+	if (!text.isEmpty() && must_show)
 	{
 		painter.save();
 		painter.setFont(QETApp::diagramTextsFont(6));
 
 		QRectF r, text_bounding;
 		qreal center = boundingRect().center().x();
-		r = QRectF(QPointF(center - 35, boundingRect().bottom()),
-				   QPointF(center + 35, boundingRect().bottom() + 1));
-		text_bounding = painter.boundingRect(r, Qt::TextWordWrap | Qt::AlignHCenter, comment);
-		painter.drawText(text_bounding, Qt::TextWordWrap | Qt::AlignHCenter, comment);
+		qreal width = boundingRect().width() > 70 ? boundingRect().width()/2 : 35;
+
+		r = QRectF(QPointF(center - width, boundingRect().bottom()),
+				   QPointF(center + width, boundingRect().bottom() + 1));
+
+		text_bounding = painter.boundingRect(r, Qt::TextWordWrap | Qt::AlignHCenter, text);
+		painter.drawText(text_bounding, Qt::TextWordWrap | Qt::AlignHCenter, text);
 
 		text_bounding.adjust(-1,0,1,0); //adjust only for better visual
 
 		m_shape_path.addRect(text_bounding);
 		prepareGeometryChange();
 		m_bounding_rect = m_bounding_rect.united(text_bounding);
-		painter.drawRoundedRect(text_bounding, 2, 2);
+		if (type == "comment") painter.drawRoundedRect(text_bounding, 2, 2);
 		painter.restore();
 	}
 }
@@ -566,3 +729,62 @@ void CrossRefItem::setTextParent() {
 	else qDebug() << "CrossRefItem,no text tagged 'label' found to set has parent";
 }
 
+/**
+ * @brief CrossRefItem::NOElements
+ * @return The linked elements of @m_element wich are open or switch contact.
+ * If linked element is a power contact, xref propertie is set to don't show power contact
+ * and this cross item must be drawed as cross, the element is not append in the list.
+ */
+QList<Element *> CrossRefItem::NOElements() const
+{
+	QList<Element *> no_list;
+
+	foreach (Element *elmt, m_element->linkedElements())
+	{
+			//We continue if element is a power contact and xref propertie
+			//is set to don't show power contact
+		if (m_properties.displayHas() == XRefProperties::Cross &&
+			!m_properties.showPowerContact() &&
+			elmt -> kindInformations()["type"].toString() == "power")
+			continue;
+
+		QString state = elmt->kindInformations()["state"].toString();
+
+		if (state == "NO" || state == "SW")
+		{
+			no_list.append(elmt);
+		}
+	}
+
+	return no_list;
+}
+
+/**
+ * @brief CrossRefItem::NCElements
+ * @return The linked elements of @m_element wich are close or switch contact
+ * If linked element is a power contact, xref propertie is set to don't show power contact
+ * and this cross item must be drawed as cross, the element is not append in the list.
+ */
+QList<Element *> CrossRefItem::NCElements() const
+{
+	QList<Element *> nc_list;
+
+	foreach (Element *elmt, m_element->linkedElements())
+	{
+			//We continue if element is a power contact and xref propertie
+			//is set to don't show power contact
+		if (m_properties.displayHas() == XRefProperties::Cross &&
+			!m_properties.showPowerContact() &&
+			elmt -> kindInformations()["type"].toString() == "power")
+			continue;
+
+		QString state = elmt->kindInformations()["state"].toString();
+
+		if (state == "NC" || state == "SW")
+		{
+			nc_list.append(elmt);
+		}
+	}
+
+	return nc_list;
+}
