@@ -1,17 +1,17 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
-	
+
 	QElectroTech is free software: you can redistribute it and/or modify
 	it under the terms of the GNU General Public License as published by
 	the Free Software Foundation, either version 2 of the License, or
 	(at your option) any later version.
-	
+
 	QElectroTech is distributed in the hope that it will be useful,
 	but WITHOUT ANY WARRANTY; without even the implied warranty of
 	MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 	GNU General Public License for more details.
-	
+
 	You should have received a copy of the GNU General Public License
 	along with QElectroTech.  If not, see <http://www.gnu.org/licenses/>.
 */
@@ -20,9 +20,10 @@
 #include "diagram.h"
 #include "qetapp.h"
 #include "partline.h"
-#include "elementdefinition.h"
 #include <iostream>
 #include "terminal.h"
+#include "diagramposition.h"
+#include "diagramcontent.h"
 
 /**
 	Constructeur de la classe CustomElement. Permet d'instancier un element
@@ -46,48 +47,30 @@
 */
 CustomElement::CustomElement(const ElementsLocation &location, QGraphicsItem *qgi, int *state) :
 	FixedElement(qgi),
-	elmt_state(-1),
 	location_(location),
 	forbid_antialiasing(false)
 {
-	// recupere la definition de l'element
-	ElementsCollectionItem *element_item = QETApp::collectionItem(location);
-	ElementDefinition *element_definition;
-	if (
-		!element_item ||\
-		!element_item -> isElement() ||\
-		!(element_definition = qobject_cast<ElementDefinition *>(element_item))
-	) {
+
+	if(Q_UNLIKELY( !(location.isElement() && location.exist()) ))
+	{
 		if (state) *state = 1;
-		elmt_state = 1;
-		return;
-	}
-	
-	if (!element_definition -> isReadable()) {
-		if (state) *state = 2;
-		elmt_state = 2;
-		return;
-	}
-	
-	if (element_definition -> isNull()) {
-		if (state) *state = 3;
-		elmt_state = 3;
 		return;
 	}
 
-	//Start from empty lists.
+		//Start from empty lists.
 	list_lines_.clear();
 	list_rectangles_.clear();
 	list_circles_.clear();
 	list_polygons_.clear();
 	list_arcs_.clear();
+	setPrefix(autonum::elementPrefixForLocation(location));
 
-	buildFromXml(element_definition -> xml(), &elmt_state);
+	int elmt_state;
+	buildFromXml(location.xml(), &elmt_state);
 	if (state) *state = elmt_state;
 	if (elmt_state) return;
-	
+
 	if (state) *state = 0;
-	elmt_state = 0;
 }
 
 /**
@@ -105,12 +88,13 @@ CustomElement::CustomElement(const ElementsLocation &location, QGraphicsItem *qg
 	@return true si le chargement a reussi, false sinon
 */
 bool CustomElement::buildFromXml(const QDomElement &xml_def_elmt, int *state) {
-	
-	if (xml_def_elmt.tagName() != "definition" || xml_def_elmt.attribute("type") != "element") {
+
+	if (xml_def_elmt.tagName() != "definition" || xml_def_elmt.attribute("type") != "element")
+	{
 		if (state) *state = 4;
 		return(false);
 	}
-	
+
 	// verifie basiquement que la version actuelle est capable de lire ce fichier
 	if (xml_def_elmt.hasAttribute("version")) {
 		bool conv_ok;
@@ -123,7 +107,7 @@ bool CustomElement::buildFromXml(const QDomElement &xml_def_elmt, int *state) {
 			) << std::endl;
 		}
 	}
-	
+
 	// ces attributs doivent etre presents et valides
 	int w, h, hot_x, hot_y;
 	if (
@@ -136,35 +120,35 @@ bool CustomElement::buildFromXml(const QDomElement &xml_def_elmt, int *state) {
 		if (state) *state = 5;
 		return(false);
 	}
-	
+
 	setSize(w, h);
 	setHotspot(QPoint(hot_x, hot_y));
-	
+
 		//the definition must have childs
 	if (xml_def_elmt.firstChild().isNull())
 	{
 		if (state) *state = 6;
 		return(false);
 	}
-	
+
 	// initialisation du QPainter (pour dessiner l'element)
 	QPainter qp;
 	qp.begin(&drawing);
-	
+
 	QPainter low_zoom_qp;
 	low_zoom_qp.begin(&low_zoom_drawing);
 	QPen tmp;
 	tmp.setWidthF(1.0); // ligne vaudou pour prise en compte du setCosmetic - ne pas enlever
 	tmp.setCosmetic(true);
 	low_zoom_qp.setPen(tmp);
-	
+
 	// extrait les noms de la definition XML
 	names.fromXml(xml_def_elmt);
 	setToolTip(name());
 
 	//load kind informations
 	kind_informations_.fromXml(xml_def_elmt.firstChildElement("kindInformations"), "kindInformation");
-	
+
 	// parcours des enfants de la definition : parties du dessin
 	int parsed_elements_count = 0;
 	for (QDomNode node = xml_def_elmt.firstChild() ; !node.isNull() ; node = node.nextSibling()) {
@@ -191,11 +175,11 @@ bool CustomElement::buildFromXml(const QDomElement &xml_def_elmt, int *state) {
 			}
 		}
 	}
-	
+
 	// fin du dessin
 	qp.end();
 	low_zoom_qp.end();
-	
+
 	// il doit y avoir au moins un element charge
 	if (!parsed_elements_count) {
 		if (state) *state = 8;
@@ -215,6 +199,8 @@ CustomElement::~CustomElement() {
 	qDeleteAll (list_circles_);
 	qDeleteAll (list_polygons_);
 	qDeleteAll (list_arcs_);
+	qDeleteAll (list_texts_);
+	qDeleteAll (list_terminals);
 }
 
 /// @return la liste des bornes de cet element
@@ -310,7 +296,7 @@ bool CustomElement::parseElement(QDomElement &e, QPainter &qp) {
 	La ligne est definie par les attributs suivants :
 		- x1, y1 : reels, coordonnees d'une extremite de la ligne
 		- x2, y2 : reels, coordonnees de l'autre extremite de la ligne
-		
+
 	@param e L'element XML a analyser
 	@param qp Le QPainter a utiliser pour dessiner l'element perso
 	@return true si l'analyse reussit, false sinon
@@ -322,19 +308,19 @@ bool CustomElement::parseLine(QDomElement &e, QPainter &qp) {
 	if (!QET::attributeIsAReal(e, QString("y1"), &y1)) return(false);
 	if (!QET::attributeIsAReal(e, QString("x2"), &x2)) return(false);
 	if (!QET::attributeIsAReal(e, QString("y2"), &y2)) return(false);
-	
+
 	Qet::EndType first_end = Qet::endTypeFromString(e.attribute("end1"));
 	Qet::EndType second_end = Qet::endTypeFromString(e.attribute("end2"));
 	qreal length1, length2;
 	if (!QET::attributeIsAReal(e, QString("length1"), &length1)) length1 = 1.5;
 	if (!QET::attributeIsAReal(e, QString("length2"), &length2)) length2 = 1.5;
-	
+
 	qp.save();
 	setPainterStyle(e, qp);
 	QPen t = qp.pen();
 	t.setJoinStyle(Qt::MiterJoin);
 	qp.setPen(t);
-	
+
 	QLineF line(x1, y1, x2, y2);
 
 	//Add line to the list
@@ -343,10 +329,10 @@ bool CustomElement::parseLine(QDomElement &e, QPainter &qp) {
 
 	QPointF point1(line.p1());
 	QPointF point2(line.p2());
-	
+
 	qreal line_length(line.length());
 	qreal pen_width = qp.pen().widthF();
-	
+
 	// determine s'il faut dessiner les extremites
 	bool draw_1st_end, draw_2nd_end;
 	qreal reduced_line_length = line_length - (length1 * PartLine::requiredLengthForEndType(first_end));
@@ -357,7 +343,7 @@ bool CustomElement::parseLine(QDomElement &e, QPainter &qp) {
 		reduced_line_length = line_length - (length2 * PartLine::requiredLengthForEndType(second_end));
 	}
 	draw_2nd_end = second_end && reduced_line_length >= 0;
-	
+
 	// dessine la premiere extremite
 	QPointF start_point, stop_point;
 	if (draw_1st_end) {
@@ -371,12 +357,12 @@ bool CustomElement::parseLine(QDomElement &e, QPainter &qp) {
 		} else if (first_end == Qet::Simple) {
 			qp.drawPolyline(QPolygonF() << four_points1[3] << point1 << four_points1[2]);
 			start_point = point1;
-			
+
 		} else if (first_end == Qet::Triangle) {
 			qp.drawPolygon(QPolygonF() << four_points1[0] << four_points1[2] << point1 << four_points1[3]);
 			start_point = four_points1[0];
 		}
-		
+
 		// ajuste le depart selon l'epaisseur du trait
 		if (pen_width && (first_end == Qet::Simple || first_end == Qet::Circle)) {
 			start_point = QLineF(start_point, point2).pointAt(pen_width / 2.0 / line_length);
@@ -384,7 +370,7 @@ bool CustomElement::parseLine(QDomElement &e, QPainter &qp) {
 	} else {
 		start_point = point1;
 	}
-	
+
 	// dessine la seconde extremite
 	if (draw_2nd_end) {
 		QList<QPointF> four_points2(PartLine::fourEndPoints(point2, point1, length2));
@@ -401,7 +387,7 @@ bool CustomElement::parseLine(QDomElement &e, QPainter &qp) {
 			qp.drawPolygon(QPolygonF() << four_points2[0] << four_points2[2] << point2 << four_points2[3] << four_points2[0]);
 			stop_point = four_points2[0];
 		}
-		
+
 		// ajuste l'arrivee selon l'epaisseur du trait
 		if (pen_width && (second_end == Qet::Simple || second_end == Qet::Circle)) {
 			stop_point = QLineF(point1, stop_point).pointAt((line_length - (pen_width / 2.0)) / line_length);
@@ -409,9 +395,9 @@ bool CustomElement::parseLine(QDomElement &e, QPainter &qp) {
 	} else {
 		stop_point = point2;
 	}
-	
+
 	qp.drawLine(start_point, stop_point);
-	
+
 	qp.restore();
 	return(true);
 }
@@ -424,7 +410,7 @@ bool CustomElement::parseLine(QDomElement &e, QPainter &qp) {
 		- y : ordonnee du coin superieur gauche du rectangle
 		- width : largeur du rectangle
 		- height : hauteur du rectangle
-		
+
 	@param e L'element XML a analyser
 	@param qp Le QPainter a utiliser pour dessiner l'element perso
 	@return true si l'analyse reussit, false sinon
@@ -443,12 +429,12 @@ bool CustomElement::parseRect(QDomElement &e, QPainter &qp) {
 
 	qp.save();
 	setPainterStyle(e, qp);
-	
+
 	// force le type de jointures pour les rectangles
 	QPen p = qp.pen();
 	p.setJoinStyle(Qt::MiterJoin);
 	qp.setPen(p);
-	
+
 	qp.drawRect(QRectF(rect_x, rect_y, rect_w, rect_h));
 	qp.restore();
 	return(true);
@@ -461,7 +447,7 @@ bool CustomElement::parseRect(QDomElement &e, QPainter &qp) {
 		- x : abscisse du coin superieur gauche de la quadrature du cercle
 		- y : ordonnee du coin superieur gauche de la quadrature du cercle
 		- diameter : diametre du cercle
-		
+
 	@param e L'element XML a analyser
 	@param qp Le QPainter a utiliser pour dessiner l'element perso
 	@return true si l'analyse reussit, false sinon
@@ -493,7 +479,7 @@ bool CustomElement::parseCircle(QDomElement &e, QPainter &qp) {
 		- y : ordonnee du coin superieur gauche du rectangle dans lequel s'inscrit l'ellipse
 		- width : dimension de la diagonale horizontale de l'ellipse
 		- height : dimension de la diagonale verticale de l'ellipse
-		
+
 	@param e L'element XML a analyser
 	@param qp Le QPainter a utiliser pour dessiner l'element perso
 	@return true si l'analyse reussit, false sinon
@@ -531,7 +517,7 @@ bool CustomElement::parseEllipse(QDomElement &e, QPainter &qp) {
 		- start : angle de depart : l'angle "0 degre" est a trois heures
 		- angle : etendue (en degres) de l'arc de cercle ; une valeur positive
 		va dans le sens contraire des aiguilles d'une montre
-		
+
 	@param e L'element XML a analyser
 	@param qp Le QPainter a utiliser pour dessiner l'element perso
 	@return true si l'analyse reussit, false sinon
@@ -545,7 +531,7 @@ bool CustomElement::parseArc(QDomElement &e, QPainter &qp) {
 	if (!QET::attributeIsAReal(e, QString("height"),  &arc_h))  return(false);
 	if (!QET::attributeIsAReal(e, QString("start"),   &arc_s))  return(false);
 	if (!QET::attributeIsAReal(e, QString("angle"),   &arc_a))  return(false);
-	
+
 	qp.save();
 	setPainterStyle(e, qp);
 
@@ -628,15 +614,15 @@ bool CustomElement::parseText(QDomElement &e, QPainter &qp) {
 		!QET::attributeIsAnInteger(e, "size", &size) ||\
 		!e.hasAttribute("text")
 	) return(false);
-	
+
 	qp.save();
 	setPainterStyle(e, qp);
-	
+
 	// determine la police a utiliser et en recupere les metriques associees
 	QFont used_font = QETApp::diagramTextsFont(size);
 	QFontMetrics qfm(used_font);
 	QColor text_color = (e.attribute("color") != "white"? Qt::black : Qt::white);
-	
+
 	// instancie un QTextDocument (comme la classe QGraphicsTextItem) pour
 	// generer le rendu graphique du texte
 	QTextDocument text_document;
@@ -654,18 +640,18 @@ bool CustomElement::parseText(QDomElement &e, QPainter &qp) {
 	eti -> setRotationAngle(original_rotation_angle);
 	eti -> setFollowParentRotations(e.attribute("rotate") == "true");
 	list_texts_ << eti;
-	
-	// Se positionne aux coordonnees indiquees dans la description du texte	
+
+	// Se positionne aux coordonnees indiquees dans la description du texte
 	qp.setTransform(QTransform(), false);
 	qp.translate(pos_x, pos_y);
-	
+
 	// Pivote le systeme de coordonnees du QPainter pour effectuer le rendu
 	// dans le bon sens
 	qreal default_rotation_angle = 0.0;
 	if (QET::attributeIsAReal(e, "rotation", &default_rotation_angle)) {
 		qp.rotate(default_rotation_angle);
 	}
-	
+
 	/*
 		Deplace le systeme de coordonnees du QPainter pour effectuer le rendu au
 		bon endroit ; note : on soustrait l'ascent() de la police pour
@@ -673,12 +659,12 @@ bool CustomElement::parseText(QDomElement &e, QPainter &qp) {
 		indiquee correspond a la baseline.
 	*/
 	QPointF qpainter_offset(0.0, -qfm.ascent());
-	
+
 		//adjusts the offset by the margin of the text document
 	text_document.setDocumentMargin(0.0);
-	
+
 	qp.translate(qpainter_offset);
-	
+
 	// force the palette used to render the QTextDocument
 	QAbstractTextDocumentLayout::PaintContext ctx;
 	ctx.palette.setColor(QPalette::Text, text_color);
@@ -707,26 +693,29 @@ ElementTextItem *CustomElement::parseInput(QDomElement &e) {
 		!QET::attributeIsAReal(e, "y", &pos_y) ||\
 		!QET::attributeIsAnInteger(e, "size", &size)
 	) return(0);
-	
+
 	ElementTextItem *eti = new ElementTextItem(e.attribute("text"), this);
 	eti -> setFont(QETApp::diagramTextsFont(size));
 	eti -> setTagg(e.attribute("tagg", "other"));
-	
-	// position the text field
+	m_element_informations.addValue(e.attribute("tagg", "other"), e.attribute("text"));
+
+		// position the text field
 	eti -> setOriginalPos(QPointF(pos_x, pos_y));
 	eti -> setPos(pos_x, pos_y);
-	
-	// rotation of the text field
+
+		// rotation of the text field
 	qreal original_rotation_angle = 0.0;
 	QET::attributeIsAReal(e, "rotation", &original_rotation_angle);
 	eti -> setOriginalRotationAngle(original_rotation_angle);
 	eti -> setRotationAngle(original_rotation_angle);
-	
-	// behavior when the parent element is rotated
+
+		// behavior when the parent element is rotated
 	eti -> setFollowParentRotations(e.attribute("rotate") == "true");
-	
+
 	list_texts_ << eti;
-	
+
+	connect(eti, &ElementTextItem::diagramTextChanged, this, &Element::textItemChanged);
+
 	return(eti);
 }
 
@@ -736,7 +725,7 @@ ElementTextItem *CustomElement::parseInput(QDomElement &e) {
 	Une borne est definie par les attributs suivants :
 		- x, y : coordonnees de la borne
 		- orientation  : orientation de la borne = Nord (n), Sud (s), Est (e) ou Ouest (w)
-		
+
 	@param e L'element XML a analyser
 	@return Un pointeur vers l'objet Terminal ainsi cree, 0 sinon
 */
@@ -778,12 +767,12 @@ void CustomElement::setQPainterAntiAliasing(QPainter &qp, bool aa) {
 		- une pour l'Est
 		- une pour le Sud
 		- une pour l'Ouest
-	 
+
 	Pour chaque orientation, on indique si elle est :
 		- l'orientation par defaut : d
 		- une orientation autorisee : y
 		- une orientation interdire : n
-		
+
 	Exemple : "dnny" represente un element par defaut oriente vers le nord et qui
 	peut etre oriente vers l'ouest mais pas vers le sud ou vers l'est.
 	@param e Element XML
@@ -842,7 +831,7 @@ bool CustomElement::validOrientationAttribute(const QDomElement &e) {
 			- hachures gauche
 			- hachures  droite
 			- none : pas de contour
-			
+
 	Les autres valeurs ne sont pas prises en compte.
 	@param e L'element XML a parser
 	@param qp Le QPainter a modifier en fonction des styles
@@ -851,14 +840,14 @@ void CustomElement::setPainterStyle(QDomElement &e, QPainter &qp) {
 	// recupere le QPen et la QBrush du QPainter
 	QPen pen = qp.pen();
 	QBrush brush = qp.brush();
-	
+
 	// attributs par defaut
 	pen.setJoinStyle(Qt::BevelJoin);
 	pen.setCapStyle(Qt::SquareCap);
-	
+
 	// recupere la liste des couples style / valeur
 	QStringList styles = e.attribute("style").split(";", QString::SkipEmptyParts);
-	
+
 	// agit sur le QPen et la QBrush en fonction des valeurs rencontrees
 	QRegExp rx("^\\s*([a-z-]+)\\s*:\\s*([a-z-]+)\\s*$");
 	foreach (QString style, styles) {
@@ -965,11 +954,11 @@ void CustomElement::setPainterStyle(QDomElement &e, QPainter &qp) {
 			}
 		}
 	}
-	
-	// affectation du QPen et de la QBrush modifies au QPainter 
+
+	// affectation du QPen et de la QBrush modifies au QPainter
 	qp.setPen(pen);
 	qp.setBrush(brush);
-	
+
 	// mise en place (ou non) de l'antialiasing
 	setQPainterAntiAliasing(qp, e.attribute("antialias") == "true");
 }
@@ -994,6 +983,8 @@ ElementTextItem* CustomElement::setTaggedText(const QString &tagg, const QString
 /**
  * @brief CustomElement::taggedText
  * return the text field tagged with @tagg or NULL if text field isn't found
+ * Some of available taggs :
+ * function, tension-protocol, label, comment, location
  * @param tagg
  */
 ElementTextItem* CustomElement::taggedText(const QString &tagg) const {
