@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -26,6 +26,38 @@
 #include "terminal.h"
 #include "PropertiesEditor/propertieseditordialog.h"
 #include "elementpropertieswidget.h"
+#include "numerotationcontextcommands.h"
+#include "diagramcontext.h"
+#include "changeelementinformationcommand.h"
+
+class ElementXmlRetroCompatibility
+{
+	friend class Element;
+
+	static void loadSequential(const QDomElement &dom_element, QString seq, QStringList* list)
+	{
+		int i = 0;
+		while (!dom_element.attribute(seq + QString::number(i+1)).isEmpty())
+		{
+				list->append(dom_element.attribute(seq + QString::number(i+1)));
+				i++;
+		}
+	}
+
+	static void loadSequential(const QDomElement &dom_element, Element *element)
+	{
+		autonum::sequentialNumbers sn;
+
+		loadSequential(dom_element,"sequ_",&sn.unit);
+		loadSequential(dom_element,"sequf_",&sn.unit_folio);
+		loadSequential(dom_element,"seqt_",&sn.ten);
+		loadSequential(dom_element,"seqtf_",&sn.ten_folio);
+		loadSequential(dom_element,"seqh_",&sn.hundred);
+		loadSequential(dom_element,"seqhf_",&sn.hundred_folio);
+
+		element->rSequenceStruct() = sn;
+	}
+};
 
 /**
 	Constructeur pour un element sans scene ni parent
@@ -305,6 +337,25 @@ void Element::updatePixmap() {
 	paint(&p, 0);
 }
 
+/**
+	This class is used to retrieve label and function information from element
+	and add it to Diagram Context. Used to make older versions work correctly
+	@param Element Text item to check information
+*/
+void Element::etiToElementLabels(ElementTextItem *eti) {
+	if (eti->tagg() == "label" && eti->toPlainText()!= "_") {
+		DiagramContext &dc = this->rElementInformations();
+		dc.addValue("label", eti->toPlainText());
+		this->setElementInformations(dc);
+		this->setTaggedText("label", eti->toPlainText());
+	}
+	else if(eti->tagg() == "function" && eti->toPlainText() != "_") {
+		DiagramContext &dc = this->rElementInformations();
+		dc.addValue("function", eti->toPlainText());
+		this->setElementInformations(dc);
+	}
+}
+
 /**
 	Permet de savoir si un element XML (QDomElement) represente bien un element
 	@param e Le QDomElement a valide
@@ -343,7 +394,14 @@ bool Element::valideXml(QDomElement &e) {
 	@return true si l'import a reussi, false sinon
 	
 */
-bool Element::fromXml(QDomElement &e, QHash<int, Terminal *> &table_id_adr, bool handle_inputs_rotation) {
+bool Element::fromXml(QDomElement &e, QHash<int, Terminal *> &table_id_adr, bool handle_inputs_rotation)
+{
+	QDomDocument doc = e.ownerDocument();
+	QDomElement root = doc.documentElement();
+	double saved_version = -1;
+	if(root.tagName() == "project")
+		saved_version = root.attribute("version", "-1").toDouble();
+		
 	/*
 		les bornes vont maintenant etre recensees pour associer leurs id a leur adresse reelle
 		ce recensement servira lors de la mise en place des fils
@@ -386,12 +444,18 @@ bool Element::fromXml(QDomElement &e, QHash<int, Terminal *> &table_id_adr, bool
 			table_id_adr.insert(id_trouve, priv_id_adr.value(id_trouve));
 		}
 	}
-	
-	// importe les valeurs des champs de texte
+
+		//import text filed value
 	QList<QDomElement> inputs = QET::findInDomElement(e, "inputs", "input");
-	foreach(QGraphicsItem *qgi, childItems()) {
-		if (ElementTextItem *eti = qgraphicsitem_cast<ElementTextItem *>(qgi)) {
-			foreach(QDomElement input, inputs) eti -> fromXml(input);
+	foreach(QGraphicsItem *qgi, childItems())
+	{
+		if (ElementTextItem *eti = qgraphicsitem_cast<ElementTextItem *>(qgi))
+		{
+			foreach(QDomElement input, inputs)
+			{
+				eti -> fromXml(input);
+				etiToElementLabels(eti);
+			}
 		}
 	}
 
@@ -402,11 +466,57 @@ bool Element::fromXml(QDomElement &e, QHash<int, Terminal *> &table_id_adr, bool
 	//uuid of this element
 	uuid_= QUuid(e.attribute("uuid", QUuid::createUuid().toString()));
 
-	//load informations
-	m_element_informations.fromXml(e.firstChildElement("elementInformations"), "elementInformation");
+		//load prefix
+	m_prefix = e.attribute("prefix");
 
-		//Position and selection.
-		//We directly call setPos from QGraphicsObject, because QetGraphicsItem will snap to grid
+	QString fl = e.attribute("freezeLabel", "false");
+	m_freeze_label = fl == "false"? false : true;
+
+		//Load Sequential Values
+	if (e.hasAttribute("sequ_1") || e.hasAttribute("sequf_1") || e.hasAttribute("seqt_1") || e.hasAttribute("seqtf_1") || e.hasAttribute("seqh_1") || e.hasAttribute("sequf_1"))
+		ElementXmlRetroCompatibility::loadSequential(e, this);
+	else
+		m_autoNum_seq.fromXml(e.firstChildElement("sequentialNumbers"));
+
+		//load informations
+	m_element_informations.fromXml(e.firstChildElement("elementInformations"), "elementInformation");
+		/**
+		 * Since the commit 4791, the value used as "label" and "formula" is stored in differents keys (instead of the same key, "label" in previous version),
+		 * so, if "label" contain "%" (Use variable value), and "formula" does not exist,
+		 * this mean the label was made before commit 4791 (0.51 dev). So we swap the value stored in "label" to "formula" as expected.
+		 * @TODO remove this code at version 0.7 or more (probably useless).
+		 */
+	if (m_element_informations["label"].toString().contains("%") && m_element_informations["formula"].toString().isNull())
+	{
+		m_element_informations.addValue("formula", m_element_informations["label"]);
+	}
+	
+		/**
+		  * At the start of the 0.51 devel, if the text item with tagg "label" was edited directly in the diagram,
+		  * the text was not write to the element information value "formula".
+		  * During the devel, this behavior change, when user edit the text item direclty in the diagram,
+		  * the text was also write in the element information.
+		  * Then when open a .qet file, the text item with tagg "label", is write with the value stored in the element information.
+		  * The mistake is :
+		  * if user write directly in the diagram  with a version befor the change (so the text is not in the element information),
+		  * and open the project with a version after the change, then the text item with tagg "label" is empty. 
+		  * The code below fix this.
+		  */
+	if (saved_version > -1 && saved_version <= 0.51)
+	{
+		if (ElementTextItem *eti = taggedText("label"))
+		{
+			if (m_element_informations["label"].toString().isEmpty() &&
+				m_element_informations["formula"].toString().isEmpty() &&
+				!eti->toPlainText().isEmpty())
+			{
+				m_element_informations.addValue("formula", eti->toPlainText());
+			}
+		}
+	}
+
+	//Position and selection.
+	//We directly call setPos from QGraphicsObject, because QetGraphicsItem will snap to grid
 	QGraphicsObject::setPos(e.attribute("x").toDouble(), e.attribute("y").toDouble());
 	setFlags(QGraphicsItem::ItemIsMovable | QGraphicsItem::ItemIsSelectable);
 	
@@ -430,13 +540,26 @@ bool Element::fromXml(QDomElement &e, QHash<int, Terminal *> &table_id_adr, bool
 	methode
 	@return L'element XML representant cet element electrique
 */
-QDomElement Element::toXml(QDomDocument &document, QHash<Terminal *, int> &table_adr_id) const {
+QDomElement Element::toXml(QDomDocument &document, QHash<Terminal *, int> &table_adr_id) const
+{
 	QDomElement element = document.createElement("element");
 	
-	// type
+		// type
 	element.setAttribute("type", typeId());
-	// uuid
+
+		// uuid
 	element.setAttribute("uuid", uuid().toString());
+
+		// prefix
+	element.setAttribute("prefix", m_prefix);
+
+		//frozen label
+	element.setAttribute("freezeLabel", m_freeze_label? "true" : "false");
+
+		// sequential num
+	QDomElement seq = m_autoNum_seq.toXml(document);
+	if (seq.hasChildNodes())
+		element.appendChild(seq);
 	
 	// position, selection et orientation
 	element.setAttribute("x", QString("%1").arg(pos().x()));
@@ -635,3 +758,183 @@ void Element::hoverLeaveEvent(QGraphicsSceneHoverEvent *e) {
 	m_mouse_over = false;
 	update();
 }
+
+/**
+ * @brief Element::setUpFormula
+ * Set up the formula used to create the label of this element
+ * @param : if true set tagged text to code letter (ex K for coil) with condition :
+ * formula is empty, text tagged "label" is emptty or "_";
+ */
+void Element::setUpFormula(bool code_letter)
+{
+	if (linkType() == Element::Slave || linkType() & Element::AllReport)
+		return;
+
+	if (diagram())
+	{
+		QString formula = diagram()->project()->elementAutoNumCurrentFormula();
+
+		if (formula.isEmpty())
+		{
+			if (code_letter && !m_prefix.isEmpty())
+			{
+				if (ElementTextItem *eti = taggedText("label"))
+				{
+					QString text = eti->toPlainText();
+					if (text.isEmpty() || text == "_")
+					{
+						m_element_informations.addValue("formula", "%prefix");
+					}
+				}
+			}
+		}
+		else
+		{
+			m_element_informations.addValue("formula", formula);
+
+			QString element_currentAutoNum = diagram()->project()->elementCurrentAutoNum();
+			NumerotationContext nc = diagram()->project()->elementAutoNum(element_currentAutoNum);
+			NumerotationContextCommands ncc (nc);
+
+			autonum::setSequential(formula, m_autoNum_seq, nc, diagram(), element_currentAutoNum);
+			diagram()->project()->addElementAutoNum(element_currentAutoNum, ncc.next());
+		}
+	}
+}
+
+/**
+ * @brief ElementTextItem::setTaggedText
+ * Set text @newstr to the text tagged with @tagg.
+ * If tagg is found return the text item, else return NULL.
+ * @param tagg required tagg
+ * @param newstr new label
+ * @param noeditable set editable or not (by default, set editable)
+ */
+ElementTextItem* Element::setTaggedText(const QString &tagg, const QString &newstr, const bool noeditable) {
+	ElementTextItem *eti = taggedText(tagg);
+	if (eti) {
+		eti -> setPlainText(newstr);
+		eti -> setNoEditable(noeditable);
+	}
+	return eti;
+}
+
+/**
+ * @brief Element::textItemChanged
+ * Use to keep up to date the element information when text item changed.
+ * @param dti
+ * @param old_str
+ * @param new_str
+ */
+void Element::textItemChanged(DiagramTextItem *dti, QString old_str, QString new_str)
+{
+	Q_UNUSED(new_str)
+
+	if (!diagram())
+		return;
+
+	ElementTextItem *eti = qgraphicsitem_cast<ElementTextItem *>(dti);
+	if (!eti)
+		return;
+
+	QString tagg = eti->tagg();
+	if (m_element_informations.contains(tagg))
+	{
+		DiagramContext dc = m_element_informations;
+		dc.addValue(tagg, eti->toPlainText(), dc.keyMustShow(tagg));
+		if (tagg == "label")
+			dc.addValue("formula", eti->toPlainText(), dc.keyMustShow("formula"));
+
+		diagram()->undoStack().push(new ChangeElementInformationCommand(this, m_element_informations, dc));
+	}
+	else
+	{
+		diagram()->undoStack().push(new ChangeDiagramTextCommand(eti, old_str, eti->toPlainText()));
+	}
+}
+
+/**
+ * @brief Element::getPrefix
+ * get Element Prefix
+ */
+QString Element::getPrefix() const{
+	return m_prefix;
+}
+
+/**
+ * @brief Element::setPrefix
+ * set Element Prefix
+ */
+void Element::setPrefix(QString prefix) {
+	m_prefix = prefix;
+}
+
+/**
+ * @brief Element::freezeLabel
+ * Freeze this element label
+ */
+void Element::freezeLabel(bool freeze)
+{
+	if (m_freeze_label != freeze)
+	{
+		m_freeze_label = freeze;
+		QString f = m_element_informations["formula"].toString();
+		setUpConnectionForFormula(f,f);
+
+		if (m_freeze_label == true)
+			updateLabel();
+	}
+}
+
+/**
+ * @brief Element::freezeNewAddedElement
+ * Freeze this label if needed
+ */
+void Element::freezeNewAddedElement() {
+	if (this->diagram()->freezeNewElements() || this->diagram()->project()->isFreezeNewElements()) {
+		freezeLabel(true);
+	}
+	else return;
+}
+
+/**
+ * @brief Element::setUpConnectionForFormula
+ * setup connection according to the variable of formula
+ * @param old_formula
+ * @param new_formula
+ */
+void Element::setUpConnectionForFormula(QString old_formula, QString new_formula)
+{
+		//Because the variable %F is a reference to another text which can contain variables,
+		//we must to replace %F by the real text, to check if the real text contain the variable %id
+	if (diagram() && old_formula.contains("%F"))
+	{
+		disconnect(&diagram()->border_and_titleblock, &BorderTitleBlock::titleBlockFolioChanged, this, &Element::updateLabel);
+		old_formula.replace("%F", m_F_str);
+	}
+
+	if (diagram() && (old_formula.contains("%f") || old_formula.contains("%id")))
+		disconnect(diagram()->project(), &QETProject::projectDiagramsOrderChanged, this, &Element::updateLabel);
+	if (old_formula.contains("%l"))
+		disconnect(this, &Element::yChanged, this, &Element::updateLabel);
+	if (old_formula.contains("%c"))
+		disconnect(this, &Element::xChanged, this, &Element::updateLabel);
+
+		//Label is frozen, so we don't update it.
+	if (m_freeze_label == true)
+		return;
+	
+	if (diagram() && new_formula.contains("%F"))
+	{
+		m_F_str = diagram()->border_and_titleblock.folio();
+		new_formula.replace("%F", m_F_str);
+		connect(&diagram()->border_and_titleblock, &BorderTitleBlock::titleBlockFolioChanged, this, &Element::updateLabel);
+	}
+	
+	if (diagram() && (new_formula.contains("%f") || new_formula.contains("%id")))
+		connect(diagram()->project(), &QETProject::projectDiagramsOrderChanged, this, &Element::updateLabel);
+	if (new_formula.contains("%l"))
+		connect(this, &Element::yChanged, this, &Element::updateLabel);
+	if (new_formula.contains("%c"))
+		connect(this, &Element::xChanged, this, &Element::updateLabel);
+}
