@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -21,16 +21,21 @@
 #include "qet.h"
 #include "qetgraphicsitem.h"
 #include "diagramcontext.h"
+#include "assignvariables.h"
+#include <algorithm>
 
 class ElementTextItem;
 class QETProject;
 class Terminal;
 class Conductor;
+class NumerotationContext;
+class DiagramTextItem;
 
 /**
 	This is the base class for electrical elements.
 */
-class Element : public QetGraphicsItem {	
+class Element : public QetGraphicsItem
+{
 	Q_OBJECT
 	
 		// constructors, destructor
@@ -43,8 +48,7 @@ class Element : public QetGraphicsItem {
 		// attributes
 	public:
 			/**
-			 * Enable the use of qgraphicsitem_cast to safely cast
-			 * a QGraphicsItem into an Element.
+			 * Enable the use of qgraphicsitem_cast to safely cast a QGraphicsItem into an Element.
 			 * @return the QGraphicsItem type
 			 */
 		enum { Type = UserType + 1000 };
@@ -69,30 +73,30 @@ class Element : public QetGraphicsItem {
 
 		// methods
 	public:
-		/// @return the list of terminals for this element
-	virtual QList<Terminal *> terminals() const = 0;
-		/// @return the list of conductors attached to this element
-	virtual QList<Conductor *> conductors() const = 0;
-		/// @return the list of text items attached to this element
-	virtual QList<ElementTextItem *> texts() const = 0;
-		/// @return the text field tagged with @tagg or NULL if text field isn't found
-	virtual ElementTextItem* taggedText(const QString &tagg) const = 0;
-		/// @return the list of lines items in this element
-	virtual QList<QLineF *> lines() const = 0;
-		/// @return the list of rectangles items in this element
-	virtual QList<QRectF *> rectangles() const = 0;
-		/// @return the list of bounding rectangles for circles items in this element
-	virtual QList<QRectF *> circles() const = 0;
-		/// @return the list of polygons in this element
-	virtual QList<QVector<QPointF> *> polygons() const = 0;	
-		/// @return the list of arcs in this element
-	virtual QList<QVector<qreal> *> arcs() const = 0;
-		/// @return the current number of terminals of this element
-	virtual int terminalsCount() const = 0;
-		/// @return the minimum number of terminals for this element
-	virtual int minTerminalsCount() const = 0;
-		/// @return the maximum number of terminals for this element
-	virtual int maxTerminalsCount() const = 0;
+			/// @return the list of terminals for this element
+		virtual QList<Terminal *> terminals() const = 0;
+			/// @return the list of conductors attached to this element
+		virtual QList<Conductor *> conductors() const = 0;
+			/// @return the list of text items attached to this element
+		virtual QList<ElementTextItem *> texts() const = 0;
+			/// @return the text field tagged with @tagg or NULL if text field isn't found
+		virtual ElementTextItem* taggedText(const QString &tagg) const = 0;
+			/// @return the list of lines items in this element
+		virtual QList<QLineF *> lines() const = 0;
+			/// @return the list of rectangles items in this element
+		virtual QList<QRectF *> rectangles() const = 0;
+			/// @return the list of bounding rectangles for circles items in this element
+		virtual QList<QRectF *> circles() const = 0;
+			/// @return the list of polygons in this element
+		virtual QList<QVector<QPointF> *> polygons() const = 0;
+			/// @return the list of arcs in this element
+		virtual QList<QVector<qreal> *> arcs() const = 0;
+			/// @return the current number of terminals of this element
+		virtual int terminalsCount() const = 0;
+			/// @return the minimum number of terminals for this element
+		virtual int minTerminalsCount() const = 0;
+			/// @return the maximum number of terminals for this element
+		virtual int maxTerminalsCount() const = 0;
 
 		QList <QPair <Terminal *, Terminal *> > AlignedFreeTerminals () const;
 
@@ -118,13 +122,16 @@ class Element : public QetGraphicsItem {
 		QList <QUuid>     tmp_uuids_link;
 		QUuid             uuid_;
 		kind              link_type_;
+		ElementTextItem* setTaggedText(const QString &tagg, const QString &newstr, const bool noeditable=false);
 
 	signals:
-		void linkedElementChanged(); //This signal is emtied when the linked elements with this element change
+		void linkedElementChanged(); //This signal is emited when the linked elements with this element change
 		void elementInfoChange(DiagramContext old_info, DiagramContext new_info);
+		void updateLabel(); //This signal is emited to update element's label
 
 		//METHODS related to information
 	public:
+		void textItemChanged(DiagramTextItem *dti, QString old_str, QString new_str);
 		DiagramContext  elementInformations    ()const              {return m_element_informations;}
 		DiagramContext& rElementInformations   ()                   {return m_element_informations;}
 		virtual void    setElementInformations (DiagramContext dc);
@@ -132,9 +139,24 @@ class Element : public QetGraphicsItem {
 																									//about the herited class like contactelement for know
 																									// kind of contact (simple tempo) or number of contact show by the element.
 
-	//ATTRIBUTES
+		autonum::sequentialNumbers sequenceStruct () const {return m_autoNum_seq;}
+		autonum::sequentialNumbers& rSequenceStruct()      {return m_autoNum_seq;}
+
+		void setUpFormula(bool code_letter = true);
+		void setPrefix(QString);
+		QString getPrefix() const;
+		void freezeLabel(bool freeze);
+		void freezeNewAddedElement();
+
+	protected:
+		virtual void setUpConnectionForFormula(QString old_formula, QString new_formula);
+
+		//ATTRIBUTES
 	protected:
 		DiagramContext m_element_informations, kind_informations_;
+		autonum::sequentialNumbers m_autoNum_seq;
+		bool m_freeze_label = false;
+		QString m_F_str;
 
 	/**
 		Draw this element
@@ -161,7 +183,7 @@ class Element : public QetGraphicsItem {
 	
 	// selection-related methods
 	void select();
-	void deselect();	
+	void deselect();
 	
 	virtual void rotateBy(const qreal &);
 	virtual void editProperty();
@@ -171,10 +193,10 @@ class Element : public QetGraphicsItem {
 	virtual bool fromXml(QDomElement &, QHash<int, Terminal *> &, bool = false);
 	virtual QDomElement toXml(QDomDocument &, QHash<Terminal *, int> &) const;
 	QUuid uuid() const;
-	
+
 	// orientation-related methods
 	int orientation() const;
-	
+
 	protected:
 		void drawAxes(QPainter *, const QStyleOptionGraphicsItem *);
 	
@@ -183,6 +205,7 @@ class Element : public QetGraphicsItem {
 		void drawSelection(QPainter *, const QStyleOptionGraphicsItem *);
 		void drawHighlight(QPainter *, const QStyleOptionGraphicsItem *);
 		void updatePixmap();
+		void etiToElementLabels(ElementTextItem*);
 
 	protected:
 		virtual void mouseMoveEvent    ( QGraphicsSceneMouseEvent *event );
@@ -192,6 +215,7 @@ class Element : public QetGraphicsItem {
 
 	private:
 		bool m_mouse_over;
+		QString m_prefix;
 
 };
 
@@ -226,7 +250,7 @@ inline QUuid Element::uuid() const {
  * @return the list of linked elements, the list is sorted by position
  */
 inline QList <Element *> Element::linkedElements() {
-	 qSort(connected_elements.begin(), connected_elements.end(), comparPos);
+	 std::sort(connected_elements.begin(), connected_elements.end(), comparPos);
 	return connected_elements;
 }
 
