@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -18,6 +18,8 @@
 #include "masterelement.h"
 #include "crossrefitem.h"
 #include "elementtextitem.h"
+#include "diagram.h"
+#include <QRegularExpression>
 
 /**
  * @brief MasterElement::MasterElement
@@ -29,10 +31,11 @@
  */
 MasterElement::MasterElement(const ElementsLocation &location, QGraphicsItem *qgi, int *state) :
 	CustomElement(location, qgi, state),
-	cri_ (nullptr)
+	m_Xref_item (nullptr)
 {
 	link_type_ = Master;
 	connect(this, SIGNAL(elementInfoChange(DiagramContext, DiagramContext)), this, SLOT(updateLabel(DiagramContext, DiagramContext)));
+	connect(this, &Element::updateLabel, [this]() {this->updateLabel(this->elementInformations(), this->elementInformations());});
 }
 
 /**
@@ -57,11 +60,13 @@ void MasterElement::linkToElement(Element *elmt)
 		connected_elements << elmt;
 		elmt->linkToElement(this);
 
-		if (!cri_) cri_ = new CrossRefItem(this); //create cross ref item if not yet
+		if (!m_Xref_item) m_Xref_item = new CrossRefItem(this); //create cross ref item if not yet
 
-		connect(elmt, SIGNAL(xChanged()), cri_, SLOT(updateLabel()));
-		connect(elmt, SIGNAL(yChanged()), cri_, SLOT(updateLabel()));
-		cri_ -> updateLabel();
+		connect(elmt, SIGNAL(xChanged()),    m_Xref_item, SLOT(updateLabel()));
+		connect(elmt, SIGNAL(yChanged()),    m_Xref_item, SLOT(updateLabel()));
+		connect(elmt, SIGNAL(updateLabel()), m_Xref_item, SLOT(updateLabel()));
+		connect(&elmt->diagram()->border_and_titleblock, &BorderTitleBlock::titleBlockFolioChanged, m_Xref_item, &CrossRefItem::updateLabel);
+		m_Xref_item -> updateLabel();
 		emit linkedElementChanged();
 	}
 }
@@ -96,10 +101,12 @@ void MasterElement::unlinkElement(Element *elmt)
 		elmt -> setHighlighted (false);
 
 			//update the graphics cross ref
-		disconnect(elmt, SIGNAL(xChanged()), cri_, SLOT(updateLabel()));
-		disconnect(elmt, SIGNAL(yChanged()), cri_, SLOT(updateLabel()));
+		disconnect(elmt, SIGNAL(xChanged()),    m_Xref_item, SLOT(updateLabel()));
+		disconnect(elmt, SIGNAL(yChanged()),    m_Xref_item, SLOT(updateLabel()));
+		disconnect(elmt, SIGNAL(updateLabel()), m_Xref_item, SLOT(updateLabel()));
+		disconnect(&elmt->diagram()->border_and_titleblock, &BorderTitleBlock::titleBlockFolioChanged, m_Xref_item, &CrossRefItem::updateLabel);
 
-		cri_ -> updateLabel();
+		m_Xref_item -> updateLabel();
 		aboutDeleteXref();
 		emit linkedElementChanged();
 	}
@@ -122,30 +129,46 @@ void MasterElement::initLink(QETProject *project) {
  * update label of this element
  * and the comment item if he's displayed.
  */
-void MasterElement::updateLabel(DiagramContext old_info, DiagramContext new_info) {
-	//Label of element
-	if (old_info["label"].toString() != new_info["label"].toString()) {
-		if (new_info["label"].toString().isEmpty())
-			setTaggedText("label", "_", false);
-		else
-			setTaggedText("label", new_info["label"].toString(), true);
+void MasterElement::updateLabel(DiagramContext old_info, DiagramContext new_info)
+{
+	QString old_formula = old_info["formula"].toString();
+	QString new_formula = new_info["formula"].toString();
+
+	setUpConnectionForFormula(old_formula, new_formula);
+
+	QString label = autonum::AssignVariables::formulaToLabel(new_formula, m_autoNum_seq, diagram(), this);
+
+	if (label.isEmpty())
+	{
+		setTaggedText("label", new_info["label"].toString());
+	}
+	else
+	{
+		bool visible = m_element_informations.contains("label") ? m_element_informations.keyMustShow("label") : true;
+		m_element_informations.addValue("label", label, visible);
+		setTaggedText("label", label);
 	}
 
-	if (ElementTextItem *eti = taggedText("label")) {
+	if (ElementTextItem *eti = taggedText("label"))
+	{
 		new_info["label"].toString().isEmpty() ? eti->setVisible(true) : eti -> setVisible(new_info.keyMustShow("label"));
 	}
 
+
 	//Delete or update the xref
-	if (cri_) {
-		cri_ -> updateLabel();
+	if (m_Xref_item) {
+		m_Xref_item -> updateLabel();
 		aboutDeleteXref();
 	}
 	else {
 		QString comment   = elementInformations()["comment"].toString();
-		bool    must_show = elementInformations().keyMustShow("comment");
+		bool    must_show_comment = elementInformations().keyMustShow("comment");
 
-		if (! (comment.isEmpty() || !must_show)) {
-			cri_ = new CrossRefItem(this);
+		QString location  = elementInformations()["location"].toString();
+		bool	must_show_location = elementInformations().keyMustShow("location");
+
+		if (! (comment.isEmpty() || !must_show_comment) || !(location.isEmpty() || !must_show_location)) {
+			m_Xref_item = new CrossRefItem(this);
 		}
 	}
 }
@@ -161,12 +184,12 @@ void MasterElement::updateLabel(DiagramContext old_info, DiagramContext new_info
  * @return
  */
 bool MasterElement::aboutDeleteXref() {
-	if(!cri_) return true;
+	if(!m_Xref_item) return true;
 	if(!linkedElements().isEmpty()) return false;
 
-	if (cri_ -> boundingRect().isNull()) {
-		delete cri_;
-		cri_ = nullptr;
+	if (m_Xref_item -> boundingRect().isNull()) {
+		delete m_Xref_item;
+		m_Xref_item = nullptr;
 		return true;
 	}
 
