@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -20,10 +20,11 @@
 
 #include <QPen>
 #include "qetgraphicsitem.h"
-#include "QetGraphicsItemModeler/qetgraphicshandlerutility.h"
+#include "QetGraphicsItemModeler/qetgraphicshandleritem.h"
 
 class QDomElement;
 class QDomDocument;
+class QetGraphicsHandlerItem;
 
 /**
  * @brief The QetShapeItem class
@@ -35,19 +36,23 @@ class QetShapeItem : public QetGraphicsItem
 	Q_OBJECT
 
 		Q_PROPERTY(QPen pen READ pen WRITE setPen NOTIFY penChanged)
+		Q_PROPERTY(QBrush brush READ brush WRITE setBrush NOTIFY brushChanged)
 		Q_PROPERTY(QRectF rect READ rect WRITE setRect)
 		Q_PROPERTY(QLineF line READ line WRITE setLine)
 		Q_PROPERTY(QPolygonF polygon READ polygon WRITE setPolygon)
+		Q_PROPERTY(bool close READ isClosed WRITE setClosed NOTIFY closeChanged)
 
 	signals:
 		void penChanged();
+		void brushChanged();
+		void closeChanged();
 
 	public:
 		Q_ENUMS(ShapeType)
 		enum ShapeType {Line	  =1,
 						Rectangle =2,
 						Ellipse	  =4,
-						Polygon  =8 };
+						Polygon   =8 };
 
 		enum { Type = UserType + 1008 };
 
@@ -60,6 +65,8 @@ class QetShapeItem : public QetGraphicsItem
 			///METHODS
 		QPen pen() const {return m_pen;}
 		void setPen(const QPen &pen);
+		QBrush brush() const {return m_brush;}
+		void setBrush(const QBrush &brush);
 		ShapeType shapeType() const {return m_shapeType;}
 
 		virtual bool	    fromXml (const QDomElement &);
@@ -76,6 +83,8 @@ class QetShapeItem : public QetGraphicsItem
 		bool setRect    (const QRectF &rect);
 		QPolygonF polygon() const {return m_polygon;}
 		bool setPolygon (const QPolygonF &polygon);
+		bool isClosed() const {return m_close;}
+		void setClosed (bool close);
 
 			//Methods available for polygon shape
 		int  pointsCount  () const;
@@ -88,21 +97,30 @@ class QetShapeItem : public QetGraphicsItem
 	protected:
 		virtual void paint(QPainter *painter, const QStyleOptionGraphicsItem *option, QWidget *widget);
 		virtual void hoverEnterEvent   (QGraphicsSceneHoverEvent *event);
-		virtual void hoverMoveEvent    (QGraphicsSceneHoverEvent *event);
 		virtual void hoverLeaveEvent   (QGraphicsSceneHoverEvent *event);
-		virtual void mousePressEvent   (QGraphicsSceneMouseEvent *event);
-		virtual void mouseMoveEvent    (QGraphicsSceneMouseEvent *event);
 		virtual void mouseReleaseEvent (QGraphicsSceneMouseEvent *event);
+        virtual QVariant itemChange(GraphicsItemChange change, const QVariant &value);
+        virtual bool sceneEventFilter(QGraphicsItem *watched, QEvent *event);
+
+	private:
+		void switchResizeMode();
+		void adjusteHandlerPos();
+		
+		void handlerMousePressEvent   (QetGraphicsHandlerItem *qghi, QGraphicsSceneMouseEvent *event);
+		void handlerMouseMoveEvent    (QetGraphicsHandlerItem *qghi, QGraphicsSceneMouseEvent *event);
+		void handlerMouseReleaseEvent (QetGraphicsHandlerItem *qghi, QGraphicsSceneMouseEvent *event);
 
 		///ATTRIBUTES
 	private:
-		ShapeType    m_shapeType;
+		ShapeType	 m_shapeType;
 		QPen		 m_pen;
+		QBrush       m_brush;
 		QPointF		 m_P1, m_P2, m_old_P1, m_old_P2;
 		QPolygonF	 m_polygon, m_old_polygon;
-		bool         m_hovered,
-					 m_mouse_grab_handler;
+		bool		 m_hovered;
 		int			 m_vector_index;
-		QetGraphicsHandlerUtility m_handler;
+		bool m_close = false;
+		int m_resize_mode = 1;
+        QVector<QetGraphicsHandlerItem *> m_handler_vector;
 };
 #endif // QETSHAPEITEM_H
