@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -43,12 +43,13 @@ bool centerToParentBottom(QGraphicsItem *item) {
 
 /**
  * @brief centerToBottomDiagram
- * Set item pos to the bottom of diagram and centered vertically to element_to_follow
+ * Set item pos to the bottom of diagram and centered vertically to element_to_follow, and add offset.
  * @param item_to_center
  * @param element_to_follow
+ * @param offset
  * @return true if element is centered else false (element_to_follow have not diagram)
  */
-bool centerToBottomDiagram (QGraphicsItem *item_to_center, Element *element_to_follow) {
+bool centerToBottomDiagram (QGraphicsItem *item_to_center, Element *element_to_follow, int offset) {
 	if (! element_to_follow -> diagram()) {
 		qDebug() << "qgraphicsitemutility centerAtBottomDiagram : Element_to_follow have not diagram";
 		return false;
@@ -57,8 +58,7 @@ bool centerToBottomDiagram (QGraphicsItem *item_to_center, Element *element_to_f
 	QRectF  border = element_to_follow -> diagram() -> border_and_titleblock.insideBorderRect();
 	QPointF point  = element_to_follow -> sceneBoundingRect().center();
 
-	point.setY(border.bottom() - item_to_center -> boundingRect().height() - 5);
-
+	point.setY(border.bottom() - item_to_center -> boundingRect().height() - offset );
 	point.rx() -= (item_to_center -> boundingRect().width()/2 +
 				   item_to_center -> boundingRect().left()); //< we add boundingrect.left because this value can be négative
 
