@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -37,20 +37,22 @@ class ReportElement : public CustomElement
 		virtual void linkToElement(Element *);
 		virtual void unlinkAllElements();
 		virtual void unlinkElement(Element *elmt);
-
-	private:
-		int              inverse_report;
-		QString          label_;
-		ElementTextItem *m_text_field;
-		Conductor *m_watched_conductor;
-
+		
 	private:
 		void conductorWasAdded(Conductor *conductor);
 		void conductorWasRemoved(Conductor *conductor);
-
-	private slots:
-		void setLabel (QString label);
+		void setFormula (QString label);
 		void updateLabel();
+		void reportPropertiesChange(const QString &old_str, const QString &new_str);
+		void setConnectionForFormula(const QString &str);
+		void removeConnectionForFormula(const QString &str);
+		void updateFormulaConnection();
+		
+	private:
+		int              m_inverse_report;
+		QString          m_formula;
+		ElementTextItem *m_text_field;
+		Conductor       *m_watched_conductor;
 };
 
 #endif // REPORTELEMENT_H
