@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -37,14 +37,12 @@ class SimpleElement : public CustomElement {
 
 		virtual void initLink(QETProject *project);
 
-	signals:
-
 	public slots:
 		void updateLabel(DiagramContext old_info, DiagramContext new_info);
 
 	private:
 		CommentItem *m_comment_item;
-
+		CommentItem *m_location_item;
 };
 
 #endif // SIMPLEELEMENT_H
