@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -32,8 +32,9 @@
 SlaveElement::SlaveElement(const ElementsLocation &location, QGraphicsItem *qgi, int *state) :
 	CustomElement(location, qgi, state)
 {
-	Xref_item = NULL;
+	m_xref_item = nullptr;
 	link_type_ = Slave;
+	connect(this, SIGNAL(updateLabel()), this, SLOT(updateLabel()));
 }
 
 /**
@@ -56,13 +57,17 @@ void SlaveElement::linkToElement(Element *elmt)
 	if (elmt->linkType() == Master && !connected_elements.contains(elmt))
 	{
 		if(!isFree()) unlinkAllElements();
+		this->disconnect();
 		connected_elements << elmt;
 
-		connect(elmt,                 SIGNAL(xChanged()),                                       this, SLOT(updateLabel()));
-		connect(elmt,                 SIGNAL(yChanged()),                                       this, SLOT(updateLabel()));
-		connect(elmt,                 SIGNAL(elementInfoChange(DiagramContext, DiagramContext)),this, SLOT(updateLabel()));
-		connect(diagram()->project(), SIGNAL(projectDiagramsOrderChanged(QETProject*,int,int)), this, SLOT(updateLabel()));
-		connect(diagram()->project(), SIGNAL(diagramRemoved(QETProject*,Diagram*)),             this, SLOT(updateLabel()));
+		QETProject *project = elmt->diagram()->project();
+		connect(elmt,    SIGNAL(xChanged()),                                        this, SLOT(updateLabel()));
+		connect(elmt,    SIGNAL(yChanged()),                                        this, SLOT(updateLabel()));
+		connect(elmt,    SIGNAL(elementInfoChange(DiagramContext, DiagramContext)), this, SLOT(updateLabel()));
+		connect(project, SIGNAL(projectDiagramsOrderChanged(QETProject*,int,int)),  this, SLOT(updateLabel()));
+		connect(project, SIGNAL(diagramRemoved(QETProject*,Diagram*)),              this, SLOT(updateLabel()));
+		connect(project, SIGNAL(XRefPropertiesChanged()),                           this, SLOT(updateLabel()));
+		connect(elmt,    SIGNAL(updateLabel()),                                     this, SLOT(updateLabel()));
 
 		updateLabel();
 		elmt -> linkToElement(this);
@@ -102,9 +107,14 @@ void SlaveElement::unlinkElement(Element *elmt)
 		disconnect(elmt,                 SIGNAL(elementInfoChange(DiagramContext, DiagramContext)),this, SLOT(updateLabel()));
 		disconnect(diagram()->project(), SIGNAL(projectDiagramsOrderChanged(QETProject*,int,int)), this, SLOT(updateLabel()));
 		disconnect(diagram()->project(), SIGNAL(diagramRemoved(QETProject*,Diagram*)),             this, SLOT(updateLabel()));
+		disconnect(elmt -> diagram(),    SIGNAL(XRefPropertiesChanged()),                          this, SLOT(updateLabel()));
+		disconnect(elmt,                 SIGNAL(updateLabel()),                                    this, SLOT(updateLabel()));
 
-		delete Xref_item; Xref_item = NULL;
-
+		delete m_xref_item; m_xref_item = NULL;
+		
+		if (ElementTextItem *eti = this->taggedText("label"))
+			eti->setPlainText("_");
+		
 		updateLabel();
 		elmt -> unlinkElement  (this) ;
 		elmt -> setHighlighted (false);
@@ -119,32 +129,39 @@ void SlaveElement::unlinkElement(Element *elmt)
  * the label show the string tagged by "label" of the master
  * and add a qgraphicstextitem for show the position of the master
  */
-void SlaveElement::updateLabel() {
-	QString label("_");
+void SlaveElement::updateLabel()
+{
+	QString label;
+	if (ElementTextItem *eti = this->taggedText("label"))
+		label = eti->toPlainText();
 	QString Xreflabel;
 	bool no_editable = false;
 
 	//must be linked to set the label of master
-	if (linkedElements().count()) {
+	if (linkedElements().count())
+	{
 		no_editable = true;
 		Element *elmt = linkedElements().first();
-		label = elmt -> elementInformations()["label"].toString();
-
-		Xreflabel = "(";
-		Xreflabel += QString::number(elmt->diagram()->folioIndex()+1);
-		Xreflabel += "-";
-		Xreflabel += elmt->diagram() -> convertPosition(elmt -> scenePos()).toString();
-		Xreflabel += ")";
+		label = elmt->elementInformations()["label"].toString();
+		
+		XRefProperties xrp = elmt->diagram()->project()->defaultXRefProperties(elmt->kindInformations()["type"].toString());
+		Xreflabel = xrp.slaveLabel();
+		Xreflabel = autonum::AssignVariables::formulaToLabel(Xreflabel, elmt->rSequenceStruct(), elmt->diagram(), elmt);
 	}
+	else
+		label = autonum::AssignVariables::formulaToLabel(label, m_autoNum_seq, diagram(), this);
 
 	// set the new label
 	ElementTextItem *eti = setTaggedText("label", label, no_editable);
-	if (eti && !isFree()) {
-		if (Xref_item) Xref_item -> setPlainText(Xreflabel);
-		else {
-			Xref_item = new QGraphicsTextItem(Xreflabel, eti);
-			Xref_item -> setFont(QETApp::diagramTextsFont(5));
-			Xref_item -> setPos(eti ->  boundingRect().bottomLeft());
+	if (eti && !isFree())
+	{
+		if (m_xref_item)
+			m_xref_item->setPlainText(Xreflabel);
+		else 
+		{
+			m_xref_item = new QGraphicsTextItem(Xreflabel, eti);
+			m_xref_item->setFont(QETApp::diagramTextsFont(5));
+			m_xref_item->setPos(eti ->  boundingRect().bottomLeft());
 		}
 	}
 }
