@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -19,6 +19,7 @@
 #define SLAVEELEMENT_H
 
 #include "customelement.h"
+#include"properties/xrefproperties.h"
 
 class SlaveElement : public CustomElement
 {
@@ -36,8 +37,7 @@ class SlaveElement : public CustomElement
 	void updateLabel();
 
 	private:
-	QGraphicsTextItem *Xref_item;
-
+		QGraphicsTextItem *m_xref_item;
 };
 
 #endif // SLAVEELEMENT_H
