@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -21,6 +21,7 @@
 #include "qetgraphicsitem/conductor.h"
 #include "diagramcommands.h"
 #include "conductorautonumerotation.h"
+#include "conductortextitem.h"
 
 QColor Terminal::neutralColor      = QColor(Qt::blue);
 QColor Terminal::allowedColor      = QColor(Qt::darkGreen);
@@ -594,25 +595,36 @@ void Terminal::mouseReleaseEvent(QGraphicsSceneMouseEvent *e)
 	{
 		use_properties = true;
 		others_properties = (*conductors_list.begin())->properties();
-		foreach (Conductor *conductor, conductors_list)
+		foreach (Conductor *conductor, conductors_list) {
 			if (conductor->properties() != others_properties)
 				use_properties = false;
+		}
 	}
 
 
-	QUndoCommand *undo = new AddItemCommand<Conductor *>(new_conductor, diagram());
+	QUndoCommand *undo = new QUndoCommand();
+	QUndoCommand *aic = new AddItemCommand<Conductor *>(new_conductor, diagram(), QPointF(), undo);
+	undo->setText(aic->text());
 
 	if (use_properties)
+	{
+		Conductor *other = conductors_list.toList().first();
+		new_conductor->rSequenceNum() = other->sequenceNum();
 		new_conductor->setProperties(others_properties);
+	}
 	else
 	{
-			//Autonum it
+		//Autonum it
 		ConductorAutoNumerotation can (new_conductor, diagram(), undo);
 		can.numerate();
 	}
-
-		//Add undo command to the parent diagram
+	//Add undo command to the parent diagram
 	diagram() -> undoStack().push(undo);
+	if (use_properties)
+	{
+		Conductor *other = conductors_list.toList().first();
+		new_conductor->setProperties(other->properties());
+	}
 }
 
 /**
@@ -753,24 +765,27 @@ Element *Terminal::parentElement() const {
  * @param t terminal to start search
  * @param all_diagram :if true return all related terminal,
  * false return only terminal in the same diagram of @t
- * @return
+ * @return the list of terminal at the same potential
  */
-Terminal * relatedPotentialTerminal (const Terminal *terminal, const bool all_diagram) {
-	// If terminal parent element is a folio report.
-	if (all_diagram && terminal -> parentElement() -> linkType() & Element::AllReport) {
+QList<Terminal *> relatedPotentialTerminal (const Terminal *terminal, const bool all_diagram)
+{
+		// If terminal parent element is a folio report.
+	if (all_diagram && terminal -> parentElement() -> linkType() & Element::AllReport)
+	{
 		QList <Element *> elmt_list = terminal -> parentElement() -> linkedElements();
-		if (!elmt_list.isEmpty()) {
-			return (elmt_list.first() -> terminals().first());
+		if (!elmt_list.isEmpty())
+		{
+			return (elmt_list.first()->terminals());
 		}
 	}
-	// If terminal parent element is a Terminal element.
-	else if (terminal -> parentElement() -> linkType() & Element::Terminale) {
-		QList <Terminal *> terminals = terminal -> parentElement() -> terminals();
-		terminals.removeAll(const_cast<Terminal *> (terminal));
-		if (!terminals.isEmpty())
-			return terminals.first();
+		// If terminal parent element is a Terminal element.
+	else if (terminal -> parentElement() -> linkType() & Element::Terminale)
+	{
+		QList <Terminal *> terminals = terminal->parentElement()->terminals();
+		terminals.removeAll(const_cast<Terminal *>(terminal));
+		return terminals;
 	}
 
-	return nullptr;
+	return QList<Terminal *>();
 }
 
