@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -169,6 +169,6 @@ inline QString Terminal::name() const {
 	return(name_terminal_);
 }
 
-Terminal * relatedPotentialTerminal (const Terminal *terminal, const bool all_diagram = true);
+QList<Terminal *> relatedPotentialTerminal (const Terminal *terminal, const bool all_diagram = true);
 
 #endif
