@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -20,12 +20,23 @@
 
 #include "customelement.h"
 
+class CommentItem;
+class QETProject;
+
 class TerminalElement : public CustomElement
 {
 		Q_OBJECT
 	public:
 		TerminalElement(const ElementsLocation &, QGraphicsItem * = 0, int * = 0);
 		~TerminalElement();
+		virtual void initLink(QETProject *project);
+
+	public slots:
+		void updateLabel(DiagramContext old_info, DiagramContext new_info);
+
+	private:
+		CommentItem *m_comment_item;
+		CommentItem *m_location_item;
 };
 
 #endif // TERMINALELEMENT_H
