@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -33,6 +33,7 @@ namespace QET {
 		QIcon BringForward;
 		QIcon Cancel;
 		QIcon Conductor;
+        QIcon ConductorEdit;
 		QIcon ConductorSettings;
 		QIcon Configure;
 		QIcon ConfigureToolbars;
@@ -40,8 +41,8 @@ namespace QET {
 		QIcon DefaultConductor;
 		QIcon DiagramAdd;
 		QIcon Diagram;
-        QIcon DiagramBg;
-        QIcon DiagramDelete;
+		QIcon DiagramBg;
+		QIcon DiagramDelete;
 		QIcon DialogCancel;
 		QIcon DialogInformation;
 		QIcon DialogOk;
@@ -67,6 +68,8 @@ namespace QET {
 		QIcon EditRedo;
 		QIcon EditRename;
 		QIcon EditSelectAll;
+        QIcon EditSelectInvert;
+        QIcon EditSelectNone;
 		QIcon EditTableCellMerge;
 		QIcon EditTableCellSplit;
 		QIcon EditTableDeleteColumn;
@@ -81,7 +84,8 @@ namespace QET {
 		QIcon ElementDelete;
 		QIcon ElementEdit;
 		QIcon ElementNew;
-		QIcon EndLineCircle;
+        QIcon ElementSmall;
+        QIcon EndLineCircle;
 		QIcon EndLineDiamond;
 		QIcon EndLineNone;
 		QIcon EndLineSimple;
@@ -91,12 +95,21 @@ namespace QET {
 		QIcon FolderDelete;
 		QIcon FolderEdit;
 		QIcon FolderNew;
+        QIcon FolderOnlyThis;
+        QIcon FolderOpen;
+        QIcon FolderProperties;
+        QIcon FolderShowAll;
 		QIcon Forbidden;
 		QIcon FullScreenEnter;
 		QIcon FullScreenExit;
-		QIcon GoDown;
-		QIcon GoUp;
+        QIcon GoBottom;
+        QIcon GoDown;
+        QIcon GoDownDouble;
+        QIcon GoTop;
+        QIcon GoUp;
+        QIcon GoUpDouble;
 		QIcon Ground;
+		QIcon Grid;
 		QIcon Hide;
 		QIcon Home;
 		QIcon HotSpot;
@@ -133,6 +146,7 @@ namespace QET {
 		QIcon Projects;
 		QIcon ProjectFile;
 		QIcon ProjectFileGP;
+        QIcon ProjectProperties;
 		QIcon QETIcon;
 		QIcon QETLogo;
 		QIcon QETOxygenLogo;
@@ -140,13 +154,18 @@ namespace QET {
 		QIcon Raise;
 		QIcon Remove;
 		QIcon Restore;
+        QIcon RunDxf;
 		QIcon SendBackward;
 		QIcon Settings;
 		QIcon SinglePage;
 		QIcon South;
 		QIcon Start;
-		QIcon Terminal;
+        QIcon TableOfContent;
+        QIcon Terminal;
 		QIcon TitleBlock;
+        QIcon TitleBlockBottom;
+        QIcon TitleBlockRight;
+        QIcon TransformRotate;
 		QIcon UserInformations;
 		QIcon ViewFitWidth;
 		QIcon ViewFitWindow;
@@ -163,9 +182,11 @@ namespace QET {
 		QIcon adding_image;
 		QIcon resize_image;
 		QIcon ar;
+		QIcon br;
 		QIcon catalonia;
 		QIcon cs;
 		QIcon de;
+		QIcon da;
 		QIcon gr;
 		QIcon en;
 		QIcon es;
@@ -182,6 +203,13 @@ namespace QET {
 		QIcon translation;
 		QIcon listDrawings;
 		QIcon AutoNum;
+		QIcon TerminalStrip;
+		QIcon QETManual;
+		QIcon QETDonate;
+		QIcon QETDownload;
+		QIcon QETVideo;
+		QIcon super;
+		QIcon sub;
 	}
 }
 
@@ -209,21 +237,25 @@ void QET::Icons::initIcons() {
 	ArrowRightDouble    .addFile(":/ico/22x22/arrow-right-double.png");
 	Autoconnect         .addFile(":/ico/22x22/autoconnect.png");
 	BringForward        .addFile(":/ico/22x22/bring_forward.png");
-	Cancel              .addFile(":/ico/16x16/item_cancel.png");
-	Conductor           .addFile(":/ico/22x22/conductor.png");
-	ConductorSettings   .addFile(":/ico/22x22/conductor2.png");
+    Cancel              .addFile(":/ico/16x16/item-cancel.png");
+    ConductorEdit       .addFile(":/ico/16x16/conductor-edit.png");
+    ConductorSettings   .addFile(":/ico/16x16/conductor-reset.png");
+    ConductorSettings   .addFile(":/ico/22x22/conductor2.png");
 	Configure           .addFile(":/ico/16x16/configure.png");
 	Configure           .addFile(":/ico/22x22/configure.png");
 	ConfigureToolbars   .addFile(":/ico/16x16/configure-toolbars.png");
 	ConfigureToolbars   .addFile(":/ico/22x22/configure-toolbars.png");
-	IC_CopyFile            .addFile(":/ico/16x16/item_copy.png");
-	DefaultConductor    .addFile(":/ico/22x22/conductor3.png");
-	DiagramAdd          .addFile(":/ico/22x22/diagram_add.png");
+    IC_CopyFile            .addFile(":/ico/16x16/item-copy.png");
+    DiagramAdd          .addFile(":/ico/16x16/folio-new.png");
+    DiagramAdd          .addFile(":/ico/22x22/diagram_add.png");
+    Diagram             .addFile(":/ico/16x16/diagram.png");
 	Diagram             .addFile(":/ico/diagram.png");
-    DiagramBg           .addFile(":/ico/22x22/diagram_bg.png");
+	DiagramBg           .addFile(":/ico/22x22/diagram_bg.png");
+    DiagramDelete       .addFile(":/ico/16x16/folio-delete.png");
     DiagramDelete       .addFile(":/ico/22x22/diagram_del.png");
 	DialogCancel        .addFile(":/ico/16x16/dialog-cancel.png");
 	DialogCancel        .addFile(":/ico/22x22/dialog-cancel.png");
+    DialogInformation   .addFile(":/ico/16x16/folio-properties.png");
 	DialogInformation   .addFile(":/ico/22x22/dialog-information.png");
 	DialogOk            .addFile(":/ico/16x16/dialog-ok.png");
 	DialogOk            .addFile(":/ico/22x22/dialog-ok.png");
@@ -231,7 +263,7 @@ void QET::Icons::initIcons() {
 	DocumentClose       .addFile(":/ico/22x22/document-close.png");
 	DocumentExport      .addFile(":/ico/16x16/document-export.png");
 	DocumentExport      .addFile(":/ico/22x22/document-export.png");
-	DocumentSpreadsheet .addFile(":/ico/22x22/qelectrotab-into.png");
+    DocumentSpreadsheet .addFile(":/ico/16x16/export-csv.png");
 	DocumentExport      .addFile(":/ico/128x128/document-export.png");
 	DocumentImport      .addFile(":/ico/16x16/document-import.png");
 	DocumentImport      .addFile(":/ico/22x22/document-import.png");
@@ -254,7 +286,7 @@ void QET::Icons::initIcons() {
 	East                .addFile(":/ico/16x16/east.png");
 	EditClear           .addFile(":/ico/16x16/edit-clear.png");
 	EditClear           .addFile(":/ico/22x22/edit-clear.png");
-    EditText            .addFile(":/ico/22x22/names.png");
+	EditText            .addFile(":/ico/22x22/names.png");
 	adding_image        .addFile(":/ico/22x22/insert-image.png");
 	
 	if (rtl) {
@@ -279,26 +311,28 @@ void QET::Icons::initIcons() {
 		EditRedo            .addFile(":/ico/16x16/edit-redo.png");
 		EditRedo            .addFile(":/ico/22x22/edit-redo.png");
 	}
-	EditRename          .addFile(":/ico/16x16/edit-rename.png");
-	EditRename          .addFile(":/ico/22x22/edit-rename.png");
-	EditSelectAll       .addFile(":/ico/16x16/edit-select-all.png");
-	EditSelectAll       .addFile(":/ico/22x22/edit-select-all.png");
-	EditTableCellMerge        .addFile(":ico/16x16/edit-table-cell-merge.png");
-	EditTableCellMerge        .addFile(":ico/22x22/edit-table-cell-merge.png");
-	EditTableCellSplit        .addFile(":ico/16x16/edit-table-cell-split.png");
-	EditTableCellSplit        .addFile(":ico/22x22/edit-table-cell-split.png");
-	EditTableDeleteColumn     .addFile(":ico/16x16/edit-table-delete-column.png");
-	EditTableDeleteColumn     .addFile(":ico/22x22/edit-table-delete-column.png");
-	EditTableDeleteRow        .addFile(":ico/16x16/edit-table-delete-row.png");
-	EditTableDeleteRow        .addFile(":ico/22x22/edit-table-delete-row.png");
-	EditTableInsertColumnLeft .addFile(":ico/16x16/edit-table-insert-column-left.png");
-	EditTableInsertColumnLeft .addFile(":ico/22x22/edit-table-insert-column-left.png");
-	EditTableInsertColumnRight.addFile(":ico/16x16/edit-table-insert-column-right.png");
-	EditTableInsertColumnRight.addFile(":ico/22x22/edit-table-insert-column-right.png");
-	EditTableInsertRowAbove   .addFile(":ico/16x16/edit-table-insert-row-above.png");
-	EditTableInsertRowAbove   .addFile(":ico/22x22/edit-table-insert-row-above.png");
-	EditTableInsertRowUnder   .addFile(":ico/16x16/edit-table-insert-row-under.png");
-	EditTableInsertRowUnder   .addFile(":ico/22x22/edit-table-insert-row-under.png");
+    EditRename                .addFile(":/ico/16x16/edit-rename.png");
+    EditRename                .addFile(":/ico/22x22/edit-rename.png");
+    EditSelectAll             .addFile(":/ico/16x16/edit-select-all.png");
+    EditSelectAll             .addFile(":/ico/22x22/edit-select-all.png");
+    EditSelectInvert          .addFile(":/ico/16x16/edit-select-invert.png");
+    EditSelectNone            .addFile(":/ico/16x16/edit-select-none.png");
+	EditTableCellMerge        .addFile(":/ico/16x16/edit-table-cell-merge.png");
+	EditTableCellMerge        .addFile(":/ico/22x22/edit-table-cell-merge.png");
+	EditTableCellSplit        .addFile(":/ico/16x16/edit-table-cell-split.png");
+	EditTableCellSplit        .addFile(":/ico/22x22/edit-table-cell-split.png");
+	EditTableDeleteColumn     .addFile(":/ico/16x16/edit-table-delete-column.png");
+	EditTableDeleteColumn     .addFile(":/ico/22x22/edit-table-delete-column.png");
+	EditTableDeleteRow        .addFile(":/ico/16x16/edit-table-delete-row.png");
+	EditTableDeleteRow        .addFile(":/ico/22x22/edit-table-delete-row.png");
+	EditTableInsertColumnLeft .addFile(":/ico/16x16/edit-table-insert-column-left.png");
+	EditTableInsertColumnLeft .addFile(":/ico/22x22/edit-table-insert-column-left.png");
+	EditTableInsertColumnRight.addFile(":/ico/16x16/edit-table-insert-column-right.png");
+	EditTableInsertColumnRight.addFile(":/ico/22x22/edit-table-insert-column-right.png");
+	EditTableInsertRowAbove   .addFile(":/ico/16x16/edit-table-insert-row-above.png");
+	EditTableInsertRowAbove   .addFile(":/ico/22x22/edit-table-insert-row-above.png");
+	EditTableInsertRowUnder   .addFile(":/ico/16x16/edit-table-insert-row-under.png");
+	EditTableInsertRowUnder   .addFile(":/ico/22x22/edit-table-insert-row-under.png");
 	if (rtl) {
 		EditUndo.addPixmap(QPixmap(":/ico/16x16/edit-undo.png").transformed(reverse));
 		EditUndo.addPixmap(QPixmap(":/ico/22x22/edit-undo.png").transformed(reverse));
@@ -306,45 +340,63 @@ void QET::Icons::initIcons() {
 		EditUndo            .addFile(":/ico/16x16/edit-undo.png");
 		EditUndo            .addFile(":/ico/22x22/edit-undo.png");
 	}
-	Element             .addFile(":/ico/oxygen-icons/16x16/mimetypes/application-x-qet-element.png");
-	Element             .addFile(":/ico/oxygen-icons/22x22/mimetypes/application-x-qet-element.png");
-	Element             .addFile(":/ico/oxygen-icons/32x32/mimetypes/application-x-qet-element.png");
-	ElementDelete       .addFile(":/ico/22x22/element-delete.png");
+    Element             .addFile(":/ico/breeze-icons/16x16/mimetypes/application-x-qet-element.png");
+    Element             .addFile(":/ico/breeze-icons/22x22/mimetypes/application-x-qet-element.png");
+    Element             .addFile(":/ico/breeze-icons/32x32/mimetypes/application-x-qet-element.png");
+    ElementDelete       .addFile(":/ico/16x16/element-delete.png");
+    ElementDelete       .addFile(":/ico/22x22/element-delete.png");
+    ElementEdit         .addFile(":/ico/16x16/element-edit.png");
 	ElementEdit         .addFile(":/ico/22x22/element-edit.png");
+    ElementNew          .addFile(":/ico/16x16/element-new.png");
 	ElementNew          .addFile(":/ico/22x22/element-new.png");
-	EndLineCircle       .addFile(":/ico/16x16/endline-circle.png");
+    ElementSmall        .addFile(":/ico/16x16/element.png");
+    EndLineCircle       .addFile(":/ico/16x16/endline-circle.png");
 	EndLineDiamond      .addFile(":/ico/16x16/endline-diamond.png");
 	EndLineNone         .addFile(":/ico/16x16/endline-none.png");
 	EndLineSimple       .addFile(":/ico/16x16/endline-simple.png");
 	EndLineTriangle     .addFile(":/ico/16x16/endline-triangle.png");
 	EPS                 .addFile(":/ico/32x32/image-x-eps.png");
 	Folder              .addFile(":/ico/16x16/folder.png");
+    FolderDelete        .addFile(":/ico/16x16/folder-delete.png");
 	FolderDelete        .addFile(":/ico/22x22/folder-delete.png");
+    FolderEdit          .addFile(":/ico/16x16/folder-edit.png");
 	FolderEdit          .addFile(":/ico/22x22/folder-edit.png");
 	FolderNew           .addFile(":/ico/16x16/folder-new.png");
 	FolderNew           .addFile(":/ico/22x22/folder-new.png");
+    FolderOnlyThis      .addFile(":/ico/16x16/folder-only-this.png");
+    FolderOpen          .addFile(":/ico/16x16/folder-open.png");
+    FolderOpen          .addFile(":/ico/22x22/folder-open.png");
+    FolderProperties    .addFile(":/ico/16x16/folder-properties.png");
+    FolderShowAll       .addFile(":/ico/16x16/folder-show-all.png");
 	Forbidden           .addFile(":/ico/16x16/user-busy.png");
 	FullScreenEnter     .addFile(":/ico/16x16/view-fullscreen.png");
 	FullScreenEnter     .addFile(":/ico/22x22/view-fullscreen.png");
 	FullScreenExit      .addFile(":/ico/16x16/view-restore.png");
 	FullScreenExit      .addFile(":/ico/22x22/view-restore.png");
+    GoBottom            .addFile(":/ico/16x16/go-bottom.png");
 	GoDown              .addFile(":/ico/16x16/go-down.png");
 	GoDown              .addFile(":/ico/22x22/go-down.png");
+    GoDownDouble        .addFile(":/ico/16x16/go-down-double.png");
+    GoTop               .addFile(":/ico/16x16/go-top.png");
 	GoUp                .addFile(":/ico/16x16/go-up.png");
 	GoUp                .addFile(":/ico/22x22/go-up.png");
+    GoUpDouble          .addFile(":/ico/16x16/go-up-double.png");
 	Ground              .addFile(":/ico/16x16/ground.png");
+    Grid                .addFile(":/ico/16x16/grid.png");
+	Grid                .addFile(":/ico/22x22/grid.png");
 	Hide                .addFile(":/ico/16x16/masquer.png");
 	Home                .addFile(":/ico/16x16/go-home.png");
 	Home                .addFile(":/ico/22x22/go-home.png");
 	HotSpot             .addFile(":/ico/22x22/hotspot.png");
 	InsertImage         .addFile(":/ico/22x22/insert-image.png");
 	Lower               .addFile(":/ico/22x22/lower.png");
-	IC_MoveFile         .addFile(":/ico/16x16/item_move.png");
+    IC_MoveFile         .addFile(":/ico/16x16/item-move.png");
 	Names               .addFile(":/ico/22x22/names.png");
 	Neutral             .addFile(":/ico/16x16/neutral.png");
 	NewDiagram          .addFile(":/ico/128x128/diagram.png");
 	North               .addFile(":/ico/16x16/north.png");
 	ObjectLocked        .addFile(":/ico/22x22/object-locked.png");
+    ObjectRotateRight   .addFile(":/ico/16x16/object-rotate-right.png");
 	ObjectRotateRight   .addFile(":/ico/22x22/object-rotate-right.png");
 	ObjectUnlocked      .addFile(":/ico/22x22/object-unlocked.png");
 	Orientations        .addFile(":/ico/16x16/orientations.png");
@@ -354,6 +406,7 @@ void QET::Icons::initIcons() {
 	PartLine            .addFile(":/ico/22x22/line.png");
 	PartPolygon         .addFile(":/ico/22x22/polygon.png");
 	PartRectangle       .addFile(":/ico/22x22/rectangle.png");
+    PartSelect          .addFile(":/ico/16x16/select.png");
 	PartSelect          .addFile(":/ico/22x22/select.png");
 	PartText            .addFile(":/ico/22x22/text.png");
 	PartTextField       .addFile(":/ico/22x22/textfield.png");
@@ -366,42 +419,55 @@ void QET::Icons::initIcons() {
 	PrintPortrait       .addFile(":/ico/22x22/portrait.png");
 	PrintTwoPages       .addFile(":/ico/22x22/two_pages.png");
 	Projects            .addFile(":/ico/128x128/project.png");
-	ProjectClose        .addFile(":/ico/16x16/project-WH-close.png");
-	ProjectClose        .addFile(":/ico/22x22/project-WH-close.png");
-	ProjectNew          .addFile(":/ico/16x16/project-WH-new.png");
-	ProjectNew          .addFile(":/ico/22x22/project-WH-new.png");
-	ProjectFile         .addFile(":/ico/oxygen-icons/16x16/mimetypes/application-x-qet-project.png");
-	ProjectFile         .addFile(":/ico/oxygen-icons/22x22/mimetypes/application-x-qet-project.png");
-	ProjectFile         .addFile(":/ico/oxygen-icons/32x32/mimetypes/application-x-qet-project.png");
+    ProjectClose        .addFile(":/ico/16x16/project-close.png");
+    ProjectClose        .addFile(":/ico/22x22/project-close.png");
+    ProjectNew          .addFile(":/ico/16x16/project-new.png");
+    ProjectNew          .addFile(":/ico/22x22/project-new.png");
+    ProjectFile         .addFile(":/ico/breeze-icons/16x16/mimetypes/application-x-qet-project.png");
+    ProjectFile         .addFile(":/ico/breeze-icons/22x22/mimetypes/application-x-qet-project.png");
+    ProjectFile         .addFile(":/ico/breeze-icons/32x32/mimetypes/application-x-qet-project.png");
+    ProjectProperties   .addFile(":/ico/16x16/project-properties.png");
+    QETDonate           .addFile(":/ico/16x16/help-donate.png");
+    QETDownload         .addFile(":/ico/16x16/edit-download.png");
 	QETIcon             .addFile(":/ico/256x256/qelectrotech.png");
-	ProjectFileGP       .addFile(":/ico/16x16/project-WH.png");
+    ProjectFileGP       .addFile(":/ico/16x16/project.png");
 	QETLogo             .addFile(":/ico/16x16/qet.png");
+    QETManual           .addFile(":/ico/16x16/help-contents.png");
 	QETLogo             .addFile(":/ico/256x256/qet.png");
-	QETOxygenLogo       .addFile(":/ico/oxygen-icons/128x128/apps/qelectrotech.png");
-	QETOxygenLogo       .addFile(":/ico/oxygen-icons/16x16/apps/qelectrotech.png");
-	QETOxygenLogo       .addFile(":/ico/oxygen-icons/22x22/apps/qelectrotech.png");
-	QETOxygenLogo       .addFile(":/ico/oxygen-icons/256x256/apps/qelectrotech.png");
-	QETOxygenLogo       .addFile(":/ico/oxygen-icons/32x32/apps/qelectrotech.png");
-	QETOxygenLogo       .addFile(":/ico/oxygen-icons/48x48/apps/qelectrotech.png");
-	QETOxygenLogo       .addFile(":/ico/oxygen-icons/64x64/apps/qelectrotech.png");
-	QtLogo              .addFile(":/ico/32x32/qt.png");
+    QETOxygenLogo       .addFile(":/ico/breeze-icons/128x128/apps/qelectrotech.png");
+    QETOxygenLogo       .addFile(":/ico/breeze-icons/16x16/apps/qelectrotech.png");
+    QETOxygenLogo       .addFile(":/ico/breeze-icons/22x22/apps/qelectrotech.png");
+    QETOxygenLogo       .addFile(":/ico/breeze-icons/256x256/apps/qelectrotech.png");
+    QETOxygenLogo       .addFile(":/ico/breeze-icons/32x32/apps/qelectrotech.png");
+    QETOxygenLogo       .addFile(":/ico/breeze-icons/48x48/apps/qelectrotech.png");
+    QETOxygenLogo       .addFile(":/ico/breeze-icons/64x64/apps/qelectrotech.png");
+    QETVideo            .addFile(":/ico/16x16/kdenlive-show-video.png");
+    QtLogo              .addFile(":/ico/16x16/qt.png");
 	Raise               .addFile(":/ico/22x22/raise.png");
 	Remove              .addFile(":/ico/16x16/list-remove.png");
 	Remove              .addFile(":/ico/22x22/list-remove.png");
 	resize_image        .addFile(":/ico/22x22/transform-scale.png");
 	Restore             .addFile(":/ico/22x22/restaurer.png");
+    RunDxf              .addFile(":/ico/16x16/run-dxf.png");
 	SendBackward        .addFile(":/ico/22x22/send_backward.png");
 	Settings            .addFile(":/ico/128x128/settings.png");
 	SinglePage          .addFile(":/ico/22x22/single_page.png");
 	South               .addFile(":/ico/16x16/south.png");
 	Start               .addFile(":/ico/22x22/start.png");
-	Terminal            .addFile(":/ico/22x22/terminal.png");
-	TitleBlock          .addFile(":/ico/16x16/label.png");
+    TableOfContent      .addFile(":/ico/16x16/table-of-content.png");
+    Terminal            .addFile(":/ico/22x22/terminal.png");
+    TerminalStrip       .addFile(":/ico/16x16/terminalstrip.png");
+    TerminalStrip       .addFile(":/ico/22x22/terminalstrip.png");
+    TitleBlock          .addFile(":/ico/16x16/label.png");
 	TitleBlock          .addFile(":/ico/22x22/label.png");
+    TitleBlockBottom    .addFile(":/ico/22x22/titleblock-bottom.png");
+    TitleBlockRight     .addFile(":/ico/22x22/titleblock-right.png");
+    TransformRotate     .addFile(":/ico/16x16/transform-rotate.png");
 	UserInformations    .addFile(":/ico/16x16/preferences-desktop-user.png");
 	UserInformations    .addFile(":/ico/22x22/preferences-desktop-user.png");
 	ViewFitWidth        .addFile(":/ico/22x22/view_fit_width.png");
-	ViewFitWindow       .addFile(":/ico/22x22/view_fit_window.png");
+    ViewFitWindow       .addFile(":/ico/22x22/view-fit-window.png");
+    ViewMove            .addFile(":/ico/16x16/move.png");
 	ViewMove            .addFile(":/ico/22x22/move.png");
 	if (rtl) {
 		ViewRefresh.addPixmap(QPixmap(":/ico/16x16/view-refresh.png").transformed(reverse));
@@ -427,8 +493,10 @@ void QET::Icons::initIcons() {
 	ZoomOut             .addFile(":/ico/16x16/zoom-out.png");
 	ZoomOut             .addFile(":/ico/22x22/zoom-out.png");
 	ar                  .addFile(":/ico/24x16/ar.png");
+	br                  .addFile(":/ico/24x16/br.png");
 	catalonia           .addFile(":/ico/24x16/catalonia.png");
 	cs                  .addFile(":/ico/24x16/cs.png");
+	da                  .addFile(":/ico/24x16/dk.png");
 	de                  .addFile(":/ico/24x16/de.png");
 	gr                  .addFile(":/ico/24x16/gr.png");
 	en                  .addFile(":/ico/24x16/en.png");
@@ -446,4 +514,6 @@ void QET::Icons::initIcons() {
 	translation         .addFile(":/ico/22x22/applications-development-translation.png");
 	listDrawings        .addFile(":/ico/48x48/view-pim-journal.png");
 	AutoNum             .addFile(":/ico/128x128/plasmagik.png");
+    sub                 .addFile(":/ico/22x22/format-text-subscript.png");
+    super               .addFile(":/ico/22x22/format-text-superscript.png");
 }
