@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -40,6 +40,7 @@ namespace QET {
 		extern QIcon BringForward;
 		extern QIcon Cancel;
 		extern QIcon Conductor;
+        extern QIcon ConductorEdit;
 		extern QIcon ConductorSettings;
 		extern QIcon Configure;
 		extern QIcon ConfigureToolbars;
@@ -47,7 +48,7 @@ namespace QET {
 		extern QIcon DefaultConductor;
 		extern QIcon DiagramAdd;
 		extern QIcon Diagram;
-        extern QIcon DiagramBg;
+		extern QIcon DiagramBg;
 		extern QIcon DiagramDelete;
 		extern QIcon DialogCancel;
 		extern QIcon DialogInformation;
@@ -74,6 +75,8 @@ namespace QET {
 		extern QIcon EditRedo;
 		extern QIcon EditRename;
 		extern QIcon EditSelectAll;
+        extern QIcon EditSelectInvert;
+        extern QIcon EditSelectNone;
 		extern QIcon EditTableCellMerge;
 		extern QIcon EditTableCellSplit;
 		extern QIcon EditTableDeleteColumn;
@@ -98,12 +101,21 @@ namespace QET {
 		extern QIcon FolderDelete;
 		extern QIcon FolderEdit;
 		extern QIcon FolderNew;
+        extern QIcon FolderOnlyThis;
+        extern QIcon FolderOpen;
+        extern QIcon FolderProperties;
+        extern QIcon FolderShowAll;
 		extern QIcon Forbidden;
 		extern QIcon FullScreenEnter;
 		extern QIcon FullScreenExit;
-		extern QIcon GoDown;
-		extern QIcon GoUp;
+        extern QIcon GoBottom;
+        extern QIcon GoDown;
+        extern QIcon GoDownDouble;
+        extern QIcon GoTop;
+        extern QIcon GoUp;
+        extern QIcon GoUpDouble;
 		extern QIcon Ground;
+		extern QIcon Grid;
 		extern QIcon Hide;
 		extern QIcon Home;
 		extern QIcon HotSpot;
@@ -141,6 +153,7 @@ namespace QET {
 		extern QIcon ProjectFile;
 		extern QIcon ProjectFileGP;
 		extern QIcon ProjectNew;
+        extern QIcon ProjectProperties;
 		extern QIcon Projects;
 		extern QIcon QETIcon;
 		extern QIcon QETLogo;
@@ -148,14 +161,19 @@ namespace QET {
 		extern QIcon QtLogo;
 		extern QIcon Raise;
 		extern QIcon Remove;
-		extern QIcon Restore;
-		extern QIcon SendBackward;
+        extern QIcon Restore;
+        extern QIcon RunDxf;
+        extern QIcon SendBackward;
 		extern QIcon Settings;
 		extern QIcon SinglePage;
 		extern QIcon South;
 		extern QIcon Start;
-		extern QIcon Terminal;
+        extern QIcon TableOfContent;
+        extern QIcon Terminal;
 		extern QIcon TitleBlock;
+        extern QIcon TitleBlockBottom;
+        extern QIcon TitleBlockRight;
+        extern QIcon TransformRotate;
 		extern QIcon UserInformations;
 		extern QIcon ViewFitWidth;
 		extern QIcon ViewFitWindow;
@@ -172,9 +190,11 @@ namespace QET {
 		extern QIcon adding_image;
 		extern QIcon resize_image;
 		extern QIcon ar;
+		extern QIcon br;
 		extern QIcon catalonia;
 		extern QIcon cs;
 		extern QIcon de;
+		extern QIcon da;
 		extern QIcon gr;
 		extern QIcon en;
 		extern QIcon es;
@@ -191,6 +211,13 @@ namespace QET {
 		extern QIcon translation;
 		extern QIcon listDrawings;
 		extern QIcon AutoNum;
+		extern QIcon TerminalStrip;
+		extern QIcon QETManual;
+		extern QIcon QETDonate;
+		extern QIcon QETDownload;
+		extern QIcon QETVideo;
+		extern QIcon super;
+		extern QIcon sub;
 	}
 }
 #endif
