@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -15,9 +15,18 @@
 	You should have received a copy of the GNU General Public License
 	along with QElectroTech.  If not, see <http://www.gnu.org/licenses/>.
 */
+#include <QAction>
+#include <QWhatsThis>
+#include <QMenu>
+#include <QMenuBar>
+#include <QDragEnterEvent>
+#include <QDesktopServices>
+
 #include "qetmainwindow.h"
 #include "qeticons.h"
 #include "qetapp.h"
+#include "qetdiagrameditor.h"
+#include "projectview.h"
 
 /**
 	Constructor
@@ -47,7 +56,20 @@ void QETMainWindow::initCommonActions() {
 	
 	configure_action_ = new QAction(QET::Icons::Configure, tr("&Configurer QElectroTech"), this);
 	configure_action_ -> setStatusTip(tr("Permet de régler différents paramètres de QElectroTech", "status bar tip"));
-	connect(configure_action_,  SIGNAL(triggered()), qet_app, SLOT(configureQET()));
+	connect(configure_action_, &QAction::triggered, [qet_app]()
+	{
+		qet_app->configureQET();
+			//TODO we use reloadOldElementPanel only to keep up to date the string of the folio in the old element panel.
+			//then, if user change the option "Use labels of folio instead of their ID" the string of folio in the old element panel is up to date
+		for (QETDiagramEditor *qde : qet_app->diagramEditors())
+		{
+			qde->reloadOldElementPanel();
+			for (ProjectView *pv : qde->openedProjects())
+			{
+				pv->updateAllTabsTitle();
+			}
+		}
+	});
 	
 	fullscreen_action_ = new QAction(this);
 	updateFullScreenAction();
@@ -59,6 +81,48 @@ void QETMainWindow::initCommonActions() {
 	about_qet_ -> setStatusTip(tr("Affiche des informations sur QElectroTech", "status bar tip"));
 	connect(about_qet_,  SIGNAL(triggered()), qet_app, SLOT(aboutQET()));
 	
+	manual_online_ = new QAction(QET::Icons::QETManual, tr("Manuel en ligne"), this);
+	manual_online_ -> setStatusTip(tr("Lance le navigateur par défaut vers le manuel en ligne de QElectroTech", "status bar tip"));
+	
+	connect(manual_online_, &QAction::triggered, [this](bool) {
+	QString link = "http://download.tuxfamily.org/qet/joshua/html/QET.html";
+	QDesktopServices::openUrl(QUrl(link));
+	});
+	
+	manual_online_            -> setShortcut(Qt::Key_F1);
+	
+	youtube_ = new QAction(QET::Icons::QETVideo, tr("Chaine Youtube"), this);
+	youtube_ -> setStatusTip(tr("Lance le navigateur par défaut vers la chaine Youtube de QElectroTech", "status bar tip"));
+	
+	connect(youtube_, &QAction::triggered, [this](bool) {
+	QString link = "https://www.youtube.com/user/scorpio8101/videos";
+	QDesktopServices::openUrl(QUrl(link));
+	});
+	
+	upgrade_ = new QAction(QET::Icons::QETDownload, tr("Télécharger une nouvelle version (dev)"), this);
+	upgrade_ -> setStatusTip(tr("Lance le navigateur par défaut vers le dépot Nightly en ligne de QElectroTech", "status bar tip"));
+	
+	upgrade_M = new QAction(QET::Icons::QETDownload, tr("Télécharger une nouvelle version (dev)"), this);
+	upgrade_M -> setStatusTip(tr("Lance le navigateur par défaut vers le dépot Nightly en ligne de QElectroTech", "status bar tip"));
+	
+	connect(upgrade_, &QAction::triggered, [this](bool) {
+	QString link = "https://qelectrotech.org/download_windows_QET.html";
+	QDesktopServices::openUrl(QUrl(link));
+	});
+	
+	connect(upgrade_M, &QAction::triggered, [this](bool) {
+	QString link = "https://qelectrotech.org/download_mac_QET.html";
+	QDesktopServices::openUrl(QUrl(link));
+	});
+	
+	donate_ = new QAction(QET::Icons::QETDonate, tr("Soutenir le projet par un don"), this);
+	donate_ -> setStatusTip(tr("Soutenir le projet QElectroTech par un don", "status bar tip"));
+	
+	connect(donate_, &QAction::triggered, [this](bool) {
+	QString link = "https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=ZZHC9D7C3MDPC";
+	QDesktopServices::openUrl(QUrl(link));
+	});
+	
 	about_qt_ = new QAction(QET::Icons::QtLogo,  tr("À propos de &Qt"), this);
 	about_qt_ -> setStatusTip(tr("Affiche des informations sur la bibliothèque Qt", "status bar tip"));
 	connect(about_qt_, SIGNAL(triggered()), qet_app, SLOT(aboutQt()));
@@ -78,8 +142,25 @@ void QETMainWindow::initCommonMenus() {
 	help_menu_ -> addAction(whatsthis_action_);
 	help_menu_ -> addSeparator();
 	help_menu_ -> addAction(about_qet_);
+	help_menu_ -> addAction(manual_online_);
+	help_menu_ -> addAction(youtube_);
+	help_menu_ -> addAction(upgrade_);
+	help_menu_ -> addAction(upgrade_M);
+	help_menu_ -> addAction(donate_);
 	help_menu_ -> addAction(about_qt_);
 	
+#ifdef Q_OS_WIN32
+upgrade_ -> setVisible(true);
+#else
+upgrade_ -> setVisible(false);
+#endif
+
+#ifdef Q_OS_MAC
+upgrade_M -> setVisible(true);
+#else
+upgrade_M -> setVisible(false);
+#endif
+
 	insertMenu(0, settings_menu_);
 	insertMenu(0, help_menu_);
 }
