@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -437,6 +437,10 @@ QString TitleBlockTemplateCellWidget::defaultVariablesString() const {
 		"<li>%{date} : date du folio</li>"
 		"<li>%{title} : titre du folio</li>"
 		"<li>%{filename} : nom de fichier du projet</li>"
+		"<li>%{machine} : nom du groupe fonctionnel du projet</li>"
+		"<li>%{locmach} : nom de la localisation dans le groupe fonctionnel du projet</li>"
+		"<li>%{indexrev} : indice de révision du folio</li>"
+		"<li>%{version} : version du logiciel</li>"
 		"<li>%{folio} : indications relatives au folio</li>"
 		"<li>%{folio-id} : position du folio dans le projet</li>"
 		"<li>%{folio-total} : nombre total de folios dans le projet</li>"
