@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -47,7 +47,12 @@ bool TitleBlockProperties::operator==(const TitleBlockProperties &ip) {
 		ip.author == author &&\
 		ip.date == date &&\
 		ip.filename == filename &&\
+		ip.machine == machine &&\
+		ip.locmach == locmach &&\
+		ip.indexrev == indexrev &&\
+		ip.version == version &&\
 		ip.folio == folio &&\
+		ip.auto_page_num == auto_page_num &&\
 		ip.template_name == template_name &&\
 		ip.context == context &&\
 		ip.display_at == display_at &&\
@@ -72,7 +77,12 @@ void TitleBlockProperties::toXml(QDomElement &e) const {
 	e.setAttribute("author",   author);
 	e.setAttribute("title",    title);
 	e.setAttribute("filename", filename);
+	e.setAttribute("machine", machine);
+	e.setAttribute("locmach", locmach);
+	e.setAttribute("indexrev",indexrev);
+	e.setAttribute("version", version);
 	e.setAttribute("folio",    folio);
+	e.setAttribute("auto_page_num", auto_page_num);
 	e.setAttribute("date",     exportDate());
 	e.setAttribute("displayAt", (display_at == Qt::BottomEdge? "bottom" : "right"));
 	if (!template_name.isEmpty())
@@ -97,7 +107,12 @@ void TitleBlockProperties::fromXml(const QDomElement &e) {
 	if (e.hasAttribute("author"))      author   = e.attribute("author");
 	if (e.hasAttribute("title"))       title    = e.attribute("title");
 	if (e.hasAttribute("filename"))    filename = e.attribute("filename");
+	if (e.hasAttribute("machine"))    machine   = e.attribute("machine");
+	if (e.hasAttribute("locmach"))     locmach  = e.attribute("locmach");
+	if (e.hasAttribute("indexrev"))   indexrev  = e.attribute("indexrev");
+	if (e.hasAttribute("version"))    version   = e.attribute("version");
 	if (e.hasAttribute("folio"))       folio    = e.attribute("folio");
+	if (e.hasAttribute("auto_page_num")) auto_page_num = e.attribute("auto_page_num");
 	if (e.hasAttribute("date"))        setDateFromString(e.attribute("date"));
 	if (e.hasAttribute("displayAt")) display_at = (e.attribute("displayAt") == "bottom" ? Qt::BottomEdge : Qt::RightEdge);
 	
@@ -125,7 +140,12 @@ void TitleBlockProperties::toSettings(QSettings &settings, const QString &prefix
 	settings.setValue(prefix + "title",    title);
 	settings.setValue(prefix + "author",   author);
 	settings.setValue(prefix + "filename", filename);
+	settings.setValue(prefix + "machine", machine);
+	settings.setValue(prefix + "locmach", locmach);
+	settings.setValue(prefix + "indexrev", indexrev);
+	settings.setValue(prefix + "version", version);
 	settings.setValue(prefix + "folio",    folio);
+	settings.setValue(prefix + "auto_page_num",    auto_page_num);
 	settings.setValue(prefix + "date",     exportDate());
 	settings.setValue(prefix + "displayAt", (display_at == Qt::BottomEdge? "bottom" : "right"));
 	settings.setValue(prefix + "titleblocktemplate", template_name.isEmpty()? QString() : template_name);
@@ -142,7 +162,12 @@ void TitleBlockProperties::fromSettings(QSettings &settings, const QString &pref
 	title    = settings.value(prefix + "title").toString();
 	author   = settings.value(prefix + "author").toString();
 	filename = settings.value(prefix + "filename").toString();
+	machine  = settings.value(prefix + "machine").toString();
+	locmach  = settings.value(prefix + "locmach").toString();
+	indexrev = settings.value(prefix + "indexrev").toString();
+	version  = settings.value(prefix + "version").toString();
 	folio    = settings.value(prefix + "folio", "%id/%total").toString();
+	auto_page_num = settings.value(prefix + "auto_page_num").toString();
 	setDateFromString(settings.value(prefix + "date").toString());
 	display_at = (settings.value(prefix + "displayAt", QVariant("bottom")).toString() == "bottom" ? Qt::BottomEdge : Qt::RightEdge);
 	template_name = settings.value(prefix + "titleblocktemplate").toString();
