@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 	
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -43,6 +43,8 @@ class TitleBlockProperties {
 	void toSettings(QSettings &, const QString & = QString()) const;
 	void fromSettings(QSettings &, const QString & = QString());
 
+	void setAutoPageNum(QString autonum) {auto_page_num = autonum;}
+
 	static TitleBlockProperties defaultProperties();
 	
 	QDate finalDate() const ;
@@ -52,13 +54,19 @@ class TitleBlockProperties {
 	QString author;           ///< Author of the diagram/folio (displayed by the default template)
 	QDate date;               ///< Date (displayed by the default template)
 	QString filename;         ///< Filename (displayed by the default template)
+	QString machine;          ///< Machine (displayed by the default template)
+	QString locmach;              ///< Location(displayed by the default template)
+	QString indexrev;         ///< Revision Index (displayed by the default template)
+	QString version;          ///< Version (displayed by the default template)
 	QString folio;            ///< Folio information (displayed by the default template)
+	QString auto_page_num;
+	QString location;
 	DateManagement useDate;   ///< Wheter to use the date attribute
 	QString template_name;    ///< Name of the template used to render the title block - an empty string means "the default template provided by the application"
 	DiagramContext context;   ///< Container for the additional, user-defined fields
 	Qt::Edge display_at;       ///< Edge to display the titleblock
 	QET::QetCollection collection; ///<Specify the location of the title block
-	
+
 	private:
 	QString exportDate() const;
 	void setDateFromString(const QString &);
