@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -68,17 +68,21 @@ ConductorPropertiesWidget::~ConductorPropertiesWidget()
  */
 void ConductorPropertiesWidget::setProperties(const ConductorProperties &properties)
 {
-	if (m_properties == properties) return;
+	if (m_properties == properties)
+		return;
+	
 	m_properties = properties;
 
 	setColorButton(m_properties.color);
 	int index = ui -> m_line_style_cb -> findData(QPen(m_properties.style));
 	if (index != -1) ui -> m_line_style_cb -> setCurrentIndex(index);
 
+	ui->m_formula_le            -> setText    (m_properties.m_formula);
 	ui->m_text_le               -> setText    (m_properties.text);
-	ui->m_function_le           ->setText     (m_properties.m_function);
-	ui->m_tension_protocol_le   ->setText     (m_properties.m_tension_protocol);
+	ui->m_function_le           -> setText    (m_properties.m_function);
+	ui->m_tension_protocol_le   -> setText    (m_properties.m_tension_protocol);
 	ui->m_text_size_sb          -> setValue   (m_properties.text_size);
+	ui->m_cond_size_sb          -> setValue   (m_properties.cond_size);
 	ui->m_show_text_cb          -> setChecked (m_properties.m_show_text);
 	ui->m_one_text_per_folio_cb -> setChecked (m_properties.m_one_text_per_folio);
 	ui->m_earth_cb              -> setChecked (m_properties.singleLineProperties.hasGround);
@@ -106,10 +110,12 @@ ConductorProperties ConductorPropertiesWidget::properties() const
 
 	properties_.color                   = ui -> m_color_pb->palette().color(QPalette::Button);
 	properties_.style                   = ui -> m_line_style_cb->itemData(ui->m_line_style_cb->currentIndex()).value<QPen>().style();
+	properties_.m_formula               = ui->m_formula_le->text();
 	properties_.text                    = ui -> m_text_le -> text();
 	properties_.m_function              = ui -> m_function_le->text();
 	properties_.m_tension_protocol      = ui -> m_tension_protocol_le->text();
 	properties_.text_size               = ui -> m_text_size_sb -> value();
+	properties_.cond_size               = ui -> m_cond_size_sb -> value();
 	properties_.m_show_text             = ui -> m_show_text_cb -> isChecked();
 	properties_.m_one_text_per_folio    = ui -> m_one_text_per_folio_cb -> isChecked();
 	properties_.verti_rotate_text       = m_verti_select -> value();
@@ -131,7 +137,7 @@ ConductorProperties ConductorPropertiesWidget::properties() const
 bool ConductorPropertiesWidget::event(QEvent *event)
 {
 	if (event->type() == QEvent::WindowActivate) {
-		ui -> m_text_le -> setFocus();
+		ui -> m_formula_le -> setFocus();
 	}
 	return(QWidget::event(event));
 }
@@ -169,6 +175,28 @@ void ConductorPropertiesWidget::setDisabledShowText(const bool &disable) {
 	ui->m_show_text_cb->setDisabled(disable==true? true : false);
 }
 
+/**
+ * @brief ConductorPropertiesWidget::setHiddenAvailableAutonum
+ * Hide the label, combo box and push button of available autonum
+ * @param hide
+ */
+void ConductorPropertiesWidget::setHiddenAvailableAutonum(const bool &hide)
+{
+	ui->m_autonum_label->setHidden(hide);
+	ui->m_available_autonum_cb->setHidden(hide);
+	ui->m_edit_autonum_pb->setHidden(hide);
+}
+
+QComboBox *ConductorPropertiesWidget::autonumComboBox() const
+{
+	return ui->m_available_autonum_cb;
+}
+
+QPushButton *ConductorPropertiesWidget::editAutonumPushButton() const
+{
+	return ui->m_edit_autonum_pb;
+}
+
 /**
  * @brief ConductorPropertiesWidget::initWidget
  */
@@ -186,6 +214,7 @@ void ConductorPropertiesWidget::initWidget() {
 
 	connect(ui->m_multiwires_gb, &QGroupBox::toggled, [this](bool toggle) {this->ui->m_singlewire_gb->setChecked(!toggle);});
 	connect(ui->m_singlewire_gb, &QGroupBox::toggled, [this](bool toggle) {this->ui->m_multiwires_gb->setChecked(!toggle);});
+	connect(ui->m_formula_le, &QLineEdit::textChanged, [this](QString text) {this->ui->m_text_le->setEnabled(text.isEmpty());});
 	ui->m_multiwires_gb->setChecked(true);
 	ui->m_singlewire_gb->setChecked(true);
 }
@@ -250,7 +279,7 @@ void ConductorPropertiesWidget::on_m_earth_cb_toggled(bool checked) {
 void ConductorPropertiesWidget::on_m_neutral_cb_toggled(bool checked) {
 	if (checked && ui -> m_earth_cb -> isChecked())
 		ui -> m_pen_cb -> setEnabled(true);
-   else ui -> m_pen_cb -> setDisabled(true);
+	else ui -> m_pen_cb -> setDisabled(true);
 }
 
 /**
@@ -268,7 +297,7 @@ void ConductorPropertiesWidget::on_m_color_pb_clicked() {
  * Set m_color_pb to @color
  * @param color
  */
-void ConductorPropertiesWidget::setColorButton(const QColor &color) {
+void ConductorPropertiesWidget::setColorButton(const QColor &color){
 	QPalette palette;
 	palette.setColor(QPalette::Button, color);
 	ui -> m_color_pb -> setStyleSheet(QString("background-color: %1; min-height: 1.5em; border-style: outset; border-width: 2px; border-color: gray; border-radius: 4px;").arg(color.name()));
