@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -21,6 +21,8 @@
 #include <QWidget>
 #include "conductorproperties.h"
 class QTextOrientationSpinBoxWidget;
+class QComboBox;
+class QPushButton;
 
 namespace Ui {
 	class ConductorPropertiesWidget;
@@ -43,6 +45,9 @@ class ConductorPropertiesWidget : public QWidget
 		void addAutonumWidget (QWidget *widget);
 		void setHiddenOneTextPerFolio   (const bool &hide);
 		void setDisabledShowText        (const bool &disable = true);
+		void setHiddenAvailableAutonum (const bool &hide);
+		QComboBox *autonumComboBox() const;
+		QPushButton *editAutonumPushButton() const;
 
 	private:
 		void initWidget();
@@ -61,7 +66,7 @@ class ConductorPropertiesWidget : public QWidget
 		void on_m_color_pb_clicked();
 		void setColorButton (const QColor &color);
 		void on_m_update_preview_pb_clicked();
-
+		
 	private:
 		Ui::ConductorPropertiesWidget *ui;
 		ConductorProperties m_properties;
