@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -21,7 +21,7 @@
 #include "qdialog.h"
 
 class Diagram;
-class AutonumSelectorWidget;
+class ConductorPropertiesWidget;
 
 /**
  * @brief The DiagramPropertiesDialog class
@@ -37,10 +37,11 @@ class DiagramPropertiesDialog : public QDialog {
 
 	public slots:
 		void editAutonum ();
+        void editAutoFolioNum ();
 
 	private:
 		Diagram               *m_diagram;
-		AutonumSelectorWidget *m_asw;
+		ConductorPropertiesWidget *m_cpw;
 };
 
 #endif // DIAGRAMPROPERTIESDIALOG_H
