@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -64,6 +64,22 @@ void ElementInfoWidget::setElement(Element *element)
 	m_element = element;
 	updateUi();
 
+	ElementInfoPartWidget *f = infoPartWidgetForKey("formula");
+	ElementInfoPartWidget *l = infoPartWidgetForKey("label");
+
+	if (f && l)
+	{
+		if (f->text().isEmpty())
+			l->setEnabled(true);
+		else
+			l->setDisabled(true);
+
+		connect(f, &ElementInfoPartWidget::textChanged, [l](const QString text)
+		{
+			l->setEnabled(text.isEmpty()? true : false);
+		});
+	}
+
 	connect(m_element, &Element::elementInfoChange, this, &ElementInfoWidget::elementInfoChange);
 }
 
@@ -176,6 +192,22 @@ void ElementInfoWidget::buildInterface()
 	ui->scroll_vlayout->addStretch();
 }
 
+/**
+ * @brief ElementInfoWidget::infoPartWidgetForKey
+ * @param key
+ * @return the ElementInfoPartWidget with key @key, if not found return nullptr;
+ */
+ElementInfoPartWidget *ElementInfoWidget::infoPartWidgetForKey(const QString &key) const
+{
+	foreach (ElementInfoPartWidget *eipw, m_eipw_list)
+	{
+		if (eipw->key() == key)
+			return eipw;
+	}
+
+	return nullptr;
+}
+
 /**
  * @brief ElementInfoWidget::updateUi
  * fill information fetch in m_element_info to the
@@ -195,7 +227,7 @@ void ElementInfoWidget::updateUi()
 
 			//If the current eipw is for label or comment and the text is empty
 			//we force the checkbox to ckecked
-		if (eipw -> key() == "label" || eipw -> key() == "comment") {
+		if (eipw -> key() == "label" || eipw -> key() == "comment" || eipw -> key() == "location" ) {
 			if (element_info[eipw->key()].toString().isEmpty())
 				eipw->setShow(true);
 		}
