@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -172,12 +172,15 @@ void ElementPropertiesWidget::updateUi()
 
 		//Purge the tab widget and delete all widget
 	m_tab->clear();
-	qDeleteAll(m_list_editor); m_list_editor.clear();
-	if(m_general_widget) delete m_general_widget; m_general_widget = nullptr;
+	qDeleteAll(m_list_editor);
+	m_list_editor.clear();
+	if(m_general_widget) {
+		delete m_general_widget;
+		m_general_widget = nullptr;
+	}
 
 		//Create editor according to the type of element
-	switch (m_element -> linkType())
-	{
+	switch (m_element -> linkType())	{
 		case Element::Simple:
 			m_list_editor << new ElementInfoWidget(m_element, this);
 			break;
@@ -195,6 +198,7 @@ void ElementPropertiesWidget::updateUi()
 			m_list_editor << new LinkSingleElementWidget(m_element, this);
 			break;
 		case Element::Terminale:
+			m_list_editor << new ElementInfoWidget(m_element, this);
 			break;
 		default:
 			break;
@@ -272,19 +276,18 @@ QWidget *ElementPropertiesWidget::generalWidget()
 		description_string += QString(tr("Emplacement : %1\n")).arg(custom_element -> location().toString());
 	}
 
-	// widget himself
+		// widget himself
 	QWidget *general_widget = new QWidget (m_tab);
 	QVBoxLayout *vlayout_ = new QVBoxLayout (general_widget);
 	general_widget -> setLayout(vlayout_);
 
-	//widget for the text
+		//widget for the text
 	QLabel *label = new QLabel (description_string, general_widget);
 	label->setWordWrap(true);
 	vlayout_->addWidget(label);
 
-	//widget for the pixmap
+		//widget for the pixmap
 	QLabel *pix = new QLabel(general_widget);
-	pix->setPixmap(m_element->pixmap().scaled (34, 34, Qt::KeepAspectRatioByExpanding, Qt::SmoothTransformation));
 	vlayout_->addWidget(pix, 0, Qt::AlignHCenter);
 	vlayout_ -> addStretch();
 
@@ -296,7 +299,21 @@ QWidget *ElementPropertiesWidget::generalWidget()
 	QHBoxLayout *hlayout_ = new QHBoxLayout;
 	hlayout_->addWidget(find_in_panel);
 	hlayout_->addWidget(edit_element);
-
 	vlayout_->addLayout(hlayout_);
+
+		//Set the maximum size of the pixmap to the minimum size of the layout
+	QPixmap pixmap = m_element->pixmap();
+	int margin = vlayout_->contentsMargins().left() + vlayout_->contentsMargins().right();
+	int widht_ = vlayout_->minimumSize().width()-margin;
+
+	if (pixmap.size().width() > widht_ || pixmap.size().height() > widht_)
+	{
+		pix->setPixmap(m_element->pixmap().scaled (widht_, widht_, Qt::KeepAspectRatio, Qt::SmoothTransformation));
+	}
+	else
+	{
+		pix->setPixmap(pixmap);
+	}
+
 	return general_widget;
 }
