@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -28,11 +28,18 @@
  * @param parent : parent widget of this dialog
  */
 ProjectPropertiesDialog::ProjectPropertiesDialog(QETProject *project, QWidget *parent) {
+    NewDiagramPage *newDiagramPage = new NewDiagramPage(project,parent,this);
+    ProjectAutoNumConfigPage *projectAutoNumConfigPage = new ProjectAutoNumConfigPage (project);
 	m_properties_dialog = new ConfigDialog (parent);
 	m_properties_dialog -> setWindowTitle(QObject::tr("Propriétés du projet", "window title"));
 	m_properties_dialog -> addPage(new ProjectMainConfigPage       (project));
-	m_properties_dialog -> addPage(new NewDiagramPage (project));
-	m_properties_dialog -> addPage(new ProjectAutoNumConfigPage    (project));
+    m_properties_dialog -> addPage(newDiagramPage);
+    m_properties_dialog -> addPage(projectAutoNumConfigPage);
+    connect(projectAutoNumConfigPage,SIGNAL(setAutoNum(QString)),newDiagramPage,SLOT(setFolioAutonum(QString)));
+    connect(projectAutoNumConfigPage,SIGNAL(saveCurrentTbp()),newDiagramPage,SLOT(saveCurrentTbp()));
+    connect(projectAutoNumConfigPage,SIGNAL(loadSavedTbp()),newDiagramPage,SLOT(loadSavedTbp()));
+	m_properties_dialog->setMinimumHeight(690);
+    
 }
 
 /**
@@ -47,6 +54,7 @@ ProjectPropertiesDialog::~ProjectPropertiesDialog () {
  * execute this dialog.
  */
 void ProjectPropertiesDialog::exec() {
+	m_properties_dialog->setWindowModality(Qt::WindowModal);
 	m_properties_dialog -> exec();
 }
 
@@ -58,3 +66,12 @@ void ProjectPropertiesDialog::exec() {
 void ProjectPropertiesDialog::setCurrentPage(ProjectPropertiesDialog::Page p) {
 	m_properties_dialog -> setCurrentPage(static_cast <int> (p));
 }
+
+/**
+ * @brief ProjectPropertiesDialog::changeToFolio
+ * Change the current displayed tab to folio tab.
+ */
+void ProjectPropertiesDialog::changeToFolio() {
+	ProjectAutoNumConfigPage *autoNumPage = static_cast <ProjectAutoNumConfigPage*>(m_properties_dialog->pages.at(2));
+	autoNumPage->changeToTab(3);
+}
