@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -18,11 +18,15 @@
 #ifndef TITLEBLOCKPROPERTIESWIDGET_H
 #define TITLEBLOCKPROPERTIESWIDGET_H
 
+#include "qetproject.h"
 #include <QWidget>
 #include "titleblockproperties.h"
 #include "diagramcontextwidget.h"
 #include "qet.h"
+#include "numerotationcontext.h"
 
+class NumerotationContext;
+class QETProject;
 class QMenu;
 class TitleBlockTemplatesCollection;
 
@@ -35,13 +39,16 @@ class TitleBlockPropertiesWidget : public QWidget
 		Q_OBJECT
 
 	public:
-		explicit TitleBlockPropertiesWidget(const TitleBlockProperties &titleblock = TitleBlockProperties(), bool current_date = false, QWidget *parent = 0);
-		explicit TitleBlockPropertiesWidget(TitleBlockTemplatesCollection *tbt_collection, const TitleBlockProperties &titleblock = TitleBlockProperties(), bool current_date = false, QWidget *parent = 0);
-		explicit TitleBlockPropertiesWidget(QList <TitleBlockTemplatesCollection *> tbt_collection, const TitleBlockProperties &titleblock = TitleBlockProperties(), bool current_date = false, QWidget *parent = 0);
+		explicit TitleBlockPropertiesWidget(const TitleBlockProperties &titleblock = TitleBlockProperties(), bool current_date = false, QETProject *project = NULL, QWidget *parent = 0);
+		explicit TitleBlockPropertiesWidget(TitleBlockTemplatesCollection *tbt_collection, const TitleBlockProperties &titleblock = TitleBlockProperties(), bool current_date = false, QETProject *project = NULL, QWidget *parent = 0);
+		explicit TitleBlockPropertiesWidget(QList <TitleBlockTemplatesCollection *> tbt_collection, const TitleBlockProperties &titleblock = TitleBlockProperties(), bool current_date = false, QETProject *project = NULL, QWidget *parent = 0);
 		~TitleBlockPropertiesWidget();
 
 		void setProperties(const TitleBlockProperties &properties);
 		TitleBlockProperties properties() const;
+		TitleBlockProperties propertiesAutoNum(QString autoNum) const;
+		TitleBlockTemplateLocation currentTitleBlockLocation () const;
+		void setPropertiesWithAutoNum(const TitleBlockProperties &properties, QString autoNum);
 
 		void setTitleBlockTemplatesVisible(const bool &visible);
 		void setReadOnly (const bool &ro);
@@ -49,7 +56,7 @@ class TitleBlockPropertiesWidget : public QWidget
 	private:
 		void addCollection (TitleBlockTemplatesCollection *tbt_collection);
 		QString currentTitleBlockTemplateName () const;
-		void initDialog(const bool &current_date);
+		void initDialog(const bool &current_date, QETProject *project);
 		int getIndexFor (const QString &tbt_name, const QET::QetCollection collection) const;
 
 	private slots:
@@ -58,9 +65,11 @@ class TitleBlockPropertiesWidget : public QWidget
 		void updateTemplateList();
 		void changeCurrentTitleBlockTemplate(int);
 		void on_m_date_now_pb_clicked();
+		void on_m_edit_autofolionum_pb_clicked();
 
 	signals:
-		void editTitleBlockTemplate(const QString &, bool);
+		void set_auto_page_num() const;
+		void openAutoNumFolioEditor (QString);
 
 	private:
 		Ui::TitleBlockPropertiesWidget *ui;
@@ -69,6 +78,7 @@ class TitleBlockPropertiesWidget : public QWidget
 		QMenu *m_tbt_menu;
 		QList <TitleBlockTemplatesCollection *> m_tbt_collection_list;
 		QList <QET::QetCollection> m_map_index_to_collection_type;
+		QList <QString> keys_2;
 };
 
 #endif // TITLEBLOCKPROPERTIESWIDGET_H
