@@ -1,5 +1,5 @@
 /*
-	Copyright 2006-2015 The QElectroTech Team
+	Copyright 2006-2017 The QElectroTech Team
 	This file is part of QElectroTech.
 
 	QElectroTech is free software: you can redistribute it and/or modify
@@ -34,6 +34,7 @@ XRefPropertiesWidget::XRefPropertiesWidget(QHash <QString, XRefProperties> prope
 	buildUi();
 	connect(ui->m_display_has_cross_rb, SIGNAL(toggled(bool)),            ui->m_cross_properties_gb, SLOT(setEnabled(bool)));
 	connect(ui->m_type_cb,              SIGNAL(currentIndexChanged(int)), this,                      SLOT(typeChanged()));
+	connect(ui->m_snap_to_cb, SIGNAL(currentIndexChanged(int)), this, SLOT(enableOffsetSB(int)));
 	updateDisplay();
 }
 
@@ -45,6 +46,7 @@ XRefPropertiesWidget::~XRefPropertiesWidget()
 {
 	disconnect(ui->m_display_has_cross_rb, SIGNAL(toggled(bool)),            ui->m_cross_properties_gb, SLOT(setEnabled(bool)));
 	disconnect(ui->m_type_cb,              SIGNAL(currentIndexChanged(int)), this,                      SLOT(typeChanged()));
+	disconnect(ui->m_snap_to_cb,           SIGNAL(currentIndexChanged(int)), this,                      SLOT(enableOffsetSB(int)));
 	delete ui;
 }
 
@@ -117,6 +119,9 @@ void XRefPropertiesWidget::saveProperties(int index) {
 	xrp.setPrefix("power",  ui->m_power_prefix_le->text());
 	xrp.setPrefix("delay",  ui->m_delay_prefix_le->text());
 	xrp.setPrefix("switch", ui->m_switch_prefix_le->text());
+	xrp.setMasterLabel(ui->m_master_le->text());
+	xrp.setSlaveLabel(ui->m_slave_le->text());
+	xrp.setOffset(ui->m_offset_sb->value());
 
 	m_properties.insert(type, xrp);
 }
@@ -137,9 +142,23 @@ void XRefPropertiesWidget::updateDisplay() {
 		ui->m_display_has_contacts_rb->setChecked(true);
 	}
 
-	if (xrp.snapTo() == XRefProperties::Bottom)
+	QString master = xrp.masterLabel();
+	ui->m_master_le->setText(master);
+
+	QString slave = xrp.slaveLabel();
+	ui->m_slave_le->setText(slave);
+
+	int offset = xrp.offset();
+	ui->m_offset_sb->setValue(offset);
+
+	if (xrp.snapTo() == XRefProperties::Bottom){
 		 ui->m_snap_to_cb->setCurrentIndex(ui->m_snap_to_cb->findData("bottom"));
-	else ui->m_snap_to_cb->setCurrentIndex(ui->m_snap_to_cb->findData("label"));
+		 ui->m_offset_sb->setEnabled(true);
+	}
+	else {
+		ui->m_snap_to_cb->setCurrentIndex(ui->m_snap_to_cb->findData("label"));
+		ui->m_offset_sb->setEnabled(false);
+	}
 	ui->m_show_power_cb->setChecked(xrp.showPowerContact());
 	ui->m_power_prefix_le-> setText(xrp.prefix("power"));
 	ui->m_delay_prefix_le-> setText(xrp.prefix("delay"));
@@ -161,3 +180,14 @@ void XRefPropertiesWidget::typeChanged() {
 	//previous index is now the current index
 	m_previous_type_index = ui->m_type_cb->currentIndex();
 }
+
+/**
+ * @brief XRefPropertiesWidget::enableOffsetSB
+ * Enable Offset SB only if Snap to Footer is selected
+ */
+void XRefPropertiesWidget::enableOffsetSB(int i){
+	if (i)
+		ui->m_offset_sb->setEnabled(false);
+	else
+		ui->m_offset_sb->setEnabled(true);
+}
